diff -uprN libiconv-1.15-old/NEWS libiconv-1.15/NEWS
--- libiconv-1.15-old/NEWS	2016-11-18 07:12:47.000000000 +0900
+++ libiconv-1.15/NEWS	2017-09-17 05:38:53.872115000 +0900
@@ -16,6 +16,28 @@ New in 1.14:
 * Fixed a bug in the conversion to wchar_t.
 * Fixed a small bug in the CP1258 converter.
 
+New in libiconv-ja-2.patch:
+* Updated for compile-time error on RHEL7/CentOS7.
+
+New in libiconv-ja-1.patch:
+* Changed EUC-JP, SHIFT_JIS, ISO-2022-JP, ISO-2022-JP-1, ISO-2022-JP-2,
+  ISO-2022-JP-3, DEC-KANJI converters, so that JIS X 0208 1-29(0x815C) EM DASH
+  is converted into U+2014 EM DASH instead of U+2015 HORIZONTAL BAR.
+* Changed SHIFT_JIS, SHIFT_JISX0213, ISO-2022-JP, ISO-2022-JP-1, ISO-2022-JP-2,
+  ISO-2022-JP-3 converters, so that JIS X 0201 5/12(0x5C) YEN SIGN is
+  converted into U+005C REVERSE SOLIDUS instead of U+00A5 YEN SIGN and
+  JIS X 0201 7/14(0x7E) OVER LINE is converted into U+007E TILDE instead of
+  U+203E OVER LINE.
+* Changed EUC-JP, SHIFT_JIS converters to exclude UDC mappings.
+* Changed CP932 converter to use exact mapping table.
+* Added WINDOWS-31J, csWINDOWS31J, SJIS-OPEN, SJIS-WIN, Shift_JIS-MS, SJIS-MS,
+  MS932, WINDOWS-932 as aliases for CP932.
+* Added EUCJP-MS converter.
+* Added EUC-JP-MS, EUCJP-OPEN, EUCJP-WIN as aliases for EUCJP-MS.
+* Added CP51932 converter.
+* Added ISO-2022-JP-MS converter.
+* Added WINDOWS-51932 and MS51932 as alias of CP51932.
+
 New in 1.13:
 * The library and the iconv program now understand platform dependent aliases,
   for better compatibility with the platform's own iconv_open function.
diff -uprN libiconv-1.15-old/README libiconv-1.15/README
--- libiconv-1.15-old/README	2016-11-25 19:38:06.000000000 +0900
+++ libiconv-1.15/README	2017-09-17 05:40:42.631226000 +0900
@@ -15,8 +15,8 @@ It provides support for the encodings:
     Semitic languages
         ISO-8859-{6,8}, CP{1255,1256}, CP862, Mac{Hebrew,Arabic}
     Japanese
-        EUC-JP, SHIFT_JIS, CP932, ISO-2022-JP, ISO-2022-JP-2, ISO-2022-JP-1,
-        ISO-2022-JP-MS
+        EUC-JP, EUCJP-MS, CP51932, SHIFT_JIS, CP932, ISO-2022-JP,
+        ISO-2022-JP-MS, ISO-2022-JP-2, ISO-2022-JP-1
     Chinese
         EUC-CN, HZ, GBK, CP936, GB18030, EUC-TW, BIG5, CP950, BIG5-HKSCS,
         BIG5-HKSCS:2004, BIG5-HKSCS:2001, BIG5-HKSCS:1999, ISO-2022-CN,
@@ -45,7 +45,7 @@ It provides support for the encodings:
         UCS-4, UCS-4BE, UCS-4LE
         UTF-16, UTF-16BE, UTF-16LE
         UTF-32, UTF-32BE, UTF-32LE
-        UTF-7
+        UTF-7, UTF-7-IMAP
         C99, JAVA
     Full Unicode, in terms of 'uint16_t' or 'uint32_t'
         (with machine dependent endianness and alignment)
diff -uprN libiconv-1.15-old/include/iconv.h libiconv-1.15/include/iconv.h
--- libiconv-1.15-old/include/iconv.h	1970-01-01 09:00:00.000000000 +0900
+++ libiconv-1.15/include/iconv.h	2017-08-02 10:58:40.000000000 +0900
@@ -0,0 +1,247 @@
+/* Copyright (C) 1999-2003, 2005-2006, 2008-2011 Free Software Foundation, Inc.
+   This file is part of the GNU LIBICONV Library.
+
+   The GNU LIBICONV Library is free software; you can redistribute it
+   and/or modify it under the terms of the GNU Library General Public
+   License as published by the Free Software Foundation; either version 2
+   of the License, or (at your option) any later version.
+
+   The GNU LIBICONV Library is distributed in the hope that it will be
+   useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+   Library General Public License for more details.
+
+   You should have received a copy of the GNU Library General Public
+   License along with the GNU LIBICONV Library; see the file COPYING.LIB.
+   If not, see <http://www.gnu.org/licenses/>.  */
+
+/* When installed, this file is called "iconv.h". */
+
+#ifndef _LIBICONV_H
+#define _LIBICONV_H
+
+#define _LIBICONV_VERSION 0x010F    /* version number: (major<<8) + minor */
+
+#if 1 && BUILDING_LIBICONV
+#define LIBICONV_DLL_EXPORTED __attribute__((__visibility__("default")))
+#else
+#define LIBICONV_DLL_EXPORTED
+#endif
+extern LIBICONV_DLL_EXPORTED  int _libiconv_version; /* Likewise */
+
+/* We would like to #include any system header file which could define
+   iconv_t, 1. in order to eliminate the risk that the user gets compilation
+   errors because some other system header file includes /usr/include/iconv.h
+   which defines iconv_t or declares iconv after this file, 2. when compiling
+   for LIBICONV_PLUG, we need the proper iconv_t type in order to produce
+   binary compatible code.
+   But gcc's #include_next is not portable. Thus, once libiconv's iconv.h
+   has been installed in /usr/local/include, there is no way any more to
+   include the original /usr/include/iconv.h. We simply have to get away
+   without it.
+   Ad 1. The risk that a system header file does
+   #include "iconv.h"  or  #include_next "iconv.h"
+   is small. They all do #include <iconv.h>.
+   Ad 2. The iconv_t type is a pointer type in all cases I have seen. (It
+   has to be a scalar type because (iconv_t)(-1) is a possible return value
+   from iconv_open().) */
+
+/* Define iconv_t ourselves. */
+#undef iconv_t
+#define iconv_t libiconv_t
+typedef void* iconv_t;
+
+/* Get size_t declaration.
+   Get wchar_t declaration if it exists. */
+#include <stddef.h>
+
+/* Get errno declaration and values. */
+#include <errno.h>
+/* Some systems, like SunOS 4, don't have EILSEQ. Some systems, like BSD/OS,
+   have EILSEQ in a different header.  On these systems, define EILSEQ
+   ourselves. */
+#ifndef EILSEQ
+#define EILSEQ 
+#endif
+
+
+#ifdef __cplusplus
+extern "C" {
+#endif
+
+
+/* Allocates descriptor for code conversion from encoding efromcodef to
+   encoding etocodef. */
+#ifndef LIBICONV_PLUG
+#define iconv_open libiconv_open
+#endif
+extern LIBICONV_DLL_EXPORTED iconv_t iconv_open (const char* tocode, const char* fromcode);
+
+/* Converts, using conversion descriptor ecdf, at most e*inbytesleftf bytes
+   starting at e*inbuff, writing at most e*outbytesleftf bytes starting at
+   e*outbuff.
+   Decrements e*inbytesleftf and increments e*inbuff by the same amount.
+   Decrements e*outbytesleftf and increments e*outbuff by the same amount. */
+#ifndef LIBICONV_PLUG
+#define iconv libiconv
+#endif
+extern LIBICONV_DLL_EXPORTED size_t iconv (iconv_t cd,  char* * inbuf, size_t *inbytesleft, char* * outbuf, size_t *outbytesleft);
+
+/* Frees resources allocated for conversion descriptor ecdf. */
+#ifndef LIBICONV_PLUG
+#define iconv_close libiconv_close
+#endif
+extern LIBICONV_DLL_EXPORTED int iconv_close (iconv_t cd);
+
+
+#ifdef __cplusplus
+}
+#endif
+
+
+#ifndef LIBICONV_PLUG
+
+/* Nonstandard extensions. */
+
+#if 1
+#if 0
+/* Tru64 with Desktop Toolkit C has a bug: <stdio.h> must be included before
+   <wchar.h>.
+   BSD/OS 4.0.1 has a bug: <stddef.h>, <stdio.h> and <time.h> must be
+   included before <wchar.h>.  */
+#include <stddef.h>
+#include <stdio.h>
+#include <time.h>
+#endif
+#include <wchar.h>
+#endif
+
+#ifdef __cplusplus
+extern "C" {
+#endif
+
+/* A type that holds all memory needed by a conversion descriptor.
+   A pointer to such an object can be used as an iconv_t. */
+typedef struct {
+  void* dummy1[28];
+#if 1
+  mbstate_t dummy2;
+#endif
+} iconv_allocation_t;
+
+/* Allocates descriptor for code conversion from encoding efromcodef to
+   encoding etocodef into preallocated memory. Returns an error indicator
+   (0 or -1 with errno set). */
+#define iconv_open_into libiconv_open_into
+extern LIBICONV_DLL_EXPORTED int iconv_open_into (const char* tocode, const char* fromcode,
+                            iconv_allocation_t* resultp);
+
+/* Control of attributes. */
+#define iconvctl libiconvctl
+extern LIBICONV_DLL_EXPORTED int iconvctl (iconv_t cd, int request, void* argument);
+
+/* Hook performed after every successful conversion of a Unicode character. */
+typedef void (*iconv_unicode_char_hook) (unsigned int uc, void* data);
+/* Hook performed after every successful conversion of a wide character. */
+typedef void (*iconv_wide_char_hook) (wchar_t wc, void* data);
+/* Set of hooks. */
+struct iconv_hooks {
+  iconv_unicode_char_hook uc_hook;
+  iconv_wide_char_hook wc_hook;
+  void* data;
+};
+
+/* Fallback function.  Invoked when a small number of bytes could not be
+   converted to a Unicode character.  This function should process all
+   bytes from inbuf and may produce replacement Unicode characters by calling
+   the write_replacement callback repeatedly.  */
+typedef void (*iconv_unicode_mb_to_uc_fallback)
+             (const char* inbuf, size_t inbufsize,
+              void (*write_replacement) (const unsigned int *buf, size_t buflen,
+                                         void* callback_arg),
+              void* callback_arg,
+              void* data);
+/* Fallback function.  Invoked when a Unicode character could not be converted
+   to the target encoding.  This function should process the character and
+   may produce replacement bytes (in the target encoding) by calling the
+   write_replacement callback repeatedly.  */
+typedef void (*iconv_unicode_uc_to_mb_fallback)
+             (unsigned int code,
+              void (*write_replacement) (const char *buf, size_t buflen,
+                                         void* callback_arg),
+              void* callback_arg,
+              void* data);
+#if 1
+/* Fallback function.  Invoked when a number of bytes could not be converted to
+   a wide character.  This function should process all bytes from inbuf and may
+   produce replacement wide characters by calling the write_replacement
+   callback repeatedly.  */
+typedef void (*iconv_wchar_mb_to_wc_fallback)
+             (const char* inbuf, size_t inbufsize,
+              void (*write_replacement) (const wchar_t *buf, size_t buflen,
+                                         void* callback_arg),
+              void* callback_arg,
+              void* data);
+/* Fallback function.  Invoked when a wide character could not be converted to
+   the target encoding.  This function should process the character and may
+   produce replacement bytes (in the target encoding) by calling the
+   write_replacement callback repeatedly.  */
+typedef void (*iconv_wchar_wc_to_mb_fallback)
+             (wchar_t code,
+              void (*write_replacement) (const char *buf, size_t buflen,
+                                         void* callback_arg),
+              void* callback_arg,
+              void* data);
+#else
+/* If the wchar_t type does not exist, these two fallback functions are never
+   invoked.  Their argument list therefore does not matter.  */
+typedef void (*iconv_wchar_mb_to_wc_fallback) ();
+typedef void (*iconv_wchar_wc_to_mb_fallback) ();
+#endif
+/* Set of fallbacks. */
+struct iconv_fallbacks {
+  iconv_unicode_mb_to_uc_fallback mb_to_uc_fallback;
+  iconv_unicode_uc_to_mb_fallback uc_to_mb_fallback;
+  iconv_wchar_mb_to_wc_fallback mb_to_wc_fallback;
+  iconv_wchar_wc_to_mb_fallback wc_to_mb_fallback;
+  void* data;
+};
+
+/* Requests for iconvctl. */
+#define ICONV_TRIVIALP            0  /* int *argument */
+#define ICONV_GET_TRANSLITERATE   1  /* int *argument */
+#define ICONV_SET_TRANSLITERATE   2  /* const int *argument */
+#define ICONV_GET_DISCARD_ILSEQ   3  /* int *argument */
+#define ICONV_SET_DISCARD_ILSEQ   4  /* const int *argument */
+#define ICONV_SET_HOOKS           5  /* const struct iconv_hooks *argument */
+#define ICONV_SET_FALLBACKS       6  /* const struct iconv_fallbacks *argument */
+
+/* Listing of locale independent encodings. */
+#define iconvlist libiconvlist
+extern LIBICONV_DLL_EXPORTED void iconvlist (int (*do_one) (unsigned int namescount,
+                                      const char * const * names,
+                                      void* data),
+                       void* data);
+
+/* Canonicalize an encoding name.
+   The result is either a canonical encoding name, or name itself. */
+extern LIBICONV_DLL_EXPORTED const char * iconv_canonicalize (const char * name);
+
+/* Support for relocatable packages.  */
+
+/* Sets the original and the current installation prefix of the package.
+   Relocation simply replaces a pathname starting with the original prefix
+   by the corresponding pathname with the current prefix instead.  Both
+   prefixes should be directory names without trailing slash (i.e. use ""
+   instead of "/").  */
+extern LIBICONV_DLL_EXPORTED void libiconv_set_relocation_prefix (const char *orig_prefix,
+                                            const char *curr_prefix);
+
+#ifdef __cplusplus
+}
+#endif
+
+#endif
+
+
+#endif /* _LIBICONV_H */
diff -uprN libiconv-1.15-old/lib/Makefile.ms libiconv-1.15/lib/Makefile.ms
--- libiconv-1.15-old/lib/Makefile.ms	1970-01-01 09:00:00.000000000 +0900
+++ libiconv-1.15/lib/Makefile.ms	2015-11-18 11:36:46.000000000 +0900
@@ -0,0 +1,71 @@
+# Makefile for libiconv/lib
+
+#### Start of system configuration section. ####
+
+# Directories used by "make":
+srcdir = .
+x32dir = x32
+x64dir = x64
+
+# Programs used by "make":
+CC = cl
+CFLAGS = /MT /Ox /Ob2 /Oi /Ot /W1 /nologo -D_NDEBUG -DHAVE_CONFIG_H -DENABLE_RELOCATABLE=1 -DIN_LIBRARY -DINSTALLDIR=\"$(IIbindir)\" -DNO_XMALLOC -Dset_relocation_prefix=libiconv_set_relocation_prefix -Drelocate=libiconv_relocate -DLIBDIR=\".\"
+INCLUDES = -I. -I..\include -I..\libcharset\include
+#PICFLAGS = -GD -DBUILDING_LIBICONV -DBUILDING_DLL -DPIC
+X32FLAGS =
+X64FLAGS = /GS- /Gy
+
+CP = copy
+RM = del
+MD = mkdir
+AR = lib
+AR_FLAGS = /nologo /LTCG /out:
+
+#### End of system configuration section. ####
+
+# Before making a release, change this according to the libtool documentation,
+# section "Library interface versions".
+LIBICONV_VERSION_INFO = 7:1:5
+PACKAGE_VERSION = 1.14
+
+X32OBJECTS = $(x32dir)/iconv.obj $(x32dir)/localcharset.obj $(x32dir)/relocatable.obj
+X64OBJECTS = $(x64dir)/iconv.obj $(x64dir)/localcharset.obj $(x64dir)/relocatable.obj
+
+all :
+	@echo nmake x32 or x64 ?
+
+x32 :  $(x32dir)/iconv.lib
+
+x64 :  $(x64dir)/iconv.lib
+
+$(x32dir)/stamp :
+	$(MD) $(x32dir)
+	@echo mkdir >$(x32dir)/stamp
+
+$(x32dir)/iconv.obj : $(srcdir)/iconv.c $(srcdir)/encodings.def $(srcdir)/encodings_local.def $(srcdir)/aliases.h config.h $(x32dir)/stamp
+	$(CC) $(INCLUDES) $(CFLAGS) $(X32FLAGS) -c $(srcdir)/iconv.c -Fo$(x32dir)\iconv.obj
+
+$(x32dir)/localcharset.obj : $(srcdir)/../libcharset/lib/localcharset.c $(srcdir)/relocatable.h config.h $(x32dir)/stamp
+	$(CC) $(INCLUDES) $(CFLAGS) $(X32FLAGS) -c $(srcdir)/../libcharset/lib/localcharset.c -Fo$(x32dir)\localcharset.obj
+
+$(x32dir)/relocatable.obj : $(srcdir)/relocatable.c $(srcdir)/relocatable.h config.h $(x32dir)/stamp
+	$(CC) $(INCLUDES) $(CFLAGS) $(X32FLAGS) -c $(srcdir)/relocatable.c -Fo$(x32dir)\relocatable.obj
+
+$(x32dir)/iconv.lib : $(X32OBJECTS)
+	$(AR) $(AR_FLAGS)$(x32dir)\iconv.lib $(X32OBJECTS)
+
+$(x64dir)/stamp :
+	$(MD) $(x64dir)
+	@echo mkdir >$(x64dir)/stamp
+
+$(x64dir)/iconv.obj : $(srcdir)/iconv.c $(srcdir)/encodings.def $(srcdir)/encodings_local.def $(srcdir)/aliases.h config.h $(x64dir)/stamp
+	$(CC) $(INCLUDES) $(CFLAGS) $(X64FLAGS) -c $(srcdir)/iconv.c -Fo$(x64dir)/iconv.obj
+
+$(x64dir)/localcharset.obj : $(srcdir)/../libcharset/lib/localcharset.c $(srcdir)/relocatable.h config.h $(x64dir)/stamp
+	$(CC) $(INCLUDES) $(CFLAGS) $(X64FLAGS) -c $(srcdir)/../libcharset/lib/localcharset.c -Fo$(x64dir)/localcharset.obj
+
+$(x64dir)/relocatable.obj : $(srcdir)/relocatable.c $(srcdir)/relocatable.h config.h $(x64dir)/stamp
+	$(CC) $(INCLUDES) $(CFLAGS) $(X64FLAGS) -c $(srcdir)/relocatable.c -Fo$(x64dir)/relocatable.obj
+
+$(x64dir)/iconv.lib : $(X64OBJECTS)
+	$(AR) $(AR_FLAGS)$(x64dir)\iconv.lib $(X64OBJECTS)
diff -uprN libiconv-1.15-old/lib/aliases.gperf libiconv-1.15/lib/aliases.gperf
--- libiconv-1.15-old/lib/aliases.gperf	2017-01-02 08:02:56.000000000 +0900
+++ libiconv-1.15/lib/aliases.gperf	2017-09-17 06:32:19.001860000 +0900
@@ -44,6 +44,8 @@ UTF-32LE, ei_utf32le
 UTF-7, ei_utf7
 UNICODE-1-1-UTF-7, ei_utf7
 CSUNICODE11UTF7, ei_utf7
+UTF-7-IMAP, ei_utf7imap
+UTF7IMAP, ei_utf7imap
 UCS-2-INTERNAL, ei_ucs2internal
 UCS-2-SWAPPED, ei_ucs2swapped
 UCS-4-INTERNAL, ei_ucs4internal
@@ -303,12 +305,28 @@ EUC-JP, ei_euc_jp
 EUCJP, ei_euc_jp
 EXTENDED_UNIX_CODE_PACKED_FORMAT_FOR_JAPANESE, ei_euc_jp
 CSEUCPKDFMTJAPANESE, ei_euc_jp
+EUCJP-MS, ei_eucjp_ms
+EUCJP-OPEN, ei_eucjp_ms
+EUC-JP-MS, ei_eucjp_ms
+EUCJP-WIN, ei_eucjp_ms
+EUCJPMS, ei_eucjp_ms
+CP51932, ei_cp51932
+WINDOWS-51932, ei_cp51932
+MS51932, ei_cp51932
 SHIFT_JIS, ei_sjis
 SHIFT-JIS, ei_sjis
 SJIS, ei_sjis
 MS_KANJI, ei_sjis
 CSSHIFTJIS, ei_sjis
 CP932, ei_cp932
+WINDOWS-31J, ei_cp932
+CSWINDOWS31J, ei_cp932
+SJIS-OPEN, ei_cp932
+SJIS-WIN, ei_cp932
+WINDOWS-932, ei_cp932
+MS932, ei_cp932
+SHIFT_JIS-MS, ei_cp932
+SJIS-MS, ei_cp932
 ISO-2022-JP, ei_iso2022_jp
 CSISO2022JP, ei_iso2022_jp
 ISO-2022-JP-1, ei_iso2022_jp1
diff -uprN libiconv-1.15-old/lib/aliases.h libiconv-1.15/lib/aliases.h
--- libiconv-1.15-old/lib/aliases.h	2017-01-02 08:02:56.000000000 +0900
+++ libiconv-1.15/lib/aliases.h	2017-09-17 06:32:19.366205000 +0900
@@ -1,4 +1,4 @@
-/* ANSI-C code produced by gperf version 3.0.4 */
+/* ANSI-C code produced by gperf version 3.0.3 */
 /* Command-line: gperf -m 10 lib/aliases.gperf  */
 /* Computed positions: -k'1,3-11,$' */
 
@@ -32,12 +32,12 @@
 #line 1 "lib/aliases.gperf"
 struct alias { int name; unsigned int encoding_index; };
 
-#define TOTAL_KEYWORDS 349
+#define TOTAL_KEYWORDS 367
 #define MIN_WORD_LENGTH 2
 #define MAX_WORD_LENGTH 45
-#define MIN_HASH_VALUE 15
-#define MAX_HASH_VALUE 921
-/* maximum key range = 907, duplicates = 0 */
+#define MIN_HASH_VALUE 9
+#define MAX_HASH_VALUE 1151
+/* maximum key range = 1143, duplicates = 0 */
 
 #ifdef __GNUC__
 __inline
@@ -51,19 +51,19 @@ aliases_hash (register const char *str,
 {
   static const unsigned short asso_values[] =
     {
-      922, 922, 922, 922, 922, 922, 922, 922, 922, 922,
-      922, 922, 922, 922, 922, 922, 922, 922, 922, 922,
-      922, 922, 922, 922, 922, 922, 922, 922, 922, 922,
-      922, 922, 922, 922, 922, 922, 922, 922, 922, 922,
-      922, 922, 922, 922, 922,   5,   6, 922,  97,   7,
-       33, 102,  15,  17,   5, 173,  23,  25, 193, 922,
-      922, 922, 922, 922, 922, 168, 159,  11,  32,  25,
-      159,  13,  70,   6, 308, 186,   8, 132,   7,   6,
-       62, 922,   5,   8,  30, 174, 163, 180,  79,  28,
-        6, 922, 922, 922, 922,   6, 922, 922, 922, 922,
-      922, 922, 922, 922, 922, 922, 922, 922, 922, 922,
-      922, 922, 922, 922, 922, 922, 922, 922, 922, 922,
-      922, 922, 922, 922, 922, 922, 922, 922
+      1152, 1152, 1152, 1152, 1152, 1152, 1152, 1152, 1152, 1152,
+      1152, 1152, 1152, 1152, 1152, 1152, 1152, 1152, 1152, 1152,
+      1152, 1152, 1152, 1152, 1152, 1152, 1152, 1152, 1152, 1152,
+      1152, 1152, 1152, 1152, 1152, 1152, 1152, 1152, 1152, 1152,
+      1152, 1152, 1152, 1152, 1152,   10,  221, 1152,   34,    0,
+         5,    4,   48,    2,    1,  188,   11,   14,  169, 1152,
+      1152, 1152, 1152, 1152, 1152,   35,  287,    0,  120,   61,
+       205,  116,   84,    0,   23,  213,  125,  189,    7,    0,
+       126, 1152,   80,   72,   21,  136,  161,   42,  159,    2,
+         6, 1152, 1152, 1152, 1152,   39, 1152, 1152, 1152, 1152,
+      1152, 1152, 1152, 1152, 1152, 1152, 1152, 1152, 1152, 1152,
+      1152, 1152, 1152, 1152, 1152, 1152, 1152, 1152, 1152, 1152,
+      1152, 1152, 1152, 1152, 1152, 1152, 1152, 1152
     };
   register int hval = len;
 
@@ -106,1612 +106,1709 @@ aliases_hash (register const char *str,
 
 struct stringpool_t
   {
-    char stringpool_str15[sizeof("L6")];
-    char stringpool_str17[sizeof("L1")];
-    char stringpool_str20[sizeof("CN")];
-    char stringpool_str25[sizeof("L4")];
-    char stringpool_str27[sizeof("L5")];
-    char stringpool_str30[sizeof("R8")];
-    char stringpool_str33[sizeof("L8")];
-    char stringpool_str34[sizeof("SJIS")];
-    char stringpool_str36[sizeof("866")];
-    char stringpool_str43[sizeof("L2")];
-    char stringpool_str51[sizeof("ISO-IR-6")];
-    char stringpool_str54[sizeof("CP866")];
-    char stringpool_str64[sizeof("C99")];
-    char stringpool_str65[sizeof("ISO-IR-166")];
-    char stringpool_str66[sizeof("EUCCN")];
-    char stringpool_str67[sizeof("LATIN6")];
-    char stringpool_str70[sizeof("CP154")];
-    char stringpool_str71[sizeof("LATIN1")];
-    char stringpool_str72[sizeof("EUC-CN")];
-    char stringpool_str74[sizeof("CYRILLIC")];
-    char stringpool_str76[sizeof("ISO646-CN")];
-    char stringpool_str78[sizeof("HZ")];
-    char stringpool_str79[sizeof("ISO-IR-14")];
-    char stringpool_str84[sizeof("CP1256")];
-    char stringpool_str87[sizeof("LATIN4")];
-    char stringpool_str88[sizeof("CP1251")];
-    char stringpool_str89[sizeof("ISO-IR-165")];
-    char stringpool_str91[sizeof("LATIN5")];
-    char stringpool_str92[sizeof("862")];
-    char stringpool_str93[sizeof("ISO-IR-126")];
-    char stringpool_str95[sizeof("ISO-IR-144")];
-    char stringpool_str96[sizeof("CP819")];
-    char stringpool_str103[sizeof("LATIN8")];
-    char stringpool_str104[sizeof("CP1254")];
-    char stringpool_str105[sizeof("ISO-IR-58")];
-    char stringpool_str106[sizeof("CP949")];
-    char stringpool_str108[sizeof("CP1255")];
-    char stringpool_str110[sizeof("CP862")];
-    char stringpool_str111[sizeof("ISO-IR-148")];
-    char stringpool_str112[sizeof("L3")];
-    char stringpool_str113[sizeof("LATIN-9")];
-    char stringpool_str114[sizeof("CHINESE")];
-    char stringpool_str115[sizeof("ISO-IR-149")];
-    char stringpool_str117[sizeof("ISO-IR-159")];
-    char stringpool_str119[sizeof("ISO-IR-226")];
-    char stringpool_str120[sizeof("CP1258")];
-    char stringpool_str121[sizeof("PT154")];
-    char stringpool_str123[sizeof("LATIN2")];
-    char stringpool_str124[sizeof("ISO8859-6")];
-    char stringpool_str125[sizeof("ISO-IR-199")];
-    char stringpool_str128[sizeof("ISO8859-1")];
-    char stringpool_str129[sizeof("ISO-CELTIC")];
-    char stringpool_str130[sizeof("ISO-8859-6")];
-    char stringpool_str131[sizeof("ISO_8859-6")];
-    char stringpool_str132[sizeof("ISO8859-16")];
-    char stringpool_str134[sizeof("ISO-8859-1")];
-    char stringpool_str135[sizeof("ISO_8859-1")];
-    char stringpool_str136[sizeof("ISO8859-11")];
-    char stringpool_str138[sizeof("ISO-8859-16")];
-    char stringpool_str139[sizeof("ISO_8859-16")];
-    char stringpool_str140[sizeof("CP1252")];
-    char stringpool_str142[sizeof("ISO-8859-11")];
-    char stringpool_str143[sizeof("ISO_8859-11")];
-    char stringpool_str144[sizeof("ISO8859-4")];
-    char stringpool_str145[sizeof("CP1361")];
-    char stringpool_str146[sizeof("ISO_8859-16:2001")];
-    char stringpool_str147[sizeof("CP1131")];
-    char stringpool_str148[sizeof("ISO8859-5")];
-    char stringpool_str150[sizeof("ISO-8859-4")];
-    char stringpool_str151[sizeof("ISO_8859-4")];
-    char stringpool_str152[sizeof("ISO8859-14")];
-    char stringpool_str153[sizeof("CP936")];
-    char stringpool_str154[sizeof("ISO-8859-5")];
-    char stringpool_str155[sizeof("ISO_8859-5")];
-    char stringpool_str156[sizeof("ISO8859-15")];
-    char stringpool_str157[sizeof("MAC")];
-    char stringpool_str158[sizeof("ISO-8859-14")];
-    char stringpool_str159[sizeof("ISO_8859-14")];
-    char stringpool_str160[sizeof("ISO8859-8")];
-    char stringpool_str161[sizeof("ISO-IR-101")];
-    char stringpool_str162[sizeof("ISO-8859-15")];
-    char stringpool_str163[sizeof("ISO_8859-15")];
-    char stringpool_str164[sizeof("ISO8859-9")];
-    char stringpool_str166[sizeof("ISO-8859-8")];
-    char stringpool_str167[sizeof("ISO_8859-8")];
-    char stringpool_str170[sizeof("ISO-8859-9")];
-    char stringpool_str171[sizeof("ISO_8859-9")];
-    char stringpool_str172[sizeof("ISO_8859-14:1998")];
-    char stringpool_str174[sizeof("ISO_8859-15:1998")];
-    char stringpool_str176[sizeof("RK1048")];
-    char stringpool_str179[sizeof("ELOT_928")];
-    char stringpool_str180[sizeof("ISO8859-2")];
-    char stringpool_str182[sizeof("IBM866")];
-    char stringpool_str183[sizeof("L7")];
-    char stringpool_str184[sizeof("US")];
-    char stringpool_str186[sizeof("ISO-8859-2")];
-    char stringpool_str187[sizeof("ISO_8859-2")];
-    char stringpool_str190[sizeof("X0212")];
-    char stringpool_str193[sizeof("CHAR")];
-    char stringpool_str196[sizeof("PTCP154")];
-    char stringpool_str197[sizeof("ISO-IR-109")];
-    char stringpool_str198[sizeof("ISO-IR-138")];
-    char stringpool_str199[sizeof("UHC")];
-    char stringpool_str202[sizeof("ASCII")];
-    char stringpool_str204[sizeof("MS-CYRL")];
-    char stringpool_str205[sizeof("L10")];
-    char stringpool_str206[sizeof("VISCII")];
-    char stringpool_str209[sizeof("CP932")];
-    char stringpool_str210[sizeof("BIG5")];
-    char stringpool_str211[sizeof("TCVN")];
-    char stringpool_str212[sizeof("CP50221")];
-    char stringpool_str216[sizeof("BIG-5")];
-    char stringpool_str217[sizeof("MS-EE")];
-    char stringpool_str220[sizeof("850")];
-    char stringpool_str222[sizeof("UCS-4")];
-    char stringpool_str223[sizeof("CSASCII")];
-    char stringpool_str224[sizeof("IBM819")];
-    char stringpool_str225[sizeof("CSVISCII")];
-    char stringpool_str227[sizeof("GB2312")];
-    char stringpool_str228[sizeof("X0201")];
-    char stringpool_str229[sizeof("CSBIG5")];
-    char stringpool_str235[sizeof("CN-BIG5")];
-    char stringpool_str236[sizeof("KOI8-R")];
-    char stringpool_str237[sizeof("EUCKR")];
-    char stringpool_str238[sizeof("IBM862")];
-    char stringpool_str239[sizeof("CSPTCP154")];
-    char stringpool_str240[sizeof("CSUCS4")];
-    char stringpool_str241[sizeof("ISO646-US")];
-    char stringpool_str242[sizeof("CP874")];
-    char stringpool_str243[sizeof("EUC-KR")];
-    char stringpool_str244[sizeof("VISCII1.1-1")];
-    char stringpool_str246[sizeof("ISO_646.IRV:1991")];
-    char stringpool_str248[sizeof("MACCYRILLIC")];
-    char stringpool_str249[sizeof("CSKOI8R")];
-    char stringpool_str250[sizeof("CP850")];
-    char stringpool_str251[sizeof("ISO-IR-110")];
-    char stringpool_str252[sizeof("CP950")];
-    char stringpool_str254[sizeof("ISO-2022-CN")];
-    char stringpool_str255[sizeof("CN-GB-ISOIR165")];
-    char stringpool_str257[sizeof("CYRILLIC-ASIAN")];
-    char stringpool_str258[sizeof("UCS-2")];
-    char stringpool_str259[sizeof("LATIN10")];
-    char stringpool_str260[sizeof("X0208")];
-    char stringpool_str261[sizeof("LATIN3")];
-    char stringpool_str263[sizeof("CSISO2022CN")];
-    char stringpool_str264[sizeof("ISO_8859-10:1992")];
-    char stringpool_str267[sizeof("UCS-4LE")];
-    char stringpool_str268[sizeof("CP1250")];
-    char stringpool_str271[sizeof("CSISOLATIN6")];
-    char stringpool_str273[sizeof("ISO-IR-179")];
-    char stringpool_str274[sizeof("MS936")];
-    char stringpool_str275[sizeof("CSISOLATIN1")];
-    char stringpool_str276[sizeof("TIS620")];
-    char stringpool_str278[sizeof("CP1253")];
-    char stringpool_str281[sizeof("ISO-2022-CN-EXT")];
-    char stringpool_str282[sizeof("TIS-620")];
-    char stringpool_str285[sizeof("UCS-2LE")];
-    char stringpool_str286[sizeof("KOI8-T")];
-    char stringpool_str290[sizeof("CSISOLATINCYRILLIC")];
-    char stringpool_str291[sizeof("CSISOLATIN4")];
-    char stringpool_str295[sizeof("CSISOLATIN5")];
-    char stringpool_str296[sizeof("UNICODE-1-1")];
-    char stringpool_str301[sizeof("GREEK8")];
-    char stringpool_str302[sizeof("UCS-4-INTERNAL")];
-    char stringpool_str304[sizeof("CSUNICODE11")];
-    char stringpool_str306[sizeof("CSUNICODE")];
-    char stringpool_str307[sizeof("TIS620.2529-1")];
-    char stringpool_str311[sizeof("NEXTSTEP")];
-    char stringpool_str312[sizeof("GEORGIAN-PS")];
-    char stringpool_str316[sizeof("ISO8859-10")];
-    char stringpool_str318[sizeof("ISO8859-3")];
-    char stringpool_str320[sizeof("UCS-2-INTERNAL")];
-    char stringpool_str322[sizeof("ISO-8859-10")];
-    char stringpool_str323[sizeof("ISO_8859-10")];
-    char stringpool_str324[sizeof("ISO-8859-3")];
-    char stringpool_str325[sizeof("ISO_8859-3")];
-    char stringpool_str326[sizeof("ISO8859-13")];
-    char stringpool_str327[sizeof("CSISOLATIN2")];
-    char stringpool_str329[sizeof("GB_1988-80")];
-    char stringpool_str332[sizeof("ISO-8859-13")];
-    char stringpool_str333[sizeof("ISO_8859-13")];
-    char stringpool_str337[sizeof("CP1133")];
-    char stringpool_str339[sizeof("MS-ANSI")];
-    char stringpool_str341[sizeof("ISO-IR-100")];
-    char stringpool_str344[sizeof("KSC_5601")];
-    char stringpool_str349[sizeof("MACINTOSH")];
-    char stringpool_str352[sizeof("CN-GB")];
-    char stringpool_str354[sizeof("CSIBM866")];
-    char stringpool_str355[sizeof("ISO-10646-UCS-4")];
-    char stringpool_str357[sizeof("ISO_8859-4:1988")];
-    char stringpool_str359[sizeof("ISO_8859-5:1988")];
-    char stringpool_str361[sizeof("UTF-16")];
-    char stringpool_str363[sizeof("KZ-1048")];
-    char stringpool_str364[sizeof("ROMAN8")];
-    char stringpool_str365[sizeof("ISO_8859-8:1988")];
-    char stringpool_str366[sizeof("UNICODELITTLE")];
-    char stringpool_str369[sizeof("ISO_8859-9:1989")];
-    char stringpool_str372[sizeof("JP")];
-    char stringpool_str373[sizeof("ISO-10646-UCS-2")];
-    char stringpool_str375[sizeof("MULELAO-1")];
-    char stringpool_str376[sizeof("CSKZ1048")];
-    char stringpool_str377[sizeof("ISO-IR-203")];
-    char stringpool_str378[sizeof("IBM850")];
-    char stringpool_str380[sizeof("TIS620-0")];
-    char stringpool_str382[sizeof("ECMA-114")];
-    char stringpool_str386[sizeof("KS_C_5601-1989")];
-    char stringpool_str388[sizeof("GBK")];
-    char stringpool_str389[sizeof("UTF-8")];
-    char stringpool_str391[sizeof("ARMSCII-8")];
-    char stringpool_str392[sizeof("US-ASCII")];
-    char stringpool_str398[sizeof("ECMA-118")];
-    char stringpool_str399[sizeof("CSGB2312")];
-    char stringpool_str403[sizeof("LATIN7")];
-    char stringpool_str404[sizeof("KOREAN")];
-    char stringpool_str405[sizeof("ISO-IR-57")];
-    char stringpool_str408[sizeof("MS-HEBR")];
-    char stringpool_str409[sizeof("CSISO14JISC6220RO")];
-    char stringpool_str411[sizeof("ISO-IR-87")];
-    char stringpool_str413[sizeof("ISO-IR-157")];
-    char stringpool_str416[sizeof("UTF-16LE")];
-    char stringpool_str418[sizeof("UCS-4BE")];
-    char stringpool_str420[sizeof("CP1257")];
-    char stringpool_str421[sizeof("ANSI_X3.4-1986")];
-    char stringpool_str424[sizeof("CSEUCKR")];
-    char stringpool_str425[sizeof("ISO-2022-KR")];
-    char stringpool_str426[sizeof("GB_2312-80")];
-    char stringpool_str429[sizeof("ISO-IR-127")];
-    char stringpool_str430[sizeof("MACTHAI")];
-    char stringpool_str431[sizeof("EUCTW")];
-    char stringpool_str433[sizeof("EXTENDED_UNIX_CODE_PACKED_FORMAT_FOR_JAPANESE")];
-    char stringpool_str434[sizeof("CSISO2022KR")];
-    char stringpool_str436[sizeof("UCS-2BE")];
-    char stringpool_str437[sizeof("EUC-TW")];
-    char stringpool_str439[sizeof("ANSI_X3.4-1968")];
-    char stringpool_str440[sizeof("GREEK")];
-    char stringpool_str442[sizeof("MACICELAND")];
-    char stringpool_str443[sizeof("GB18030")];
-    char stringpool_str444[sizeof("ISO_8859-3:1988")];
-    char stringpool_str445[sizeof("CSISOLATINARABIC")];
-    char stringpool_str446[sizeof("GEORGIAN-ACADEMY")];
-    char stringpool_str448[sizeof("HP-ROMAN8")];
-    char stringpool_str453[sizeof("TIS620.2533-1")];
-    char stringpool_str455[sizeof("UNICODEBIG")];
-    char stringpool_str459[sizeof("TCVN5712-1")];
-    char stringpool_str460[sizeof("ISO8859-7")];
-    char stringpool_str461[sizeof("CSISO57GB1988")];
-    char stringpool_str463[sizeof("MACCENTRALEUROPE")];
-    char stringpool_str464[sizeof("CSISOLATINGREEK")];
-    char stringpool_str465[sizeof("CSISOLATIN3")];
-    char stringpool_str466[sizeof("ISO-8859-7")];
-    char stringpool_str467[sizeof("ISO_8859-7")];
-    char stringpool_str468[sizeof("UNICODE-1-1-UTF-7")];
-    char stringpool_str469[sizeof("CP367")];
-    char stringpool_str470[sizeof("HZ-GB-2312")];
-    char stringpool_str473[sizeof("EUCJP")];
-    char stringpool_str474[sizeof("CSUNICODE11UTF7")];
-    char stringpool_str476[sizeof("MACROMAN")];
-    char stringpool_str477[sizeof("TCVN-5712")];
-    char stringpool_str479[sizeof("EUC-JP")];
-    char stringpool_str483[sizeof("ISO646-JP")];
-    char stringpool_str489[sizeof("BIG5HKSCS")];
-    char stringpool_str490[sizeof("CSISO58GB231280")];
-    char stringpool_str492[sizeof("WINDOWS-1256")];
-    char stringpool_str494[sizeof("WINDOWS-1251")];
-    char stringpool_str495[sizeof("BIG5-HKSCS")];
-    char stringpool_str496[sizeof("WCHAR_T")];
-    char stringpool_str497[sizeof("ISO_8859-6:1987")];
-    char stringpool_str499[sizeof("ISO_8859-1:1987")];
-    char stringpool_str502[sizeof("WINDOWS-1254")];
-    char stringpool_str504[sizeof("WINDOWS-1255")];
-    char stringpool_str510[sizeof("WINDOWS-1258")];
-    char stringpool_str512[sizeof("UTF-32")];
-    char stringpool_str516[sizeof("CSISOLATINHEBREW")];
-    char stringpool_str517[sizeof("CSHPROMAN8")];
-    char stringpool_str519[sizeof("CSISO159JISX02121990")];
-    char stringpool_str520[sizeof("WINDOWS-1252")];
-    char stringpool_str522[sizeof("STRK1048-2002")];
-    char stringpool_str525[sizeof("ISO_8859-2:1987")];
-    char stringpool_str529[sizeof("ARABIC")];
-    char stringpool_str530[sizeof("CSMACINTOSH")];
-    char stringpool_str534[sizeof("KS_C_5601-1987")];
-    char stringpool_str536[sizeof("JIS_C6220-1969-RO")];
-    char stringpool_str537[sizeof("JIS_C6226-1983")];
-    char stringpool_str539[sizeof("UTF-32LE")];
-    char stringpool_str543[sizeof("TIS620.2533-0")];
-    char stringpool_str546[sizeof("IBM-CP1133")];
-    char stringpool_str547[sizeof("SHIFT-JIS")];
-    char stringpool_str548[sizeof("SHIFT_JIS")];
-    char stringpool_str555[sizeof("CSPC862LATINHEBREW")];
-    char stringpool_str557[sizeof("BIGFIVE")];
-    char stringpool_str560[sizeof("CSKSC56011987")];
-    char stringpool_str562[sizeof("MACCROATIAN")];
-    char stringpool_str563[sizeof("BIG-FIVE")];
-    char stringpool_str566[sizeof("WINDOWS-936")];
-    char stringpool_str567[sizeof("UTF-16BE")];
-    char stringpool_str574[sizeof("KOI8-U")];
-    char stringpool_str580[sizeof("KOI8-RU")];
-    char stringpool_str584[sizeof("WINDOWS-1250")];
-    char stringpool_str585[sizeof("MS-GREEK")];
-    char stringpool_str589[sizeof("WINDOWS-1253")];
-    char stringpool_str591[sizeof("MACGREEK")];
-    char stringpool_str592[sizeof("CSPC850MULTILINGUAL")];
-    char stringpool_str594[sizeof("ISO_8859-7:2003")];
-    char stringpool_str596[sizeof("JIS0208")];
-    char stringpool_str597[sizeof("IBM367")];
-    char stringpool_str608[sizeof("ISO-2022-JP-1")];
-    char stringpool_str610[sizeof("ISO-2022-JP-MS")];
-    char stringpool_str613[sizeof("JIS_X0212")];
-    char stringpool_str618[sizeof("CSEUCTW")];
-    char stringpool_str624[sizeof("CSSHIFTJIS")];
-    char stringpool_str625[sizeof("HEBREW")];
-    char stringpool_str634[sizeof("ISO-2022-JP-2")];
-    char stringpool_str635[sizeof("ASMO-708")];
-    char stringpool_str642[sizeof("CSISO2022JP2")];
-    char stringpool_str651[sizeof("JIS_X0201")];
-    char stringpool_str655[sizeof("WINDOWS-874")];
-    char stringpool_str660[sizeof("WINDOWS-1257")];
-    char stringpool_str661[sizeof("ISO-2022-JP")];
-    char stringpool_str665[sizeof("ISO_8859-7:1987")];
-    char stringpool_str666[sizeof("CSISO87JISX0208")];
-    char stringpool_str670[sizeof("CSISO2022JP")];
-    char stringpool_str680[sizeof("MACARABIC")];
-    char stringpool_str683[sizeof("JIS_X0208")];
-    char stringpool_str684[sizeof("JISX0201-1976")];
-    char stringpool_str689[sizeof("UTF-7")];
-    char stringpool_str690[sizeof("UTF-32BE")];
-    char stringpool_str692[sizeof("BIG5-HKSCS:2001")];
-    char stringpool_str694[sizeof("JIS_X0212-1990")];
-    char stringpool_str697[sizeof("JIS_X0212.1990-0")];
-    char stringpool_str700[sizeof("BIG5-HKSCS:2004")];
-    char stringpool_str702[sizeof("MACTURKISH")];
-    char stringpool_str708[sizeof("BIG5-HKSCS:2008")];
-    char stringpool_str710[sizeof("BIG5-HKSCS:1999")];
-    char stringpool_str725[sizeof("MS-TURK")];
-    char stringpool_str732[sizeof("UCS-4-SWAPPED")];
-    char stringpool_str749[sizeof("MACUKRAINE")];
-    char stringpool_str750[sizeof("UCS-2-SWAPPED")];
-    char stringpool_str752[sizeof("TCVN5712-1:1993")];
-    char stringpool_str774[sizeof("JIS_X0208-1990")];
-    char stringpool_str779[sizeof("JIS_X0208-1983")];
-    char stringpool_str796[sizeof("MACHEBREW")];
-    char stringpool_str803[sizeof("MS-ARAB")];
-    char stringpool_str811[sizeof("JAVA")];
-    char stringpool_str813[sizeof("MACROMANIA")];
-    char stringpool_str827[sizeof("MS_KANJI")];
-    char stringpool_str837[sizeof("WINBALTRIM")];
-    char stringpool_str866[sizeof("CSEUCPKDFMTJAPANESE")];
-    char stringpool_str869[sizeof("JOHAB")];
-    char stringpool_str921[sizeof("CSHALFWIDTHKATAKANA")];
+    char stringpool_str9[sizeof("CN")];
+    char stringpool_str10[sizeof("CP1131")];
+    char stringpool_str11[sizeof("CP1361")];
+    char stringpool_str13[sizeof("CP1251")];
+    char stringpool_str15[sizeof("CP1256")];
+    char stringpool_str16[sizeof("866")];
+    char stringpool_str17[sizeof("CP1255")];
+    char stringpool_str18[sizeof("CP1133")];
+    char stringpool_str19[sizeof("CP866")];
+    char stringpool_str21[sizeof("CP1253")];
+    char stringpool_str23[sizeof("CP1252")];
+    char stringpool_str24[sizeof("862")];
+    char stringpool_str25[sizeof("CP936")];
+    char stringpool_str27[sizeof("CP862")];
+    char stringpool_str31[sizeof("C99")];
+    char stringpool_str33[sizeof("CP932")];
+    char stringpool_str35[sizeof("CP1258")];
+    char stringpool_str37[sizeof("CP51932")];
+    char stringpool_str40[sizeof("ASCII")];
+    char stringpool_str44[sizeof("CP819")];
+    char stringpool_str53[sizeof("CP50221")];
+    char stringpool_str57[sizeof("ISO8859-1")];
+    char stringpool_str58[sizeof("ISO8859-11")];
+    char stringpool_str59[sizeof("ISO8859-6")];
+    char stringpool_str60[sizeof("ISO8859-16")];
+    char stringpool_str61[sizeof("ISO8859-5")];
+    char stringpool_str62[sizeof("ISO8859-15")];
+    char stringpool_str65[sizeof("ISO8859-3")];
+    char stringpool_str66[sizeof("ISO8859-13")];
+    char stringpool_str67[sizeof("ISO8859-2")];
+    char stringpool_str68[sizeof("ISO-8859-1")];
+    char stringpool_str69[sizeof("ISO-8859-11")];
+    char stringpool_str70[sizeof("ISO-8859-6")];
+    char stringpool_str71[sizeof("ISO-8859-16")];
+    char stringpool_str72[sizeof("ISO-8859-5")];
+    char stringpool_str73[sizeof("ISO-8859-15")];
+    char stringpool_str76[sizeof("ISO-8859-3")];
+    char stringpool_str77[sizeof("ISO-8859-13")];
+    char stringpool_str78[sizeof("ISO-8859-2")];
+    char stringpool_str79[sizeof("ISO8859-8")];
+    char stringpool_str80[sizeof("EUCCN")];
+    char stringpool_str81[sizeof("CP1250")];
+    char stringpool_str82[sizeof("850")];
+    char stringpool_str83[sizeof("ISO646-CN")];
+    char stringpool_str85[sizeof("ISO8859-9")];
+    char stringpool_str86[sizeof("CP850")];
+    char stringpool_str89[sizeof("CP950")];
+    char stringpool_str90[sizeof("ISO-8859-8")];
+    char stringpool_str91[sizeof("EUC-CN")];
+    char stringpool_str92[sizeof("HZ")];
+    char stringpool_str93[sizeof("R8")];
+    char stringpool_str94[sizeof("ISO-2022-CN")];
+    char stringpool_str95[sizeof("CP949")];
+    char stringpool_str96[sizeof("ISO-8859-9")];
+    char stringpool_str97[sizeof("ISO_8859-1")];
+    char stringpool_str98[sizeof("ISO_8859-11")];
+    char stringpool_str99[sizeof("ISO_8859-6")];
+    char stringpool_str100[sizeof("ISO_8859-16")];
+    char stringpool_str101[sizeof("ISO_8859-5")];
+    char stringpool_str102[sizeof("ISO_8859-15")];
+    char stringpool_str103[sizeof("CP154")];
+    char stringpool_str104[sizeof("ISO_8859-16:2001")];
+    char stringpool_str105[sizeof("ISO_8859-3")];
+    char stringpool_str106[sizeof("ISO_8859-13")];
+    char stringpool_str107[sizeof("ISO_8859-2")];
+    char stringpool_str109[sizeof("CP1254")];
+    char stringpool_str110[sizeof("ISO-IR-6")];
+    char stringpool_str112[sizeof("ISO-2022-CN-EXT")];
+    char stringpool_str113[sizeof("ISO-IR-166")];
+    char stringpool_str114[sizeof("CSASCII")];
+    char stringpool_str115[sizeof("ISO-IR-165")];
+    char stringpool_str116[sizeof("ISO_8859-15:1998")];
+    char stringpool_str117[sizeof("ISO-IR-126")];
+    char stringpool_str119[sizeof("ISO_8859-8")];
+    char stringpool_str122[sizeof("ISO-IR-226")];
+    char stringpool_str125[sizeof("ISO_8859-9")];
+    char stringpool_str126[sizeof("ISO8859-10")];
+    char stringpool_str127[sizeof("L1")];
+    char stringpool_str128[sizeof("L6")];
+    char stringpool_str129[sizeof("L5")];
+    char stringpool_str131[sizeof("L3")];
+    char stringpool_str132[sizeof("L2")];
+    char stringpool_str133[sizeof("ISO-IR-58")];
+    char stringpool_str136[sizeof("ISO-IR-138")];
+    char stringpool_str137[sizeof("ISO-8859-10")];
+    char stringpool_str138[sizeof("L8")];
+    char stringpool_str139[sizeof("UHC")];
+    char stringpool_str140[sizeof("ISO-IR-159")];
+    char stringpool_str141[sizeof("GB2312")];
+    char stringpool_str142[sizeof("ISO_8859-10:1992")];
+    char stringpool_str144[sizeof("ISO-IR-101")];
+    char stringpool_str146[sizeof("CSISO2022CN")];
+    char stringpool_str151[sizeof("JP")];
+    char stringpool_str152[sizeof("ISO-IR-199")];
+    char stringpool_str153[sizeof("ISO8859-4")];
+    char stringpool_str154[sizeof("ISO8859-14")];
+    char stringpool_str157[sizeof("ISO-IR-203")];
+    char stringpool_str159[sizeof("LATIN1")];
+    char stringpool_str161[sizeof("LATIN6")];
+    char stringpool_str162[sizeof("ISO_8859-14:1998")];
+    char stringpool_str163[sizeof("LATIN5")];
+    char stringpool_str164[sizeof("ISO-8859-4")];
+    char stringpool_str165[sizeof("ISO-8859-14")];
+    char stringpool_str166[sizeof("ISO_8859-10")];
+    char stringpool_str167[sizeof("LATIN3")];
+    char stringpool_str169[sizeof("LATIN2")];
+    char stringpool_str170[sizeof("ELOT_928")];
+    char stringpool_str171[sizeof("EUCTW")];
+    char stringpool_str172[sizeof("ISO-IR-109")];
+    char stringpool_str173[sizeof("TIS620")];
+    char stringpool_str174[sizeof("JIS_C6226-1983")];
+    char stringpool_str175[sizeof("L4")];
+    char stringpool_str178[sizeof("ISO-IR-110")];
+    char stringpool_str179[sizeof("X0212")];
+    char stringpool_str180[sizeof("ISO-IR-148")];
+    char stringpool_str181[sizeof("LATIN8")];
+    char stringpool_str182[sizeof("EUC-TW")];
+    char stringpool_str184[sizeof("TIS-620")];
+    char stringpool_str186[sizeof("ISO-IR-149")];
+    char stringpool_str190[sizeof("RK1048")];
+    char stringpool_str192[sizeof("MAC")];
+    char stringpool_str193[sizeof("ISO_8859-4")];
+    char stringpool_str194[sizeof("ISO_8859-14")];
+    char stringpool_str196[sizeof("L10")];
+    char stringpool_str197[sizeof("JIS0208")];
+    char stringpool_str198[sizeof("LATIN-9")];
+    char stringpool_str199[sizeof("CHAR")];
+    char stringpool_str200[sizeof("TCVN")];
+    char stringpool_str203[sizeof("X0201")];
+    char stringpool_str205[sizeof("ISO-IR-14")];
+    char stringpool_str206[sizeof("JIS_C6220-1969-RO")];
+    char stringpool_str209[sizeof("IBM866")];
+    char stringpool_str210[sizeof("US")];
+    char stringpool_str212[sizeof("ISO-IR-100")];
+    char stringpool_str214[sizeof("MS936")];
+    char stringpool_str217[sizeof("IBM862")];
+    char stringpool_str218[sizeof("SJIS-WIN")];
+    char stringpool_str219[sizeof("TIS620-0")];
+    char stringpool_str220[sizeof("SJIS")];
+    char stringpool_str222[sizeof("MS932")];
+    char stringpool_str225[sizeof("X0208")];
+    char stringpool_str226[sizeof("MS51932")];
+    char stringpool_str227[sizeof("ISO-CELTIC")];
+    char stringpool_str228[sizeof("LATIN10")];
+    char stringpool_str229[sizeof("PT154")];
+    char stringpool_str231[sizeof("ISO-2022-JP-1")];
+    char stringpool_str232[sizeof("CSISO14JISC6220RO")];
+    char stringpool_str233[sizeof("UCS-2")];
+    char stringpool_str234[sizeof("IBM819")];
+    char stringpool_str236[sizeof("ISO-2022-JP-2")];
+    char stringpool_str237[sizeof("CSISO159JISX02121990")];
+    char stringpool_str239[sizeof("VISCII")];
+    char stringpool_str240[sizeof("GB18030")];
+    char stringpool_str241[sizeof("CSVISCII")];
+    char stringpool_str254[sizeof("ISO-IR-144")];
+    char stringpool_str255[sizeof("LATIN4")];
+    char stringpool_str258[sizeof("JAVA")];
+    char stringpool_str260[sizeof("ISO-10646-UCS-2")];
+    char stringpool_str261[sizeof("US-ASCII")];
+    char stringpool_str268[sizeof("GB_2312-80")];
+    char stringpool_str269[sizeof("CHINESE")];
+    char stringpool_str271[sizeof("CSISOLATIN1")];
+    char stringpool_str273[sizeof("CSISOLATIN6")];
+    char stringpool_str275[sizeof("CSISOLATIN5")];
+    char stringpool_str276[sizeof("IBM850")];
+    char stringpool_str278[sizeof("CSISOLATINCYRILLIC")];
+    char stringpool_str279[sizeof("CSISOLATIN3")];
+    char stringpool_str281[sizeof("CSISOLATIN2")];
+    char stringpool_str282[sizeof("KOI8-T")];
+    char stringpool_str284[sizeof("ISO_8859-5:1988")];
+    char stringpool_str285[sizeof("EUCJP-WIN")];
+    char stringpool_str286[sizeof("ISO_8859-3:1988")];
+    char stringpool_str287[sizeof("CSISO2022JP2")];
+    char stringpool_str290[sizeof("GB_1988-80")];
+    char stringpool_str293[sizeof("ISO_8859-8:1988")];
+    char stringpool_str297[sizeof("KSC_5601")];
+    char stringpool_str299[sizeof("ISO_8859-9:1989")];
+    char stringpool_str300[sizeof("CP874")];
+    char stringpool_str303[sizeof("ISO-10646-UCS-4")];
+    char stringpool_str304[sizeof("ISO-2022-JP-MS")];
+    char stringpool_str309[sizeof("CSEUCTW")];
+    char stringpool_str310[sizeof("CSUCS4")];
+    char stringpool_str311[sizeof("CSISOLATINARABIC")];
+    char stringpool_str312[sizeof("WINDOWS-1251")];
+    char stringpool_str313[sizeof("WINDOWS-1256")];
+    char stringpool_str314[sizeof("WINDOWS-1255")];
+    char stringpool_str315[sizeof("L7")];
+    char stringpool_str316[sizeof("WINDOWS-1253")];
+    char stringpool_str317[sizeof("WINDOWS-1252")];
+    char stringpool_str319[sizeof("UCS-4")];
+    char stringpool_str320[sizeof("MS-ANSI")];
+    char stringpool_str322[sizeof("CSWINDOWS31J")];
+    char stringpool_str323[sizeof("WINDOWS-1258")];
+    char stringpool_str324[sizeof("WINDOWS-936")];
+    char stringpool_str325[sizeof("ECMA-118")];
+    char stringpool_str326[sizeof("ISO-IR-179")];
+    char stringpool_str327[sizeof("WINDOWS-51932")];
+    char stringpool_str329[sizeof("WCHAR_T")];
+    char stringpool_str330[sizeof("ISO_8859-4:1988")];
+    char stringpool_str331[sizeof("CSKZ1048")];
+    char stringpool_str332[sizeof("WINDOWS-932")];
+    char stringpool_str334[sizeof("KZ-1048")];
+    char stringpool_str335[sizeof("CSUNICODE11")];
+    char stringpool_str336[sizeof("MACTHAI")];
+    char stringpool_str337[sizeof("ARMSCII-8")];
+    char stringpool_str338[sizeof("CYRILLIC")];
+    char stringpool_str339[sizeof("ROMAN8")];
+    char stringpool_str341[sizeof("EUCJP")];
+    char stringpool_str344[sizeof("ISO646-JP")];
+    char stringpool_str346[sizeof("WINDOWS-1250")];
+    char stringpool_str347[sizeof("IBM-CP1133")];
+    char stringpool_str348[sizeof("UNICODE-1-1")];
+    char stringpool_str349[sizeof("ISO646-US")];
+    char stringpool_str351[sizeof("JIS_X0212")];
+    char stringpool_str352[sizeof("EUC-JP")];
+    char stringpool_str354[sizeof("WINDOWS-31J")];
+    char stringpool_str355[sizeof("ISO-2022-JP")];
+    char stringpool_str357[sizeof("PTCP154")];
+    char stringpool_str359[sizeof("UTF-16")];
+    char stringpool_str360[sizeof("WINDOWS-1254")];
+    char stringpool_str363[sizeof("ARABIC")];
+    char stringpool_str364[sizeof("SJIS-OPEN")];
+    char stringpool_str365[sizeof("JISX0201-1976")];
+    char stringpool_str366[sizeof("KS_C_5601-1989")];
+    char stringpool_str367[sizeof("CSISOLATIN4")];
+    char stringpool_str371[sizeof("UTF-32")];
+    char stringpool_str375[sizeof("JIS_X0201")];
+    char stringpool_str378[sizeof("UTF-8")];
+    char stringpool_str380[sizeof("CSPTCP154")];
+    char stringpool_str382[sizeof("TIS620.2533-1")];
+    char stringpool_str384[sizeof("CSPC862LATINHEBREW")];
+    char stringpool_str385[sizeof("MACCROATIAN")];
+    char stringpool_str386[sizeof("CP367")];
+    char stringpool_str387[sizeof("MS-EE")];
+    char stringpool_str389[sizeof("CP1257")];
+    char stringpool_str391[sizeof("CSKOI8R")];
+    char stringpool_str393[sizeof("TIS620.2529-1")];
+    char stringpool_str394[sizeof("CSUNICODE")];
+    char stringpool_str395[sizeof("JIS_X0212-1990")];
+    char stringpool_str397[sizeof("JIS_X0208")];
+    char stringpool_str399[sizeof("ECMA-114")];
+    char stringpool_str400[sizeof("KOI8-R")];
+    char stringpool_str402[sizeof("CSISOLATINHEBREW")];
+    char stringpool_str404[sizeof("TCVN5712-1")];
+    char stringpool_str405[sizeof("JIS_X0208-1983")];
+    char stringpool_str407[sizeof("CSISO2022JP")];
+    char stringpool_str408[sizeof("TCVN-5712")];
+    char stringpool_str409[sizeof("KOREAN")];
+    char stringpool_str411[sizeof("BIG5")];
+    char stringpool_str413[sizeof("CSBIG5")];
+    char stringpool_str416[sizeof("TIS620.2533-0")];
+    char stringpool_str417[sizeof("GEORGIAN-ACADEMY")];
+    char stringpool_str422[sizeof("BIG-5")];
+    char stringpool_str424[sizeof("CN-BIG5")];
+    char stringpool_str430[sizeof("CSGB2312")];
+    char stringpool_str431[sizeof("EUCJP-OPEN")];
+    char stringpool_str433[sizeof("ISO8859-7")];
+    char stringpool_str435[sizeof("JIS_X0208-1990")];
+    char stringpool_str436[sizeof("HP-ROMAN8")];
+    char stringpool_str439[sizeof("EUCKR")];
+    char stringpool_str444[sizeof("ISO-8859-7")];
+    char stringpool_str450[sizeof("EUC-KR")];
+    char stringpool_str453[sizeof("ISO-2022-KR")];
+    char stringpool_str459[sizeof("ISO_8859-1:1987")];
+    char stringpool_str460[sizeof("ISO_8859-6:1987")];
+    char stringpool_str463[sizeof("ISO_8859-7:2003")];
+    char stringpool_str464[sizeof("ISO_8859-2:1987")];
+    char stringpool_str466[sizeof("MACINTOSH")];
+    char stringpool_str468[sizeof("CYRILLIC-ASIAN")];
+    char stringpool_str473[sizeof("ISO_8859-7")];
+    char stringpool_str475[sizeof("VISCII1.1-1")];
+    char stringpool_str477[sizeof("UCS-2LE")];
+    char stringpool_str479[sizeof("GREEK8")];
+    char stringpool_str484[sizeof("SHIFT-JIS")];
+    char stringpool_str486[sizeof("ASMO-708")];
+    char stringpool_str487[sizeof("ISO-IR-57")];
+    char stringpool_str488[sizeof("ISO-IR-157")];
+    char stringpool_str491[sizeof("ISO-IR-127")];
+    char stringpool_str494[sizeof("SJIS-MS")];
+    char stringpool_str496[sizeof("ISO-IR-87")];
+    char stringpool_str498[sizeof("CSIBM866")];
+    char stringpool_str500[sizeof("WINDOWS-1257")];
+    char stringpool_str503[sizeof("CSMACINTOSH")];
+    char stringpool_str505[sizeof("CSISO2022KR")];
+    char stringpool_str512[sizeof("KOI8-U")];
+    char stringpool_str513[sizeof("SHIFT_JIS")];
+    char stringpool_str514[sizeof("MS_KANJI")];
+    char stringpool_str515[sizeof("MACROMAN")];
+    char stringpool_str520[sizeof("UCS-4LE")];
+    char stringpool_str525[sizeof("STRK1048-2002")];
+    char stringpool_str527[sizeof("CSUNICODE11UTF7")];
+    char stringpool_str532[sizeof("MACCYRILLIC")];
+    char stringpool_str535[sizeof("LATIN7")];
+    char stringpool_str536[sizeof("HZ-GB-2312")];
+    char stringpool_str537[sizeof("CSKSC56011987")];
+    char stringpool_str538[sizeof("MS-CYRL")];
+    char stringpool_str540[sizeof("KS_C_5601-1987")];
+    char stringpool_str541[sizeof("UCS-2-INTERNAL")];
+    char stringpool_str542[sizeof("UNICODE-1-1-UTF-7")];
+    char stringpool_str545[sizeof("GBK")];
+    char stringpool_str546[sizeof("CSISO58GB231280")];
+    char stringpool_str550[sizeof("EUCJPMS")];
+    char stringpool_str551[sizeof("CSISO87JISX0208")];
+    char stringpool_str553[sizeof("CSHPROMAN8")];
+    char stringpool_str554[sizeof("MULELAO-1")];
+    char stringpool_str558[sizeof("UNICODELITTLE")];
+    char stringpool_str559[sizeof("CSSHIFTJIS")];
+    char stringpool_str561[sizeof("EUCJP-MS")];
+    char stringpool_str567[sizeof("ISO_646.IRV:1991")];
+    char stringpool_str572[sizeof("EUC-JP-MS")];
+    char stringpool_str576[sizeof("IBM367")];
+    char stringpool_str577[sizeof("CSEUCKR")];
+    char stringpool_str580[sizeof("MACROMANIA")];
+    char stringpool_str582[sizeof("TCVN5712-1:1993")];
+    char stringpool_str584[sizeof("UCS-4-INTERNAL")];
+    char stringpool_str591[sizeof("CN-GB-ISOIR165")];
+    char stringpool_str593[sizeof("KOI8-RU")];
+    char stringpool_str599[sizeof("WINDOWS-874")];
+    char stringpool_str601[sizeof("NEXTSTEP")];
+    char stringpool_str602[sizeof("HEBREW")];
+    char stringpool_str603[sizeof("ANSI_X3.4-1986")];
+    char stringpool_str604[sizeof("CSISOLATINGREEK")];
+    char stringpool_str607[sizeof("UTF-16LE")];
+    char stringpool_str608[sizeof("JIS_X0212.1990-0")];
+    char stringpool_str613[sizeof("ANSI_X3.4-1968")];
+    char stringpool_str615[sizeof("UTF-32LE")];
+    char stringpool_str635[sizeof("MACARABIC")];
+    char stringpool_str639[sizeof("UCS-2BE")];
+    char stringpool_str645[sizeof("GEORGIAN-PS")];
+    char stringpool_str647[sizeof("ISO_8859-7:1987")];
+    char stringpool_str656[sizeof("MACCENTRALEUROPE")];
+    char stringpool_str667[sizeof("MACICELAND")];
+    char stringpool_str669[sizeof("GREEK")];
+    char stringpool_str682[sizeof("UCS-4BE")];
+    char stringpool_str703[sizeof("CSISO57GB1988")];
+    char stringpool_str705[sizeof("CN-GB")];
+    char stringpool_str715[sizeof("SHIFT_JIS-MS")];
+    char stringpool_str721[sizeof("JOHAB")];
+    char stringpool_str732[sizeof("UTF-7")];
+    char stringpool_str739[sizeof("EXTENDED_UNIX_CODE_PACKED_FORMAT_FOR_JAPANESE")];
+    char stringpool_str767[sizeof("UCS-2-SWAPPED")];
+    char stringpool_str769[sizeof("UTF-16BE")];
+    char stringpool_str770[sizeof("CSHALFWIDTHKATAKANA")];
+    char stringpool_str777[sizeof("UTF-32BE")];
+    char stringpool_str788[sizeof("CSPC850MULTILINGUAL")];
+    char stringpool_str792[sizeof("MACUKRAINE")];
+    char stringpool_str798[sizeof("MS-HEBR")];
+    char stringpool_str810[sizeof("UCS-4-SWAPPED")];
+    char stringpool_str846[sizeof("UNICODEBIG")];
+    char stringpool_str855[sizeof("MACHEBREW")];
+    char stringpool_str869[sizeof("MS-TURK")];
+    char stringpool_str889[sizeof("MACTURKISH")];
+    char stringpool_str898[sizeof("BIGFIVE")];
+    char stringpool_str909[sizeof("BIG-FIVE")];
+    char stringpool_str927[sizeof("BIG5HKSCS")];
+    char stringpool_str930[sizeof("MS-ARAB")];
+    char stringpool_str938[sizeof("BIG5-HKSCS")];
+    char stringpool_str941[sizeof("MACGREEK")];
+    char stringpool_str951[sizeof("MS-GREEK")];
+    char stringpool_str985[sizeof("WINBALTRIM")];
+    char stringpool_str1013[sizeof("UTF7IMAP")];
+    char stringpool_str1035[sizeof("UTF-7-IMAP")];
+    char stringpool_str1040[sizeof("BIG5-HKSCS:2001")];
+    char stringpool_str1051[sizeof("BIG5-HKSCS:2008")];
+    char stringpool_str1054[sizeof("BIG5-HKSCS:1999")];
+    char stringpool_str1088[sizeof("BIG5-HKSCS:2004")];
+    char stringpool_str1151[sizeof("CSEUCPKDFMTJAPANESE")];
   };
 static const struct stringpool_t stringpool_contents =
   {
-    "L6",
-    "L1",
     "CN",
-    "L4",
-    "L5",
-    "R8",
-    "L8",
-    "SJIS",
+    "CP1131",
+    "CP1361",
+    "CP1251",
+    "CP1256",
     "866",
-    "L2",
-    "ISO-IR-6",
+    "CP1255",
+    "CP1133",
     "CP866",
-    "C99",
-    "ISO-IR-166",
-    "EUCCN",
-    "LATIN6",
-    "CP154",
-    "LATIN1",
-    "EUC-CN",
-    "CYRILLIC",
-    "ISO646-CN",
-    "HZ",
-    "ISO-IR-14",
-    "CP1256",
-    "LATIN4",
-    "CP1251",
-    "ISO-IR-165",
-    "LATIN5",
+    "CP1253",
+    "CP1252",
     "862",
-    "ISO-IR-126",
-    "ISO-IR-144",
-    "CP819",
-    "LATIN8",
-    "CP1254",
-    "ISO-IR-58",
-    "CP949",
-    "CP1255",
+    "CP936",
     "CP862",
-    "ISO-IR-148",
-    "L3",
-    "LATIN-9",
-    "CHINESE",
-    "ISO-IR-149",
-    "ISO-IR-159",
-    "ISO-IR-226",
+    "C99",
+    "CP932",
     "CP1258",
-    "PT154",
-    "LATIN2",
-    "ISO8859-6",
-    "ISO-IR-199",
+    "CP51932",
+    "ASCII",
+    "CP819",
+    "CP50221",
     "ISO8859-1",
-    "ISO-CELTIC",
-    "ISO-8859-6",
-    "ISO_8859-6",
+    "ISO8859-11",
+    "ISO8859-6",
     "ISO8859-16",
+    "ISO8859-5",
+    "ISO8859-15",
+    "ISO8859-3",
+    "ISO8859-13",
+    "ISO8859-2",
     "ISO-8859-1",
-    "ISO_8859-1",
-    "ISO8859-11",
-    "ISO-8859-16",
-    "ISO_8859-16",
-    "CP1252",
     "ISO-8859-11",
-    "ISO_8859-11",
-    "ISO8859-4",
-    "CP1361",
-    "ISO_8859-16:2001",
-    "CP1131",
-    "ISO8859-5",
-    "ISO-8859-4",
-    "ISO_8859-4",
-    "ISO8859-14",
-    "CP936",
+    "ISO-8859-6",
+    "ISO-8859-16",
     "ISO-8859-5",
-    "ISO_8859-5",
-    "ISO8859-15",
-    "MAC",
-    "ISO-8859-14",
-    "ISO_8859-14",
-    "ISO8859-8",
-    "ISO-IR-101",
     "ISO-8859-15",
-    "ISO_8859-15",
+    "ISO-8859-3",
+    "ISO-8859-13",
+    "ISO-8859-2",
+    "ISO8859-8",
+    "EUCCN",
+    "CP1250",
+    "850",
+    "ISO646-CN",
     "ISO8859-9",
+    "CP850",
+    "CP950",
     "ISO-8859-8",
-    "ISO_8859-8",
+    "EUC-CN",
+    "HZ",
+    "R8",
+    "ISO-2022-CN",
+    "CP949",
     "ISO-8859-9",
+    "ISO_8859-1",
+    "ISO_8859-11",
+    "ISO_8859-6",
+    "ISO_8859-16",
+    "ISO_8859-5",
+    "ISO_8859-15",
+    "CP154",
+    "ISO_8859-16:2001",
+    "ISO_8859-3",
+    "ISO_8859-13",
+    "ISO_8859-2",
+    "CP1254",
+    "ISO-IR-6",
+    "ISO-2022-CN-EXT",
+    "ISO-IR-166",
+    "CSASCII",
+    "ISO-IR-165",
+    "ISO_8859-15:1998",
+    "ISO-IR-126",
+    "ISO_8859-8",
+    "ISO-IR-226",
     "ISO_8859-9",
+    "ISO8859-10",
+    "L1",
+    "L6",
+    "L5",
+    "L3",
+    "L2",
+    "ISO-IR-58",
+    "ISO-IR-138",
+    "ISO-8859-10",
+    "L8",
+    "UHC",
+    "ISO-IR-159",
+    "GB2312",
+    "ISO_8859-10:1992",
+    "ISO-IR-101",
+    "CSISO2022CN",
+    "JP",
+    "ISO-IR-199",
+    "ISO8859-4",
+    "ISO8859-14",
+    "ISO-IR-203",
+    "LATIN1",
+    "LATIN6",
     "ISO_8859-14:1998",
-    "ISO_8859-15:1998",
-    "RK1048",
+    "LATIN5",
+    "ISO-8859-4",
+    "ISO-8859-14",
+    "ISO_8859-10",
+    "LATIN3",
+    "LATIN2",
     "ELOT_928",
-    "ISO8859-2",
-    "IBM866",
-    "L7",
-    "US",
-    "ISO-8859-2",
-    "ISO_8859-2",
-    "X0212",
-    "CHAR",
-    "PTCP154",
+    "EUCTW",
     "ISO-IR-109",
-    "ISO-IR-138",
-    "UHC",
-    "ASCII",
-    "MS-CYRL",
+    "TIS620",
+    "JIS_C6226-1983",
+    "L4",
+    "ISO-IR-110",
+    "X0212",
+    "ISO-IR-148",
+    "LATIN8",
+    "EUC-TW",
+    "TIS-620",
+    "ISO-IR-149",
+    "RK1048",
+    "MAC",
+    "ISO_8859-4",
+    "ISO_8859-14",
     "L10",
-    "VISCII",
-    "CP932",
-    "BIG5",
+    "JIS0208",
+    "LATIN-9",
+    "CHAR",
     "TCVN",
-    "CP50221",
-    "BIG-5",
-    "MS-EE",
-    "850",
-    "UCS-4",
-    "CSASCII",
-    "IBM819",
-    "CSVISCII",
-    "GB2312",
     "X0201",
-    "CSBIG5",
-    "CN-BIG5",
-    "KOI8-R",
-    "EUCKR",
+    "ISO-IR-14",
+    "JIS_C6220-1969-RO",
+    "IBM866",
+    "US",
+    "ISO-IR-100",
+    "MS936",
     "IBM862",
-    "CSPTCP154",
-    "CSUCS4",
-    "ISO646-US",
-    "CP874",
-    "EUC-KR",
-    "VISCII1.1-1",
-    "ISO_646.IRV:1991",
-    "MACCYRILLIC",
-    "CSKOI8R",
-    "CP850",
-    "ISO-IR-110",
-    "CP950",
-    "ISO-2022-CN",
-    "CN-GB-ISOIR165",
-    "CYRILLIC-ASIAN",
-    "UCS-2",
-    "LATIN10",
+    "SJIS-WIN",
+    "TIS620-0",
+    "SJIS",
+    "MS932",
     "X0208",
-    "LATIN3",
-    "CSISO2022CN",
-    "ISO_8859-10:1992",
-    "UCS-4LE",
-    "CP1250",
-    "CSISOLATIN6",
-    "ISO-IR-179",
-    "MS936",
-    "CSISOLATIN1",
-    "TIS620",
-    "CP1253",
-    "ISO-2022-CN-EXT",
-    "TIS-620",
-    "UCS-2LE",
-    "KOI8-T",
-    "CSISOLATINCYRILLIC",
-    "CSISOLATIN4",
-    "CSISOLATIN5",
-    "UNICODE-1-1",
-    "GREEK8",
-    "UCS-4-INTERNAL",
-    "CSUNICODE11",
-    "CSUNICODE",
-    "TIS620.2529-1",
-    "NEXTSTEP",
-    "GEORGIAN-PS",
-    "ISO8859-10",
-    "ISO8859-3",
-    "UCS-2-INTERNAL",
-    "ISO-8859-10",
-    "ISO_8859-10",
-    "ISO-8859-3",
-    "ISO_8859-3",
-    "ISO8859-13",
+    "MS51932",
+    "ISO-CELTIC",
+    "LATIN10",
+    "PT154",
+    "ISO-2022-JP-1",
+    "CSISO14JISC6220RO",
+    "UCS-2",
+    "IBM819",
+    "ISO-2022-JP-2",
+    "CSISO159JISX02121990",
+    "VISCII",
+    "GB18030",
+    "CSVISCII",
+    "ISO-IR-144",
+    "LATIN4",
+    "JAVA",
+    "ISO-10646-UCS-2",
+    "US-ASCII",
+    "GB_2312-80",
+    "CHINESE",
+    "CSISOLATIN1",
+    "CSISOLATIN6",
+    "CSISOLATIN5",
+    "IBM850",
+    "CSISOLATINCYRILLIC",
+    "CSISOLATIN3",
     "CSISOLATIN2",
+    "KOI8-T",
+    "ISO_8859-5:1988",
+    "EUCJP-WIN",
+    "ISO_8859-3:1988",
+    "CSISO2022JP2",
     "GB_1988-80",
-    "ISO-8859-13",
-    "ISO_8859-13",
-    "CP1133",
-    "MS-ANSI",
-    "ISO-IR-100",
+    "ISO_8859-8:1988",
     "KSC_5601",
-    "MACINTOSH",
-    "CN-GB",
-    "CSIBM866",
+    "ISO_8859-9:1989",
+    "CP874",
     "ISO-10646-UCS-4",
+    "ISO-2022-JP-MS",
+    "CSEUCTW",
+    "CSUCS4",
+    "CSISOLATINARABIC",
+    "WINDOWS-1251",
+    "WINDOWS-1256",
+    "WINDOWS-1255",
+    "L7",
+    "WINDOWS-1253",
+    "WINDOWS-1252",
+    "UCS-4",
+    "MS-ANSI",
+    "CSWINDOWS31J",
+    "WINDOWS-1258",
+    "WINDOWS-936",
+    "ECMA-118",
+    "ISO-IR-179",
+    "WINDOWS-51932",
+    "WCHAR_T",
     "ISO_8859-4:1988",
-    "ISO_8859-5:1988",
-    "UTF-16",
+    "CSKZ1048",
+    "WINDOWS-932",
     "KZ-1048",
+    "CSUNICODE11",
+    "MACTHAI",
+    "ARMSCII-8",
+    "CYRILLIC",
     "ROMAN8",
-    "ISO_8859-8:1988",
-    "UNICODELITTLE",
-    "ISO_8859-9:1989",
-    "JP",
-    "ISO-10646-UCS-2",
-    "MULELAO-1",
-    "CSKZ1048",
-    "ISO-IR-203",
-    "IBM850",
-    "TIS620-0",
-    "ECMA-114",
+    "EUCJP",
+    "ISO646-JP",
+    "WINDOWS-1250",
+    "IBM-CP1133",
+    "UNICODE-1-1",
+    "ISO646-US",
+    "JIS_X0212",
+    "EUC-JP",
+    "WINDOWS-31J",
+    "ISO-2022-JP",
+    "PTCP154",
+    "UTF-16",
+    "WINDOWS-1254",
+    "ARABIC",
+    "SJIS-OPEN",
+    "JISX0201-1976",
     "KS_C_5601-1989",
-    "GBK",
+    "CSISOLATIN4",
+    "UTF-32",
+    "JIS_X0201",
     "UTF-8",
-    "ARMSCII-8",
-    "US-ASCII",
-    "ECMA-118",
-    "CSGB2312",
-    "LATIN7",
-    "KOREAN",
-    "ISO-IR-57",
-    "MS-HEBR",
-    "CSISO14JISC6220RO",
-    "ISO-IR-87",
-    "ISO-IR-157",
-    "UTF-16LE",
-    "UCS-4BE",
-    "CP1257",
-    "ANSI_X3.4-1986",
-    "CSEUCKR",
-    "ISO-2022-KR",
-    "GB_2312-80",
-    "ISO-IR-127",
-    "MACTHAI",
-    "EUCTW",
-    "EXTENDED_UNIX_CODE_PACKED_FORMAT_FOR_JAPANESE",
-    "CSISO2022KR",
-    "UCS-2BE",
-    "EUC-TW",
-    "ANSI_X3.4-1968",
-    "GREEK",
-    "MACICELAND",
-    "GB18030",
-    "ISO_8859-3:1988",
-    "CSISOLATINARABIC",
-    "GEORGIAN-ACADEMY",
-    "HP-ROMAN8",
+    "CSPTCP154",
     "TIS620.2533-1",
-    "UNICODEBIG",
+    "CSPC862LATINHEBREW",
+    "MACCROATIAN",
+    "CP367",
+    "MS-EE",
+    "CP1257",
+    "CSKOI8R",
+    "TIS620.2529-1",
+    "CSUNICODE",
+    "JIS_X0212-1990",
+    "JIS_X0208",
+    "ECMA-114",
+    "KOI8-R",
+    "CSISOLATINHEBREW",
     "TCVN5712-1",
+    "JIS_X0208-1983",
+    "CSISO2022JP",
+    "TCVN-5712",
+    "KOREAN",
+    "BIG5",
+    "CSBIG5",
+    "TIS620.2533-0",
+    "GEORGIAN-ACADEMY",
+    "BIG-5",
+    "CN-BIG5",
+    "CSGB2312",
+    "EUCJP-OPEN",
     "ISO8859-7",
-    "CSISO57GB1988",
-    "MACCENTRALEUROPE",
-    "CSISOLATINGREEK",
-    "CSISOLATIN3",
+    "JIS_X0208-1990",
+    "HP-ROMAN8",
+    "EUCKR",
     "ISO-8859-7",
-    "ISO_8859-7",
-    "UNICODE-1-1-UTF-7",
-    "CP367",
-    "HZ-GB-2312",
-    "EUCJP",
-    "CSUNICODE11UTF7",
-    "MACROMAN",
-    "TCVN-5712",
-    "EUC-JP",
-    "ISO646-JP",
-    "BIG5HKSCS",
-    "CSISO58GB231280",
-    "WINDOWS-1256",
-    "WINDOWS-1251",
-    "BIG5-HKSCS",
-    "WCHAR_T",
-    "ISO_8859-6:1987",
+    "EUC-KR",
+    "ISO-2022-KR",
     "ISO_8859-1:1987",
-    "WINDOWS-1254",
-    "WINDOWS-1255",
-    "WINDOWS-1258",
-    "UTF-32",
-    "CSISOLATINHEBREW",
-    "CSHPROMAN8",
-    "CSISO159JISX02121990",
-    "WINDOWS-1252",
-    "STRK1048-2002",
+    "ISO_8859-6:1987",
+    "ISO_8859-7:2003",
     "ISO_8859-2:1987",
-    "ARABIC",
-    "CSMACINTOSH",
-    "KS_C_5601-1987",
-    "JIS_C6220-1969-RO",
-    "JIS_C6226-1983",
-    "UTF-32LE",
-    "TIS620.2533-0",
-    "IBM-CP1133",
+    "MACINTOSH",
+    "CYRILLIC-ASIAN",
+    "ISO_8859-7",
+    "VISCII1.1-1",
+    "UCS-2LE",
+    "GREEK8",
     "SHIFT-JIS",
+    "ASMO-708",
+    "ISO-IR-57",
+    "ISO-IR-157",
+    "ISO-IR-127",
+    "SJIS-MS",
+    "ISO-IR-87",
+    "CSIBM866",
+    "WINDOWS-1257",
+    "CSMACINTOSH",
+    "CSISO2022KR",
+    "KOI8-U",
     "SHIFT_JIS",
-    "CSPC862LATINHEBREW",
-    "BIGFIVE",
+    "MS_KANJI",
+    "MACROMAN",
+    "UCS-4LE",
+    "STRK1048-2002",
+    "CSUNICODE11UTF7",
+    "MACCYRILLIC",
+    "LATIN7",
+    "HZ-GB-2312",
     "CSKSC56011987",
-    "MACCROATIAN",
-    "BIG-FIVE",
-    "WINDOWS-936",
-    "UTF-16BE",
-    "KOI8-U",
-    "KOI8-RU",
-    "WINDOWS-1250",
-    "MS-GREEK",
-    "WINDOWS-1253",
-    "MACGREEK",
-    "CSPC850MULTILINGUAL",
-    "ISO_8859-7:2003",
-    "JIS0208",
-    "IBM367",
-    "ISO-2022-JP-1",
-    "ISO-2022-JP-MS",
-    "JIS_X0212",
-    "CSEUCTW",
+    "MS-CYRL",
+    "KS_C_5601-1987",
+    "UCS-2-INTERNAL",
+    "UNICODE-1-1-UTF-7",
+    "GBK",
+    "CSISO58GB231280",
+    "EUCJPMS",
+    "CSISO87JISX0208",
+    "CSHPROMAN8",
+    "MULELAO-1",
+    "UNICODELITTLE",
     "CSSHIFTJIS",
-    "HEBREW",
-    "ISO-2022-JP-2",
-    "ASMO-708",
-    "CSISO2022JP2",
-    "JIS_X0201",
+    "EUCJP-MS",
+    "ISO_646.IRV:1991",
+    "EUC-JP-MS",
+    "IBM367",
+    "CSEUCKR",
+    "MACROMANIA",
+    "TCVN5712-1:1993",
+    "UCS-4-INTERNAL",
+    "CN-GB-ISOIR165",
+    "KOI8-RU",
     "WINDOWS-874",
-    "WINDOWS-1257",
-    "ISO-2022-JP",
-    "ISO_8859-7:1987",
-    "CSISO87JISX0208",
-    "CSISO2022JP",
+    "NEXTSTEP",
+    "HEBREW",
+    "ANSI_X3.4-1986",
+    "CSISOLATINGREEK",
+    "UTF-16LE",
+    "JIS_X0212.1990-0",
+    "ANSI_X3.4-1968",
+    "UTF-32LE",
     "MACARABIC",
-    "JIS_X0208",
-    "JISX0201-1976",
+    "UCS-2BE",
+    "GEORGIAN-PS",
+    "ISO_8859-7:1987",
+    "MACCENTRALEUROPE",
+    "MACICELAND",
+    "GREEK",
+    "UCS-4BE",
+    "CSISO57GB1988",
+    "CN-GB",
+    "SHIFT_JIS-MS",
+    "JOHAB",
     "UTF-7",
+    "EXTENDED_UNIX_CODE_PACKED_FORMAT_FOR_JAPANESE",
+    "UCS-2-SWAPPED",
+    "UTF-16BE",
+    "CSHALFWIDTHKATAKANA",
     "UTF-32BE",
-    "BIG5-HKSCS:2001",
-    "JIS_X0212-1990",
-    "JIS_X0212.1990-0",
-    "BIG5-HKSCS:2004",
-    "MACTURKISH",
-    "BIG5-HKSCS:2008",
-    "BIG5-HKSCS:1999",
-    "MS-TURK",
-    "UCS-4-SWAPPED",
+    "CSPC850MULTILINGUAL",
     "MACUKRAINE",
-    "UCS-2-SWAPPED",
-    "TCVN5712-1:1993",
-    "JIS_X0208-1990",
-    "JIS_X0208-1983",
+    "MS-HEBR",
+    "UCS-4-SWAPPED",
+    "UNICODEBIG",
     "MACHEBREW",
+    "MS-TURK",
+    "MACTURKISH",
+    "BIGFIVE",
+    "BIG-FIVE",
+    "BIG5HKSCS",
     "MS-ARAB",
-    "JAVA",
-    "MACROMANIA",
-    "MS_KANJI",
+    "BIG5-HKSCS",
+    "MACGREEK",
+    "MS-GREEK",
     "WINBALTRIM",
-    "CSEUCPKDFMTJAPANESE",
-    "JOHAB",
-    "CSHALFWIDTHKATAKANA"
+    "UTF7IMAP",
+    "UTF-7-IMAP",
+    "BIG5-HKSCS:2001",
+    "BIG5-HKSCS:2008",
+    "BIG5-HKSCS:1999",
+    "BIG5-HKSCS:2004",
+    "CSEUCPKDFMTJAPANESE"
   };
 #define stringpool ((const char *) &stringpool_contents)
 
 static const struct alias aliases[] =
   {
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-    {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-#line 134 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str15, ei_iso8859_10},
+#line 290 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str9, ei_iso646_cn},
+#line 211 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str10, ei_cp1131},
+#line 374 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str11, ei_johab},
+    {-1},
+#line 176 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str13, ei_cp1251},
+    {-1},
+#line 191 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str15, ei_cp1256},
+#line 209 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str16, ei_cp866},
+#line 188 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str17, ei_cp1255},
+#line 246 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str18, ei_cp1133},
+#line 207 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str19, ei_cp866},
+    {-1},
+#line 182 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str21, ei_cp1253},
+    {-1},
+#line 179 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str23, ei_cp1252},
+#line 205 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str24, ei_cp862},
+#line 343 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str25, ei_cp936},
+    {-1},
+#line 203 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str27, ei_cp862},
+    {-1}, {-1}, {-1},
+#line 53 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str31, ei_c99},
+    {-1},
+#line 321 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str33, ei_cp932},
+    {-1},
+#line 197 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str35, ei_cp1258},
+    {-1},
+#line 313 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str37, ei_cp51932},
+    {-1}, {-1},
+#line 13 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str40, ei_ascii},
+    {-1}, {-1}, {-1},
+#line 59 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str44, ei_iso8859_1},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+#line 336 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str53, ei_iso2022_jpms},
+    {-1}, {-1}, {-1},
+#line 64 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str57, ei_iso8859_1},
+#line 141 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str58, ei_iso8859_11},
+#line 104 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str59, ei_iso8859_6},
+#line 168 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str60, ei_iso8859_16},
+#line 95 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str61, ei_iso8859_5},
+#line 161 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str62, ei_iso8859_15},
+    {-1}, {-1},
+#line 80 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str65, ei_iso8859_3},
+#line 147 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str66, ei_iso8859_13},
+#line 72 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str67, ei_iso8859_2},
+#line 55 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str68, ei_iso8859_1},
+#line 139 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str69, ei_iso8859_11},
+#line 96 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str70, ei_iso8859_6},
+#line 162 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str71, ei_iso8859_16},
+#line 89 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str72, ei_iso8859_5},
+#line 156 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str73, ei_iso8859_15},
+    {-1}, {-1},
+#line 73 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str76, ei_iso8859_3},
+#line 142 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str77, ei_iso8859_13},
+#line 65 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str78, ei_iso8859_2},
+#line 122 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str79, ei_iso8859_8},
+#line 338 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str80, ei_euc_cn},
+#line 173 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str81, ei_cp1250},
+#line 201 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str82, ei_cp850},
+#line 288 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str83, ei_iso646_cn},
+    {-1},
+#line 130 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str85, ei_iso8859_9},
+#line 199 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str86, ei_cp850},
+    {-1}, {-1},
+#line 361 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str89, ei_cp950},
+#line 116 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str90, ei_iso8859_8},
+#line 337 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str91, ei_euc_cn},
+#line 350 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str92, ei_hz},
+#line 229 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str93, ei_hp_roman8},
+#line 347 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str94, ei_iso2022_cn},
+#line 371 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str95, ei_cp949},
+#line 123 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str96, ei_iso8859_9},
+#line 56 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str97, ei_iso8859_1},
+#line 140 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str98, ei_iso8859_11},
+#line 97 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str99, ei_iso8859_6},
+#line 163 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str100, ei_iso8859_16},
+#line 90 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str101, ei_iso8859_5},
+#line 157 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str102, ei_iso8859_15},
+#line 238 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str103, ei_pt154},
+#line 164 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str104, ei_iso8859_16},
+#line 74 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str105, ei_iso8859_3},
+#line 143 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str106, ei_iso8859_13},
+#line 66 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str107, ei_iso8859_2},
     {-1},
-#line 60 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str17, ei_iso8859_1},
-    {-1}, {-1},
-#line 288 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str20, ei_iso646_cn},
-    {-1}, {-1}, {-1}, {-1},
-#line 84 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str25, ei_iso8859_4},
+#line 185 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str109, ei_cp1254},
+#line 16 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str110, ei_ascii},
     {-1},
-#line 126 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str27, ei_iso8859_9},
+#line 349 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str112, ei_iso2022_cn_ext},
+#line 254 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str113, ei_tis620},
+#line 22 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str114, ei_ascii},
+#line 296 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str115, ei_isoir165},
+#line 158 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str116, ei_iso8859_15},
+#line 109 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str117, ei_iso8859_7},
+    {-1},
+#line 117 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str119, ei_iso8859_8},
     {-1}, {-1},
-#line 227 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str30, ei_hp_roman8},
+#line 165 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str122, ei_iso8859_16},
     {-1}, {-1},
-#line 151 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str33, ei_iso8859_14},
-#line 308 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str34, ei_sjis},
+#line 124 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str125, ei_iso8859_9},
+#line 138 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str126, ei_iso8859_10},
+#line 62 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str127, ei_iso8859_1},
+#line 136 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str128, ei_iso8859_10},
+#line 128 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str129, ei_iso8859_9},
     {-1},
-#line 207 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str36, ei_cp866},
-    {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-#line 68 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str43, ei_iso8859_2},
-    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-#line 16 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str51, ei_ascii},
+#line 78 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str131, ei_iso8859_3},
+#line 70 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str132, ei_iso8859_2},
+#line 293 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str133, ei_gb2312},
     {-1}, {-1},
-#line 205 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str54, ei_cp866},
-    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-#line 51 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str64, ei_c99},
-#line 252 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str65, ei_tis620},
-#line 320 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str66, ei_euc_cn},
+#line 119 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str136, ei_iso8859_8},
+#line 131 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str137, ei_iso8859_10},
+#line 153 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str138, ei_iso8859_14},
+#line 372 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str139, ei_cp949},
+#line 285 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str140, ei_jisx0212},
+#line 339 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str141, ei_euc_cn},
 #line 133 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str67, ei_iso8859_10},
-    {-1}, {-1},
-#line 236 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str70, ei_pt154},
-#line 59 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str71, ei_iso8859_1},
-#line 319 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str72, ei_euc_cn},
-    {-1},
-#line 91 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str74, ei_iso8859_5},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str142, ei_iso8859_10},
     {-1},
-#line 286 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str76, ei_iso646_cn},
+#line 68 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str144, ei_iso8859_2},
     {-1},
-#line 332 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str78, ei_hz},
-#line 264 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str79, ei_iso646_jp},
+#line 348 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str146, ei_iso2022_cn},
     {-1}, {-1}, {-1}, {-1},
-#line 189 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str84, ei_cp1256},
+#line 267 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str151, ei_iso646_jp},
+#line 151 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str152, ei_iso8859_14},
+#line 88 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str153, ei_iso8859_4},
+#line 155 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str154, ei_iso8859_14},
     {-1}, {-1},
-#line 83 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str87, ei_iso8859_4},
-#line 174 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str88, ei_cp1251},
-#line 294 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str89, ei_isoir165},
+#line 159 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str157, ei_iso8859_15},
     {-1},
-#line 125 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str91, ei_iso8859_9},
-#line 203 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str92, ei_cp862},
-#line 107 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str93, ei_iso8859_7},
+#line 61 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str159, ei_iso8859_1},
     {-1},
-#line 90 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str95, ei_iso8859_5},
-#line 57 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str96, ei_iso8859_1},
-    {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+#line 135 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str161, ei_iso8859_10},
 #line 150 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str103, ei_iso8859_14},
-#line 183 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str104, ei_cp1254},
-#line 291 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str105, ei_gb2312},
-#line 353 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str106, ei_cp949},
-    {-1},
-#line 186 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str108, ei_cp1255},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str162, ei_iso8859_14},
+#line 127 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str163, ei_iso8859_9},
+#line 81 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str164, ei_iso8859_4},
+#line 148 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str165, ei_iso8859_14},
+#line 132 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str166, ei_iso8859_10},
+#line 77 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str167, ei_iso8859_3},
     {-1},
-#line 201 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str110, ei_cp862},
-#line 124 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str111, ei_iso8859_9},
+#line 69 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str169, ei_iso8859_2},
+#line 111 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str170, ei_iso8859_7},
+#line 353 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str171, ei_euc_tw},
 #line 76 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str112, ei_iso8859_3},
-#line 158 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str113, ei_iso8859_15},
-#line 293 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str114, ei_gb2312},
-#line 299 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str115, ei_ksc5601},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str172, ei_iso8859_3},
+#line 249 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str173, ei_tis620},
+#line 279 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str174, ei_jisx0208},
+#line 86 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str175, ei_iso8859_4},
+    {-1}, {-1},
+#line 84 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str178, ei_iso8859_4},
+#line 284 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str179, ei_jisx0212},
+#line 126 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str180, ei_iso8859_9},
+#line 152 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str181, ei_iso8859_14},
+#line 352 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str182, ei_euc_tw},
     {-1},
-#line 283 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str117, ei_jisx0212},
+#line 248 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str184, ei_tis620},
     {-1},
-#line 163 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str119, ei_iso8859_16},
-#line 195 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str120, ei_cp1258},
-#line 234 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str121, ei_pt154},
+#line 301 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str186, ei_ksc5601},
+    {-1}, {-1}, {-1},
+#line 241 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str190, ei_rk1048},
     {-1},
-#line 67 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str123, ei_iso8859_2},
-#line 102 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str124, ei_iso8859_6},
+#line 214 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str192, ei_mac_roman},
+#line 82 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str193, ei_iso8859_4},
 #line 149 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str125, ei_iso8859_14},
-    {-1}, {-1},
-#line 62 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str128, ei_iso8859_1},
-#line 152 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str129, ei_iso8859_14},
-#line 94 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str130, ei_iso8859_6},
-#line 95 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str131, ei_iso8859_6},
-#line 166 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str132, ei_iso8859_16},
-    {-1},
-#line 53 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str134, ei_iso8859_1},
-#line 54 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str135, ei_iso8859_1},
-#line 139 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str136, ei_iso8859_11},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str194, ei_iso8859_14},
     {-1},
+#line 167 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str196, ei_iso8859_16},
+#line 276 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str197, ei_jisx0208},
 #line 160 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str138, ei_iso8859_16},
-#line 161 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str139, ei_iso8859_16},
-#line 177 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str140, ei_cp1252},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str198, ei_iso8859_15},
+#line 377 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str199, ei_local_char},
+#line 260 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str200, ei_tcvn},
+    {-1}, {-1},
+#line 271 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str203, ei_jisx0201},
     {-1},
-#line 137 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str142, ei_iso8859_11},
-#line 138 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str143, ei_iso8859_11},
-#line 86 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str144, ei_iso8859_4},
-#line 356 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str145, ei_johab},
-#line 162 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str146, ei_iso8859_16},
-#line 209 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str147, ei_cp1131},
-#line 93 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str148, ei_iso8859_5},
+#line 266 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str205, ei_iso646_jp},
+#line 264 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str206, ei_iso646_jp},
+    {-1}, {-1},
+#line 208 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str209, ei_cp866},
+#line 21 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str210, ei_ascii},
     {-1},
-#line 79 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str150, ei_iso8859_4},
-#line 80 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str151, ei_iso8859_4},
-#line 153 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str152, ei_iso8859_14},
+#line 58 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str212, ei_iso8859_1},
+    {-1},
+#line 344 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str214, ei_cp936},
+    {-1}, {-1},
+#line 204 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str217, ei_cp862},
 #line 325 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str153, ei_cp936},
-#line 87 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str154, ei_iso8859_5},
-#line 88 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str155, ei_iso8859_5},
-#line 159 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str156, ei_iso8859_15},
-#line 212 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str157, ei_mac_roman},
-#line 146 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str158, ei_iso8859_14},
-#line 147 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str159, ei_iso8859_14},
-#line 120 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str160, ei_iso8859_8},
-#line 66 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str161, ei_iso8859_2},
-#line 154 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str162, ei_iso8859_15},
-#line 155 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str163, ei_iso8859_15},
-#line 128 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str164, ei_iso8859_9},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str218, ei_cp932},
+#line 250 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str219, ei_tis620},
+#line 318 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str220, ei_sjis},
     {-1},
-#line 114 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str166, ei_iso8859_8},
-#line 115 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str167, ei_iso8859_8},
+#line 327 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str222, ei_cp932},
     {-1}, {-1},
-#line 121 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str170, ei_iso8859_9},
-#line 122 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str171, ei_iso8859_9},
-#line 148 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str172, ei_iso8859_14},
+#line 277 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str225, ei_jisx0208},
+#line 315 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str226, ei_cp51932},
+#line 154 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str227, ei_iso8859_14},
+#line 166 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str228, ei_iso8859_16},
+#line 236 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str229, ei_pt154},
     {-1},
-#line 156 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str174, ei_iso8859_15},
+#line 332 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str231, ei_iso2022_jp1},
+#line 268 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str232, ei_iso646_jp},
+#line 24 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str233, ei_ucs2},
+#line 60 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str234, ei_iso8859_1},
     {-1},
-#line 239 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str176, ei_rk1048},
+#line 333 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str236, ei_iso2022_jp2},
+#line 286 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str237, ei_jisx0212},
+    {-1},
+#line 257 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str239, ei_viscii},
+#line 346 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str240, ei_gb18030},
+#line 259 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str241, ei_viscii},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+    {-1}, {-1}, {-1},
+#line 92 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str254, ei_iso8859_5},
+#line 85 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str255, ei_iso8859_4},
     {-1}, {-1},
-#line 109 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str179, ei_iso8859_7},
-#line 70 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str180, ei_iso8859_2},
+#line 54 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str258, ei_java},
     {-1},
-#line 206 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str182, ei_cp866},
-#line 144 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str183, ei_iso8859_13},
-#line 21 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str184, ei_ascii},
+#line 25 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str260, ei_ucs2},
+#line 12 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str261, ei_ascii},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+#line 292 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str268, ei_gb2312},
+#line 295 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str269, ei_gb2312},
     {-1},
 #line 63 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str186, ei_iso8859_2},
-#line 64 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str187, ei_iso8859_2},
-    {-1}, {-1},
-#line 282 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str190, ei_jisx0212},
-    {-1}, {-1},
-#line 359 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str193, ei_local_char},
-    {-1}, {-1},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str271, ei_iso8859_1},
+    {-1},
+#line 137 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str273, ei_iso8859_10},
+    {-1},
+#line 129 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str275, ei_iso8859_9},
+#line 200 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str276, ei_cp850},
+    {-1},
+#line 94 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str278, ei_iso8859_5},
+#line 79 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str279, ei_iso8859_3},
+    {-1},
+#line 71 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str281, ei_iso8859_2},
 #line 235 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str196, ei_pt154},
-#line 74 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str197, ei_iso8859_3},
-#line 117 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str198, ei_iso8859_8},
-#line 354 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str199, ei_cp949},
-    {-1}, {-1},
-#line 13 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str202, ei_ascii},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str282, ei_koi8_t},
     {-1},
-#line 176 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str204, ei_cp1251},
-#line 165 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str205, ei_iso8859_16},
-#line 255 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str206, ei_viscii},
-    {-1}, {-1},
+#line 91 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str284, ei_iso8859_5},
 #line 311 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str209, ei_cp932},
-#line 337 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str210, ei_ces_big5},
-#line 258 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str211, ei_tcvn},
-#line 318 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str212, ei_iso2022_jpms},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str285, ei_eucjp_ms},
+#line 75 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str286, ei_iso8859_3},
+#line 334 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str287, ei_iso2022_jp2},
+    {-1}, {-1},
+#line 287 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str290, ei_iso646_cn},
+    {-1}, {-1},
+#line 118 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str293, ei_iso8859_8},
     {-1}, {-1}, {-1},
-#line 338 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str216, ei_ces_big5},
-#line 173 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str217, ei_cp1250},
+#line 298 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str297, ei_ksc5601},
+    {-1},
+#line 125 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str299, ei_iso8859_9},
+#line 255 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str300, ei_cp874},
     {-1}, {-1},
-#line 199 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str220, ei_cp850},
+#line 34 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str303, ei_ucs4},
+#line 335 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str304, ei_iso2022_jpms},
+    {-1}, {-1}, {-1}, {-1},
+#line 354 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str309, ei_euc_tw},
+#line 35 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str310, ei_ucs4},
+#line 103 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str311, ei_iso8859_6},
+#line 177 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str312, ei_cp1251},
+#line 192 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str313, ei_cp1256},
+#line 189 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str314, ei_cp1255},
+#line 146 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str315, ei_iso8859_13},
+#line 183 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str316, ei_cp1253},
+#line 180 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str317, ei_cp1252},
     {-1},
 #line 33 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str222, ei_ucs4},
-#line 22 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str223, ei_ascii},
-#line 58 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str224, ei_iso8859_1},
-#line 257 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str225, ei_viscii},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str319, ei_ucs4},
+#line 181 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str320, ei_cp1252},
     {-1},
-#line 321 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str227, ei_euc_cn},
-#line 269 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str228, ei_jisx0201},
-#line 342 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str229, ei_ces_big5},
-    {-1}, {-1}, {-1}, {-1}, {-1},
-#line 341 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str235, ei_ces_big5},
-#line 167 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str236, ei_koi8_r},
-#line 351 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str237, ei_euc_kr},
-#line 202 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str238, ei_cp862},
-#line 238 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str239, ei_pt154},
-#line 35 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str240, ei_ucs4},
-#line 14 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str241, ei_ascii},
-#line 253 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str242, ei_cp874},
-#line 350 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str243, ei_euc_kr},
-#line 256 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str244, ei_viscii},
+#line 323 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str322, ei_cp932},
+#line 198 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str323, ei_cp1258},
+#line 345 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str324, ei_cp936},
+#line 110 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str325, ei_iso8859_7},
+#line 144 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str326, ei_iso8859_13},
+#line 314 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str327, ei_cp51932},
     {-1},
-#line 15 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str246, ei_ascii},
+#line 378 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str329, ei_local_wchar_t},
+#line 83 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str330, ei_iso8859_4},
+#line 244 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str331, ei_rk1048},
+#line 326 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str332, ei_cp932},
     {-1},
-#line 218 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str248, ei_mac_cyrillic},
-#line 168 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str249, ei_koi8_r},
-#line 197 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str250, ei_cp850},
-#line 82 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str251, ei_iso8859_4},
-#line 343 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str252, ei_cp950},
+#line 243 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str334, ei_rk1048},
+#line 30 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str335, ei_ucs2be},
+#line 226 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str336, ei_mac_thai},
+#line 232 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str337, ei_armscii_8},
+#line 93 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str338, ei_iso8859_5},
+#line 228 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str339, ei_hp_roman8},
     {-1},
-#line 329 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str254, ei_iso2022_cn},
-#line 295 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str255, ei_isoir165},
+#line 305 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str341, ei_euc_jp},
+    {-1}, {-1},
+#line 265 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str344, ei_iso646_jp},
     {-1},
-#line 237 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str257, ei_pt154},
-#line 24 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str258, ei_ucs2},
-#line 164 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str259, ei_iso8859_16},
-#line 275 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str260, ei_jisx0208},
-#line 75 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str261, ei_iso8859_3},
+#line 174 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str346, ei_cp1250},
+#line 247 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str347, ei_cp1133},
+#line 29 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str348, ei_ucs2be},
+#line 14 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str349, ei_ascii},
     {-1},
+#line 281 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str351, ei_jisx0212},
+#line 304 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str352, ei_euc_jp},
+    {-1},
+#line 322 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str354, ei_cp932},
 #line 330 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str263, ei_iso2022_cn},
-#line 131 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str264, ei_iso8859_10},
-    {-1}, {-1},
-#line 37 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str267, ei_ucs4le},
-#line 171 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str268, ei_cp1250},
-    {-1}, {-1},
-#line 135 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str271, ei_iso8859_10},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str355, ei_iso2022_jp},
     {-1},
-#line 142 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str273, ei_iso8859_13},
-#line 326 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str274, ei_cp936},
-#line 61 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str275, ei_iso8859_1},
-#line 247 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str276, ei_tis620},
+#line 237 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str357, ei_pt154},
     {-1},
-#line 180 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str278, ei_cp1253},
-    {-1}, {-1},
-#line 331 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str281, ei_iso2022_cn_ext},
-#line 246 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str282, ei_tis620},
+#line 38 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str359, ei_utf16},
+#line 186 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str360, ei_cp1254},
     {-1}, {-1},
-#line 31 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str285, ei_ucs2le},
-#line 233 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str286, ei_koi8_t},
+#line 102 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str363, ei_iso8859_6},
+#line 324 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str364, ei_cp932},
+#line 270 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str365, ei_jisx0201},
+#line 300 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str366, ei_ksc5601},
+#line 87 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str367, ei_iso8859_4},
     {-1}, {-1}, {-1},
-#line 92 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str290, ei_iso8859_5},
-#line 85 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str291, ei_iso8859_4},
+#line 41 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str371, ei_utf32},
     {-1}, {-1}, {-1},
-#line 127 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str295, ei_iso8859_9},
-#line 29 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str296, ei_ucs2be},
-    {-1}, {-1}, {-1}, {-1},
-#line 110 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str301, ei_iso8859_7},
-#line 49 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str302, ei_ucs4internal},
+#line 269 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str375, ei_jisx0201},
+    {-1}, {-1},
+#line 23 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str378, ei_utf8},
     {-1},
-#line 30 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str304, ei_ucs2be},
+#line 240 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str380, ei_pt154},
     {-1},
-#line 26 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str306, ei_ucs2},
-#line 249 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str307, ei_tis620},
-    {-1}, {-1}, {-1},
-#line 229 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str311, ei_nextstep},
-#line 232 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str312, ei_georgian_ps},
-    {-1}, {-1}, {-1},
-#line 136 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str316, ei_iso8859_10},
+#line 253 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str382, ei_tis620},
     {-1},
-#line 78 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str318, ei_iso8859_3},
+#line 206 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str384, ei_cp862},
+#line 218 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str385, ei_mac_croatian},
+#line 19 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str386, ei_ascii},
+#line 175 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str387, ei_cp1250},
     {-1},
-#line 47 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str320, ei_ucs2internal},
+#line 194 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str389, ei_cp1257},
     {-1},
-#line 129 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str322, ei_iso8859_10},
-#line 130 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str323, ei_iso8859_10},
-#line 71 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str324, ei_iso8859_3},
-#line 72 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str325, ei_iso8859_3},
-#line 145 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str326, ei_iso8859_13},
-#line 69 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str327, ei_iso8859_2},
+#line 170 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str391, ei_koi8_r},
     {-1},
-#line 285 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str329, ei_iso646_cn},
-    {-1}, {-1},
-#line 140 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str332, ei_iso8859_13},
-#line 141 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str333, ei_iso8859_13},
-    {-1}, {-1}, {-1},
-#line 244 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str337, ei_cp1133},
+#line 251 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str393, ei_tis620},
+#line 26 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str394, ei_ucs2},
+#line 283 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str395, ei_jisx0212},
     {-1},
-#line 179 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str339, ei_cp1252},
+#line 273 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str397, ei_jisx0208},
     {-1},
-#line 56 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str341, ei_iso8859_1},
-    {-1}, {-1},
-#line 296 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str344, ei_ksc5601},
-    {-1}, {-1}, {-1}, {-1},
-#line 211 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str349, ei_mac_roman},
-    {-1}, {-1},
-#line 322 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str352, ei_euc_cn},
+#line 100 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str399, ei_iso8859_6},
+#line 169 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str400, ei_koi8_r},
     {-1},
-#line 208 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str354, ei_cp866},
-#line 34 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str355, ei_ucs4},
+#line 121 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str402, ei_iso8859_8},
     {-1},
-#line 81 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str357, ei_iso8859_4},
+#line 262 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str404, ei_tcvn},
+#line 274 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str405, ei_jisx0208},
     {-1},
-#line 89 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str359, ei_iso8859_5},
+#line 331 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str407, ei_iso2022_jp},
+#line 261 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str408, ei_tcvn},
+#line 303 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str409, ei_ksc5601},
     {-1},
-#line 38 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str361, ei_utf16},
+#line 355 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str411, ei_ces_big5},
     {-1},
-#line 241 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str363, ei_rk1048},
-#line 226 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str364, ei_hp_roman8},
-#line 116 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str365, ei_iso8859_8},
-#line 32 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str366, ei_ucs2le},
-    {-1}, {-1},
-#line 123 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str369, ei_iso8859_9},
+#line 360 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str413, ei_ces_big5},
     {-1}, {-1},
-#line 265 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str372, ei_iso646_jp},
-#line 25 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str373, ei_ucs2},
+#line 252 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str416, ei_tis620},
+#line 233 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str417, ei_georgian_academy},
+    {-1}, {-1}, {-1}, {-1},
+#line 356 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str422, ei_ces_big5},
     {-1},
-#line 243 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str375, ei_mulelao},
-#line 242 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str376, ei_rk1048},
-#line 157 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str377, ei_iso8859_15},
-#line 198 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str378, ei_cp850},
+#line 359 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str424, ei_ces_big5},
+    {-1}, {-1}, {-1}, {-1}, {-1},
+#line 341 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str430, ei_euc_cn},
+#line 309 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str431, ei_eucjp_ms},
     {-1},
-#line 248 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str380, ei_tis620},
+#line 115 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str433, ei_iso8859_7},
     {-1},
+#line 275 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str435, ei_jisx0208},
+#line 227 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str436, ei_hp_roman8},
+    {-1}, {-1},
+#line 369 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str439, ei_euc_kr},
+    {-1}, {-1}, {-1}, {-1},
+#line 105 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str444, ei_iso8859_7},
+    {-1}, {-1}, {-1}, {-1}, {-1},
+#line 368 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str450, ei_euc_kr},
+    {-1}, {-1},
+#line 375 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str453, ei_iso2022_kr},
+    {-1}, {-1}, {-1}, {-1}, {-1},
+#line 57 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str459, ei_iso8859_1},
 #line 98 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str382, ei_iso8859_6},
-    {-1}, {-1}, {-1},
-#line 298 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str386, ei_ksc5601},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str460, ei_iso8859_6},
+    {-1}, {-1},
+#line 108 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str463, ei_iso8859_7},
+#line 67 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str464, ei_iso8859_2},
     {-1},
-#line 324 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str388, ei_ces_gbk},
-#line 23 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str389, ei_utf8},
+#line 213 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str466, ei_mac_roman},
     {-1},
-#line 230 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str391, ei_armscii_8},
-#line 12 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str392, ei_ascii},
-    {-1}, {-1}, {-1}, {-1}, {-1},
-#line 108 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str398, ei_iso8859_7},
-#line 323 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str399, ei_euc_cn},
-    {-1}, {-1}, {-1},
-#line 143 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str403, ei_iso8859_13},
-#line 301 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str404, ei_ksc5601},
-#line 287 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str405, ei_iso646_cn},
-    {-1}, {-1},
-#line 188 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str408, ei_cp1255},
-#line 266 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str409, ei_iso646_jp},
+#line 239 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str468, ei_pt154},
+    {-1}, {-1}, {-1}, {-1},
+#line 106 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str473, ei_iso8859_7},
     {-1},
-#line 276 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str411, ei_jisx0208},
+#line 258 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str475, ei_viscii},
     {-1},
-#line 132 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str413, ei_iso8859_10},
-    {-1}, {-1},
-#line 40 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str416, ei_utf16le},
+#line 31 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str477, ei_ucs2le},
     {-1},
-#line 36 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str418, ei_ucs4be},
+#line 112 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str479, ei_iso8859_7},
+    {-1}, {-1}, {-1}, {-1},
+#line 317 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str484, ei_sjis},
     {-1},
-#line 192 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str420, ei_cp1257},
-#line 18 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str421, ei_ascii},
+#line 101 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str486, ei_iso8859_6},
+#line 289 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str487, ei_iso646_cn},
+#line 134 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str488, ei_iso8859_10},
     {-1}, {-1},
-#line 352 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str424, ei_euc_kr},
-#line 357 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str425, ei_iso2022_kr},
-#line 290 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str426, ei_gb2312},
+#line 99 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str491, ei_iso8859_6},
     {-1}, {-1},
-#line 97 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str429, ei_iso8859_6},
-#line 224 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str430, ei_mac_thai},
-#line 335 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str431, ei_euc_tw},
-    {-1},
-#line 304 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str433, ei_euc_jp},
-#line 358 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str434, ei_iso2022_kr},
+#line 329 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str494, ei_cp932},
     {-1},
-#line 27 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str436, ei_ucs2be},
-#line 334 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str437, ei_euc_tw},
+#line 278 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str496, ei_jisx0208},
     {-1},
-#line 17 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str439, ei_ascii},
-#line 111 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str440, ei_iso8859_7},
+#line 210 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str498, ei_cp866},
     {-1},
+#line 195 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str500, ei_cp1257},
+    {-1}, {-1},
 #line 215 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str442, ei_mac_iceland},
-#line 328 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str443, ei_gb18030},
-#line 73 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str444, ei_iso8859_3},
-#line 101 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str445, ei_iso8859_6},
-#line 231 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str446, ei_georgian_academy},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str503, ei_mac_roman},
     {-1},
-#line 225 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str448, ei_hp_roman8},
+#line 376 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str505, ei_iso2022_kr},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+#line 171 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str512, ei_koi8_u},
+#line 316 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str513, ei_sjis},
+#line 319 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str514, ei_sjis},
+#line 212 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str515, ei_mac_roman},
+    {-1}, {-1}, {-1}, {-1},
+#line 37 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str520, ei_ucs4le},
     {-1}, {-1}, {-1}, {-1},
-#line 251 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str453, ei_tis620},
+#line 242 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str525, ei_rk1048},
     {-1},
-#line 28 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str455, ei_ucs2be},
-    {-1}, {-1}, {-1},
-#line 260 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str459, ei_tcvn},
-#line 113 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str460, ei_iso8859_7},
-#line 289 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str461, ei_iso646_cn},
+#line 46 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str527, ei_utf7},
+    {-1}, {-1}, {-1}, {-1},
+#line 220 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str532, ei_mac_cyrillic},
+    {-1}, {-1},
+#line 145 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str535, ei_iso8859_13},
+#line 351 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str536, ei_hz},
+#line 302 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str537, ei_ksc5601},
+#line 178 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str538, ei_cp1251},
     {-1},
-#line 214 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str463, ei_mac_centraleurope},
-#line 112 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str464, ei_iso8859_7},
-#line 77 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str465, ei_iso8859_3},
-#line 103 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str466, ei_iso8859_7},
-#line 104 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str467, ei_iso8859_7},
+#line 299 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str540, ei_ksc5601},
+#line 49 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str541, ei_ucs2internal},
 #line 45 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str468, ei_utf7},
-#line 19 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str469, ei_ascii},
-#line 333 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str470, ei_hz},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str542, ei_utf7},
     {-1}, {-1},
-#line 303 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str473, ei_euc_jp},
-#line 46 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str474, ei_utf7},
+#line 342 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str545, ei_ces_gbk},
+#line 294 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str546, ei_gb2312},
+    {-1}, {-1}, {-1},
+#line 312 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str550, ei_eucjp_ms},
+#line 280 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str551, ei_jisx0208},
     {-1},
-#line 210 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str476, ei_mac_roman},
-#line 259 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str477, ei_tcvn},
+#line 230 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str553, ei_hp_roman8},
+#line 245 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str554, ei_mulelao},
+    {-1}, {-1}, {-1},
+#line 32 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str558, ei_ucs2le},
+#line 320 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str559, ei_sjis},
     {-1},
-#line 302 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str479, ei_euc_jp},
+#line 308 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str561, ei_eucjp_ms},
+    {-1}, {-1}, {-1}, {-1}, {-1},
+#line 15 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str567, ei_ascii},
+    {-1}, {-1}, {-1}, {-1},
+#line 310 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str572, ei_eucjp_ms},
     {-1}, {-1}, {-1},
+#line 20 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str576, ei_ascii},
+#line 370 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str577, ei_euc_kr},
+    {-1}, {-1},
+#line 219 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str580, ei_mac_romania},
+    {-1},
 #line 263 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str483, ei_iso646_jp},
-    {-1}, {-1}, {-1}, {-1}, {-1},
-#line 348 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str489, ei_big5hkscs2008},
-#line 292 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str490, ei_gb2312},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str582, ei_tcvn},
     {-1},
-#line 190 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str492, ei_cp1256},
+#line 51 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str584, ei_ucs4internal},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+#line 297 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str591, ei_isoir165},
     {-1},
-#line 175 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str494, ei_cp1251},
-#line 347 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str495, ei_big5hkscs2008},
-#line 360 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str496, ei_local_wchar_t},
-#line 96 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str497, ei_iso8859_6},
+#line 172 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str593, ei_koi8_ru},
+    {-1}, {-1}, {-1}, {-1}, {-1},
+#line 256 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str599, ei_cp874},
     {-1},
-#line 55 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str499, ei_iso8859_1},
+#line 231 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str601, ei_nextstep},
+#line 120 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str602, ei_iso8859_8},
+#line 18 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str603, ei_ascii},
+#line 114 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str604, ei_iso8859_7},
     {-1}, {-1},
-#line 184 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str502, ei_cp1254},
+#line 40 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str607, ei_utf16le},
+#line 282 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str608, ei_jisx0212},
+    {-1}, {-1}, {-1}, {-1},
+#line 17 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str613, ei_ascii},
     {-1},
-#line 187 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str504, ei_cp1255},
-    {-1}, {-1}, {-1}, {-1}, {-1},
-#line 196 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str510, ei_cp1258},
+#line 43 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str615, ei_utf32le},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
     {-1},
-#line 41 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str512, ei_utf32},
+#line 225 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str635, ei_mac_arabic},
     {-1}, {-1}, {-1},
-#line 119 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str516, ei_iso8859_8},
-#line 228 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str517, ei_hp_roman8},
-    {-1},
-#line 284 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str519, ei_jisx0212},
-#line 178 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str520, ei_cp1252},
+#line 27 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str639, ei_ucs2be},
+    {-1}, {-1}, {-1}, {-1}, {-1},
+#line 234 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str645, ei_georgian_ps},
     {-1},
-#line 240 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str522, ei_rk1048},
-    {-1}, {-1},
-#line 65 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str525, ei_iso8859_2},
-    {-1}, {-1}, {-1},
-#line 100 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str529, ei_iso8859_6},
-#line 213 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str530, ei_mac_roman},
-    {-1}, {-1}, {-1},
-#line 297 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str534, ei_ksc5601},
+#line 107 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str647, ei_iso8859_7},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+#line 216 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str656, ei_mac_centraleurope},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
     {-1},
-#line 262 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str536, ei_iso646_jp},
-#line 277 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str537, ei_jisx0208},
+#line 217 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str667, ei_mac_iceland},
     {-1},
-#line 43 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str539, ei_utf32le},
+#line 113 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str669, ei_iso8859_7},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
     {-1}, {-1}, {-1},
-#line 250 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str543, ei_tis620},
+#line 36 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str682, ei_ucs4be},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
     {-1}, {-1},
-#line 245 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str546, ei_cp1133},
-#line 307 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str547, ei_sjis},
-#line 306 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str548, ei_sjis},
-    {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-#line 204 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str555, ei_cp862},
+#line 291 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str703, ei_iso646_cn},
     {-1},
 #line 340 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str557, ei_ces_big5},
-    {-1}, {-1},
-#line 300 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str560, ei_ksc5601},
-    {-1},
-#line 216 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str562, ei_mac_croatian},
-#line 339 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str563, ei_ces_big5},
-    {-1}, {-1},
-#line 327 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str566, ei_cp936},
-#line 39 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str567, ei_utf16be},
-    {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-#line 169 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str574, ei_koi8_u},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str705, ei_euc_cn},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+#line 328 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str715, ei_cp932},
     {-1}, {-1}, {-1}, {-1}, {-1},
-#line 170 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str580, ei_koi8_ru},
-    {-1}, {-1}, {-1},
-#line 172 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str584, ei_cp1250},
-#line 182 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str585, ei_cp1253},
-    {-1}, {-1}, {-1},
-#line 181 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str589, ei_cp1253},
-    {-1},
-#line 220 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str591, ei_mac_greek},
-#line 200 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str592, ei_cp850},
-    {-1},
-#line 106 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str594, ei_iso8859_7},
+#line 373 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str721, ei_johab},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
     {-1},
-#line 274 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str596, ei_jisx0208},
-#line 20 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str597, ei_ascii},
+#line 44 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str732, ei_utf7},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+#line 306 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str739, ei_euc_jp},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+#line 50 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str767, ei_ucs2swapped},
     {-1},
-#line 314 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str608, ei_iso2022_jp1},
+#line 39 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str769, ei_utf16be},
+#line 272 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str770, ei_jisx0201},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+#line 42 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str777, ei_utf32be},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
     {-1},
-#line 317 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str610, ei_iso2022_jpms},
-    {-1}, {-1},
-#line 279 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str613, ei_jisx0212},
-    {-1}, {-1}, {-1}, {-1},
-#line 336 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str618, ei_euc_tw},
+#line 202 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str788, ei_cp850},
+    {-1}, {-1}, {-1},
+#line 221 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str792, ei_mac_ukraine},
     {-1}, {-1}, {-1}, {-1}, {-1},
-#line 310 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str624, ei_sjis},
-#line 118 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str625, ei_iso8859_8},
+#line 190 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str798, ei_cp1255},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+    {-1}, {-1},
+#line 52 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str810, ei_ucs4swapped},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-#line 315 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str634, ei_iso2022_jp2},
-#line 99 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str635, ei_iso8859_6},
-    {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-#line 316 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str642, ei_iso2022_jp2},
+#line 28 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str846, ei_ucs2be},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-#line 267 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str651, ei_jisx0201},
-    {-1}, {-1}, {-1},
-#line 254 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str655, ei_cp874},
-    {-1}, {-1}, {-1}, {-1},
-#line 193 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str660, ei_cp1257},
-#line 312 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str661, ei_iso2022_jp},
-    {-1}, {-1}, {-1},
-#line 105 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str665, ei_iso8859_7},
-#line 278 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str666, ei_jisx0208},
-    {-1}, {-1}, {-1},
-#line 313 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str670, ei_iso2022_jp},
+#line 224 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str855, ei_mac_hebrew},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-#line 223 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str680, ei_mac_arabic},
-    {-1}, {-1},
-#line 271 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str683, ei_jisx0208},
-#line 268 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str684, ei_jisx0201},
     {-1}, {-1}, {-1}, {-1},
-#line 44 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str689, ei_utf7},
-#line 42 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str690, ei_utf32be},
+#line 187 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str869, ei_cp1254},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
     {-1},
-#line 345 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str692, ei_big5hkscs2001},
+#line 223 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str889, ei_mac_turkish},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+#line 358 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str898, ei_ces_big5},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
     {-1},
-#line 281 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str694, ei_jisx0212},
+#line 357 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str909, ei_ces_big5},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+#line 366 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str927, ei_big5hkscs2008},
     {-1}, {-1},
-#line 280 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str697, ei_jisx0212},
+#line 193 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str930, ei_cp1256},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+#line 365 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str938, ei_big5hkscs2008},
     {-1}, {-1},
-#line 346 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str700, ei_big5hkscs2004},
-    {-1},
-#line 221 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str702, ei_mac_turkish},
-    {-1}, {-1}, {-1}, {-1}, {-1},
-#line 349 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str708, ei_big5hkscs2008},
-    {-1},
-#line 344 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str710, ei_big5hkscs1999},
+#line 222 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str941, ei_mac_greek},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+#line 184 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str951, ei_cp1253},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-    {-1}, {-1}, {-1}, {-1}, {-1},
-#line 185 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str725, ei_cp1254},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-#line 50 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str732, ei_ucs4swapped},
+#line 196 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str985, ei_cp1257},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-#line 219 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str749, ei_mac_ukraine},
 #line 48 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str750, ei_ucs2swapped},
-    {-1},
-#line 261 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str752, ei_tcvn},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str1013, ei_utf7imap},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
     {-1}, {-1}, {-1},
-#line 273 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str774, ei_jisx0208},
+#line 47 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str1035, ei_utf7imap},
     {-1}, {-1}, {-1}, {-1},
-#line 272 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str779, ei_jisx0208},
+#line 363 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str1040, ei_big5hkscs2001},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-#line 222 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str796, ei_mac_hebrew},
-    {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-#line 191 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str803, ei_cp1256},
-    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-#line 52 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str811, ei_java},
     {-1},
-#line 217 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str813, ei_mac_romania},
-    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-    {-1}, {-1}, {-1}, {-1},
-#line 309 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str827, ei_sjis},
+#line 367 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str1051, ei_big5hkscs2008},
+    {-1}, {-1},
+#line 362 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str1054, ei_big5hkscs1999},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-#line 194 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str837, ei_cp1257},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+#line 364 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str1088, ei_big5hkscs2004},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-    {-1},
-#line 305 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str866, ei_euc_jp},
-    {-1}, {-1},
-#line 355 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str869, ei_johab},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-    {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-#line 270 "lib/aliases.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str921, ei_jisx0201}
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+#line 307 "lib/aliases.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str1151, ei_euc_jp}
   };
 
 #ifdef __GNUC__
 __inline
-#if defined __GNUC_STDC_INLINE__ || defined __GNUC_GNU_INLINE__
+#ifdef __GNUC_STDC_INLINE__
 __attribute__ ((__gnu_inline__))
 #endif
 #endif
diff -uprN libiconv-1.15-old/lib/aliases_sysaix.gperf libiconv-1.15/lib/aliases_sysaix.gperf
--- libiconv-1.15-old/lib/aliases_sysaix.gperf	2017-01-02 08:03:01.000000000 +0900
+++ libiconv-1.15/lib/aliases_sysaix.gperf	2017-09-17 06:32:19.707838000 +0900
@@ -44,6 +44,8 @@ UTF-32LE, ei_utf32le
 UTF-7, ei_utf7
 UNICODE-1-1-UTF-7, ei_utf7
 CSUNICODE11UTF7, ei_utf7
+UTF-7-IMAP, ei_utf7imap
+UTF7IMAP, ei_utf7imap
 UCS-2-INTERNAL, ei_ucs2internal
 UCS-2-SWAPPED, ei_ucs2swapped
 UCS-4-INTERNAL, ei_ucs4internal
@@ -308,12 +310,28 @@ EUCJP, ei_euc_jp
 EXTENDED_UNIX_CODE_PACKED_FORMAT_FOR_JAPANESE, ei_euc_jp
 CSEUCPKDFMTJAPANESE, ei_euc_jp
 IBM-EUCJP, ei_euc_jp
+EUCJP-MS, ei_eucjp_ms
+EUCJP-OPEN, ei_eucjp_ms
+EUC-JP-MS, ei_eucjp_ms
+EUCJP-WIN, ei_eucjp_ms
+EUCJPMS, ei_eucjp_ms
+CP51932, ei_cp51932
+WINDOWS-51932, ei_cp51932
+MS51932, ei_cp51932
 SHIFT_JIS, ei_sjis
 SHIFT-JIS, ei_sjis
 SJIS, ei_sjis
 MS_KANJI, ei_sjis
 CSSHIFTJIS, ei_sjis
 CP932, ei_cp932
+WINDOWS-31J, ei_cp932
+CSWINDOWS31J, ei_cp932
+SJIS-OPEN, ei_cp932
+SJIS-WIN, ei_cp932
+WINDOWS-932, ei_cp932
+MS932, ei_cp932
+SHIFT_JIS-MS, ei_cp932
+SJIS-MS, ei_cp932
 IBM-932, ei_cp932
 ISO-2022-JP, ei_iso2022_jp
 CSISO2022JP, ei_iso2022_jp
diff -uprN libiconv-1.15-old/lib/aliases_sysaix.h libiconv-1.15/lib/aliases_sysaix.h
--- libiconv-1.15-old/lib/aliases_sysaix.h	2017-01-02 08:03:01.000000000 +0900
+++ libiconv-1.15/lib/aliases_sysaix.h	2017-09-17 06:32:20.009800000 +0900
@@ -1,4 +1,4 @@
-/* ANSI-C code produced by gperf version 3.0.4 */
+/* ANSI-C code produced by gperf version 3.0.3 */
 /* Command-line: gperf -m 10 lib/aliases_sysaix.gperf  */
 /* Computed positions: -k'1,3-11,$' */
 
@@ -32,12 +32,12 @@
 #line 1 "lib/aliases_sysaix.gperf"
 struct alias { int name; unsigned int encoding_index; };
 
-#define TOTAL_KEYWORDS 358
+#define TOTAL_KEYWORDS 376
 #define MIN_WORD_LENGTH 2
 #define MAX_WORD_LENGTH 45
-#define MIN_HASH_VALUE 5
-#define MAX_HASH_VALUE 1039
-/* maximum key range = 1035, duplicates = 0 */
+#define MIN_HASH_VALUE 9
+#define MAX_HASH_VALUE 1067
+/* maximum key range = 1059, duplicates = 0 */
 
 #ifdef __GNUC__
 __inline
@@ -51,19 +51,19 @@ aliases_hash (register const char *str,
 {
   static const unsigned short asso_values[] =
     {
-      1040, 1040, 1040, 1040, 1040, 1040, 1040, 1040, 1040, 1040,
-      1040, 1040, 1040, 1040, 1040, 1040, 1040, 1040, 1040, 1040,
-      1040, 1040, 1040, 1040, 1040, 1040, 1040, 1040, 1040, 1040,
-      1040, 1040, 1040, 1040, 1040, 1040, 1040, 1040, 1040, 1040,
-      1040, 1040, 1040, 1040, 1040,    0,  174, 1040,   44,    2,
-        16,   28,    9,   13,    5,  188,   20,    0,  170, 1040,
-      1040, 1040, 1040, 1040, 1040,    9,  191,    2,   19,   65,
-       140,   65,   42,   88,  376,  199,    6,  206,    3,    0,
-        52, 1040,    0,   11,  118,   97,   59,  189,  220,   13,
-         4, 1040, 1040, 1040, 1040,    1, 1040, 1040, 1040, 1040,
-      1040, 1040, 1040, 1040, 1040, 1040, 1040, 1040, 1040, 1040,
-      1040, 1040, 1040, 1040, 1040, 1040, 1040, 1040, 1040, 1040,
-      1040, 1040, 1040, 1040, 1040, 1040, 1040, 1040
+      1068, 1068, 1068, 1068, 1068, 1068, 1068, 1068, 1068, 1068,
+      1068, 1068, 1068, 1068, 1068, 1068, 1068, 1068, 1068, 1068,
+      1068, 1068, 1068, 1068, 1068, 1068, 1068, 1068, 1068, 1068,
+      1068, 1068, 1068, 1068, 1068, 1068, 1068, 1068, 1068, 1068,
+      1068, 1068, 1068, 1068, 1068,    6,   41, 1068,   53,    3,
+        11,   10,  111,    7,    4,  229,   13,   29,  136, 1068,
+      1068, 1068, 1068, 1068, 1068,  124,  201,    4,  165,   87,
+        66,   35,  163,    3,   30,  210,    8,  120,    3,    3,
+       107, 1068,  103,   12,   35,  112,   93,   94,  228,    8,
+        11, 1068, 1068, 1068, 1068,  191, 1068, 1068, 1068, 1068,
+      1068, 1068, 1068, 1068, 1068, 1068, 1068, 1068, 1068, 1068,
+      1068, 1068, 1068, 1068, 1068, 1068, 1068, 1068, 1068, 1068,
+      1068, 1068, 1068, 1068, 1068, 1068, 1068, 1068
     };
   register int hval = len;
 
@@ -106,1649 +106,1741 @@ aliases_hash (register const char *str,
 
 struct stringpool_t
   {
-    char stringpool_str5[sizeof("C99")];
-    char stringpool_str7[sizeof("CN")];
-    char stringpool_str10[sizeof("L1")];
-    char stringpool_str13[sizeof("L6")];
-    char stringpool_str15[sizeof("CHAR")];
-    char stringpool_str16[sizeof("CP949")];
-    char stringpool_str17[sizeof("L4")];
-    char stringpool_str21[sizeof("L5")];
-    char stringpool_str22[sizeof("R8")];
-    char stringpool_str24[sizeof("L2")];
-    char stringpool_str28[sizeof("L8")];
-    char stringpool_str29[sizeof("CP819")];
-    char stringpool_str33[sizeof("866")];
-    char stringpool_str36[sizeof("L3")];
-    char stringpool_str40[sizeof("CP154")];
-    char stringpool_str42[sizeof("CP866")];
-    char stringpool_str43[sizeof("CP1251")];
-    char stringpool_str44[sizeof("CP1131")];
-    char stringpool_str45[sizeof("CP936")];
-    char stringpool_str47[sizeof("CP1361")];
-    char stringpool_str48[sizeof("HZ")];
-    char stringpool_str49[sizeof("CP1256")];
-    char stringpool_str55[sizeof("862")];
-    char stringpool_str57[sizeof("CP1254")];
-    char stringpool_str64[sizeof("CP862")];
-    char stringpool_str65[sizeof("CP1255")];
-    char stringpool_str67[sizeof("CP932")];
-    char stringpool_str71[sizeof("CP1252")];
-    char stringpool_str79[sizeof("CP1258")];
-    char stringpool_str80[sizeof("EUCCN")];
-    char stringpool_str81[sizeof("EUC-CN")];
-    char stringpool_str90[sizeof("PT154")];
-    char stringpool_str95[sizeof("CP1253")];
-    char stringpool_str96[sizeof("CP1133")];
-    char stringpool_str97[sizeof("L10")];
-    char stringpool_str101[sizeof("RK1048")];
-    char stringpool_str102[sizeof("CP50221")];
-    char stringpool_str104[sizeof("UHC")];
-    char stringpool_str108[sizeof("CP950")];
-    char stringpool_str110[sizeof("US")];
-    char stringpool_str111[sizeof("850")];
-    char stringpool_str124[sizeof("ISO646-CN")];
-    char stringpool_str125[sizeof("SJIS")];
-    char stringpool_str127[sizeof("CP1250")];
-    char stringpool_str128[sizeof("CP850")];
-    char stringpool_str131[sizeof("UCS-4")];
-    char stringpool_str136[sizeof("CSUCS4")];
-    char stringpool_str145[sizeof("UCS-2")];
-    char stringpool_str146[sizeof("PTCP154")];
-    char stringpool_str149[sizeof("GB2312")];
-    char stringpool_str150[sizeof("ISO8859-9")];
-    char stringpool_str151[sizeof("ISO-8859-9")];
-    char stringpool_str152[sizeof("ISO_8859-9")];
-    char stringpool_str154[sizeof("ISO8859-1")];
-    char stringpool_str155[sizeof("ISO-8859-1")];
-    char stringpool_str156[sizeof("ISO_8859-1")];
-    char stringpool_str157[sizeof("ISO8859-11")];
-    char stringpool_str158[sizeof("ISO-8859-11")];
-    char stringpool_str159[sizeof("ISO_8859-11")];
-    char stringpool_str160[sizeof("ISO8859-6")];
-    char stringpool_str161[sizeof("ISO-8859-6")];
-    char stringpool_str162[sizeof("ISO_8859-6")];
-    char stringpool_str163[sizeof("ISO8859-16")];
-    char stringpool_str164[sizeof("ISO-8859-16")];
-    char stringpool_str165[sizeof("ISO_8859-16")];
-    char stringpool_str167[sizeof("ISO_8859-16:2001")];
-    char stringpool_str168[sizeof("ISO8859-4")];
-    char stringpool_str169[sizeof("ISO-8859-4")];
-    char stringpool_str170[sizeof("ISO_8859-4")];
-    char stringpool_str171[sizeof("ISO8859-14")];
-    char stringpool_str172[sizeof("ISO-8859-14")];
-    char stringpool_str173[sizeof("ISO_8859-14")];
-    char stringpool_str176[sizeof("ISO8859-5")];
-    char stringpool_str177[sizeof("ISO-8859-5")];
-    char stringpool_str178[sizeof("ISO_8859-5")];
-    char stringpool_str179[sizeof("ISO8859-15")];
-    char stringpool_str180[sizeof("ISO-8859-15")];
-    char stringpool_str181[sizeof("ISO_8859-15")];
-    char stringpool_str182[sizeof("ISO8859-2")];
-    char stringpool_str183[sizeof("ISO-8859-2")];
-    char stringpool_str184[sizeof("ISO_8859-2")];
-    char stringpool_str187[sizeof("TCVN")];
-    char stringpool_str188[sizeof("ISO-IR-199")];
-    char stringpool_str189[sizeof("ISO_8859-14:1998")];
-    char stringpool_str190[sizeof("ISO8859-8")];
-    char stringpool_str191[sizeof("ISO-8859-8")];
-    char stringpool_str192[sizeof("ISO_8859-8")];
-    char stringpool_str193[sizeof("ISO_8859-15:1998")];
-    char stringpool_str194[sizeof("ISO-IR-6")];
-    char stringpool_str196[sizeof("L7")];
-    char stringpool_str197[sizeof("ISO-IR-149")];
-    char stringpool_str199[sizeof("ISO-2022-CN")];
-    char stringpool_str201[sizeof("ISO-IR-159")];
-    char stringpool_str202[sizeof("CYRILLIC")];
-    char stringpool_str203[sizeof("ISO-IR-166")];
-    char stringpool_str205[sizeof("ISO-IR-14")];
-    char stringpool_str206[sizeof("ISO8859-3")];
-    char stringpool_str207[sizeof("ISO-8859-3")];
-    char stringpool_str208[sizeof("ISO_8859-3")];
-    char stringpool_str209[sizeof("ISO8859-13")];
-    char stringpool_str210[sizeof("ISO-8859-13")];
-    char stringpool_str211[sizeof("ISO_8859-13")];
-    char stringpool_str212[sizeof("CSISO2022CN")];
-    char stringpool_str213[sizeof("MAC")];
-    char stringpool_str214[sizeof("ISO-IR-126")];
-    char stringpool_str215[sizeof("ISO-IR-144")];
-    char stringpool_str219[sizeof("ISO-IR-165")];
-    char stringpool_str220[sizeof("ISO_8859-10:1992")];
-    char stringpool_str222[sizeof("LATIN-9")];
-    char stringpool_str225[sizeof("LATIN1")];
-    char stringpool_str226[sizeof("GB_1988-80")];
-    char stringpool_str228[sizeof("ISO-IR-226")];
-    char stringpool_str229[sizeof("CYRILLIC-ASIAN")];
-    char stringpool_str231[sizeof("LATIN6")];
-    char stringpool_str232[sizeof("ISO-IR-109")];
-    char stringpool_str233[sizeof("CP874")];
-    char stringpool_str235[sizeof("ISO646-US")];
-    char stringpool_str236[sizeof("ISO-IR-101")];
-    char stringpool_str237[sizeof("ISO-IR-148")];
-    char stringpool_str238[sizeof("ISO-IR-58")];
-    char stringpool_str239[sizeof("LATIN4")];
-    char stringpool_str240[sizeof("MS-CYRL")];
-    char stringpool_str241[sizeof("ISO8859-10")];
-    char stringpool_str242[sizeof("ISO-8859-10")];
-    char stringpool_str243[sizeof("ISO_8859-10")];
-    char stringpool_str244[sizeof("TIS620")];
-    char stringpool_str245[sizeof("TIS-620")];
-    char stringpool_str246[sizeof("GB_2312-80")];
-    char stringpool_str247[sizeof("LATIN5")];
-    char stringpool_str248[sizeof("ELOT_928")];
-    char stringpool_str249[sizeof("MS936")];
-    char stringpool_str253[sizeof("LATIN2")];
-    char stringpool_str254[sizeof("GB18030")];
-    char stringpool_str255[sizeof("UTF-16")];
-    char stringpool_str256[sizeof("ISO-IR-138")];
-    char stringpool_str260[sizeof("UCS-4LE")];
-    char stringpool_str261[sizeof("LATIN8")];
-    char stringpool_str264[sizeof("ROMAN8")];
-    char stringpool_str267[sizeof("UCS-2LE")];
-    char stringpool_str268[sizeof("CSPTCP154")];
-    char stringpool_str270[sizeof("GEORGIAN-ACADEMY")];
-    char stringpool_str271[sizeof("EUCKR")];
-    char stringpool_str272[sizeof("EUC-KR")];
-    char stringpool_str274[sizeof("ISO-10646-UCS-4")];
-    char stringpool_str275[sizeof("X0212")];
-    char stringpool_str276[sizeof("KSC_5601")];
-    char stringpool_str277[sizeof("LATIN3")];
-    char stringpool_str278[sizeof("ISO-IR-110")];
-    char stringpool_str280[sizeof("ASCII")];
-    char stringpool_str281[sizeof("ISO-10646-UCS-2")];
-    char stringpool_str282[sizeof("UTF-8")];
-    char stringpool_str283[sizeof("KS_C_5601-1989")];
-    char stringpool_str285[sizeof("KOREAN")];
-    char stringpool_str286[sizeof("BIG5")];
-    char stringpool_str287[sizeof("BIG-5")];
-    char stringpool_str288[sizeof("UNICODE-1-1")];
-    char stringpool_str289[sizeof("X0201")];
-    char stringpool_str290[sizeof("TIS620-0")];
-    char stringpool_str293[sizeof("CSUNICODE11")];
-    char stringpool_str295[sizeof("CSASCII")];
-    char stringpool_str301[sizeof("KZ-1048")];
-    char stringpool_str302[sizeof("ISO-IR-203")];
-    char stringpool_str303[sizeof("UTF-32")];
-    char stringpool_str305[sizeof("MULELAO-1")];
-    char stringpool_str306[sizeof("CHINESE")];
-    char stringpool_str307[sizeof("ARABIC")];
-    char stringpool_str308[sizeof("CSKZ1048")];
-    char stringpool_str309[sizeof("HP-ROMAN8")];
-    char stringpool_str310[sizeof("ECMA-114")];
-    char stringpool_str312[sizeof("LATIN10")];
-    char stringpool_str313[sizeof("KOI8-R")];
-    char stringpool_str315[sizeof("GEORGIAN-PS")];
-    char stringpool_str316[sizeof("CSKOI8R")];
-    char stringpool_str318[sizeof("ISO-2022-CN-EXT")];
-    char stringpool_str320[sizeof("ISO-IR-100")];
-    char stringpool_str321[sizeof("IBM-921")];
-    char stringpool_str322[sizeof("IBM819")];
-    char stringpool_str325[sizeof("X0208")];
-    char stringpool_str327[sizeof("ISO_8859-9:1989")];
-    char stringpool_str332[sizeof("ECMA-118")];
-    char stringpool_str335[sizeof("IBM866")];
-    char stringpool_str338[sizeof("IBM-1131")];
-    char stringpool_str340[sizeof("CSISOLATIN1")];
-    char stringpool_str342[sizeof("VISCII")];
-    char stringpool_str344[sizeof("CSGB2312")];
-    char stringpool_str346[sizeof("CSISOLATIN6")];
-    char stringpool_str347[sizeof("CSISOLATINCYRILLIC")];
-    char stringpool_str350[sizeof("CSUNICODE")];
-    char stringpool_str352[sizeof("CSISOLATINARABIC")];
-    char stringpool_str354[sizeof("CSISOLATIN4")];
-    char stringpool_str356[sizeof("ISO_8859-4:1988")];
-    char stringpool_str357[sizeof("IBM862")];
-    char stringpool_str360[sizeof("ISO_8859-5:1988")];
-    char stringpool_str361[sizeof("IBM-932")];
-    char stringpool_str362[sizeof("CSISOLATIN5")];
-    char stringpool_str364[sizeof("CSHPROMAN8")];
-    char stringpool_str365[sizeof("IBM-1252")];
-    char stringpool_str367[sizeof("ISO_8859-8:1988")];
-    char stringpool_str368[sizeof("CSISOLATIN2")];
-    char stringpool_str372[sizeof("CSEUCKR")];
-    char stringpool_str374[sizeof("STRK1048-2002")];
-    char stringpool_str375[sizeof("ISO_8859-3:1988")];
-    char stringpool_str376[sizeof("ISO-IR-179")];
-    char stringpool_str378[sizeof("CSBIG5")];
-    char stringpool_str379[sizeof("CN-BIG5")];
-    char stringpool_str381[sizeof("ISO-CELTIC")];
-    char stringpool_str386[sizeof("HZ-GB-2312")];
-    char stringpool_str388[sizeof("UTF-16LE")];
-    char stringpool_str390[sizeof("ISO-2022-KR")];
-    char stringpool_str391[sizeof("US-ASCII")];
-    char stringpool_str392[sizeof("CSISOLATIN3")];
-    char stringpool_str403[sizeof("CSISO2022KR")];
-    char stringpool_str406[sizeof("MS-EE")];
-    char stringpool_str411[sizeof("UCS-4-INTERNAL")];
-    char stringpool_str412[sizeof("MS-ANSI")];
-    char stringpool_str413[sizeof("TCVN5712-1")];
-    char stringpool_str415[sizeof("CP1257")];
-    char stringpool_str416[sizeof("CP367")];
-    char stringpool_str418[sizeof("UCS-2-INTERNAL")];
-    char stringpool_str421[sizeof("IBM850")];
-    char stringpool_str422[sizeof("IBM-850")];
-    char stringpool_str424[sizeof("TCVN-5712")];
-    char stringpool_str425[sizeof("UTF-32LE")];
-    char stringpool_str426[sizeof("MACCYRILLIC")];
-    char stringpool_str428[sizeof("TIS620.2529-1")];
-    char stringpool_str429[sizeof("MACICELAND")];
-    char stringpool_str430[sizeof("JP")];
-    char stringpool_str434[sizeof("CSVISCII")];
-    char stringpool_str437[sizeof("MACROMAN")];
-    char stringpool_str440[sizeof("GREEK8")];
-    char stringpool_str441[sizeof("VISCII1.1-1")];
-    char stringpool_str445[sizeof("UCS-4BE")];
-    char stringpool_str446[sizeof("IBM-CP1133")];
-    char stringpool_str447[sizeof("ISO_646.IRV:1991")];
-    char stringpool_str451[sizeof("MACCROATIAN")];
-    char stringpool_str452[sizeof("UCS-2BE")];
-    char stringpool_str453[sizeof("ARMSCII-8")];
-    char stringpool_str454[sizeof("CN-GB")];
-    char stringpool_str456[sizeof("WINDOWS-1251")];
-    char stringpool_str457[sizeof("JAVA")];
-    char stringpool_str459[sizeof("WINDOWS-1256")];
-    char stringpool_str460[sizeof("WINDOWS-936")];
-    char stringpool_str462[sizeof("UCS-4-SWAPPED")];
-    char stringpool_str463[sizeof("WINDOWS-1254")];
-    char stringpool_str466[sizeof("GBK")];
-    char stringpool_str467[sizeof("WINDOWS-1255")];
-    char stringpool_str468[sizeof("TIS620.2533-1")];
-    char stringpool_str469[sizeof("UCS-2-SWAPPED")];
-    char stringpool_str470[sizeof("WINDOWS-1252")];
-    char stringpool_str471[sizeof("KS_C_5601-1987")];
-    char stringpool_str472[sizeof("CN-GB-ISOIR165")];
-    char stringpool_str474[sizeof("WINDOWS-1258")];
-    char stringpool_str475[sizeof("IBM-EUCCN")];
-    char stringpool_str476[sizeof("JIS_C6226-1983")];
-    char stringpool_str480[sizeof("UNICODE-1-1-UTF-7")];
-    char stringpool_str481[sizeof("CSKSC56011987")];
-    char stringpool_str482[sizeof("WINDOWS-1253")];
-    char stringpool_str483[sizeof("CSUNICODE11UTF7")];
-    char stringpool_str484[sizeof("WCHAR_T")];
-    char stringpool_str490[sizeof("JIS_C6220-1969-RO")];
-    char stringpool_str493[sizeof("CSISO58GB231280")];
-    char stringpool_str495[sizeof("ASMO-708")];
-    char stringpool_str498[sizeof("WINDOWS-1250")];
-    char stringpool_str507[sizeof("KOI8-U")];
-    char stringpool_str508[sizeof("KOI8-RU")];
-    char stringpool_str510[sizeof("TIS620.2533-0")];
-    char stringpool_str511[sizeof("MS-HEBR")];
-    char stringpool_str517[sizeof("ISO_8859-1:1987")];
-    char stringpool_str518[sizeof("MACARABIC")];
-    char stringpool_str520[sizeof("ISO_8859-6:1987")];
-    char stringpool_str521[sizeof("MACINTOSH")];
-    char stringpool_str525[sizeof("CSPC862LATINHEBREW")];
-    char stringpool_str526[sizeof("ISO8859-7")];
-    char stringpool_str527[sizeof("ISO-8859-7")];
-    char stringpool_str528[sizeof("ISO_8859-7")];
-    char stringpool_str530[sizeof("CSIBM866")];
-    char stringpool_str531[sizeof("ISO_8859-2:1987")];
-    char stringpool_str534[sizeof("CSMACINTOSH")];
-    char stringpool_str538[sizeof("JIS0208")];
-    char stringpool_str542[sizeof("MACROMANIA")];
-    char stringpool_str543[sizeof("ISO_8859-7:2003")];
-    char stringpool_str549[sizeof("KOI8-T")];
-    char stringpool_str552[sizeof("EUCJP")];
-    char stringpool_str553[sizeof("EUC-JP")];
-    char stringpool_str554[sizeof("BIG5HKSCS")];
-    char stringpool_str555[sizeof("BIG5-HKSCS")];
-    char stringpool_str557[sizeof("MACCENTRALEUROPE")];
-    char stringpool_str560[sizeof("MACTHAI")];
-    char stringpool_str561[sizeof("ANSI_X3.4-1986")];
-    char stringpool_str565[sizeof("EXTENDED_UNIX_CODE_PACKED_FORMAT_FOR_JAPANESE")];
-    char stringpool_str568[sizeof("EUCTW")];
-    char stringpool_str569[sizeof("EUC-TW")];
-    char stringpool_str572[sizeof("CSISOLATINHEBREW")];
-    char stringpool_str573[sizeof("UTF-16BE")];
-    char stringpool_str574[sizeof("ISO-IR-57")];
-    char stringpool_str576[sizeof("ANSI_X3.4-1968")];
-    char stringpool_str577[sizeof("ISO-IR-157")];
-    char stringpool_str580[sizeof("ISO-IR-127")];
-    char stringpool_str581[sizeof("ISO-IR-87")];
-    char stringpool_str585[sizeof("CSPC850MULTILINGUAL")];
-    char stringpool_str593[sizeof("CSISO57GB1988")];
-    char stringpool_str596[sizeof("ISO646-JP")];
-    char stringpool_str597[sizeof("LATIN7")];
-    char stringpool_str598[sizeof("GREEK")];
-    char stringpool_str604[sizeof("CSISOLATINGREEK")];
-    char stringpool_str606[sizeof("CSISO14JISC6220RO")];
-    char stringpool_str610[sizeof("UTF-32BE")];
-    char stringpool_str613[sizeof("MS-ARAB")];
-    char stringpool_str614[sizeof("TCVN5712-1:1993")];
-    char stringpool_str618[sizeof("UTF-7")];
-    char stringpool_str623[sizeof("ISO-2022-JP-1")];
-    char stringpool_str633[sizeof("ISO-2022-JP-MS")];
-    char stringpool_str637[sizeof("ISO-2022-JP-2")];
-    char stringpool_str642[sizeof("WINDOWS-1257")];
-    char stringpool_str647[sizeof("NEXTSTEP")];
-    char stringpool_str648[sizeof("WINDOWS-874")];
-    char stringpool_str649[sizeof("CSISO2022JP2")];
-    char stringpool_str655[sizeof("CSISO159JISX02121990")];
-    char stringpool_str666[sizeof("IBM-EUCKR")];
-    char stringpool_str669[sizeof("CSEUCTW")];
-    char stringpool_str671[sizeof("ISO-2022-JP")];
-    char stringpool_str679[sizeof("UNICODELITTLE")];
-    char stringpool_str680[sizeof("BIGFIVE")];
-    char stringpool_str681[sizeof("BIG-FIVE")];
-    char stringpool_str682[sizeof("HEBREW")];
-    char stringpool_str683[sizeof("CSHALFWIDTHKATAKANA")];
-    char stringpool_str684[sizeof("CSISO2022JP")];
-    char stringpool_str690[sizeof("UNICODEBIG")];
-    char stringpool_str703[sizeof("ISO_8859-7:1987")];
-    char stringpool_str709[sizeof("IBM367")];
-    char stringpool_str711[sizeof("JIS_X0212")];
-    char stringpool_str719[sizeof("BIG5-HKSCS:1999")];
-    char stringpool_str721[sizeof("BIG5-HKSCS:2001")];
-    char stringpool_str725[sizeof("JIS_X0201")];
-    char stringpool_str728[sizeof("BIG5-HKSCS:2004")];
-    char stringpool_str733[sizeof("JISX0201-1976")];
-    char stringpool_str739[sizeof("BIG5-HKSCS:2008")];
-    char stringpool_str744[sizeof("MACUKRAINE")];
-    char stringpool_str746[sizeof("JIS_X0212-1990")];
-    char stringpool_str761[sizeof("JIS_X0208")];
-    char stringpool_str776[sizeof("JIS_X0208-1983")];
-    char stringpool_str792[sizeof("JIS_X0208-1990")];
-    char stringpool_str807[sizeof("MS-GREEK")];
-    char stringpool_str809[sizeof("MACGREEK")];
-    char stringpool_str814[sizeof("JOHAB")];
-    char stringpool_str815[sizeof("MACTURKISH")];
-    char stringpool_str826[sizeof("MS-TURK")];
-    char stringpool_str852[sizeof("SHIFT-JIS")];
-    char stringpool_str853[sizeof("SHIFT_JIS")];
-    char stringpool_str897[sizeof("CSSHIFTJIS")];
-    char stringpool_str922[sizeof("JIS_X0212.1990-0")];
-    char stringpool_str947[sizeof("IBM-EUCJP")];
-    char stringpool_str958[sizeof("MACHEBREW")];
-    char stringpool_str963[sizeof("IBM-EUCTW")];
-    char stringpool_str978[sizeof("MS_KANJI")];
-    char stringpool_str984[sizeof("CSEUCPKDFMTJAPANESE")];
-    char stringpool_str1026[sizeof("WINBALTRIM")];
-    char stringpool_str1039[sizeof("CSISO87JISX0208")];
+    char stringpool_str9[sizeof("CN")];
+    char stringpool_str13[sizeof("L1")];
+    char stringpool_str14[sizeof("L6")];
+    char stringpool_str17[sizeof("L5")];
+    char stringpool_str20[sizeof("L3")];
+    char stringpool_str21[sizeof("L2")];
+    char stringpool_str23[sizeof("L8")];
+    char stringpool_str24[sizeof("866")];
+    char stringpool_str32[sizeof("CP1131")];
+    char stringpool_str33[sizeof("CP1361")];
+    char stringpool_str34[sizeof("CP866")];
+    char stringpool_str37[sizeof("CP1251")];
+    char stringpool_str38[sizeof("862")];
+    char stringpool_str39[sizeof("CP1256")];
+    char stringpool_str43[sizeof("SJIS")];
+    char stringpool_str45[sizeof("CP1255")];
+    char stringpool_str46[sizeof("CP1133")];
+    char stringpool_str48[sizeof("CP862")];
+    char stringpool_str51[sizeof("CP1253")];
+    char stringpool_str53[sizeof("CP1252")];
+    char stringpool_str56[sizeof("CP936")];
+    char stringpool_str57[sizeof("CP1258")];
+    char stringpool_str61[sizeof("LATIN1")];
+    char stringpool_str63[sizeof("LATIN6")];
+    char stringpool_str65[sizeof("C99")];
+    char stringpool_str69[sizeof("LATIN5")];
+    char stringpool_str70[sizeof("CP932")];
+    char stringpool_str75[sizeof("LATIN3")];
+    char stringpool_str77[sizeof("LATIN2")];
+    char stringpool_str81[sizeof("LATIN8")];
+    char stringpool_str82[sizeof("CP51932")];
+    char stringpool_str83[sizeof("CP819")];
+    char stringpool_str87[sizeof("GB2312")];
+    char stringpool_str89[sizeof("ISO8859-1")];
+    char stringpool_str91[sizeof("ISO8859-6")];
+    char stringpool_str93[sizeof("ISO8859-11")];
+    char stringpool_str95[sizeof("ISO8859-16")];
+    char stringpool_str96[sizeof("ISO-8859-1")];
+    char stringpool_str97[sizeof("ISO8859-5")];
+    char stringpool_str98[sizeof("ISO-8859-6")];
+    char stringpool_str99[sizeof("CP50221")];
+    char stringpool_str100[sizeof("ISO-8859-11")];
+    char stringpool_str101[sizeof("ISO8859-15")];
+    char stringpool_str102[sizeof("ISO-8859-16")];
+    char stringpool_str103[sizeof("ISO8859-3")];
+    char stringpool_str104[sizeof("ISO-8859-5")];
+    char stringpool_str105[sizeof("ISO8859-2")];
+    char stringpool_str106[sizeof("EUCCN")];
+    char stringpool_str107[sizeof("ISO8859-13")];
+    char stringpool_str108[sizeof("ISO-8859-15")];
+    char stringpool_str109[sizeof("ISO8859-8")];
+    char stringpool_str110[sizeof("ISO-8859-3")];
+    char stringpool_str112[sizeof("ISO-8859-2")];
+    char stringpool_str113[sizeof("EUC-CN")];
+    char stringpool_str114[sizeof("ISO-8859-13")];
+    char stringpool_str116[sizeof("ISO-8859-8")];
+    char stringpool_str117[sizeof("L10")];
+    char stringpool_str118[sizeof("R8")];
+    char stringpool_str120[sizeof("LATIN-9")];
+    char stringpool_str121[sizeof("L4")];
+    char stringpool_str122[sizeof("850")];
+    char stringpool_str123[sizeof("UHC")];
+    char stringpool_str124[sizeof("VISCII")];
+    char stringpool_str125[sizeof("ISO-2022-CN")];
+    char stringpool_str126[sizeof("US")];
+    char stringpool_str129[sizeof("CSISO2022CN")];
+    char stringpool_str131[sizeof("MAC")];
+    char stringpool_str133[sizeof("CSVISCII")];
+    char stringpool_str135[sizeof("CP850")];
+    char stringpool_str137[sizeof("CP1250")];
+    char stringpool_str138[sizeof("TCVN")];
+    char stringpool_str139[sizeof("JP")];
+    char stringpool_str140[sizeof("ISO-IR-6")];
+    char stringpool_str141[sizeof("ISO8859-9")];
+    char stringpool_str142[sizeof("ASCII")];
+    char stringpool_str144[sizeof("SJIS-WIN")];
+    char stringpool_str145[sizeof("CYRILLIC")];
+    char stringpool_str148[sizeof("ISO-8859-9")];
+    char stringpool_str149[sizeof("ISO-IR-166")];
+    char stringpool_str150[sizeof("ISO646-CN")];
+    char stringpool_str151[sizeof("CP950")];
+    char stringpool_str154[sizeof("IBM866")];
+    char stringpool_str155[sizeof("ISO-IR-165")];
+    char stringpool_str156[sizeof("ISO-IR-126")];
+    char stringpool_str157[sizeof("UCS-2")];
+    char stringpool_str159[sizeof("IBM-1131")];
+    char stringpool_str160[sizeof("CSASCII")];
+    char stringpool_str161[sizeof("ISO-2022-CN-EXT")];
+    char stringpool_str164[sizeof("ISO-IR-226")];
+    char stringpool_str165[sizeof("LATIN10")];
+    char stringpool_str166[sizeof("ISO-IR-58")];
+    char stringpool_str167[sizeof("ISO-CELTIC")];
+    char stringpool_str168[sizeof("IBM862")];
+    char stringpool_str172[sizeof("MS936")];
+    char stringpool_str173[sizeof("ISO-IR-138")];
+    char stringpool_str174[sizeof("TIS620")];
+    char stringpool_str176[sizeof("HZ")];
+    char stringpool_str179[sizeof("CSISO159JISX02121990")];
+    char stringpool_str180[sizeof("IBM-1252")];
+    char stringpool_str181[sizeof("TIS-620")];
+    char stringpool_str182[sizeof("IBM-921")];
+    char stringpool_str184[sizeof("SJIS-MS")];
+    char stringpool_str185[sizeof("VISCII1.1-1")];
+    char stringpool_str186[sizeof("MS932")];
+    char stringpool_str188[sizeof("SHIFT-JIS")];
+    char stringpool_str192[sizeof("JIS0208")];
+    char stringpool_str193[sizeof("ISO8859-10")];
+    char stringpool_str196[sizeof("ISO-IR-101")];
+    char stringpool_str197[sizeof("IBM-932")];
+    char stringpool_str198[sizeof("MS51932")];
+    char stringpool_str200[sizeof("ISO-8859-10")];
+    char stringpool_str201[sizeof("UTF-16")];
+    char stringpool_str202[sizeof("ISO-IR-159")];
+    char stringpool_str203[sizeof("IBM819")];
+    char stringpool_str205[sizeof("CSISO14JISC6220RO")];
+    char stringpool_str207[sizeof("CP949")];
+    char stringpool_str210[sizeof("TIS620.2533-1")];
+    char stringpool_str212[sizeof("CSISOLATIN1")];
+    char stringpool_str214[sizeof("CSISOLATIN6")];
+    char stringpool_str215[sizeof("UTF-8")];
+    char stringpool_str218[sizeof("ISO-IR-203")];
+    char stringpool_str220[sizeof("CSISOLATIN5")];
+    char stringpool_str221[sizeof("CSISOLATINCYRILLIC")];
+    char stringpool_str222[sizeof("UTF-32")];
+    char stringpool_str224[sizeof("ISO-IR-199")];
+    char stringpool_str226[sizeof("CSISOLATIN3")];
+    char stringpool_str227[sizeof("GB18030")];
+    char stringpool_str228[sizeof("CSISOLATIN2")];
+    char stringpool_str230[sizeof("TIS620.2529-1")];
+    char stringpool_str235[sizeof("TIS620-0")];
+    char stringpool_str239[sizeof("L7")];
+    char stringpool_str241[sizeof("CP154")];
+    char stringpool_str245[sizeof("SJIS-OPEN")];
+    char stringpool_str246[sizeof("ISO-IR-110")];
+    char stringpool_str248[sizeof("ISO-IR-109")];
+    char stringpool_str253[sizeof("CP1254")];
+    char stringpool_str254[sizeof("BIG5")];
+    char stringpool_str255[sizeof("IBM850")];
+    char stringpool_str257[sizeof("ISO-2022-JP-1")];
+    char stringpool_str260[sizeof("TIS620.2533-0")];
+    char stringpool_str261[sizeof("BIG-5")];
+    char stringpool_str262[sizeof("IBM-850")];
+    char stringpool_str263[sizeof("CSBIG5")];
+    char stringpool_str264[sizeof("MS-CYRL")];
+    char stringpool_str265[sizeof("ISO-2022-JP-2")];
+    char stringpool_str267[sizeof("ISO-2022-JP-MS")];
+    char stringpool_str268[sizeof("CSISO2022JP2")];
+    char stringpool_str269[sizeof("X0212")];
+    char stringpool_str270[sizeof("CN-BIG5")];
+    char stringpool_str274[sizeof("ISO-IR-148")];
+    char stringpool_str275[sizeof("US-ASCII")];
+    char stringpool_str276[sizeof("ISO646-US")];
+    char stringpool_str277[sizeof("LATIN4")];
+    char stringpool_str278[sizeof("MS-ANSI")];
+    char stringpool_str280[sizeof("MACCYRILLIC")];
+    char stringpool_str281[sizeof("ISO_8859-1")];
+    char stringpool_str283[sizeof("ISO_8859-6")];
+    char stringpool_str285[sizeof("ISO_8859-11")];
+    char stringpool_str286[sizeof("IBM-CP1133")];
+    char stringpool_str287[sizeof("ISO_8859-16")];
+    char stringpool_str289[sizeof("ISO_8859-5")];
+    char stringpool_str290[sizeof("CHINESE")];
+    char stringpool_str291[sizeof("ISO_8859-16:2001")];
+    char stringpool_str292[sizeof("CYRILLIC-ASIAN")];
+    char stringpool_str293[sizeof("ISO_8859-15")];
+    char stringpool_str294[sizeof("CSGB2312")];
+    char stringpool_str295[sizeof("ISO_8859-3")];
+    char stringpool_str296[sizeof("ISO-IR-100")];
+    char stringpool_str297[sizeof("ISO_8859-2")];
+    char stringpool_str299[sizeof("ISO_8859-13")];
+    char stringpool_str300[sizeof("JIS_C6226-1983")];
+    char stringpool_str301[sizeof("ISO_8859-8")];
+    char stringpool_str302[sizeof("RK1048")];
+    char stringpool_str303[sizeof("X0201")];
+    char stringpool_str304[sizeof("ISO_8859-15:1998")];
+    char stringpool_str305[sizeof("ISO8859-4")];
+    char stringpool_str306[sizeof("ISO-IR-149")];
+    char stringpool_str307[sizeof("ARMSCII-8")];
+    char stringpool_str308[sizeof("KOI8-T")];
+    char stringpool_str309[sizeof("ISO8859-14")];
+    char stringpool_str312[sizeof("ISO-8859-4")];
+    char stringpool_str316[sizeof("ISO-8859-14")];
+    char stringpool_str319[sizeof("EUCTW")];
+    char stringpool_str323[sizeof("X0208")];
+    char stringpool_str326[sizeof("EUC-TW")];
+    char stringpool_str330[sizeof("UCS-2LE")];
+    char stringpool_str331[sizeof("ISO-10646-UCS-2")];
+    char stringpool_str333[sizeof("ISO_8859-9")];
+    char stringpool_str338[sizeof("CHAR")];
+    char stringpool_str339[sizeof("CSISOLATINARABIC")];
+    char stringpool_str340[sizeof("EUCJP")];
+    char stringpool_str344[sizeof("PT154")];
+    char stringpool_str345[sizeof("JIS_C6220-1969-RO")];
+    char stringpool_str346[sizeof("EUCJP-WIN")];
+    char stringpool_str347[sizeof("EUC-JP")];
+    char stringpool_str348[sizeof("ISO_8859-10:1992")];
+    char stringpool_str350[sizeof("CSSHIFTJIS")];
+    char stringpool_str351[sizeof("IBM-EUCCN")];
+    char stringpool_str357[sizeof("UCS-4")];
+    char stringpool_str358[sizeof("ISO-IR-14")];
+    char stringpool_str359[sizeof("ISO-2022-JP")];
+    char stringpool_str360[sizeof("CSUCS4")];
+    char stringpool_str361[sizeof("CSIBM866")];
+    char stringpool_str363[sizeof("CSISO2022JP")];
+    char stringpool_str367[sizeof("CSISO58GB231280")];
+    char stringpool_str371[sizeof("MULELAO-1")];
+    char stringpool_str373[sizeof("SHIFT_JIS")];
+    char stringpool_str375[sizeof("JAVA")];
+    char stringpool_str377[sizeof("ECMA-118")];
+    char stringpool_str379[sizeof("EUCJPMS")];
+    char stringpool_str381[sizeof("UTF-16LE")];
+    char stringpool_str382[sizeof("ROMAN8")];
+    char stringpool_str384[sizeof("ISO646-JP")];
+    char stringpool_str385[sizeof("ISO_8859-10")];
+    char stringpool_str386[sizeof("EUCJP-MS")];
+    char stringpool_str390[sizeof("ELOT_928")];
+    char stringpool_str392[sizeof("MS-EE")];
+    char stringpool_str393[sizeof("EUC-JP-MS")];
+    char stringpool_str395[sizeof("UTF-32LE")];
+    char stringpool_str396[sizeof("GB_2312-80")];
+    char stringpool_str397[sizeof("CN-GB-ISOIR165")];
+    char stringpool_str400[sizeof("UCS-2-INTERNAL")];
+    char stringpool_str401[sizeof("CSUNICODE11")];
+    char stringpool_str403[sizeof("TCVN5712-1")];
+    char stringpool_str406[sizeof("UNICODE-1-1")];
+    char stringpool_str407[sizeof("TCVN-5712")];
+    char stringpool_str408[sizeof("ISO_8859-14:1998")];
+    char stringpool_str413[sizeof("WINDOWS-1251")];
+    char stringpool_str414[sizeof("WINDOWS-1256")];
+    char stringpool_str416[sizeof("KZ-1048")];
+    char stringpool_str417[sizeof("WINDOWS-1255")];
+    char stringpool_str419[sizeof("GB_1988-80")];
+    char stringpool_str420[sizeof("WINDOWS-1253")];
+    char stringpool_str421[sizeof("WINDOWS-1252")];
+    char stringpool_str423[sizeof("WINDOWS-1258")];
+    char stringpool_str424[sizeof("ISO-IR-179")];
+    char stringpool_str425[sizeof("CSPC862LATINHEBREW")];
+    char stringpool_str426[sizeof("CSKZ1048")];
+    char stringpool_str428[sizeof("CSISOLATIN4")];
+    char stringpool_str430[sizeof("UCS-4LE")];
+    char stringpool_str431[sizeof("ISO-10646-UCS-4")];
+    char stringpool_str433[sizeof("CSWINDOWS31J")];
+    char stringpool_str435[sizeof("WINDOWS-936")];
+    char stringpool_str436[sizeof("ISO_8859-5:1988")];
+    char stringpool_str437[sizeof("CSEUCTW")];
+    char stringpool_str439[sizeof("ISO_8859-3:1988")];
+    char stringpool_str440[sizeof("WINDOWS-51932")];
+    char stringpool_str442[sizeof("ISO_8859-8:1988")];
+    char stringpool_str444[sizeof("KOI8-R")];
+    char stringpool_str445[sizeof("JISX0201-1976")];
+    char stringpool_str446[sizeof("CSKOI8R")];
+    char stringpool_str447[sizeof("EUCJP-OPEN")];
+    char stringpool_str449[sizeof("WINDOWS-932")];
+    char stringpool_str451[sizeof("GREEK8")];
+    char stringpool_str452[sizeof("CN-GB")];
+    char stringpool_str454[sizeof("GEORGIAN-PS")];
+    char stringpool_str455[sizeof("CSISOLATINGREEK")];
+    char stringpool_str457[sizeof("PTCP154")];
+    char stringpool_str458[sizeof("GBK")];
+    char stringpool_str459[sizeof("MACTHAI")];
+    char stringpool_str461[sizeof("WINDOWS-31J")];
+    char stringpool_str462[sizeof("KOI8-U")];
+    char stringpool_str463[sizeof("WINDOWS-1250")];
+    char stringpool_str464[sizeof("GEORGIAN-ACADEMY")];
+    char stringpool_str466[sizeof("ARABIC")];
+    char stringpool_str467[sizeof("HZ-GB-2312")];
+    char stringpool_str468[sizeof("CSISOLATINHEBREW")];
+    char stringpool_str470[sizeof("ISO-IR-144")];
+    char stringpool_str473[sizeof("CP874")];
+    char stringpool_str474[sizeof("ISO_8859-9:1989")];
+    char stringpool_str477[sizeof("CSUNICODE")];
+    char stringpool_str481[sizeof("CP367")];
+    char stringpool_str483[sizeof("KSC_5601")];
+    char stringpool_str488[sizeof("MACROMAN")];
+    char stringpool_str489[sizeof("CP1257")];
+    char stringpool_str490[sizeof("CSPC850MULTILINGUAL")];
+    char stringpool_str497[sizeof("ISO_8859-4")];
+    char stringpool_str498[sizeof("CSPTCP154")];
+    char stringpool_str500[sizeof("UCS-4-INTERNAL")];
+    char stringpool_str501[sizeof("ISO_8859-14")];
+    char stringpool_str502[sizeof("SHIFT_JIS-MS")];
+    char stringpool_str512[sizeof("EUCKR")];
+    char stringpool_str513[sizeof("LATIN7")];
+    char stringpool_str515[sizeof("MACINTOSH")];
+    char stringpool_str519[sizeof("EUC-KR")];
+    char stringpool_str521[sizeof("WINDOWS-1254")];
+    char stringpool_str523[sizeof("UCS-2BE")];
+    char stringpool_str531[sizeof("ISO-2022-KR")];
+    char stringpool_str535[sizeof("CSISO2022KR")];
+    char stringpool_str536[sizeof("KOREAN")];
+    char stringpool_str537[sizeof("MACCROATIAN")];
+    char stringpool_str540[sizeof("ISO_8859-4:1988")];
+    char stringpool_str541[sizeof("ISO8859-7")];
+    char stringpool_str548[sizeof("ISO-8859-7")];
+    char stringpool_str551[sizeof("TCVN5712-1:1993")];
+    char stringpool_str552[sizeof("CSISO57GB1988")];
+    char stringpool_str555[sizeof("UNICODELITTLE")];
+    char stringpool_str557[sizeof("HP-ROMAN8")];
+    char stringpool_str559[sizeof("JIS_X0212")];
+    char stringpool_str564[sizeof("IBM-EUCTW")];
+    char stringpool_str565[sizeof("CSISO87JISX0208")];
+    char stringpool_str566[sizeof("KOI8-RU")];
+    char stringpool_str569[sizeof("ASMO-708")];
+    char stringpool_str571[sizeof("CSKSC56011987")];
+    char stringpool_str573[sizeof("ECMA-114")];
+    char stringpool_str574[sizeof("UTF-16BE")];
+    char stringpool_str575[sizeof("ISO_646.IRV:1991")];
+    char stringpool_str579[sizeof("BIGFIVE")];
+    char stringpool_str585[sizeof("IBM-EUCJP")];
+    char stringpool_str586[sizeof("BIG-FIVE")];
+    char stringpool_str588[sizeof("UTF-32BE")];
+    char stringpool_str593[sizeof("JIS_X0201")];
+    char stringpool_str598[sizeof("ISO-IR-57")];
+    char stringpool_str599[sizeof("STRK1048-2002")];
+    char stringpool_str601[sizeof("IBM367")];
+    char stringpool_str602[sizeof("ISO-IR-157")];
+    char stringpool_str604[sizeof("ISO-IR-87")];
+    char stringpool_str606[sizeof("ISO-IR-127")];
+    char stringpool_str613[sizeof("JIS_X0208")];
+    char stringpool_str615[sizeof("JIS_X0212-1990")];
+    char stringpool_str622[sizeof("NEXTSTEP")];
+    char stringpool_str623[sizeof("UCS-4BE")];
+    char stringpool_str624[sizeof("JIS_X0208-1983")];
+    char stringpool_str630[sizeof("CSEUCKR")];
+    char stringpool_str631[sizeof("CSUNICODE11UTF7")];
+    char stringpool_str634[sizeof("GREEK")];
+    char stringpool_str638[sizeof("UNICODE-1-1-UTF-7")];
+    char stringpool_str639[sizeof("WINDOWS-1257")];
+    char stringpool_str645[sizeof("CSMACINTOSH")];
+    char stringpool_str647[sizeof("UTF-7")];
+    char stringpool_str648[sizeof("ISO_8859-1:1987")];
+    char stringpool_str649[sizeof("ISO_8859-6:1987")];
+    char stringpool_str652[sizeof("JIS_X0212.1990-0")];
+    char stringpool_str655[sizeof("ISO_8859-7:2003")];
+    char stringpool_str656[sizeof("ISO_8859-2:1987")];
+    char stringpool_str658[sizeof("UNICODEBIG")];
+    char stringpool_str663[sizeof("CSHPROMAN8")];
+    char stringpool_str665[sizeof("BIG5HKSCS")];
+    char stringpool_str667[sizeof("JIS_X0208-1990")];
+    char stringpool_str672[sizeof("BIG5-HKSCS")];
+    char stringpool_str678[sizeof("MACCENTRALEUROPE")];
+    char stringpool_str692[sizeof("MS_KANJI")];
+    char stringpool_str693[sizeof("MACICELAND")];
+    char stringpool_str696[sizeof("MACARABIC")];
+    char stringpool_str715[sizeof("KS_C_5601-1989")];
+    char stringpool_str724[sizeof("JOHAB")];
+    char stringpool_str733[sizeof("ISO_8859-7")];
+    char stringpool_str738[sizeof("MACROMANIA")];
+    char stringpool_str747[sizeof("ANSI_X3.4-1986")];
+    char stringpool_str748[sizeof("HEBREW")];
+    char stringpool_str752[sizeof("WCHAR_T")];
+    char stringpool_str756[sizeof("ANSI_X3.4-1968")];
+    char stringpool_str757[sizeof("IBM-EUCKR")];
+    char stringpool_str769[sizeof("UCS-2-SWAPPED")];
+    char stringpool_str790[sizeof("MS-HEBR")];
+    char stringpool_str803[sizeof("MS-TURK")];
+    char stringpool_str804[sizeof("BIG5-HKSCS:2001")];
+    char stringpool_str814[sizeof("BIG5-HKSCS:2008")];
+    char stringpool_str821[sizeof("WINBALTRIM")];
+    char stringpool_str830[sizeof("BIG5-HKSCS:1999")];
+    char stringpool_str852[sizeof("WINDOWS-874")];
+    char stringpool_str863[sizeof("MACUKRAINE")];
+    char stringpool_str864[sizeof("MACGREEK")];
+    char stringpool_str866[sizeof("MS-GREEK")];
+    char stringpool_str869[sizeof("UCS-4-SWAPPED")];
+    char stringpool_str874[sizeof("ISO_8859-7:1987")];
+    char stringpool_str876[sizeof("UTF7IMAP")];
+    char stringpool_str886[sizeof("MS-ARAB")];
+    char stringpool_str890[sizeof("UTF-7-IMAP")];
+    char stringpool_str912[sizeof("BIG5-HKSCS:2004")];
+    char stringpool_str915[sizeof("KS_C_5601-1987")];
+    char stringpool_str935[sizeof("MACTURKISH")];
+    char stringpool_str962[sizeof("MACHEBREW")];
+    char stringpool_str968[sizeof("CSHALFWIDTHKATAKANA")];
+    char stringpool_str1016[sizeof("CSEUCPKDFMTJAPANESE")];
+    char stringpool_str1067[sizeof("EXTENDED_UNIX_CODE_PACKED_FORMAT_FOR_JAPANESE")];
   };
 static const struct stringpool_t stringpool_contents =
   {
-    "C99",
     "CN",
     "L1",
     "L6",
-    "CHAR",
-    "CP949",
-    "L4",
     "L5",
-    "R8",
+    "L3",
     "L2",
     "L8",
-    "CP819",
     "866",
-    "L3",
-    "CP154",
-    "CP866",
-    "CP1251",
     "CP1131",
-    "CP936",
     "CP1361",
-    "HZ",
-    "CP1256",
+    "CP866",
+    "CP1251",
     "862",
-    "CP1254",
-    "CP862",
+    "CP1256",
+    "SJIS",
     "CP1255",
-    "CP932",
+    "CP1133",
+    "CP862",
+    "CP1253",
     "CP1252",
+    "CP936",
     "CP1258",
-    "EUCCN",
-    "EUC-CN",
-    "PT154",
-    "CP1253",
-    "CP1133",
-    "L10",
-    "RK1048",
-    "CP50221",
-    "UHC",
-    "CP950",
-    "US",
-    "850",
-    "ISO646-CN",
-    "SJIS",
-    "CP1250",
-    "CP850",
-    "UCS-4",
-    "CSUCS4",
-    "UCS-2",
-    "PTCP154",
+    "LATIN1",
+    "LATIN6",
+    "C99",
+    "LATIN5",
+    "CP932",
+    "LATIN3",
+    "LATIN2",
+    "LATIN8",
+    "CP51932",
+    "CP819",
     "GB2312",
-    "ISO8859-9",
-    "ISO-8859-9",
-    "ISO_8859-9",
     "ISO8859-1",
-    "ISO-8859-1",
-    "ISO_8859-1",
-    "ISO8859-11",
-    "ISO-8859-11",
-    "ISO_8859-11",
     "ISO8859-6",
-    "ISO-8859-6",
-    "ISO_8859-6",
+    "ISO8859-11",
     "ISO8859-16",
-    "ISO-8859-16",
-    "ISO_8859-16",
-    "ISO_8859-16:2001",
-    "ISO8859-4",
-    "ISO-8859-4",
-    "ISO_8859-4",
-    "ISO8859-14",
-    "ISO-8859-14",
-    "ISO_8859-14",
+    "ISO-8859-1",
     "ISO8859-5",
-    "ISO-8859-5",
-    "ISO_8859-5",
+    "ISO-8859-6",
+    "CP50221",
+    "ISO-8859-11",
     "ISO8859-15",
-    "ISO-8859-15",
-    "ISO_8859-15",
+    "ISO-8859-16",
+    "ISO8859-3",
+    "ISO-8859-5",
     "ISO8859-2",
-    "ISO-8859-2",
-    "ISO_8859-2",
-    "TCVN",
-    "ISO-IR-199",
-    "ISO_8859-14:1998",
+    "EUCCN",
+    "ISO8859-13",
+    "ISO-8859-15",
     "ISO8859-8",
-    "ISO-8859-8",
-    "ISO_8859-8",
-    "ISO_8859-15:1998",
-    "ISO-IR-6",
-    "L7",
-    "ISO-IR-149",
-    "ISO-2022-CN",
-    "ISO-IR-159",
-    "CYRILLIC",
-    "ISO-IR-166",
-    "ISO-IR-14",
-    "ISO8859-3",
     "ISO-8859-3",
-    "ISO_8859-3",
-    "ISO8859-13",
+    "ISO-8859-2",
+    "EUC-CN",
     "ISO-8859-13",
-    "ISO_8859-13",
+    "ISO-8859-8",
+    "L10",
+    "R8",
+    "LATIN-9",
+    "L4",
+    "850",
+    "UHC",
+    "VISCII",
+    "ISO-2022-CN",
+    "US",
     "CSISO2022CN",
     "MAC",
-    "ISO-IR-126",
-    "ISO-IR-144",
+    "CSVISCII",
+    "CP850",
+    "CP1250",
+    "TCVN",
+    "JP",
+    "ISO-IR-6",
+    "ISO8859-9",
+    "ASCII",
+    "SJIS-WIN",
+    "CYRILLIC",
+    "ISO-8859-9",
+    "ISO-IR-166",
+    "ISO646-CN",
+    "CP950",
+    "IBM866",
     "ISO-IR-165",
-    "ISO_8859-10:1992",
-    "LATIN-9",
-    "LATIN1",
-    "GB_1988-80",
+    "ISO-IR-126",
+    "UCS-2",
+    "IBM-1131",
+    "CSASCII",
+    "ISO-2022-CN-EXT",
     "ISO-IR-226",
-    "CYRILLIC-ASIAN",
-    "LATIN6",
-    "ISO-IR-109",
-    "CP874",
-    "ISO646-US",
-    "ISO-IR-101",
-    "ISO-IR-148",
+    "LATIN10",
     "ISO-IR-58",
-    "LATIN4",
-    "MS-CYRL",
-    "ISO8859-10",
-    "ISO-8859-10",
-    "ISO_8859-10",
-    "TIS620",
-    "TIS-620",
-    "GB_2312-80",
-    "LATIN5",
-    "ELOT_928",
+    "ISO-CELTIC",
+    "IBM862",
     "MS936",
-    "LATIN2",
-    "GB18030",
-    "UTF-16",
     "ISO-IR-138",
-    "UCS-4LE",
-    "LATIN8",
-    "ROMAN8",
-    "UCS-2LE",
-    "CSPTCP154",
-    "GEORGIAN-ACADEMY",
-    "EUCKR",
-    "EUC-KR",
-    "ISO-10646-UCS-4",
-    "X0212",
-    "KSC_5601",
-    "LATIN3",
-    "ISO-IR-110",
-    "ASCII",
-    "ISO-10646-UCS-2",
-    "UTF-8",
-    "KS_C_5601-1989",
-    "KOREAN",
-    "BIG5",
-    "BIG-5",
-    "UNICODE-1-1",
-    "X0201",
-    "TIS620-0",
-    "CSUNICODE11",
-    "CSASCII",
-    "KZ-1048",
-    "ISO-IR-203",
-    "UTF-32",
-    "MULELAO-1",
-    "CHINESE",
-    "ARABIC",
-    "CSKZ1048",
-    "HP-ROMAN8",
-    "ECMA-114",
-    "LATIN10",
-    "KOI8-R",
-    "GEORGIAN-PS",
-    "CSKOI8R",
-    "ISO-2022-CN-EXT",
-    "ISO-IR-100",
+    "TIS620",
+    "HZ",
+    "CSISO159JISX02121990",
+    "IBM-1252",
+    "TIS-620",
     "IBM-921",
+    "SJIS-MS",
+    "VISCII1.1-1",
+    "MS932",
+    "SHIFT-JIS",
+    "JIS0208",
+    "ISO8859-10",
+    "ISO-IR-101",
+    "IBM-932",
+    "MS51932",
+    "ISO-8859-10",
+    "UTF-16",
+    "ISO-IR-159",
     "IBM819",
-    "X0208",
-    "ISO_8859-9:1989",
-    "ECMA-118",
-    "IBM866",
-    "IBM-1131",
+    "CSISO14JISC6220RO",
+    "CP949",
+    "TIS620.2533-1",
     "CSISOLATIN1",
-    "VISCII",
-    "CSGB2312",
     "CSISOLATIN6",
-    "CSISOLATINCYRILLIC",
-    "CSUNICODE",
-    "CSISOLATINARABIC",
-    "CSISOLATIN4",
-    "ISO_8859-4:1988",
-    "IBM862",
-    "ISO_8859-5:1988",
-    "IBM-932",
+    "UTF-8",
+    "ISO-IR-203",
     "CSISOLATIN5",
-    "CSHPROMAN8",
-    "IBM-1252",
-    "ISO_8859-8:1988",
+    "CSISOLATINCYRILLIC",
+    "UTF-32",
+    "ISO-IR-199",
+    "CSISOLATIN3",
+    "GB18030",
     "CSISOLATIN2",
-    "CSEUCKR",
-    "STRK1048-2002",
-    "ISO_8859-3:1988",
-    "ISO-IR-179",
-    "CSBIG5",
-    "CN-BIG5",
-    "ISO-CELTIC",
-    "HZ-GB-2312",
-    "UTF-16LE",
-    "ISO-2022-KR",
-    "US-ASCII",
-    "CSISOLATIN3",
-    "CSISO2022KR",
-    "MS-EE",
-    "UCS-4-INTERNAL",
-    "MS-ANSI",
-    "TCVN5712-1",
-    "CP1257",
-    "CP367",
-    "UCS-2-INTERNAL",
+    "TIS620.2529-1",
+    "TIS620-0",
+    "L7",
+    "CP154",
+    "SJIS-OPEN",
+    "ISO-IR-110",
+    "ISO-IR-109",
+    "CP1254",
+    "BIG5",
     "IBM850",
+    "ISO-2022-JP-1",
+    "TIS620.2533-0",
+    "BIG-5",
     "IBM-850",
-    "TCVN-5712",
-    "UTF-32LE",
+    "CSBIG5",
+    "MS-CYRL",
+    "ISO-2022-JP-2",
+    "ISO-2022-JP-MS",
+    "CSISO2022JP2",
+    "X0212",
+    "CN-BIG5",
+    "ISO-IR-148",
+    "US-ASCII",
+    "ISO646-US",
+    "LATIN4",
+    "MS-ANSI",
     "MACCYRILLIC",
-    "TIS620.2529-1",
-    "MACICELAND",
-    "JP",
-    "CSVISCII",
-    "MACROMAN",
-    "GREEK8",
-    "VISCII1.1-1",
-    "UCS-4BE",
+    "ISO_8859-1",
+    "ISO_8859-6",
+    "ISO_8859-11",
     "IBM-CP1133",
-    "ISO_646.IRV:1991",
-    "MACCROATIAN",
-    "UCS-2BE",
+    "ISO_8859-16",
+    "ISO_8859-5",
+    "CHINESE",
+    "ISO_8859-16:2001",
+    "CYRILLIC-ASIAN",
+    "ISO_8859-15",
+    "CSGB2312",
+    "ISO_8859-3",
+    "ISO-IR-100",
+    "ISO_8859-2",
+    "ISO_8859-13",
+    "JIS_C6226-1983",
+    "ISO_8859-8",
+    "RK1048",
+    "X0201",
+    "ISO_8859-15:1998",
+    "ISO8859-4",
+    "ISO-IR-149",
     "ARMSCII-8",
-    "CN-GB",
-    "WINDOWS-1251",
+    "KOI8-T",
+    "ISO8859-14",
+    "ISO-8859-4",
+    "ISO-8859-14",
+    "EUCTW",
+    "X0208",
+    "EUC-TW",
+    "UCS-2LE",
+    "ISO-10646-UCS-2",
+    "ISO_8859-9",
+    "CHAR",
+    "CSISOLATINARABIC",
+    "EUCJP",
+    "PT154",
+    "JIS_C6220-1969-RO",
+    "EUCJP-WIN",
+    "EUC-JP",
+    "ISO_8859-10:1992",
+    "CSSHIFTJIS",
+    "IBM-EUCCN",
+    "UCS-4",
+    "ISO-IR-14",
+    "ISO-2022-JP",
+    "CSUCS4",
+    "CSIBM866",
+    "CSISO2022JP",
+    "CSISO58GB231280",
+    "MULELAO-1",
+    "SHIFT_JIS",
     "JAVA",
+    "ECMA-118",
+    "EUCJPMS",
+    "UTF-16LE",
+    "ROMAN8",
+    "ISO646-JP",
+    "ISO_8859-10",
+    "EUCJP-MS",
+    "ELOT_928",
+    "MS-EE",
+    "EUC-JP-MS",
+    "UTF-32LE",
+    "GB_2312-80",
+    "CN-GB-ISOIR165",
+    "UCS-2-INTERNAL",
+    "CSUNICODE11",
+    "TCVN5712-1",
+    "UNICODE-1-1",
+    "TCVN-5712",
+    "ISO_8859-14:1998",
+    "WINDOWS-1251",
     "WINDOWS-1256",
-    "WINDOWS-936",
-    "UCS-4-SWAPPED",
-    "WINDOWS-1254",
-    "GBK",
+    "KZ-1048",
     "WINDOWS-1255",
-    "TIS620.2533-1",
-    "UCS-2-SWAPPED",
+    "GB_1988-80",
+    "WINDOWS-1253",
     "WINDOWS-1252",
-    "KS_C_5601-1987",
-    "CN-GB-ISOIR165",
     "WINDOWS-1258",
-    "IBM-EUCCN",
-    "JIS_C6226-1983",
-    "UNICODE-1-1-UTF-7",
-    "CSKSC56011987",
-    "WINDOWS-1253",
-    "CSUNICODE11UTF7",
-    "WCHAR_T",
-    "JIS_C6220-1969-RO",
-    "CSISO58GB231280",
-    "ASMO-708",
-    "WINDOWS-1250",
+    "ISO-IR-179",
+    "CSPC862LATINHEBREW",
+    "CSKZ1048",
+    "CSISOLATIN4",
+    "UCS-4LE",
+    "ISO-10646-UCS-4",
+    "CSWINDOWS31J",
+    "WINDOWS-936",
+    "ISO_8859-5:1988",
+    "CSEUCTW",
+    "ISO_8859-3:1988",
+    "WINDOWS-51932",
+    "ISO_8859-8:1988",
+    "KOI8-R",
+    "JISX0201-1976",
+    "CSKOI8R",
+    "EUCJP-OPEN",
+    "WINDOWS-932",
+    "GREEK8",
+    "CN-GB",
+    "GEORGIAN-PS",
+    "CSISOLATINGREEK",
+    "PTCP154",
+    "GBK",
+    "MACTHAI",
+    "WINDOWS-31J",
     "KOI8-U",
-    "KOI8-RU",
-    "TIS620.2533-0",
-    "MS-HEBR",
-    "ISO_8859-1:1987",
-    "MACARABIC",
-    "ISO_8859-6:1987",
+    "WINDOWS-1250",
+    "GEORGIAN-ACADEMY",
+    "ARABIC",
+    "HZ-GB-2312",
+    "CSISOLATINHEBREW",
+    "ISO-IR-144",
+    "CP874",
+    "ISO_8859-9:1989",
+    "CSUNICODE",
+    "CP367",
+    "KSC_5601",
+    "MACROMAN",
+    "CP1257",
+    "CSPC850MULTILINGUAL",
+    "ISO_8859-4",
+    "CSPTCP154",
+    "UCS-4-INTERNAL",
+    "ISO_8859-14",
+    "SHIFT_JIS-MS",
+    "EUCKR",
+    "LATIN7",
     "MACINTOSH",
-    "CSPC862LATINHEBREW",
+    "EUC-KR",
+    "WINDOWS-1254",
+    "UCS-2BE",
+    "ISO-2022-KR",
+    "CSISO2022KR",
+    "KOREAN",
+    "MACCROATIAN",
+    "ISO_8859-4:1988",
     "ISO8859-7",
     "ISO-8859-7",
-    "ISO_8859-7",
-    "CSIBM866",
-    "ISO_8859-2:1987",
+    "TCVN5712-1:1993",
+    "CSISO57GB1988",
+    "UNICODELITTLE",
+    "HP-ROMAN8",
+    "JIS_X0212",
+    "IBM-EUCTW",
+    "CSISO87JISX0208",
+    "KOI8-RU",
+    "ASMO-708",
+    "CSKSC56011987",
+    "ECMA-114",
+    "UTF-16BE",
+    "ISO_646.IRV:1991",
+    "BIGFIVE",
+    "IBM-EUCJP",
+    "BIG-FIVE",
+    "UTF-32BE",
+    "JIS_X0201",
+    "ISO-IR-57",
+    "STRK1048-2002",
+    "IBM367",
+    "ISO-IR-157",
+    "ISO-IR-87",
+    "ISO-IR-127",
+    "JIS_X0208",
+    "JIS_X0212-1990",
+    "NEXTSTEP",
+    "UCS-4BE",
+    "JIS_X0208-1983",
+    "CSEUCKR",
+    "CSUNICODE11UTF7",
+    "GREEK",
+    "UNICODE-1-1-UTF-7",
+    "WINDOWS-1257",
     "CSMACINTOSH",
-    "JIS0208",
-    "MACROMANIA",
+    "UTF-7",
+    "ISO_8859-1:1987",
+    "ISO_8859-6:1987",
+    "JIS_X0212.1990-0",
     "ISO_8859-7:2003",
-    "KOI8-T",
-    "EUCJP",
-    "EUC-JP",
+    "ISO_8859-2:1987",
+    "UNICODEBIG",
+    "CSHPROMAN8",
     "BIG5HKSCS",
+    "JIS_X0208-1990",
     "BIG5-HKSCS",
     "MACCENTRALEUROPE",
-    "MACTHAI",
+    "MS_KANJI",
+    "MACICELAND",
+    "MACARABIC",
+    "KS_C_5601-1989",
+    "JOHAB",
+    "ISO_8859-7",
+    "MACROMANIA",
     "ANSI_X3.4-1986",
-    "EXTENDED_UNIX_CODE_PACKED_FORMAT_FOR_JAPANESE",
-    "EUCTW",
-    "EUC-TW",
-    "CSISOLATINHEBREW",
-    "UTF-16BE",
-    "ISO-IR-57",
+    "HEBREW",
+    "WCHAR_T",
     "ANSI_X3.4-1968",
-    "ISO-IR-157",
-    "ISO-IR-127",
-    "ISO-IR-87",
-    "CSPC850MULTILINGUAL",
-    "CSISO57GB1988",
-    "ISO646-JP",
-    "LATIN7",
-    "GREEK",
-    "CSISOLATINGREEK",
-    "CSISO14JISC6220RO",
-    "UTF-32BE",
-    "MS-ARAB",
-    "TCVN5712-1:1993",
-    "UTF-7",
-    "ISO-2022-JP-1",
-    "ISO-2022-JP-MS",
-    "ISO-2022-JP-2",
-    "WINDOWS-1257",
-    "NEXTSTEP",
-    "WINDOWS-874",
-    "CSISO2022JP2",
-    "CSISO159JISX02121990",
     "IBM-EUCKR",
-    "CSEUCTW",
-    "ISO-2022-JP",
-    "UNICODELITTLE",
-    "BIGFIVE",
-    "BIG-FIVE",
-    "HEBREW",
-    "CSHALFWIDTHKATAKANA",
-    "CSISO2022JP",
-    "UNICODEBIG",
-    "ISO_8859-7:1987",
-    "IBM367",
-    "JIS_X0212",
-    "BIG5-HKSCS:1999",
+    "UCS-2-SWAPPED",
+    "MS-HEBR",
+    "MS-TURK",
     "BIG5-HKSCS:2001",
-    "JIS_X0201",
-    "BIG5-HKSCS:2004",
-    "JISX0201-1976",
     "BIG5-HKSCS:2008",
+    "WINBALTRIM",
+    "BIG5-HKSCS:1999",
+    "WINDOWS-874",
     "MACUKRAINE",
-    "JIS_X0212-1990",
-    "JIS_X0208",
-    "JIS_X0208-1983",
-    "JIS_X0208-1990",
-    "MS-GREEK",
     "MACGREEK",
-    "JOHAB",
+    "MS-GREEK",
+    "UCS-4-SWAPPED",
+    "ISO_8859-7:1987",
+    "UTF7IMAP",
+    "MS-ARAB",
+    "UTF-7-IMAP",
+    "BIG5-HKSCS:2004",
+    "KS_C_5601-1987",
     "MACTURKISH",
-    "MS-TURK",
-    "SHIFT-JIS",
-    "SHIFT_JIS",
-    "CSSHIFTJIS",
-    "JIS_X0212.1990-0",
-    "IBM-EUCJP",
     "MACHEBREW",
-    "IBM-EUCTW",
-    "MS_KANJI",
+    "CSHALFWIDTHKATAKANA",
     "CSEUCPKDFMTJAPANESE",
-    "WINBALTRIM",
-    "CSISO87JISX0208"
+    "EXTENDED_UNIX_CODE_PACKED_FORMAT_FOR_JAPANESE"
   };
 #define stringpool ((const char *) &stringpool_contents)
 
 static const struct alias aliases[] =
   {
-    {-1}, {-1}, {-1}, {-1}, {-1},
-#line 51 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str5, ei_c99},
-    {-1},
-#line 292 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str7, ei_iso646_cn},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+#line 294 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str9, ei_iso646_cn},
+    {-1}, {-1}, {-1},
+#line 62 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str13, ei_iso8859_1},
+#line 136 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str14, ei_iso8859_10},
     {-1}, {-1},
-#line 60 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str10, ei_iso8859_1},
+#line 128 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str17, ei_iso8859_9},
     {-1}, {-1},
-#line 134 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str13, ei_iso8859_10},
-    {-1},
-#line 368 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str15, ei_local_char},
-#line 362 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str16, ei_cp949},
-#line 84 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str17, ei_iso8859_4},
-    {-1}, {-1}, {-1},
-#line 126 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str21, ei_iso8859_9},
-#line 231 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str22, ei_hp_roman8},
+#line 78 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str20, ei_iso8859_3},
+#line 70 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str21, ei_iso8859_2},
     {-1},
-#line 68 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str24, ei_iso8859_2},
-    {-1}, {-1}, {-1},
-#line 152 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str28, ei_iso8859_14},
-#line 57 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str29, ei_iso8859_1},
-    {-1}, {-1}, {-1},
+#line 154 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str23, ei_iso8859_14},
+#line 212 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str24, ei_cp866},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+#line 214 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str32, ei_cp1131},
+#line 383 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str33, ei_johab},
 #line 210 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str33, ei_cp866},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str34, ei_cp866},
     {-1}, {-1},
-#line 76 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str36, ei_iso8859_3},
+#line 177 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str37, ei_cp1251},
+#line 208 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str38, ei_cp862},
+#line 193 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str39, ei_cp1256},
     {-1}, {-1}, {-1},
-#line 240 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str40, ei_pt154},
+#line 323 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str43, ei_sjis},
     {-1},
-#line 208 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str42, ei_cp866},
-#line 175 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str43, ei_cp1251},
-#line 212 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str44, ei_cp1131},
-#line 332 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str45, ei_cp936},
+#line 190 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str45, ei_cp1255},
+#line 250 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str46, ei_cp1133},
     {-1},
-#line 365 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str47, ei_johab},
-#line 339 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str48, ei_hz},
-#line 191 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str49, ei_cp1256},
-    {-1}, {-1}, {-1}, {-1}, {-1},
 #line 206 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str55, ei_cp862},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str48, ei_cp862},
+    {-1}, {-1},
+#line 184 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str51, ei_cp1253},
     {-1},
-#line 185 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str57, ei_cp1254},
-    {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-#line 204 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str64, ei_cp862},
-#line 188 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str65, ei_cp1255},
+#line 180 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str53, ei_cp1252},
+    {-1}, {-1},
+#line 350 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str56, ei_cp936},
+#line 199 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str57, ei_cp1258},
+    {-1}, {-1}, {-1},
+#line 61 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str61, ei_iso8859_1},
     {-1},
-#line 316 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str67, ei_cp932},
+#line 135 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str63, ei_iso8859_10},
+    {-1},
+#line 53 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str65, ei_c99},
     {-1}, {-1}, {-1},
-#line 178 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str71, ei_cp1252},
-    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-#line 197 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str79, ei_cp1258},
+#line 127 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str69, ei_iso8859_9},
 #line 326 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str80, ei_euc_cn},
-#line 325 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str81, ei_euc_cn},
-    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-#line 238 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str90, ei_pt154},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str70, ei_cp932},
     {-1}, {-1}, {-1}, {-1},
-#line 182 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str95, ei_cp1253},
-#line 248 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str96, ei_cp1133},
-#line 166 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str97, ei_iso8859_16},
+#line 77 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str75, ei_iso8859_3},
+    {-1},
+#line 69 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str77, ei_iso8859_2},
     {-1}, {-1}, {-1},
-#line 243 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str101, ei_rk1048},
-#line 324 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str102, ei_iso2022_jpms},
+#line 153 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str81, ei_iso8859_14},
+#line 318 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str82, ei_cp51932},
+#line 59 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str83, ei_iso8859_1},
+    {-1}, {-1}, {-1},
+#line 345 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str87, ei_euc_cn},
+    {-1},
+#line 64 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str89, ei_iso8859_1},
+    {-1},
+#line 104 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str91, ei_iso8859_6},
+    {-1},
+#line 141 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str93, ei_iso8859_11},
+    {-1},
+#line 169 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str95, ei_iso8859_16},
+#line 55 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str96, ei_iso8859_1},
+#line 95 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str97, ei_iso8859_5},
+#line 96 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str98, ei_iso8859_6},
+#line 342 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str99, ei_iso2022_jpms},
+#line 139 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str100, ei_iso8859_11},
+#line 162 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str101, ei_iso8859_15},
+#line 163 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str102, ei_iso8859_16},
+#line 80 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str103, ei_iso8859_3},
+#line 89 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str104, ei_iso8859_5},
+#line 72 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str105, ei_iso8859_2},
+#line 344 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str106, ei_euc_cn},
+#line 147 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str107, ei_iso8859_13},
+#line 157 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str108, ei_iso8859_15},
+#line 122 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str109, ei_iso8859_8},
+#line 73 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str110, ei_iso8859_3},
     {-1},
-#line 363 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str104, ei_cp949},
-    {-1}, {-1}, {-1},
-#line 351 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str108, ei_cp950},
+#line 65 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str112, ei_iso8859_2},
+#line 343 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str113, ei_euc_cn},
+#line 142 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str114, ei_iso8859_13},
+    {-1},
+#line 116 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str116, ei_iso8859_8},
+#line 168 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str117, ei_iso8859_16},
+#line 233 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str118, ei_hp_roman8},
     {-1},
+#line 161 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str120, ei_iso8859_15},
+#line 86 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str121, ei_iso8859_4},
+#line 203 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str122, ei_cp850},
+#line 381 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str123, ei_cp949},
+#line 261 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str124, ei_viscii},
+#line 354 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str125, ei_iso2022_cn},
 #line 21 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str110, ei_ascii},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str126, ei_ascii},
+    {-1}, {-1},
+#line 355 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str129, ei_iso2022_cn},
+    {-1},
+#line 218 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str131, ei_mac_roman},
+    {-1},
+#line 263 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str133, ei_viscii},
+    {-1},
 #line 201 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str111, ei_cp850},
-    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-    {-1}, {-1}, {-1},
-#line 290 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str124, ei_iso646_cn},
-#line 313 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str125, ei_sjis},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str135, ei_cp850},
     {-1},
-#line 172 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str127, ei_cp1250},
-#line 199 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str128, ei_cp850},
+#line 174 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str137, ei_cp1250},
+#line 264 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str138, ei_tcvn},
+#line 271 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str139, ei_iso646_jp},
+#line 16 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str140, ei_ascii},
+#line 130 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str141, ei_iso8859_9},
+#line 13 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str142, ei_ascii},
+    {-1},
+#line 330 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str144, ei_cp932},
+#line 93 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str145, ei_iso8859_5},
     {-1}, {-1},
-#line 33 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str131, ei_ucs4},
-    {-1}, {-1}, {-1}, {-1},
-#line 35 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str136, ei_ucs4},
-    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-#line 24 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str145, ei_ucs2},
-#line 239 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str146, ei_pt154},
+#line 123 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str148, ei_iso8859_9},
+#line 258 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str149, ei_tis620},
+#line 292 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str150, ei_iso646_cn},
+#line 369 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str151, ei_cp950},
     {-1}, {-1},
-#line 327 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str149, ei_euc_cn},
-#line 128 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str150, ei_iso8859_9},
-#line 121 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str151, ei_iso8859_9},
-#line 122 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str152, ei_iso8859_9},
+#line 211 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str154, ei_cp866},
+#line 300 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str155, ei_isoir165},
+#line 109 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str156, ei_iso8859_7},
+#line 24 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str157, ei_ucs2},
     {-1},
-#line 62 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str154, ei_iso8859_1},
-#line 53 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str155, ei_iso8859_1},
-#line 54 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str156, ei_iso8859_1},
-#line 139 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str157, ei_iso8859_11},
-#line 137 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str158, ei_iso8859_11},
-#line 138 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str159, ei_iso8859_11},
-#line 102 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str160, ei_iso8859_6},
-#line 94 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str161, ei_iso8859_6},
-#line 95 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str162, ei_iso8859_6},
-#line 167 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str163, ei_iso8859_16},
-#line 161 "lib/aliases_sysaix.gperf"
+#line 215 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str159, ei_cp1131},
+#line 22 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str160, ei_ascii},
+#line 356 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str161, ei_iso2022_cn_ext},
+    {-1}, {-1},
+#line 166 "lib/aliases_sysaix.gperf"
     {(int)(long)&((struct stringpool_t *)0)->stringpool_str164, ei_iso8859_16},
-#line 162 "lib/aliases_sysaix.gperf"
+#line 167 "lib/aliases_sysaix.gperf"
     {(int)(long)&((struct stringpool_t *)0)->stringpool_str165, ei_iso8859_16},
-    {-1},
-#line 163 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str167, ei_iso8859_16},
-#line 86 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str168, ei_iso8859_4},
-#line 79 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str169, ei_iso8859_4},
-#line 80 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str170, ei_iso8859_4},
-#line 154 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str171, ei_iso8859_14},
-#line 147 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str172, ei_iso8859_14},
-#line 148 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str173, ei_iso8859_14},
-    {-1}, {-1},
-#line 93 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str176, ei_iso8859_5},
-#line 87 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str177, ei_iso8859_5},
-#line 88 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str178, ei_iso8859_5},
-#line 160 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str179, ei_iso8859_15},
+#line 297 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str166, ei_gb2312},
 #line 155 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str180, ei_iso8859_15},
-#line 156 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str181, ei_iso8859_15},
-#line 70 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str182, ei_iso8859_2},
-#line 63 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str183, ei_iso8859_2},
-#line 64 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str184, ei_iso8859_2},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str167, ei_iso8859_14},
+#line 207 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str168, ei_cp862},
+    {-1}, {-1}, {-1},
+#line 351 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str172, ei_cp936},
+#line 119 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str173, ei_iso8859_8},
+#line 253 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str174, ei_tis620},
+    {-1},
+#line 357 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str176, ei_hz},
     {-1}, {-1},
-#line 262 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str187, ei_tcvn},
-#line 150 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str188, ei_iso8859_14},
-#line 149 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str189, ei_iso8859_14},
-#line 120 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str190, ei_iso8859_8},
-#line 114 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str191, ei_iso8859_8},
-#line 115 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str192, ei_iso8859_8},
-#line 157 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str193, ei_iso8859_15},
-#line 16 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str194, ei_ascii},
+#line 290 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str179, ei_jisx0212},
+#line 183 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str180, ei_cp1252},
+#line 252 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str181, ei_tis620},
+#line 148 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str182, ei_iso8859_13},
     {-1},
-#line 144 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str196, ei_iso8859_13},
-#line 303 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str197, ei_ksc5601},
+#line 334 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str184, ei_cp932},
+#line 262 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str185, ei_viscii},
+#line 332 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str186, ei_cp932},
     {-1},
-#line 336 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str199, ei_iso2022_cn},
+#line 322 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str188, ei_sjis},
+    {-1}, {-1}, {-1},
+#line 280 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str192, ei_jisx0208},
+#line 138 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str193, ei_iso8859_10},
+    {-1}, {-1},
+#line 68 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str196, ei_iso8859_2},
+#line 335 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str197, ei_cp932},
+#line 320 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str198, ei_cp51932},
     {-1},
-#line 287 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str201, ei_jisx0212},
-#line 91 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str202, ei_iso8859_5},
-#line 256 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str203, ei_tis620},
+#line 131 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str200, ei_iso8859_10},
+#line 38 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str201, ei_utf16},
+#line 289 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str202, ei_jisx0212},
+#line 60 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str203, ei_iso8859_1},
     {-1},
-#line 268 "lib/aliases_sysaix.gperf"
+#line 272 "lib/aliases_sysaix.gperf"
     {(int)(long)&((struct stringpool_t *)0)->stringpool_str205, ei_iso646_jp},
-#line 78 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str206, ei_iso8859_3},
-#line 71 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str207, ei_iso8859_3},
-#line 72 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str208, ei_iso8859_3},
-#line 145 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str209, ei_iso8859_13},
-#line 140 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str210, ei_iso8859_13},
-#line 141 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str211, ei_iso8859_13},
-#line 337 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str212, ei_iso2022_cn},
-#line 216 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str213, ei_mac_roman},
-#line 107 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str214, ei_iso8859_7},
-#line 90 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str215, ei_iso8859_5},
-    {-1}, {-1}, {-1},
-#line 298 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str219, ei_isoir165},
-#line 131 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str220, ei_iso8859_10},
     {-1},
-#line 159 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str222, ei_iso8859_15},
+#line 380 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str207, ei_cp949},
     {-1}, {-1},
-#line 59 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str225, ei_iso8859_1},
-#line 289 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str226, ei_iso646_cn},
+#line 257 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str210, ei_tis620},
     {-1},
-#line 164 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str228, ei_iso8859_16},
-#line 241 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str229, ei_pt154},
+#line 63 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str212, ei_iso8859_1},
     {-1},
-#line 133 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str231, ei_iso8859_10},
-#line 74 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str232, ei_iso8859_3},
-#line 257 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str233, ei_cp874},
+#line 137 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str214, ei_iso8859_10},
+#line 23 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str215, ei_utf8},
+    {-1}, {-1},
+#line 160 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str218, ei_iso8859_15},
     {-1},
-#line 14 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str235, ei_ascii},
-#line 66 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str236, ei_iso8859_2},
-#line 124 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str237, ei_iso8859_9},
-#line 295 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str238, ei_gb2312},
-#line 83 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str239, ei_iso8859_4},
-#line 177 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str240, ei_cp1251},
-#line 136 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str241, ei_iso8859_10},
 #line 129 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str242, ei_iso8859_10},
-#line 130 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str243, ei_iso8859_10},
-#line 251 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str244, ei_tis620},
-#line 250 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str245, ei_tis620},
-#line 294 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str246, ei_gb2312},
-#line 125 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str247, ei_iso8859_9},
-#line 109 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str248, ei_iso8859_7},
-#line 333 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str249, ei_cp936},
-    {-1}, {-1}, {-1},
-#line 67 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str253, ei_iso8859_2},
-#line 335 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str254, ei_gb18030},
-#line 38 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str255, ei_utf16},
-#line 117 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str256, ei_iso8859_8},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str220, ei_iso8859_9},
+#line 94 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str221, ei_iso8859_5},
+#line 41 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str222, ei_utf32},
+    {-1},
+#line 152 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str224, ei_iso8859_14},
+    {-1},
+#line 79 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str226, ei_iso8859_3},
+#line 353 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str227, ei_gb18030},
+#line 71 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str228, ei_iso8859_2},
+    {-1},
+#line 255 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str230, ei_tis620},
+    {-1}, {-1}, {-1}, {-1},
+#line 254 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str235, ei_tis620},
     {-1}, {-1}, {-1},
-#line 37 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str260, ei_ucs4le},
-#line 151 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str261, ei_iso8859_14},
-    {-1}, {-1},
-#line 230 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str264, ei_hp_roman8},
-    {-1}, {-1},
-#line 31 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str267, ei_ucs2le},
+#line 146 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str239, ei_iso8859_13},
+    {-1},
 #line 242 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str268, ei_pt154},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str241, ei_pt154},
+    {-1}, {-1}, {-1},
+#line 329 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str245, ei_cp932},
+#line 84 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str246, ei_iso8859_4},
     {-1},
-#line 235 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str270, ei_georgian_academy},
-#line 359 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str271, ei_euc_kr},
-#line 358 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str272, ei_euc_kr},
+#line 76 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str248, ei_iso8859_3},
+    {-1}, {-1}, {-1}, {-1},
+#line 187 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str253, ei_cp1254},
+#line 363 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str254, ei_ces_big5},
+#line 202 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str255, ei_cp850},
     {-1},
-#line 34 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str274, ei_ucs4},
-#line 286 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str275, ei_jisx0212},
-#line 300 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str276, ei_ksc5601},
-#line 75 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str277, ei_iso8859_3},
-#line 82 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str278, ei_iso8859_4},
+#line 338 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str257, ei_iso2022_jp1},
+    {-1}, {-1},
+#line 256 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str260, ei_tis620},
+#line 364 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str261, ei_ces_big5},
+#line 205 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str262, ei_cp850},
+#line 368 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str263, ei_ces_big5},
+#line 179 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str264, ei_cp1251},
+#line 339 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str265, ei_iso2022_jp2},
     {-1},
-#line 13 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str280, ei_ascii},
-#line 25 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str281, ei_ucs2},
-#line 23 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str282, ei_utf8},
-#line 302 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str283, ei_ksc5601},
+#line 341 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str267, ei_iso2022_jpms},
+#line 340 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str268, ei_iso2022_jp2},
+#line 288 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str269, ei_jisx0212},
+#line 367 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str270, ei_ces_big5},
+    {-1}, {-1}, {-1},
+#line 126 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str274, ei_iso8859_9},
+#line 12 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str275, ei_ascii},
+#line 14 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str276, ei_ascii},
+#line 85 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str277, ei_iso8859_4},
+#line 182 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str278, ei_cp1252},
     {-1},
-#line 305 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str285, ei_ksc5601},
-#line 345 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str286, ei_ces_big5},
-#line 346 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str287, ei_ces_big5},
-#line 29 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str288, ei_ucs2be},
-#line 273 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str289, ei_jisx0201},
-#line 252 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str290, ei_tis620},
-    {-1}, {-1},
-#line 30 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str293, ei_ucs2be},
+#line 224 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str280, ei_mac_cyrillic},
+#line 56 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str281, ei_iso8859_1},
     {-1},
-#line 22 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str295, ei_ascii},
-    {-1}, {-1}, {-1}, {-1}, {-1},
-#line 245 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str301, ei_rk1048},
-#line 158 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str302, ei_iso8859_15},
-#line 41 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str303, ei_utf32},
+#line 97 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str283, ei_iso8859_6},
     {-1},
-#line 247 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str305, ei_mulelao},
-#line 297 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str306, ei_gb2312},
-#line 100 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str307, ei_iso8859_6},
-#line 246 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str308, ei_rk1048},
-#line 229 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str309, ei_hp_roman8},
-#line 98 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str310, ei_iso8859_6},
+#line 140 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str285, ei_iso8859_11},
+#line 251 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str286, ei_cp1133},
+#line 164 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str287, ei_iso8859_16},
     {-1},
+#line 90 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str289, ei_iso8859_5},
+#line 299 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str290, ei_gb2312},
 #line 165 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str312, ei_iso8859_16},
-#line 168 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str313, ei_koi8_r},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str291, ei_iso8859_16},
+#line 243 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str292, ei_pt154},
+#line 158 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str293, ei_iso8859_15},
+#line 347 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str294, ei_euc_cn},
+#line 74 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str295, ei_iso8859_3},
+#line 58 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str296, ei_iso8859_1},
+#line 66 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str297, ei_iso8859_2},
     {-1},
+#line 143 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str299, ei_iso8859_13},
+#line 283 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str300, ei_jisx0208},
+#line 117 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str301, ei_iso8859_8},
+#line 245 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str302, ei_rk1048},
+#line 275 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str303, ei_jisx0201},
+#line 159 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str304, ei_iso8859_15},
+#line 88 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str305, ei_iso8859_4},
+#line 305 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str306, ei_ksc5601},
 #line 236 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str315, ei_georgian_ps},
-#line 169 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str316, ei_koi8_r},
-    {-1},
-#line 338 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str318, ei_iso2022_cn_ext},
-    {-1},
-#line 56 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str320, ei_iso8859_1},
-#line 146 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str321, ei_iso8859_13},
-#line 58 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str322, ei_iso8859_1},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str307, ei_armscii_8},
+#line 239 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str308, ei_koi8_t},
+#line 156 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str309, ei_iso8859_14},
     {-1}, {-1},
-#line 279 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str325, ei_jisx0208},
-    {-1},
-#line 123 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str327, ei_iso8859_9},
-    {-1}, {-1}, {-1}, {-1},
-#line 108 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str332, ei_iso8859_7},
+#line 81 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str312, ei_iso8859_4},
+    {-1}, {-1}, {-1},
+#line 149 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str316, ei_iso8859_14},
     {-1}, {-1},
-#line 209 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str335, ei_cp866},
+#line 360 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str319, ei_euc_tw},
+    {-1}, {-1}, {-1},
+#line 281 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str323, ei_jisx0208},
     {-1}, {-1},
-#line 213 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str338, ei_cp1131},
+#line 359 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str326, ei_euc_tw},
+    {-1}, {-1}, {-1},
+#line 31 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str330, ei_ucs2le},
+#line 25 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str331, ei_ucs2},
     {-1},
-#line 61 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str340, ei_iso8859_1},
+#line 124 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str333, ei_iso8859_9},
+    {-1}, {-1}, {-1}, {-1},
+#line 386 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str338, ei_local_char},
+#line 103 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str339, ei_iso8859_6},
+#line 309 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str340, ei_euc_jp},
+    {-1}, {-1}, {-1},
+#line 240 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str344, ei_pt154},
+#line 268 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str345, ei_iso646_jp},
+#line 316 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str346, ei_eucjp_ms},
+#line 308 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str347, ei_euc_jp},
+#line 133 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str348, ei_iso8859_10},
     {-1},
-#line 259 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str342, ei_viscii},
+#line 325 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str350, ei_sjis},
+#line 348 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str351, ei_euc_cn},
+    {-1}, {-1}, {-1}, {-1}, {-1},
+#line 33 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str357, ei_ucs4},
+#line 270 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str358, ei_iso646_jp},
+#line 336 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str359, ei_iso2022_jp},
+#line 35 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str360, ei_ucs4},
+#line 213 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str361, ei_cp866},
     {-1},
-#line 329 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str344, ei_euc_cn},
+#line 337 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str363, ei_iso2022_jp},
+    {-1}, {-1}, {-1},
+#line 298 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str367, ei_gb2312},
+    {-1}, {-1}, {-1},
+#line 249 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str371, ei_mulelao},
     {-1},
-#line 135 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str346, ei_iso8859_10},
-#line 92 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str347, ei_iso8859_5},
-    {-1}, {-1},
-#line 26 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str350, ei_ucs2},
+#line 321 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str373, ei_sjis},
     {-1},
-#line 101 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str352, ei_iso8859_6},
+#line 54 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str375, ei_java},
     {-1},
-#line 85 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str354, ei_iso8859_4},
+#line 110 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str377, ei_iso8859_7},
     {-1},
-#line 81 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str356, ei_iso8859_4},
-#line 205 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str357, ei_cp862},
-    {-1}, {-1},
-#line 89 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str360, ei_iso8859_5},
 #line 317 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str361, ei_cp932},
-#line 127 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str362, ei_iso8859_9},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str379, ei_eucjp_ms},
     {-1},
+#line 40 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str381, ei_utf16le},
 #line 232 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str364, ei_hp_roman8},
-#line 181 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str365, ei_cp1252},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str382, ei_hp_roman8},
     {-1},
-#line 116 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str367, ei_iso8859_8},
-#line 69 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str368, ei_iso8859_2},
+#line 269 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str384, ei_iso646_jp},
+#line 132 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str385, ei_iso8859_10},
+#line 313 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str386, ei_eucjp_ms},
     {-1}, {-1}, {-1},
-#line 360 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str372, ei_euc_kr},
-    {-1},
-#line 244 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str374, ei_rk1048},
-#line 73 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str375, ei_iso8859_3},
-#line 142 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str376, ei_iso8859_13},
-    {-1},
-#line 350 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str378, ei_ces_big5},
-#line 349 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str379, ei_ces_big5},
-    {-1},
-#line 153 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str381, ei_iso8859_14},
-    {-1}, {-1}, {-1}, {-1},
-#line 340 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str386, ei_hz},
-    {-1},
-#line 40 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str388, ei_utf16le},
+#line 111 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str390, ei_iso8859_7},
     {-1},
-#line 366 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str390, ei_iso2022_kr},
-#line 12 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str391, ei_ascii},
-#line 77 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str392, ei_iso8859_3},
-    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+#line 176 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str392, ei_cp1250},
+#line 315 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str393, ei_eucjp_ms},
     {-1},
-#line 367 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str403, ei_iso2022_kr},
+#line 43 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str395, ei_utf32le},
+#line 296 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str396, ei_gb2312},
+#line 301 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str397, ei_isoir165},
     {-1}, {-1},
-#line 174 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str406, ei_cp1250},
-    {-1}, {-1}, {-1}, {-1},
 #line 49 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str411, ei_ucs4internal},
-#line 180 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str412, ei_cp1252},
-#line 264 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str413, ei_tcvn},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str400, ei_ucs2internal},
+#line 30 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str401, ei_ucs2be},
     {-1},
+#line 266 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str403, ei_tcvn},
+    {-1}, {-1},
+#line 29 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str406, ei_ucs2be},
+#line 265 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str407, ei_tcvn},
+#line 151 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str408, ei_iso8859_14},
+    {-1}, {-1}, {-1}, {-1},
+#line 178 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str413, ei_cp1251},
 #line 194 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str415, ei_cp1257},
-#line 19 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str416, ei_ascii},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str414, ei_cp1256},
+    {-1},
+#line 247 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str416, ei_rk1048},
+#line 191 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str417, ei_cp1255},
+    {-1},
+#line 291 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str419, ei_iso646_cn},
+#line 185 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str420, ei_cp1253},
+#line 181 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str421, ei_cp1252},
     {-1},
-#line 47 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str418, ei_ucs2internal},
-    {-1}, {-1},
 #line 200 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str421, ei_cp850},
-#line 203 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str422, ei_cp850},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str423, ei_cp1258},
+#line 144 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str424, ei_iso8859_13},
+#line 209 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str425, ei_cp862},
+#line 248 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str426, ei_rk1048},
     {-1},
-#line 263 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str424, ei_tcvn},
-#line 43 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str425, ei_utf32le},
-#line 222 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str426, ei_mac_cyrillic},
+#line 87 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str428, ei_iso8859_4},
+    {-1},
+#line 37 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str430, ei_ucs4le},
+#line 34 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str431, ei_ucs4},
     {-1},
-#line 253 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str428, ei_tis620},
-#line 219 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str429, ei_mac_iceland},
-#line 269 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str430, ei_iso646_jp},
-    {-1}, {-1}, {-1},
-#line 261 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str434, ei_viscii},
-    {-1}, {-1},
-#line 214 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str437, ei_mac_roman},
-    {-1}, {-1},
-#line 110 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str440, ei_iso8859_7},
-#line 260 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str441, ei_viscii},
-    {-1}, {-1}, {-1},
-#line 36 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str445, ei_ucs4be},
-#line 249 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str446, ei_cp1133},
-#line 15 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str447, ei_ascii},
-    {-1}, {-1}, {-1},
-#line 220 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str451, ei_mac_croatian},
-#line 27 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str452, ei_ucs2be},
-#line 234 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str453, ei_armscii_8},
 #line 328 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str454, ei_euc_cn},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str433, ei_cp932},
     {-1},
-#line 176 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str456, ei_cp1251},
-#line 52 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str457, ei_java},
+#line 352 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str435, ei_cp936},
+#line 91 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str436, ei_iso8859_5},
+#line 361 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str437, ei_euc_tw},
     {-1},
-#line 192 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str459, ei_cp1256},
-#line 334 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str460, ei_cp936},
+#line 75 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str439, ei_iso8859_3},
+#line 319 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str440, ei_cp51932},
+    {-1},
+#line 118 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str442, ei_iso8859_8},
+    {-1},
+#line 170 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str444, ei_koi8_r},
+#line 274 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str445, ei_jisx0201},
+#line 171 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str446, ei_koi8_r},
+#line 314 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str447, ei_eucjp_ms},
     {-1},
-#line 50 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str462, ei_ucs4swapped},
-#line 186 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str463, ei_cp1254},
-    {-1}, {-1},
 #line 331 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str466, ei_ces_gbk},
-#line 189 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str467, ei_cp1255},
-#line 255 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str468, ei_tis620},
-#line 48 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str469, ei_ucs2swapped},
-#line 179 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str470, ei_cp1252},
-#line 301 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str471, ei_ksc5601},
-#line 299 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str472, ei_isoir165},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str449, ei_cp932},
     {-1},
-#line 198 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str474, ei_cp1258},
-#line 330 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str475, ei_euc_cn},
-#line 281 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str476, ei_jisx0208},
-    {-1}, {-1}, {-1},
-#line 45 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str480, ei_utf7},
-#line 304 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str481, ei_ksc5601},
-#line 183 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str482, ei_cp1253},
-#line 46 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str483, ei_utf7},
-#line 369 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str484, ei_local_wchar_t},
-    {-1}, {-1}, {-1}, {-1}, {-1},
-#line 266 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str490, ei_iso646_jp},
-    {-1}, {-1},
-#line 296 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str493, ei_gb2312},
+#line 112 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str451, ei_iso8859_7},
+#line 346 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str452, ei_euc_cn},
     {-1},
-#line 99 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str495, ei_iso8859_6},
+#line 238 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str454, ei_georgian_ps},
+#line 114 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str455, ei_iso8859_7},
+    {-1},
+#line 241 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str457, ei_pt154},
+#line 349 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str458, ei_ces_gbk},
+#line 230 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str459, ei_mac_thai},
+    {-1},
+#line 327 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str461, ei_cp932},
+#line 172 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str462, ei_koi8_u},
+#line 175 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str463, ei_cp1250},
+#line 237 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str464, ei_georgian_academy},
+    {-1},
+#line 102 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str466, ei_iso8859_6},
+#line 358 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str467, ei_hz},
+#line 121 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str468, ei_iso8859_8},
+    {-1},
+#line 92 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str470, ei_iso8859_5},
     {-1}, {-1},
-#line 173 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str498, ei_cp1250},
-    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-#line 170 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str507, ei_koi8_u},
-#line 171 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str508, ei_koi8_ru},
+#line 259 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str473, ei_cp874},
+#line 125 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str474, ei_iso8859_9},
+    {-1}, {-1},
+#line 26 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str477, ei_ucs2},
+    {-1}, {-1}, {-1},
+#line 19 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str481, ei_ascii},
     {-1},
-#line 254 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str510, ei_tis620},
-#line 190 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str511, ei_cp1255},
-    {-1}, {-1}, {-1}, {-1}, {-1},
-#line 55 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str517, ei_iso8859_1},
-#line 227 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str518, ei_mac_arabic},
+#line 302 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str483, ei_ksc5601},
+    {-1}, {-1}, {-1}, {-1},
+#line 216 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str488, ei_mac_roman},
+#line 196 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str489, ei_cp1257},
+#line 204 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str490, ei_cp850},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+#line 82 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str497, ei_iso8859_4},
+#line 244 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str498, ei_pt154},
     {-1},
-#line 96 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str520, ei_iso8859_6},
-#line 215 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str521, ei_mac_roman},
-    {-1}, {-1}, {-1},
-#line 207 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str525, ei_cp862},
-#line 113 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str526, ei_iso8859_7},
-#line 103 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str527, ei_iso8859_7},
-#line 104 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str528, ei_iso8859_7},
+#line 51 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str500, ei_ucs4internal},
+#line 150 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str501, ei_iso8859_14},
+#line 333 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str502, ei_cp932},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+#line 377 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str512, ei_euc_kr},
+#line 145 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str513, ei_iso8859_13},
     {-1},
-#line 211 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str530, ei_cp866},
-#line 65 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str531, ei_iso8859_2},
-    {-1}, {-1},
 #line 217 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str534, ei_mac_roman},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str515, ei_mac_roman},
     {-1}, {-1}, {-1},
-#line 278 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str538, ei_jisx0208},
+#line 376 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str519, ei_euc_kr},
+    {-1},
+#line 188 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str521, ei_cp1254},
+    {-1},
+#line 27 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str523, ei_ucs2be},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+#line 384 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str531, ei_iso2022_kr},
     {-1}, {-1}, {-1},
-#line 221 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str542, ei_mac_romania},
-#line 106 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str543, ei_iso8859_7},
-    {-1}, {-1}, {-1}, {-1}, {-1},
-#line 237 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str549, ei_koi8_t},
-    {-1}, {-1},
+#line 385 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str535, ei_iso2022_kr},
 #line 307 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str552, ei_euc_jp},
-#line 306 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str553, ei_euc_jp},
-#line 356 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str554, ei_big5hkscs2008},
-#line 355 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str555, ei_big5hkscs2008},
-    {-1},
-#line 218 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str557, ei_mac_centraleurope},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str536, ei_ksc5601},
+#line 222 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str537, ei_mac_croatian},
     {-1}, {-1},
-#line 228 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str560, ei_mac_thai},
-#line 18 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str561, ei_ascii},
-    {-1}, {-1}, {-1},
-#line 308 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str565, ei_euc_jp},
+#line 83 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str540, ei_iso8859_4},
+#line 115 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str541, ei_iso8859_7},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+#line 105 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str548, ei_iso8859_7},
     {-1}, {-1},
-#line 342 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str568, ei_euc_tw},
-#line 341 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str569, ei_euc_tw},
+#line 267 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str551, ei_tcvn},
+#line 295 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str552, ei_iso646_cn},
     {-1}, {-1},
-#line 119 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str572, ei_iso8859_8},
-#line 39 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str573, ei_utf16be},
-#line 291 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str574, ei_iso646_cn},
+#line 32 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str555, ei_ucs2le},
     {-1},
-#line 17 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str576, ei_ascii},
-#line 132 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str577, ei_iso8859_10},
+#line 231 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str557, ei_hp_roman8},
+    {-1},
+#line 285 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str559, ei_jisx0212},
+    {-1}, {-1}, {-1}, {-1},
+#line 362 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str564, ei_euc_tw},
+#line 284 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str565, ei_jisx0208},
+#line 173 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str566, ei_koi8_ru},
     {-1}, {-1},
-#line 97 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str580, ei_iso8859_6},
-#line 280 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str581, ei_jisx0208},
+#line 101 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str569, ei_iso8859_6},
+    {-1},
+#line 306 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str571, ei_ksc5601},
+    {-1},
+#line 100 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str573, ei_iso8859_6},
+#line 39 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str574, ei_utf16be},
+#line 15 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str575, ei_ascii},
     {-1}, {-1}, {-1},
-#line 202 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str585, ei_cp850},
-    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-#line 293 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str593, ei_iso646_cn},
-    {-1}, {-1},
-#line 267 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str596, ei_iso646_jp},
-#line 143 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str597, ei_iso8859_13},
-#line 111 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str598, ei_iso8859_7},
+#line 366 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str579, ei_ces_big5},
     {-1}, {-1}, {-1}, {-1}, {-1},
-#line 112 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str604, ei_iso8859_7},
+#line 312 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str585, ei_euc_jp},
+#line 365 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str586, ei_ces_big5},
     {-1},
-#line 270 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str606, ei_iso646_jp},
-    {-1}, {-1}, {-1},
 #line 42 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str610, ei_utf32be},
-    {-1}, {-1},
-#line 193 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str613, ei_cp1256},
-#line 265 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str614, ei_tcvn},
-    {-1}, {-1}, {-1},
-#line 44 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str618, ei_utf7},
-    {-1}, {-1}, {-1}, {-1},
-#line 320 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str623, ei_iso2022_jp1},
-    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-#line 323 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str633, ei_iso2022_jpms},
-    {-1}, {-1}, {-1},
-#line 321 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str637, ei_iso2022_jp2},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str588, ei_utf32be},
     {-1}, {-1}, {-1}, {-1},
-#line 195 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str642, ei_cp1257},
+#line 273 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str593, ei_jisx0201},
     {-1}, {-1}, {-1}, {-1},
-#line 233 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str647, ei_nextstep},
-#line 258 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str648, ei_cp874},
-#line 322 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str649, ei_iso2022_jp2},
-    {-1}, {-1}, {-1}, {-1}, {-1},
-#line 288 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str655, ei_jisx0212},
-    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+#line 293 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str598, ei_iso646_cn},
+#line 246 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str599, ei_rk1048},
     {-1},
-#line 361 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str666, ei_euc_kr},
-    {-1}, {-1},
-#line 343 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str669, ei_euc_tw},
+#line 20 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str601, ei_ascii},
+#line 134 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str602, ei_iso8859_10},
     {-1},
-#line 318 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str671, ei_iso2022_jp},
-    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-#line 32 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str679, ei_ucs2le},
-#line 348 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str680, ei_ces_big5},
-#line 347 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str681, ei_ces_big5},
-#line 118 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str682, ei_iso8859_8},
-#line 274 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str683, ei_jisx0201},
-#line 319 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str684, ei_iso2022_jp},
+#line 282 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str604, ei_jisx0208},
+    {-1},
+#line 99 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str606, ei_iso8859_6},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+#line 277 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str613, ei_jisx0208},
+    {-1},
+#line 287 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str615, ei_jisx0212},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+#line 235 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str622, ei_nextstep},
+#line 36 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str623, ei_ucs4be},
+#line 278 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str624, ei_jisx0208},
     {-1}, {-1}, {-1}, {-1}, {-1},
-#line 28 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str690, ei_ucs2be},
-    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+#line 378 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str630, ei_euc_kr},
+#line 46 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str631, ei_utf7},
+    {-1}, {-1},
+#line 113 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str634, ei_iso8859_7},
     {-1}, {-1}, {-1},
-#line 105 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str703, ei_iso8859_7},
+#line 45 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str638, ei_utf7},
+#line 197 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str639, ei_cp1257},
     {-1}, {-1}, {-1}, {-1}, {-1},
-#line 20 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str709, ei_ascii},
-    {-1},
-#line 283 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str711, ei_jisx0212},
-    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-#line 352 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str719, ei_big5hkscs1999},
+#line 219 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str645, ei_mac_roman},
     {-1},
-#line 353 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str721, ei_big5hkscs2001},
-    {-1}, {-1}, {-1},
-#line 271 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str725, ei_jisx0201},
+#line 44 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str647, ei_utf7},
+#line 57 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str648, ei_iso8859_1},
+#line 98 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str649, ei_iso8859_6},
     {-1}, {-1},
-#line 354 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str728, ei_big5hkscs2004},
+#line 286 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str652, ei_jisx0212},
+    {-1}, {-1},
+#line 108 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str655, ei_iso8859_7},
+#line 67 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str656, ei_iso8859_2},
+    {-1},
+#line 28 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str658, ei_ucs2be},
     {-1}, {-1}, {-1}, {-1},
-#line 272 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str733, ei_jisx0201},
+#line 234 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str663, ei_hp_roman8},
+    {-1},
+#line 374 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str665, ei_big5hkscs2008},
+    {-1},
+#line 279 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str667, ei_jisx0208},
+    {-1}, {-1}, {-1}, {-1},
+#line 373 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str672, ei_big5hkscs2008},
     {-1}, {-1}, {-1}, {-1}, {-1},
-#line 357 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str739, ei_big5hkscs2008},
+#line 220 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str678, ei_mac_centraleurope},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+    {-1}, {-1}, {-1}, {-1},
+#line 324 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str692, ei_sjis},
+#line 221 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str693, ei_mac_iceland},
+    {-1}, {-1},
+#line 229 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str696, ei_mac_arabic},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+#line 304 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str715, ei_ksc5601},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+#line 382 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str724, ei_johab},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+#line 106 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str733, ei_iso8859_7},
     {-1}, {-1}, {-1}, {-1},
 #line 223 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str744, ei_mac_ukraine},
-    {-1},
-#line 285 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str746, ei_jisx0212},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str738, ei_mac_romania},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+#line 18 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str747, ei_ascii},
+#line 120 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str748, ei_iso8859_8},
+    {-1}, {-1}, {-1},
+#line 387 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str752, ei_local_wchar_t},
+    {-1}, {-1}, {-1},
+#line 17 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str756, ei_ascii},
+#line 379 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str757, ei_euc_kr},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-    {-1}, {-1}, {-1}, {-1}, {-1},
-#line 275 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str761, ei_jisx0208},
+    {-1}, {-1},
+#line 50 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str769, ei_ucs2swapped},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-    {-1}, {-1}, {-1}, {-1}, {-1},
-#line 276 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str776, ei_jisx0208},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+    {-1}, {-1},
+#line 192 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str790, ei_cp1255},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+    {-1}, {-1}, {-1},
+#line 189 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str803, ei_cp1254},
+#line 371 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str804, ei_big5hkscs2001},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+#line 375 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str814, ei_big5hkscs2008},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-#line 277 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str792, ei_jisx0208},
+#line 198 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str821, ei_cp1257},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+#line 370 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str830, ei_big5hkscs1999},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+    {-1}, {-1}, {-1},
+#line 260 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str852, ei_cp874},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-    {-1}, {-1}, {-1}, {-1}, {-1},
-#line 184 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str807, ei_cp1253},
     {-1},
-#line 224 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str809, ei_mac_greek},
-    {-1}, {-1}, {-1}, {-1},
-#line 364 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str814, ei_johab},
 #line 225 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str815, ei_mac_turkish},
-    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str863, ei_mac_ukraine},
+#line 226 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str864, ei_mac_greek},
     {-1},
-#line 187 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str826, ei_cp1254},
+#line 186 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str866, ei_cp1253},
+    {-1}, {-1},
+#line 52 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str869, ei_ucs4swapped},
+    {-1}, {-1}, {-1}, {-1},
+#line 107 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str874, ei_iso8859_7},
+    {-1},
+#line 48 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str876, ei_utf7imap},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+#line 195 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str886, ei_cp1256},
+    {-1}, {-1}, {-1},
+#line 47 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str890, ei_utf7imap},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-#line 312 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str852, ei_sjis},
-#line 311 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str853, ei_sjis},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+    {-1}, {-1}, {-1},
+#line 372 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str912, ei_big5hkscs2004},
+    {-1}, {-1},
+#line 303 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str915, ei_ksc5601},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+    {-1},
+#line 227 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str935, ei_mac_turkish},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-#line 315 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str897, ei_sjis},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+#line 228 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str962, ei_mac_hebrew},
+    {-1}, {-1}, {-1}, {-1}, {-1},
+#line 276 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str968, ei_jisx0201},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-    {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-#line 284 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str922, ei_jisx0212},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-    {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-#line 310 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str947, ei_euc_jp},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-    {-1},
-#line 226 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str958, ei_mac_hebrew},
-    {-1}, {-1}, {-1}, {-1},
-#line 344 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str963, ei_euc_tw},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-    {-1}, {-1}, {-1}, {-1}, {-1},
-#line 314 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str978, ei_sjis},
-    {-1}, {-1}, {-1}, {-1}, {-1},
-#line 309 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str984, ei_euc_jp},
+    {-1}, {-1},
+#line 311 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str1016, ei_euc_jp},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-    {-1}, {-1}, {-1}, {-1}, {-1},
-#line 196 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str1026, ei_cp1257},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-    {-1}, {-1}, {-1},
-#line 282 "lib/aliases_sysaix.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str1039, ei_jisx0208}
+    {-1}, {-1}, {-1}, {-1}, {-1},
+#line 310 "lib/aliases_sysaix.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str1067, ei_euc_jp}
   };
 
 #ifdef __GNUC__
 __inline
-#if defined __GNUC_STDC_INLINE__ || defined __GNUC_GNU_INLINE__
+#ifdef __GNUC_STDC_INLINE__
 __attribute__ ((__gnu_inline__))
 #endif
 #endif
diff -uprN libiconv-1.15-old/lib/aliases_syshpux.gperf libiconv-1.15/lib/aliases_syshpux.gperf
--- libiconv-1.15-old/lib/aliases_syshpux.gperf	2017-01-02 08:03:06.000000000 +0900
+++ libiconv-1.15/lib/aliases_syshpux.gperf	2017-09-17 06:32:20.352185000 +0900
@@ -45,6 +45,8 @@ UTF-32LE, ei_utf32le
 UTF-7, ei_utf7
 UNICODE-1-1-UTF-7, ei_utf7
 CSUNICODE11UTF7, ei_utf7
+UTF-7-IMAP, ei_utf7imap
+UTF7IMAP, ei_utf7imap
 UCS-2-INTERNAL, ei_ucs2internal
 UCS-2-SWAPPED, ei_ucs2swapped
 UCS-4-INTERNAL, ei_ucs4internal
@@ -312,12 +314,28 @@ EUC-JP, ei_euc_jp
 EUCJP, ei_euc_jp
 EXTENDED_UNIX_CODE_PACKED_FORMAT_FOR_JAPANESE, ei_euc_jp
 CSEUCPKDFMTJAPANESE, ei_euc_jp
+EUCJP-MS, ei_eucjp_ms
+EUCJP-OPEN, ei_eucjp_ms
+EUC-JP-MS, ei_eucjp_ms
+EUCJP-WIN, ei_eucjp_ms
+EUCJPMS, ei_eucjp_ms
+CP51932, ei_cp51932
+WINDOWS-51932, ei_cp51932
+MS51932, ei_cp51932
 SHIFT_JIS, ei_sjis
 SHIFT-JIS, ei_sjis
 SJIS, ei_sjis
 MS_KANJI, ei_sjis
 CSSHIFTJIS, ei_sjis
 CP932, ei_cp932
+WINDOWS-31J, ei_cp932
+CSWINDOWS31J, ei_cp932
+SJIS-OPEN, ei_cp932
+SJIS-WIN, ei_cp932
+WINDOWS-932, ei_cp932
+MS932, ei_cp932
+SHIFT_JIS-MS, ei_cp932
+SJIS-MS, ei_cp932
 ISO-2022-JP, ei_iso2022_jp
 CSISO2022JP, ei_iso2022_jp
 ISO-2022-JP-1, ei_iso2022_jp1
diff -uprN libiconv-1.15-old/lib/aliases_syshpux.h libiconv-1.15/lib/aliases_syshpux.h
--- libiconv-1.15-old/lib/aliases_syshpux.h	2017-01-02 08:03:06.000000000 +0900
+++ libiconv-1.15/lib/aliases_syshpux.h	2017-09-17 06:32:20.655318000 +0900
@@ -1,4 +1,4 @@
-/* ANSI-C code produced by gperf version 3.0.4 */
+/* ANSI-C code produced by gperf version 3.0.3 */
 /* Command-line: gperf -m 10 lib/aliases_syshpux.gperf  */
 /* Computed positions: -k'1,3-11,$' */
 
@@ -32,12 +32,12 @@
 #line 1 "lib/aliases_syshpux.gperf"
 struct alias { int name; unsigned int encoding_index; };
 
-#define TOTAL_KEYWORDS 359
+#define TOTAL_KEYWORDS 377
 #define MIN_WORD_LENGTH 2
 #define MAX_WORD_LENGTH 45
-#define MIN_HASH_VALUE 19
-#define MAX_HASH_VALUE 1033
-/* maximum key range = 1015, duplicates = 0 */
+#define MIN_HASH_VALUE 14
+#define MAX_HASH_VALUE 1254
+/* maximum key range = 1241, duplicates = 0 */
 
 #ifdef __GNUC__
 __inline
@@ -51,19 +51,19 @@ aliases_hash (register const char *str,
 {
   static const unsigned short asso_values[] =
     {
-      1034, 1034, 1034, 1034, 1034, 1034, 1034, 1034, 1034, 1034,
-      1034, 1034, 1034, 1034, 1034, 1034, 1034, 1034, 1034, 1034,
-      1034, 1034, 1034, 1034, 1034, 1034, 1034, 1034, 1034, 1034,
-      1034, 1034, 1034, 1034, 1034, 1034, 1034, 1034, 1034, 1034,
-      1034, 1034, 1034, 1034, 1034,    2,   22, 1034,   56,    4,
-        36,   62,   23,   18,   11,  100,   30,    3,  115, 1034,
-      1034, 1034, 1034, 1034, 1034,   62,  170,  101,    3,   35,
-        78,   78,  169,    3,  375,   55,   16,  149,   18,    8,
-         3, 1034,    2,    4,  161,  210,  136,  158,  191,    6,
-         5, 1034, 1034, 1034, 1034,    3, 1034, 1034, 1034, 1034,
-      1034, 1034, 1034, 1034, 1034, 1034, 1034, 1034, 1034, 1034,
-      1034, 1034, 1034, 1034, 1034, 1034, 1034, 1034, 1034, 1034,
-      1034, 1034, 1034, 1034, 1034, 1034, 1034, 1034
+      1255, 1255, 1255, 1255, 1255, 1255, 1255, 1255, 1255, 1255,
+      1255, 1255, 1255, 1255, 1255, 1255, 1255, 1255, 1255, 1255,
+      1255, 1255, 1255, 1255, 1255, 1255, 1255, 1255, 1255, 1255,
+      1255, 1255, 1255, 1255, 1255, 1255, 1255, 1255, 1255, 1255,
+      1255, 1255, 1255, 1255, 1255,    2,   43, 1255,   49,    3,
+        10,   84,   63,    9,    2,  195,   15,   16,  252, 1255,
+      1255, 1255, 1255, 1255, 1255,   32,  201,    5,  173,   40,
+       188,  141,  131,    2,   61,  234,  146,  192,    7,    2,
+       114, 1255,  112,   53,   48,  196,  123,   40,  398,    5,
+         3, 1255, 1255, 1255, 1255,   34, 1255, 1255, 1255, 1255,
+      1255, 1255, 1255, 1255, 1255, 1255, 1255, 1255, 1255, 1255,
+      1255, 1255, 1255, 1255, 1255, 1255, 1255, 1255, 1255, 1255,
+      1255, 1255, 1255, 1255, 1255, 1255, 1255, 1255
     };
   register int hval = len;
 
@@ -106,1654 +106,1763 @@ aliases_hash (register const char *str,
 
 struct stringpool_t
   {
-    char stringpool_str19[sizeof("SJIS")];
-    char stringpool_str22[sizeof("L1")];
-    char stringpool_str29[sizeof("L6")];
-    char stringpool_str34[sizeof("R8")];
-    char stringpool_str36[sizeof("L5")];
-    char stringpool_str41[sizeof("L4")];
-    char stringpool_str43[sizeof("ISO-IR-199")];
-    char stringpool_str48[sizeof("L8")];
-    char stringpool_str50[sizeof("ISO-IR-6")];
-    char stringpool_str54[sizeof("L2")];
-    char stringpool_str55[sizeof("866")];
-    char stringpool_str58[sizeof("ISO-IR-159")];
-    char stringpool_str63[sizeof("ISO-IR-149")];
-    char stringpool_str67[sizeof("ISO-IR-166")];
-    char stringpool_str76[sizeof("PT154")];
-    char stringpool_str79[sizeof("ISO-IR-14")];
-    char stringpool_str80[sizeof("L3")];
-    char stringpool_str81[sizeof("ISO-IR-165")];
-    char stringpool_str92[sizeof("ISO-IR-126")];
-    char stringpool_str96[sizeof("ISO-IR-109")];
-    char stringpool_str98[sizeof("ISO-IR-101")];
-    char stringpool_str100[sizeof("KOI8-R")];
-    char stringpool_str103[sizeof("ISO-IR-144")];
-    char stringpool_str105[sizeof("862")];
-    char stringpool_str106[sizeof("ISO88599")];
-    char stringpool_str107[sizeof("ISO-IR-58")];
-    char stringpool_str108[sizeof("ISO88591")];
-    char stringpool_str109[sizeof("ISO8859-9")];
-    char stringpool_str110[sizeof("C99")];
-    char stringpool_str111[sizeof("ISO8859-1")];
-    char stringpool_str112[sizeof("ISO-8859-9")];
-    char stringpool_str113[sizeof("ISO_8859-9")];
-    char stringpool_str114[sizeof("ISO-8859-1")];
-    char stringpool_str115[sizeof("ISO_8859-1")];
-    char stringpool_str116[sizeof("ISO8859-11")];
-    char stringpool_str117[sizeof("ISO-IR-148")];
-    char stringpool_str118[sizeof("L7")];
-    char stringpool_str119[sizeof("ISO-8859-11")];
-    char stringpool_str120[sizeof("ISO_8859-11")];
-    char stringpool_str121[sizeof("CN")];
-    char stringpool_str122[sizeof("ISO88596")];
-    char stringpool_str124[sizeof("ISO-IR-226")];
-    char stringpool_str125[sizeof("ISO8859-6")];
-    char stringpool_str128[sizeof("ISO-8859-6")];
-    char stringpool_str129[sizeof("ISO_8859-6")];
-    char stringpool_str130[sizeof("ISO8859-16")];
-    char stringpool_str131[sizeof("L10")];
-    char stringpool_str132[sizeof("ISO_8859-16:2001")];
-    char stringpool_str133[sizeof("ISO-8859-16")];
-    char stringpool_str134[sizeof("ISO_8859-16")];
-    char stringpool_str136[sizeof("ISO88595")];
-    char stringpool_str138[sizeof("CP949")];
-    char stringpool_str139[sizeof("ISO8859-5")];
-    char stringpool_str140[sizeof("ISO-IR-179")];
-    char stringpool_str141[sizeof("ISO885915")];
-    char stringpool_str142[sizeof("ISO-8859-5")];
-    char stringpool_str143[sizeof("ISO_8859-5")];
-    char stringpool_str144[sizeof("ISO8859-15")];
-    char stringpool_str145[sizeof("850")];
-    char stringpool_str146[sizeof("CP819")];
-    char stringpool_str147[sizeof("ISO-8859-15")];
-    char stringpool_str148[sizeof("ISO_8859-15")];
-    char stringpool_str149[sizeof("ISO8859-4")];
-    char stringpool_str150[sizeof("ISO-IR-110")];
-    char stringpool_str151[sizeof("RK1048")];
-    char stringpool_str152[sizeof("ISO-8859-4")];
-    char stringpool_str153[sizeof("ISO_8859-4")];
-    char stringpool_str154[sizeof("ISO8859-14")];
-    char stringpool_str156[sizeof("ISO-IR-138")];
-    char stringpool_str157[sizeof("ISO-8859-14")];
-    char stringpool_str158[sizeof("ISO_8859-14")];
-    char stringpool_str160[sizeof("ISO88598")];
-    char stringpool_str163[sizeof("ISO8859-8")];
-    char stringpool_str165[sizeof("ISO_8859-15:1998")];
-    char stringpool_str166[sizeof("ISO-8859-8")];
-    char stringpool_str167[sizeof("ISO_8859-8")];
-    char stringpool_str169[sizeof("CP866")];
-    char stringpool_str170[sizeof("ISO_8859-14:1998")];
-    char stringpool_str171[sizeof("CHAR")];
-    char stringpool_str172[sizeof("ISO88592")];
-    char stringpool_str173[sizeof("CP1251")];
-    char stringpool_str174[sizeof("CP154")];
-    char stringpool_str175[sizeof("ISO8859-2")];
-    char stringpool_str176[sizeof("HZ")];
-    char stringpool_str177[sizeof("ASCII")];
-    char stringpool_str178[sizeof("ISO-8859-2")];
-    char stringpool_str179[sizeof("ISO_8859-2")];
-    char stringpool_str182[sizeof("PTCP154")];
-    char stringpool_str185[sizeof("CP1131")];
-    char stringpool_str187[sizeof("CP1256")];
-    char stringpool_str191[sizeof("GBK")];
-    char stringpool_str192[sizeof("CP1361")];
-    char stringpool_str193[sizeof("CP936")];
-    char stringpool_str196[sizeof("KOREAN")];
-    char stringpool_str198[sizeof("IBM819")];
-    char stringpool_str200[sizeof("EUCKR")];
-    char stringpool_str201[sizeof("CP1255")];
-    char stringpool_str202[sizeof("ISO-IR-100")];
-    char stringpool_str203[sizeof("EUC-KR")];
-    char stringpool_str204[sizeof("ISO646-CN")];
-    char stringpool_str207[sizeof("KZ-1048")];
-    char stringpool_str208[sizeof("CSKOI8R")];
-    char stringpool_str209[sizeof("ISO_8859-10:1992")];
-    char stringpool_str211[sizeof("CP1254")];
-    char stringpool_str212[sizeof("LATIN1")];
-    char stringpool_str213[sizeof("LATIN-9")];
-    char stringpool_str216[sizeof("US")];
-    char stringpool_str219[sizeof("CP862")];
-    char stringpool_str220[sizeof("ISO8859-10")];
+    char stringpool_str14[sizeof("CN")];
+    char stringpool_str22[sizeof("866")];
+    char stringpool_str31[sizeof("CP866")];
+    char stringpool_str37[sizeof("CP1256")];
+    char stringpool_str38[sizeof("862")];
+    char stringpool_str39[sizeof("CP1251")];
+    char stringpool_str40[sizeof("C99")];
+    char stringpool_str47[sizeof("CP862")];
+    char stringpool_str48[sizeof("ASCII")];
+    char stringpool_str51[sizeof("CP1255")];
+    char stringpool_str53[sizeof("CP1252")];
+    char stringpool_str60[sizeof("CP819")];
+    char stringpool_str63[sizeof("CP1258")];
+    char stringpool_str69[sizeof("EUCCN")];
+    char stringpool_str71[sizeof("ISO88596")];
+    char stringpool_str72[sizeof("EUC-CN")];
+    char stringpool_str73[sizeof("ISO88591")];
+    char stringpool_str74[sizeof("ISO8859-6")];
+    char stringpool_str76[sizeof("ISO8859-1")];
+    char stringpool_str77[sizeof("ISO-8859-6")];
+    char stringpool_str78[sizeof("ISO8859-16")];
+    char stringpool_str79[sizeof("ISO-8859-1")];
+    char stringpool_str80[sizeof("ISO8859-11")];
+    char stringpool_str81[sizeof("ISO-8859-16")];
+    char stringpool_str83[sizeof("ISO-8859-11")];
+    char stringpool_str85[sizeof("ISO88595")];
+    char stringpool_str87[sizeof("ISO88592")];
+    char stringpool_str88[sizeof("ISO8859-5")];
+    char stringpool_str89[sizeof("ISO885915")];
+    char stringpool_str90[sizeof("ISO8859-2")];
+    char stringpool_str91[sizeof("ISO-8859-5")];
+    char stringpool_str92[sizeof("ISO8859-15")];
+    char stringpool_str93[sizeof("ISO-8859-2")];
+    char stringpool_str95[sizeof("ISO-8859-15")];
+    char stringpool_str96[sizeof("CP50221")];
+    char stringpool_str97[sizeof("ISO88598")];
+    char stringpool_str99[sizeof("ISO88599")];
+    char stringpool_str100[sizeof("ISO8859-8")];
+    char stringpool_str101[sizeof("ISO646-CN")];
+    char stringpool_str102[sizeof("ISO8859-9")];
+    char stringpool_str103[sizeof("ISO-8859-8")];
+    char stringpool_str105[sizeof("ISO-8859-9")];
+    char stringpool_str106[sizeof("CP1361")];
+    char stringpool_str107[sizeof("CP1131")];
+    char stringpool_str108[sizeof("CSASCII")];
+    char stringpool_str109[sizeof("ISO_8859-6")];
+    char stringpool_str111[sizeof("ISO_8859-1")];
+    char stringpool_str113[sizeof("ISO_8859-16")];
+    char stringpool_str114[sizeof("CP936")];
+    char stringpool_str115[sizeof("ISO_8859-11")];
+    char stringpool_str116[sizeof("850")];
+    char stringpool_str117[sizeof("ISO-2022-CN")];
+    char stringpool_str119[sizeof("ISO_8859-16:2001")];
+    char stringpool_str121[sizeof("CP949")];
+    char stringpool_str123[sizeof("ISO_8859-5")];
+    char stringpool_str125[sizeof("ISO_8859-2")];
+    char stringpool_str127[sizeof("ISO_8859-15")];
+    char stringpool_str129[sizeof("R8")];
+    char stringpool_str130[sizeof("CP932")];
+    char stringpool_str131[sizeof("CP1250")];
+    char stringpool_str132[sizeof("CP850")];
+    char stringpool_str133[sizeof("CP950")];
+    char stringpool_str134[sizeof("ISO-IR-6")];
+    char stringpool_str135[sizeof("ISO_8859-8")];
+    char stringpool_str136[sizeof("HZ")];
+    char stringpool_str137[sizeof("ISO_8859-9")];
+    char stringpool_str138[sizeof("ISO_8859-15:1998")];
+    char stringpool_str141[sizeof("ISO-IR-166")];
+    char stringpool_str144[sizeof("CP51932")];
+    char stringpool_str148[sizeof("CP154")];
+    char stringpool_str149[sizeof("ISO-IR-126")];
+    char stringpool_str150[sizeof("L6")];
+    char stringpool_str151[sizeof("L1")];
+    char stringpool_str155[sizeof("ISO-IR-165")];
+    char stringpool_str156[sizeof("ISO-IR-226")];
+    char stringpool_str157[sizeof("L5")];
+    char stringpool_str158[sizeof("L2")];
+    char stringpool_str159[sizeof("CP1254")];
+    char stringpool_str162[sizeof("ISO-2022-CN-EXT")];
+    char stringpool_str163[sizeof("L8")];
+    char stringpool_str165[sizeof("SJIS")];
+    char stringpool_str168[sizeof("HP15CN")];
+    char stringpool_str170[sizeof("ISO-IR-58")];
+    char stringpool_str171[sizeof("CSISO2022CN")];
+    char stringpool_str172[sizeof("ISO8859-10")];
+    char stringpool_str173[sizeof("ISO_8859-10:1992")];
+    char stringpool_str174[sizeof("SJIS-WIN")];
+    char stringpool_str175[sizeof("ISO-8859-10")];
+    char stringpool_str176[sizeof("ISO-IR-159")];
+    char stringpool_str177[sizeof("JP")];
+    char stringpool_str178[sizeof("EUCTW")];
+    char stringpool_str181[sizeof("EUC-TW")];
+    char stringpool_str183[sizeof("ISO-IR-199")];
+    char stringpool_str188[sizeof("ELOT_928")];
+    char stringpool_str189[sizeof("TCVN")];
+    char stringpool_str190[sizeof("ISO-IR-101")];
+    char stringpool_str192[sizeof("ISO_8859-14:1998")];
+    char stringpool_str193[sizeof("VISCII")];
+    char stringpool_str194[sizeof("CHINESE")];
+    char stringpool_str196[sizeof("ISO8859-4")];
+    char stringpool_str199[sizeof("ISO-8859-4")];
+    char stringpool_str200[sizeof("ISO8859-14")];
+    char stringpool_str201[sizeof("CP1253")];
+    char stringpool_str202[sizeof("CSVISCII")];
+    char stringpool_str203[sizeof("ISO-8859-14")];
+    char stringpool_str205[sizeof("MAC")];
+    char stringpool_str207[sizeof("ISO_8859-10")];
+    char stringpool_str209[sizeof("UHC")];
+    char stringpool_str211[sizeof("L4")];
+    char stringpool_str213[sizeof("LATIN6")];
+    char stringpool_str215[sizeof("LATIN1")];
+    char stringpool_str216[sizeof("ISO-IR-109")];
+    char stringpool_str217[sizeof("TIS620")];
+    char stringpool_str220[sizeof("TIS-620")];
     char stringpool_str221[sizeof("IBM866")];
-    char stringpool_str223[sizeof("ISO-8859-10")];
-    char stringpool_str224[sizeof("ISO_8859-10")];
-    char stringpool_str225[sizeof("CP1258")];
-    char stringpool_str226[sizeof("LATIN6")];
-    char stringpool_str227[sizeof("ISO8859-3")];
-    char stringpool_str230[sizeof("ISO-8859-3")];
-    char stringpool_str231[sizeof("ISO_8859-3")];
-    char stringpool_str232[sizeof("ISO8859-13")];
-    char stringpool_str233[sizeof("ISO_8859-9:1989")];
-    char stringpool_str235[sizeof("ISO-8859-13")];
-    char stringpool_str236[sizeof("ISO_8859-13")];
-    char stringpool_str237[sizeof("CP1252")];
-    char stringpool_str238[sizeof("CHINESE")];
-    char stringpool_str239[sizeof("CP950")];
-    char stringpool_str240[sizeof("LATIN5")];
-    char stringpool_str241[sizeof("MS936")];
-    char stringpool_str242[sizeof("ISO_646.IRV:1991")];
-    char stringpool_str243[sizeof("CP932")];
-    char stringpool_str246[sizeof("ISO-IR-203")];
-    char stringpool_str247[sizeof("ISO-IR-57")];
-    char stringpool_str248[sizeof("MS-ANSI")];
-    char stringpool_str249[sizeof("ISO-2022-KR")];
-    char stringpool_str250[sizeof("LATIN4")];
-    char stringpool_str252[sizeof("ISO-IR-157")];
-    char stringpool_str256[sizeof("VISCII")];
-    char stringpool_str258[sizeof("GB2312")];
-    char stringpool_str259[sizeof("ISO-IR-87")];
-    char stringpool_str260[sizeof("KSC_5601")];
-    char stringpool_str261[sizeof("MS-EE")];
-    char stringpool_str262[sizeof("CP50221")];
-    char stringpool_str263[sizeof("GREEK")];
-    char stringpool_str264[sizeof("LATIN8")];
-    char stringpool_str266[sizeof("CP850")];
-    char stringpool_str267[sizeof("UCS-4")];
-    char stringpool_str269[sizeof("GREEK8")];
-    char stringpool_str270[sizeof("ISO-IR-127")];
-    char stringpool_str271[sizeof("IBM862")];
-    char stringpool_str273[sizeof("GEORGIAN-PS")];
-    char stringpool_str274[sizeof("KS_C_5601-1989")];
-    char stringpool_str275[sizeof("ISO_8859-5:1988")];
-    char stringpool_str276[sizeof("LATIN2")];
-    char stringpool_str277[sizeof("CP1250")];
-    char stringpool_str278[sizeof("EUCCN")];
-    char stringpool_str280[sizeof("ISO_8859-4:1988")];
-    char stringpool_str281[sizeof("EUC-CN")];
-    char stringpool_str282[sizeof("CP874")];
-    char stringpool_str284[sizeof("CSASCII")];
-    char stringpool_str285[sizeof("ISO646-US")];
-    char stringpool_str287[sizeof("ISO_8859-8:1988")];
-    char stringpool_str288[sizeof("BIG5")];
-    char stringpool_str289[sizeof("CP1253")];
-    char stringpool_str291[sizeof("BIG-5")];
-    char stringpool_str293[sizeof("UCS-2")];
-    char stringpool_str296[sizeof("X0201")];
-    char stringpool_str297[sizeof("ROMAN8")];
-    char stringpool_str298[sizeof("VISCII1.1-1")];
-    char stringpool_str299[sizeof("MS-CYRL")];
-    char stringpool_str300[sizeof("ISO88597")];
-    char stringpool_str301[sizeof("CP1133")];
-    char stringpool_str302[sizeof("GB_1988-80")];
-    char stringpool_str303[sizeof("ISO8859-7")];
-    char stringpool_str305[sizeof("MULELAO-1")];
-    char stringpool_str306[sizeof("ISO-8859-7")];
-    char stringpool_str307[sizeof("ISO_8859-7")];
-    char stringpool_str308[sizeof("X0212")];
-    char stringpool_str310[sizeof("ECMA-114")];
-    char stringpool_str312[sizeof("CSKZ1048")];
-    char stringpool_str314[sizeof("ELOT_928")];
-    char stringpool_str317[sizeof("STRK1048-2002")];
-    char stringpool_str318[sizeof("IBM850")];
-    char stringpool_str319[sizeof("ISO_8859-3:1988")];
-    char stringpool_str321[sizeof("LATIN10")];
-    char stringpool_str322[sizeof("UTF-16")];
-    char stringpool_str324[sizeof("ECMA-118")];
-    char stringpool_str327[sizeof("ISO-2022-CN")];
-    char stringpool_str328[sizeof("LATIN3")];
-    char stringpool_str330[sizeof("TIS620")];
-    char stringpool_str331[sizeof("ISO_8859-1:1987")];
-    char stringpool_str332[sizeof("UCS-4LE")];
-    char stringpool_str333[sizeof("TIS-620")];
-    char stringpool_str334[sizeof("HP15CN")];
-    char stringpool_str337[sizeof("TCVN")];
-    char stringpool_str338[sizeof("ISO_8859-6:1987")];
-    char stringpool_str342[sizeof("CYRILLIC-ASIAN")];
-    char stringpool_str345[sizeof("UCS-2LE")];
-    char stringpool_str348[sizeof("X0208")];
-    char stringpool_str349[sizeof("GB18030")];
-    char stringpool_str350[sizeof("CSISO2022KR")];
-    char stringpool_str351[sizeof("CYRILLIC")];
-    char stringpool_str352[sizeof("UTF8")];
-    char stringpool_str354[sizeof("MAC")];
-    char stringpool_str355[sizeof("UTF-8")];
-    char stringpool_str362[sizeof("CSVISCII")];
-    char stringpool_str363[sizeof("ISO_8859-2:1987")];
-    char stringpool_str365[sizeof("CP1257")];
-    char stringpool_str368[sizeof("ISO-10646-UCS-4")];
-    char stringpool_str371[sizeof("KS_C_5601-1987")];
-    char stringpool_str373[sizeof("GB_2312-80")];
-    char stringpool_str379[sizeof("CP367")];
-    char stringpool_str380[sizeof("JP")];
-    char stringpool_str381[sizeof("ISO-10646-UCS-2")];
-    char stringpool_str387[sizeof("UNICODE-1-1")];
-    char stringpool_str389[sizeof("ISO_8859-7:2003")];
-    char stringpool_str390[sizeof("TIS620-0")];
-    char stringpool_str393[sizeof("ARMSCII-8")];
-    char stringpool_str394[sizeof("CSBIG5")];
-    char stringpool_str395[sizeof("CSISOLATIN1")];
-    char stringpool_str396[sizeof("US-ASCII")];
-    char stringpool_str397[sizeof("CN-BIG5")];
-    char stringpool_str399[sizeof("UTF-16LE")];
-    char stringpool_str400[sizeof("TIS620.2529-1")];
-    char stringpool_str401[sizeof("ANSI_X3.4-1986")];
-    char stringpool_str404[sizeof("LATIN7")];
-    char stringpool_str405[sizeof("CN-GB-ISOIR165")];
-    char stringpool_str409[sizeof("CSISOLATIN6")];
-    char stringpool_str415[sizeof("UHC")];
-    char stringpool_str418[sizeof("KOI8-T")];
-    char stringpool_str419[sizeof("MS-GREEK")];
-    char stringpool_str420[sizeof("ANSI_X3.4-1968")];
-    char stringpool_str423[sizeof("CSISOLATIN5")];
-    char stringpool_str425[sizeof("WINDOWS-1251")];
-    char stringpool_str427[sizeof("ISO_8859-7:1987")];
-    char stringpool_str428[sizeof("CSISO2022CN")];
-    char stringpool_str430[sizeof("UTF-32")];
-    char stringpool_str431[sizeof("IBM367")];
-    char stringpool_str432[sizeof("WINDOWS-1256")];
-    char stringpool_str433[sizeof("CSISOLATIN4")];
-    char stringpool_str436[sizeof("GEORGIAN-ACADEMY")];
-    char stringpool_str439[sizeof("WINDOWS-1255")];
-    char stringpool_str444[sizeof("WINDOWS-1254")];
-    char stringpool_str445[sizeof("ASMO-708")];
-    char stringpool_str446[sizeof("CSPTCP154")];
-    char stringpool_str448[sizeof("ISO646-JP")];
-    char stringpool_str449[sizeof("WINDOWS-936")];
-    char stringpool_str451[sizeof("WINDOWS-1258")];
-    char stringpool_str457[sizeof("WINDOWS-1252")];
-    char stringpool_str459[sizeof("CSISOLATIN2")];
-    char stringpool_str462[sizeof("IBM-CP1133")];
-    char stringpool_str468[sizeof("CSUCS4")];
-    char stringpool_str470[sizeof("CSKSC56011987")];
-    char stringpool_str474[sizeof("ISO-2022-CN-EXT")];
-    char stringpool_str477[sizeof("WINDOWS-1250")];
-    char stringpool_str479[sizeof("HP-ROMAN8")];
-    char stringpool_str482[sizeof("UTF-32LE")];
-    char stringpool_str483[sizeof("WINDOWS-1253")];
-    char stringpool_str485[sizeof("TIS620.2533-1")];
-    char stringpool_str486[sizeof("UCS-4BE")];
-    char stringpool_str487[sizeof("UCS-4-SWAPPED")];
-    char stringpool_str489[sizeof("UNICODE-1-1-UTF-7")];
-    char stringpool_str490[sizeof("UCS-4-INTERNAL")];
-    char stringpool_str493[sizeof("TCVN5712-1")];
-    char stringpool_str494[sizeof("CSIBM866")];
-    char stringpool_str495[sizeof("UTF-7")];
-    char stringpool_str499[sizeof("UCS-2BE")];
-    char stringpool_str500[sizeof("UCS-2-SWAPPED")];
-    char stringpool_str501[sizeof("MACICELAND")];
-    char stringpool_str502[sizeof("CSUNICODE11")];
-    char stringpool_str503[sizeof("UCS-2-INTERNAL")];
-    char stringpool_str505[sizeof("ARABIC")];
-    char stringpool_str511[sizeof("CSISOLATIN3")];
-    char stringpool_str513[sizeof("CSEUCKR")];
-    char stringpool_str515[sizeof("MACROMAN")];
-    char stringpool_str516[sizeof("KOI8-U")];
-    char stringpool_str518[sizeof("MACGREEK")];
-    char stringpool_str519[sizeof("KOI8-RU")];
-    char stringpool_str520[sizeof("TCVN-5712")];
-    char stringpool_str521[sizeof("WINDOWS-1257")];
-    char stringpool_str522[sizeof("EUCJP")];
-    char stringpool_str523[sizeof("CSUNICODE")];
-    char stringpool_str524[sizeof("CSISOLATINGREEK")];
-    char stringpool_str525[sizeof("EUC-JP")];
-    char stringpool_str526[sizeof("CN-GB")];
-    char stringpool_str531[sizeof("CSGB2312")];
-    char stringpool_str532[sizeof("CSISO57GB1988")];
-    char stringpool_str536[sizeof("MS-HEBR")];
-    char stringpool_str537[sizeof("TIS620.2533-0")];
-    char stringpool_str538[sizeof("WINDOWS-874")];
-    char stringpool_str541[sizeof("ISO-CELTIC")];
-    char stringpool_str542[sizeof("BIGFIVE")];
-    char stringpool_str545[sizeof("BIG-FIVE")];
-    char stringpool_str553[sizeof("UTF-16BE")];
-    char stringpool_str555[sizeof("CSISOLATINARABIC")];
-    char stringpool_str571[sizeof("ISO-2022-JP")];
-    char stringpool_str574[sizeof("ISO-2022-JP-1")];
-    char stringpool_str575[sizeof("ISO-2022-JP-MS")];
-    char stringpool_str581[sizeof("CSISO58GB231280")];
-    char stringpool_str582[sizeof("CSHPROMAN8")];
-    char stringpool_str584[sizeof("NEXTSTEP")];
-    char stringpool_str594[sizeof("JIS0208")];
-    char stringpool_str596[sizeof("CSISOLATINCYRILLIC")];
-    char stringpool_str599[sizeof("CSISO159JISX02121990")];
-    char stringpool_str601[sizeof("EXTENDED_UNIX_CODE_PACKED_FORMAT_FOR_JAPANESE")];
-    char stringpool_str602[sizeof("CSUNICODE11UTF7")];
-    char stringpool_str605[sizeof("HZ-GB-2312")];
-    char stringpool_str606[sizeof("ISO-2022-JP-2")];
-    char stringpool_str610[sizeof("MACCYRILLIC")];
-    char stringpool_str612[sizeof("BIG5HKSCS")];
-    char stringpool_str615[sizeof("BIG5-HKSCS")];
-    char stringpool_str618[sizeof("EUCTW")];
-    char stringpool_str621[sizeof("EUC-TW")];
-    char stringpool_str624[sizeof("MS-ARAB")];
-    char stringpool_str626[sizeof("MACROMANIA")];
-    char stringpool_str636[sizeof("UTF-32BE")];
-    char stringpool_str639[sizeof("JAVA")];
-    char stringpool_str641[sizeof("MS-TURK")];
-    char stringpool_str643[sizeof("SHIFT-JIS")];
-    char stringpool_str644[sizeof("SHIFT_JIS")];
-    char stringpool_str651[sizeof("CSISO14JISC6220RO")];
-    char stringpool_str653[sizeof("JIS_C6220-1969-RO")];
-    char stringpool_str655[sizeof("MACTHAI")];
-    char stringpool_str659[sizeof("JIS_C6226-1983")];
-    char stringpool_str671[sizeof("TCVN5712-1:1993")];
-    char stringpool_str672[sizeof("CSISO2022JP")];
-    char stringpool_str676[sizeof("MS_KANJI")];
-    char stringpool_str680[sizeof("MACUKRAINE")];
-    char stringpool_str696[sizeof("MACCROATIAN")];
-    char stringpool_str698[sizeof("HEBREW")];
-    char stringpool_str699[sizeof("UNICODEBIG")];
-    char stringpool_str700[sizeof("CSPC862LATINHEBREW")];
-    char stringpool_str706[sizeof("CSISO2022JP2")];
-    char stringpool_str719[sizeof("CSISOLATINHEBREW")];
-    char stringpool_str723[sizeof("WCHAR_T")];
-    char stringpool_str731[sizeof("MACCENTRALEUROPE")];
-    char stringpool_str734[sizeof("BIG5-HKSCS:1999")];
-    char stringpool_str735[sizeof("BIG5-HKSCS:2001")];
-    char stringpool_str738[sizeof("JIS_X0201")];
-    char stringpool_str749[sizeof("UNICODELITTLE")];
-    char stringpool_str750[sizeof("JIS_X0212")];
-    char stringpool_str754[sizeof("BIG5-HKSCS:2004")];
-    char stringpool_str755[sizeof("JISX0201-1976")];
-    char stringpool_str760[sizeof("MACARABIC")];
-    char stringpool_str761[sizeof("BIG5-HKSCS:2008")];
-    char stringpool_str781[sizeof("JIS_X0212-1990")];
-    char stringpool_str790[sizeof("JIS_X0208")];
-    char stringpool_str791[sizeof("MACINTOSH")];
-    char stringpool_str803[sizeof("JIS_X0212.1990-0")];
-    char stringpool_str827[sizeof("JIS_X0208-1990")];
-    char stringpool_str833[sizeof("JIS_X0208-1983")];
-    char stringpool_str864[sizeof("CSISO87JISX0208")];
-    char stringpool_str880[sizeof("CSPC850MULTILINGUAL")];
-    char stringpool_str898[sizeof("WINBALTRIM")];
-    char stringpool_str912[sizeof("CSSHIFTJIS")];
-    char stringpool_str931[sizeof("CSEUCTW")];
-    char stringpool_str950[sizeof("CSEUCPKDFMTJAPANESE")];
-    char stringpool_str951[sizeof("JOHAB")];
-    char stringpool_str956[sizeof("CSMACINTOSH")];
-    char stringpool_str986[sizeof("MACHEBREW")];
-    char stringpool_str1001[sizeof("CSHALFWIDTHKATAKANA")];
-    char stringpool_str1033[sizeof("MACTURKISH")];
+    char stringpool_str227[sizeof("LATIN5")];
+    char stringpool_str228[sizeof("ISO-IR-148")];
+    char stringpool_str229[sizeof("LATIN2")];
+    char stringpool_str230[sizeof("ISO-IR-149")];
+    char stringpool_str231[sizeof("ISO_8859-4")];
+    char stringpool_str232[sizeof("L3")];
+    char stringpool_str235[sizeof("ISO_8859-14")];
+    char stringpool_str236[sizeof("ISO-IR-110")];
+    char stringpool_str237[sizeof("IBM862")];
+    char stringpool_str238[sizeof("ISO8859-3")];
+    char stringpool_str239[sizeof("LATIN8")];
+    char stringpool_str241[sizeof("ISO-8859-3")];
+    char stringpool_str242[sizeof("ISO8859-13")];
+    char stringpool_str244[sizeof("LATIN-9")];
+    char stringpool_str245[sizeof("ISO-8859-13")];
+    char stringpool_str247[sizeof("L10")];
+    char stringpool_str248[sizeof("JIS_C6220-1969-RO")];
+    char stringpool_str249[sizeof("ISO-IR-138")];
+    char stringpool_str250[sizeof("IBM819")];
+    char stringpool_str251[sizeof("US")];
+    char stringpool_str252[sizeof("JAVA")];
+    char stringpool_str253[sizeof("VISCII1.1-1")];
+    char stringpool_str257[sizeof("PT154")];
+    char stringpool_str259[sizeof("JIS0208")];
+    char stringpool_str260[sizeof("ISO-IR-14")];
+    char stringpool_str263[sizeof("RK1048")];
+    char stringpool_str264[sizeof("GB2312")];
+    char stringpool_str265[sizeof("CHAR")];
+    char stringpool_str266[sizeof("TIS620.2529-1")];
+    char stringpool_str267[sizeof("ISO-CELTIC")];
+    char stringpool_str268[sizeof("CSISO14JISC6220RO")];
+    char stringpool_str269[sizeof("CP1133")];
+    char stringpool_str270[sizeof("TIS620-0")];
+    char stringpool_str273[sizeof("ISO_8859-3")];
+    char stringpool_str275[sizeof("CSISO159JISX02121990")];
+    char stringpool_str276[sizeof("UCS-2")];
+    char stringpool_str277[sizeof("ISO_8859-13")];
+    char stringpool_str278[sizeof("ISO-2022-JP-1")];
+    char stringpool_str280[sizeof("JIS_C6226-1983")];
+    char stringpool_str282[sizeof("ISO-IR-100")];
+    char stringpool_str283[sizeof("ARABIC")];
+    char stringpool_str285[sizeof("ISO-2022-JP-2")];
+    char stringpool_str287[sizeof("EUCJP-WIN")];
+    char stringpool_str289[sizeof("SJIS-OPEN")];
+    char stringpool_str297[sizeof("MS-ANSI")];
+    char stringpool_str301[sizeof("MS936")];
+    char stringpool_str302[sizeof("US-ASCII")];
+    char stringpool_str310[sizeof("ECMA-118")];
+    char stringpool_str311[sizeof("LATIN10")];
+    char stringpool_str312[sizeof("CSISOLATIN6")];
+    char stringpool_str314[sizeof("CSISOLATIN1")];
+    char stringpool_str317[sizeof("MS932")];
+    char stringpool_str319[sizeof("MS-EE")];
+    char stringpool_str322[sizeof("IBM850")];
+    char stringpool_str324[sizeof("ISO-IR-144")];
+    char stringpool_str325[sizeof("CSISOLATINCYRILLIC")];
+    char stringpool_str326[sizeof("CSISOLATIN5")];
+    char stringpool_str327[sizeof("ARMSCII-8")];
+    char stringpool_str328[sizeof("CSISOLATIN2")];
+    char stringpool_str329[sizeof("ISO-2022-JP-MS")];
+    char stringpool_str331[sizeof("MS51932")];
+    char stringpool_str335[sizeof("LATIN4")];
+    char stringpool_str338[sizeof("CSISO2022JP2")];
+    char stringpool_str339[sizeof("EUCJP")];
+    char stringpool_str342[sizeof("EUC-JP")];
+    char stringpool_str343[sizeof("L7")];
+    char stringpool_str346[sizeof("CP874")];
+    char stringpool_str347[sizeof("KSC_5601")];
+    char stringpool_str348[sizeof("ISO-10646-UCS-2")];
+    char stringpool_str349[sizeof("GB_1988-80")];
+    char stringpool_str350[sizeof("CSISOLATINARABIC")];
+    char stringpool_str353[sizeof("WINDOWS-1256")];
+    char stringpool_str354[sizeof("WINDOWS-1251")];
+    char stringpool_str355[sizeof("KOI8-T")];
+    char stringpool_str359[sizeof("ISO-IR-203")];
+    char stringpool_str360[sizeof("WINDOWS-1255")];
+    char stringpool_str361[sizeof("WINDOWS-1252")];
+    char stringpool_str362[sizeof("ISO-IR-179")];
+    char stringpool_str364[sizeof("BIG5")];
+    char stringpool_str366[sizeof("WINDOWS-1258")];
+    char stringpool_str367[sizeof("BIG-5")];
+    char stringpool_str368[sizeof("WINDOWS-51932")];
+    char stringpool_str371[sizeof("ISO646-JP")];
+    char stringpool_str373[sizeof("CSBIG5")];
+    char stringpool_str376[sizeof("CN-BIG5")];
+    char stringpool_str377[sizeof("LATIN3")];
+    char stringpool_str378[sizeof("PTCP154")];
+    char stringpool_str379[sizeof("ROMAN8")];
+    char stringpool_str381[sizeof("CSEUCTW")];
+    char stringpool_str382[sizeof("UCS-4")];
+    char stringpool_str384[sizeof("ISO646-US")];
+    char stringpool_str386[sizeof("ISO_8859-5:1988")];
+    char stringpool_str387[sizeof("ISO-2022-JP")];
+    char stringpool_str388[sizeof("KZ-1048")];
+    char stringpool_str391[sizeof("CSUCS4")];
+    char stringpool_str392[sizeof("ISO_8859-8:1988")];
+    char stringpool_str394[sizeof("ISO_8859-9:1989")];
+    char stringpool_str395[sizeof("CSKZ1048")];
+    char stringpool_str397[sizeof("GB18030")];
+    char stringpool_str399[sizeof("UTF-16")];
+    char stringpool_str400[sizeof("WINDOWS-1250")];
+    char stringpool_str401[sizeof("ISO-10646-UCS-4")];
+    char stringpool_str402[sizeof("EUCJP-OPEN")];
+    char stringpool_str404[sizeof("ISO_646.IRV:1991")];
+    char stringpool_str405[sizeof("KS_C_5601-1989")];
+    char stringpool_str406[sizeof("ECMA-114")];
+    char stringpool_str407[sizeof("GB_2312-80")];
+    char stringpool_str408[sizeof("TIS620.2533-1")];
+    char stringpool_str413[sizeof("TCVN5712-1")];
+    char stringpool_str414[sizeof("WINDOWS-1254")];
+    char stringpool_str415[sizeof("SJIS-MS")];
+    char stringpool_str416[sizeof("TCVN-5712")];
+    char stringpool_str418[sizeof("UTF8")];
+    char stringpool_str419[sizeof("MACTHAI")];
+    char stringpool_str421[sizeof("UTF-8")];
+    char stringpool_str423[sizeof("CP1257")];
+    char stringpool_str429[sizeof("CSIBM866")];
+    char stringpool_str431[sizeof("CYRILLIC")];
+    char stringpool_str432[sizeof("WINDOWS-936")];
+    char stringpool_str433[sizeof("CSPTCP154")];
+    char stringpool_str434[sizeof("CSISOLATIN4")];
+    char stringpool_str435[sizeof("WINDOWS-1253")];
+    char stringpool_str436[sizeof("X0212")];
+    char stringpool_str437[sizeof("CSPC862LATINHEBREW")];
+    char stringpool_str438[sizeof("KOREAN")];
+    char stringpool_str440[sizeof("ISO_8859-4:1988")];
+    char stringpool_str441[sizeof("CSISO2022JP")];
+    char stringpool_str442[sizeof("UNICODE-1-1")];
+    char stringpool_str448[sizeof("WINDOWS-932")];
+    char stringpool_str450[sizeof("CSUNICODE11")];
+    char stringpool_str452[sizeof("WCHAR_T")];
+    char stringpool_str454[sizeof("TIS620.2533-0")];
+    char stringpool_str455[sizeof("MACCROATIAN")];
+    char stringpool_str457[sizeof("ISO88597")];
+    char stringpool_str460[sizeof("ISO8859-7")];
+    char stringpool_str461[sizeof("ISO_8859-3:1988")];
+    char stringpool_str463[sizeof("ISO-8859-7")];
+    char stringpool_str468[sizeof("X0201")];
+    char stringpool_str471[sizeof("SHIFT-JIS")];
+    char stringpool_str472[sizeof("CSGB2312")];
+    char stringpool_str476[sizeof("CSISOLATIN3")];
+    char stringpool_str479[sizeof("CSUNICODE")];
+    char stringpool_str482[sizeof("CSWINDOWS31J")];
+    char stringpool_str483[sizeof("KOI8-R")];
+    char stringpool_str484[sizeof("CSISOLATINHEBREW")];
+    char stringpool_str486[sizeof("CP367")];
+    char stringpool_str489[sizeof("CSKOI8R")];
+    char stringpool_str491[sizeof("GREEK8")];
+    char stringpool_str492[sizeof("X0208")];
+    char stringpool_str494[sizeof("UCS-2LE")];
+    char stringpool_str495[sizeof("ISO_8859-7")];
+    char stringpool_str496[sizeof("UTF-32")];
+    char stringpool_str497[sizeof("GEORGIAN-ACADEMY")];
+    char stringpool_str503[sizeof("SHIFT_JIS")];
+    char stringpool_str508[sizeof("EUCKR")];
+    char stringpool_str510[sizeof("ASMO-708")];
+    char stringpool_str511[sizeof("EUC-KR")];
+    char stringpool_str517[sizeof("HP-ROMAN8")];
+    char stringpool_str525[sizeof("EUCJPMS")];
+    char stringpool_str526[sizeof("CYRILLIC-ASIAN")];
+    char stringpool_str528[sizeof("EUCJP-MS")];
+    char stringpool_str530[sizeof("ISO-IR-57")];
+    char stringpool_str531[sizeof("EUC-JP-MS")];
+    char stringpool_str534[sizeof("ISO-IR-157")];
+    char stringpool_str535[sizeof("ISO-IR-127")];
+    char stringpool_str536[sizeof("ISO-IR-87")];
+    char stringpool_str537[sizeof("WINDOWS-31J")];
+    char stringpool_str545[sizeof("CN-GB-ISOIR165")];
+    char stringpool_str546[sizeof("WINDOWS-1257")];
+    char stringpool_str547[sizeof("UCS-4LE")];
+    char stringpool_str549[sizeof("UCS-2BE")];
+    char stringpool_str555[sizeof("CN-GB")];
+    char stringpool_str556[sizeof("ISO-2022-KR")];
+    char stringpool_str557[sizeof("MACROMAN")];
+    char stringpool_str559[sizeof("ISO_8859-6:1987")];
+    char stringpool_str560[sizeof("ISO_8859-1:1987")];
+    char stringpool_str567[sizeof("ISO_8859-2:1987")];
+    char stringpool_str570[sizeof("HEBREW")];
+    char stringpool_str572[sizeof("MS_KANJI")];
+    char stringpool_str575[sizeof("MULELAO-1")];
+    char stringpool_str580[sizeof("MACINTOSH")];
+    char stringpool_str583[sizeof("IBM-CP1133")];
+    char stringpool_str584[sizeof("KS_C_5601-1987")];
+    char stringpool_str586[sizeof("CSISO58GB231280")];
+    char stringpool_str587[sizeof("CSKSC56011987")];
+    char stringpool_str595[sizeof("MACARABIC")];
+    char stringpool_str599[sizeof("LATIN7")];
+    char stringpool_str602[sizeof("UCS-4BE")];
+    char stringpool_str604[sizeof("HZ-GB-2312")];
+    char stringpool_str606[sizeof("CSSHIFTJIS")];
+    char stringpool_str610[sizeof("CSISO2022KR")];
+    char stringpool_str612[sizeof("GBK")];
+    char stringpool_str613[sizeof("STRK1048-2002")];
+    char stringpool_str615[sizeof("MS-CYRL")];
+    char stringpool_str618[sizeof("MACROMANIA")];
+    char stringpool_str619[sizeof("CSMACINTOSH")];
+    char stringpool_str625[sizeof("UTF-16LE")];
+    char stringpool_str631[sizeof("JOHAB")];
+    char stringpool_str632[sizeof("UCS-2-INTERNAL")];
+    char stringpool_str635[sizeof("CSHPROMAN8")];
+    char stringpool_str636[sizeof("MACCYRILLIC")];
+    char stringpool_str637[sizeof("JIS_X0212")];
+    char stringpool_str640[sizeof("UNICODE-1-1-UTF-7")];
+    char stringpool_str641[sizeof("ISO_8859-7:2003")];
+    char stringpool_str646[sizeof("CSUNICODE11UTF7")];
+    char stringpool_str651[sizeof("KOI8-U")];
+    char stringpool_str655[sizeof("CSISO57GB1988")];
+    char stringpool_str659[sizeof("JISX0201-1976")];
+    char stringpool_str664[sizeof("WINDOWS-874")];
+    char stringpool_str669[sizeof("JIS_X0201")];
+    char stringpool_str670[sizeof("GEORGIAN-PS")];
+    char stringpool_str676[sizeof("IBM367")];
+    char stringpool_str680[sizeof("UTF-16BE")];
+    char stringpool_str683[sizeof("MACCENTRALEUROPE")];
+    char stringpool_str685[sizeof("UCS-4-INTERNAL")];
+    char stringpool_str686[sizeof("JIS_X0212-1990")];
+    char stringpool_str687[sizeof("CSISOLATINGREEK")];
+    char stringpool_str693[sizeof("JIS_X0208")];
+    char stringpool_str694[sizeof("GREEK")];
+    char stringpool_str700[sizeof("SHIFT_JIS-MS")];
+    char stringpool_str711[sizeof("CSEUCKR")];
+    char stringpool_str714[sizeof("UTF-32LE")];
+    char stringpool_str715[sizeof("UNICODELITTLE")];
+    char stringpool_str729[sizeof("JIS_X0212.1990-0")];
+    char stringpool_str730[sizeof("ANSI_X3.4-1986")];
+    char stringpool_str737[sizeof("JIS_X0208-1990")];
+    char stringpool_str742[sizeof("BIGFIVE")];
+    char stringpool_str743[sizeof("ANSI_X3.4-1968")];
+    char stringpool_str745[sizeof("BIG-FIVE")];
+    char stringpool_str751[sizeof("TCVN5712-1:1993")];
+    char stringpool_str752[sizeof("ISO_8859-7:1987")];
+    char stringpool_str764[sizeof("KOI8-RU")];
+    char stringpool_str769[sizeof("UTF-32BE")];
+    char stringpool_str772[sizeof("JIS_X0208-1983")];
+    char stringpool_str779[sizeof("MS-ARAB")];
+    char stringpool_str781[sizeof("UTF-7")];
+    char stringpool_str785[sizeof("MACICELAND")];
+    char stringpool_str797[sizeof("MS-HEBR")];
+    char stringpool_str802[sizeof("UCS-2-SWAPPED")];
+    char stringpool_str810[sizeof("MACHEBREW")];
+    char stringpool_str816[sizeof("CSISO87JISX0208")];
+    char stringpool_str830[sizeof("NEXTSTEP")];
+    char stringpool_str843[sizeof("EXTENDED_UNIX_CODE_PACKED_FORMAT_FOR_JAPANESE")];
+    char stringpool_str855[sizeof("UCS-4-SWAPPED")];
+    char stringpool_str870[sizeof("MACUKRAINE")];
+    char stringpool_str889[sizeof("BIG5HKSCS")];
+    char stringpool_str892[sizeof("BIG5-HKSCS")];
+    char stringpool_str913[sizeof("UNICODEBIG")];
+    char stringpool_str944[sizeof("CSPC850MULTILINGUAL")];
+    char stringpool_str947[sizeof("CSHALFWIDTHKATAKANA")];
+    char stringpool_str982[sizeof("WINBALTRIM")];
+    char stringpool_str1003[sizeof("MS-GREEK")];
+    char stringpool_str1006[sizeof("MACGREEK")];
+    char stringpool_str1025[sizeof("MS-TURK")];
+    char stringpool_str1041[sizeof("UTF7IMAP")];
+    char stringpool_str1047[sizeof("UTF-7-IMAP")];
+    char stringpool_str1099[sizeof("BIG5-HKSCS:2001")];
+    char stringpool_str1111[sizeof("BIG5-HKSCS:2008")];
+    char stringpool_str1112[sizeof("BIG5-HKSCS:1999")];
+    char stringpool_str1114[sizeof("MACTURKISH")];
+    char stringpool_str1159[sizeof("BIG5-HKSCS:2004")];
+    char stringpool_str1254[sizeof("CSEUCPKDFMTJAPANESE")];
   };
 static const struct stringpool_t stringpool_contents =
   {
-    "SJIS",
-    "L1",
-    "L6",
-    "R8",
-    "L5",
-    "L4",
-    "ISO-IR-199",
-    "L8",
-    "ISO-IR-6",
-    "L2",
+    "CN",
     "866",
-    "ISO-IR-159",
-    "ISO-IR-149",
-    "ISO-IR-166",
-    "PT154",
-    "ISO-IR-14",
-    "L3",
-    "ISO-IR-165",
-    "ISO-IR-126",
-    "ISO-IR-109",
-    "ISO-IR-101",
-    "KOI8-R",
-    "ISO-IR-144",
+    "CP866",
+    "CP1256",
     "862",
-    "ISO88599",
-    "ISO-IR-58",
-    "ISO88591",
-    "ISO8859-9",
+    "CP1251",
     "C99",
-    "ISO8859-1",
-    "ISO-8859-9",
-    "ISO_8859-9",
-    "ISO-8859-1",
-    "ISO_8859-1",
-    "ISO8859-11",
-    "ISO-IR-148",
-    "L7",
-    "ISO-8859-11",
-    "ISO_8859-11",
-    "CN",
+    "CP862",
+    "ASCII",
+    "CP1255",
+    "CP1252",
+    "CP819",
+    "CP1258",
+    "EUCCN",
     "ISO88596",
-    "ISO-IR-226",
+    "EUC-CN",
+    "ISO88591",
     "ISO8859-6",
+    "ISO8859-1",
     "ISO-8859-6",
-    "ISO_8859-6",
     "ISO8859-16",
-    "L10",
-    "ISO_8859-16:2001",
+    "ISO-8859-1",
+    "ISO8859-11",
     "ISO-8859-16",
-    "ISO_8859-16",
+    "ISO-8859-11",
     "ISO88595",
-    "CP949",
+    "ISO88592",
     "ISO8859-5",
-    "ISO-IR-179",
     "ISO885915",
+    "ISO8859-2",
     "ISO-8859-5",
-    "ISO_8859-5",
     "ISO8859-15",
-    "850",
-    "CP819",
+    "ISO-8859-2",
     "ISO-8859-15",
-    "ISO_8859-15",
-    "ISO8859-4",
-    "ISO-IR-110",
-    "RK1048",
-    "ISO-8859-4",
-    "ISO_8859-4",
-    "ISO8859-14",
-    "ISO-IR-138",
-    "ISO-8859-14",
-    "ISO_8859-14",
+    "CP50221",
     "ISO88598",
+    "ISO88599",
     "ISO8859-8",
-    "ISO_8859-15:1998",
+    "ISO646-CN",
+    "ISO8859-9",
     "ISO-8859-8",
-    "ISO_8859-8",
-    "CP866",
-    "ISO_8859-14:1998",
-    "CHAR",
-    "ISO88592",
-    "CP1251",
-    "CP154",
-    "ISO8859-2",
-    "HZ",
-    "ASCII",
-    "ISO-8859-2",
-    "ISO_8859-2",
-    "PTCP154",
-    "CP1131",
-    "CP1256",
-    "GBK",
+    "ISO-8859-9",
     "CP1361",
+    "CP1131",
+    "CSASCII",
+    "ISO_8859-6",
+    "ISO_8859-1",
+    "ISO_8859-16",
     "CP936",
-    "KOREAN",
-    "IBM819",
-    "EUCKR",
-    "CP1255",
-    "ISO-IR-100",
-    "EUC-KR",
-    "ISO646-CN",
-    "KZ-1048",
-    "CSKOI8R",
-    "ISO_8859-10:1992",
+    "ISO_8859-11",
+    "850",
+    "ISO-2022-CN",
+    "ISO_8859-16:2001",
+    "CP949",
+    "ISO_8859-5",
+    "ISO_8859-2",
+    "ISO_8859-15",
+    "R8",
+    "CP932",
+    "CP1250",
+    "CP850",
+    "CP950",
+    "ISO-IR-6",
+    "ISO_8859-8",
+    "HZ",
+    "ISO_8859-9",
+    "ISO_8859-15:1998",
+    "ISO-IR-166",
+    "CP51932",
+    "CP154",
+    "ISO-IR-126",
+    "L6",
+    "L1",
+    "ISO-IR-165",
+    "ISO-IR-226",
+    "L5",
+    "L2",
     "CP1254",
-    "LATIN1",
-    "LATIN-9",
-    "US",
-    "CP862",
+    "ISO-2022-CN-EXT",
+    "L8",
+    "SJIS",
+    "HP15CN",
+    "ISO-IR-58",
+    "CSISO2022CN",
     "ISO8859-10",
-    "IBM866",
+    "ISO_8859-10:1992",
+    "SJIS-WIN",
     "ISO-8859-10",
+    "ISO-IR-159",
+    "JP",
+    "EUCTW",
+    "EUC-TW",
+    "ISO-IR-199",
+    "ELOT_928",
+    "TCVN",
+    "ISO-IR-101",
+    "ISO_8859-14:1998",
+    "VISCII",
+    "CHINESE",
+    "ISO8859-4",
+    "ISO-8859-4",
+    "ISO8859-14",
+    "CP1253",
+    "CSVISCII",
+    "ISO-8859-14",
+    "MAC",
     "ISO_8859-10",
-    "CP1258",
+    "UHC",
+    "L4",
     "LATIN6",
+    "LATIN1",
+    "ISO-IR-109",
+    "TIS620",
+    "TIS-620",
+    "IBM866",
+    "LATIN5",
+    "ISO-IR-148",
+    "LATIN2",
+    "ISO-IR-149",
+    "ISO_8859-4",
+    "L3",
+    "ISO_8859-14",
+    "ISO-IR-110",
+    "IBM862",
     "ISO8859-3",
+    "LATIN8",
     "ISO-8859-3",
-    "ISO_8859-3",
     "ISO8859-13",
-    "ISO_8859-9:1989",
+    "LATIN-9",
     "ISO-8859-13",
+    "L10",
+    "JIS_C6220-1969-RO",
+    "ISO-IR-138",
+    "IBM819",
+    "US",
+    "JAVA",
+    "VISCII1.1-1",
+    "PT154",
+    "JIS0208",
+    "ISO-IR-14",
+    "RK1048",
+    "GB2312",
+    "CHAR",
+    "TIS620.2529-1",
+    "ISO-CELTIC",
+    "CSISO14JISC6220RO",
+    "CP1133",
+    "TIS620-0",
+    "ISO_8859-3",
+    "CSISO159JISX02121990",
+    "UCS-2",
     "ISO_8859-13",
-    "CP1252",
-    "CHINESE",
-    "CP950",
-    "LATIN5",
-    "MS936",
-    "ISO_646.IRV:1991",
-    "CP932",
-    "ISO-IR-203",
-    "ISO-IR-57",
+    "ISO-2022-JP-1",
+    "JIS_C6226-1983",
+    "ISO-IR-100",
+    "ARABIC",
+    "ISO-2022-JP-2",
+    "EUCJP-WIN",
+    "SJIS-OPEN",
     "MS-ANSI",
-    "ISO-2022-KR",
+    "MS936",
+    "US-ASCII",
+    "ECMA-118",
+    "LATIN10",
+    "CSISOLATIN6",
+    "CSISOLATIN1",
+    "MS932",
+    "MS-EE",
+    "IBM850",
+    "ISO-IR-144",
+    "CSISOLATINCYRILLIC",
+    "CSISOLATIN5",
+    "ARMSCII-8",
+    "CSISOLATIN2",
+    "ISO-2022-JP-MS",
+    "MS51932",
     "LATIN4",
-    "ISO-IR-157",
-    "VISCII",
-    "GB2312",
-    "ISO-IR-87",
+    "CSISO2022JP2",
+    "EUCJP",
+    "EUC-JP",
+    "L7",
+    "CP874",
     "KSC_5601",
-    "MS-EE",
-    "CP50221",
-    "GREEK",
-    "LATIN8",
-    "CP850",
-    "UCS-4",
-    "GREEK8",
-    "ISO-IR-127",
-    "IBM862",
-    "GEORGIAN-PS",
-    "KS_C_5601-1989",
-    "ISO_8859-5:1988",
-    "LATIN2",
-    "CP1250",
-    "EUCCN",
-    "ISO_8859-4:1988",
-    "EUC-CN",
-    "CP874",
-    "CSASCII",
-    "ISO646-US",
-    "ISO_8859-8:1988",
+    "ISO-10646-UCS-2",
+    "GB_1988-80",
+    "CSISOLATINARABIC",
+    "WINDOWS-1256",
+    "WINDOWS-1251",
+    "KOI8-T",
+    "ISO-IR-203",
+    "WINDOWS-1255",
+    "WINDOWS-1252",
+    "ISO-IR-179",
     "BIG5",
-    "CP1253",
+    "WINDOWS-1258",
     "BIG-5",
-    "UCS-2",
-    "X0201",
+    "WINDOWS-51932",
+    "ISO646-JP",
+    "CSBIG5",
+    "CN-BIG5",
+    "LATIN3",
+    "PTCP154",
     "ROMAN8",
-    "VISCII1.1-1",
-    "MS-CYRL",
-    "ISO88597",
-    "CP1133",
-    "GB_1988-80",
-    "ISO8859-7",
-    "MULELAO-1",
-    "ISO-8859-7",
-    "ISO_8859-7",
-    "X0212",
-    "ECMA-114",
+    "CSEUCTW",
+    "UCS-4",
+    "ISO646-US",
+    "ISO_8859-5:1988",
+    "ISO-2022-JP",
+    "KZ-1048",
+    "CSUCS4",
+    "ISO_8859-8:1988",
+    "ISO_8859-9:1989",
     "CSKZ1048",
-    "ELOT_928",
-    "STRK1048-2002",
-    "IBM850",
-    "ISO_8859-3:1988",
-    "LATIN10",
-    "UTF-16",
-    "ECMA-118",
-    "ISO-2022-CN",
-    "LATIN3",
-    "TIS620",
-    "ISO_8859-1:1987",
-    "UCS-4LE",
-    "TIS-620",
-    "HP15CN",
-    "TCVN",
-    "ISO_8859-6:1987",
-    "CYRILLIC-ASIAN",
-    "UCS-2LE",
-    "X0208",
     "GB18030",
-    "CSISO2022KR",
-    "CYRILLIC",
+    "UTF-16",
+    "WINDOWS-1250",
+    "ISO-10646-UCS-4",
+    "EUCJP-OPEN",
+    "ISO_646.IRV:1991",
+    "KS_C_5601-1989",
+    "ECMA-114",
+    "GB_2312-80",
+    "TIS620.2533-1",
+    "TCVN5712-1",
+    "WINDOWS-1254",
+    "SJIS-MS",
+    "TCVN-5712",
     "UTF8",
-    "MAC",
+    "MACTHAI",
     "UTF-8",
-    "CSVISCII",
-    "ISO_8859-2:1987",
     "CP1257",
-    "ISO-10646-UCS-4",
-    "KS_C_5601-1987",
-    "GB_2312-80",
-    "CP367",
-    "JP",
-    "ISO-10646-UCS-2",
+    "CSIBM866",
+    "CYRILLIC",
+    "WINDOWS-936",
+    "CSPTCP154",
+    "CSISOLATIN4",
+    "WINDOWS-1253",
+    "X0212",
+    "CSPC862LATINHEBREW",
+    "KOREAN",
+    "ISO_8859-4:1988",
+    "CSISO2022JP",
     "UNICODE-1-1",
-    "ISO_8859-7:2003",
-    "TIS620-0",
-    "ARMSCII-8",
-    "CSBIG5",
-    "CSISOLATIN1",
-    "US-ASCII",
-    "CN-BIG5",
-    "UTF-16LE",
-    "TIS620.2529-1",
-    "ANSI_X3.4-1986",
-    "LATIN7",
-    "CN-GB-ISOIR165",
-    "CSISOLATIN6",
-    "UHC",
-    "KOI8-T",
-    "MS-GREEK",
-    "ANSI_X3.4-1968",
-    "CSISOLATIN5",
-    "WINDOWS-1251",
-    "ISO_8859-7:1987",
-    "CSISO2022CN",
+    "WINDOWS-932",
+    "CSUNICODE11",
+    "WCHAR_T",
+    "TIS620.2533-0",
+    "MACCROATIAN",
+    "ISO88597",
+    "ISO8859-7",
+    "ISO_8859-3:1988",
+    "ISO-8859-7",
+    "X0201",
+    "SHIFT-JIS",
+    "CSGB2312",
+    "CSISOLATIN3",
+    "CSUNICODE",
+    "CSWINDOWS31J",
+    "KOI8-R",
+    "CSISOLATINHEBREW",
+    "CP367",
+    "CSKOI8R",
+    "GREEK8",
+    "X0208",
+    "UCS-2LE",
+    "ISO_8859-7",
     "UTF-32",
-    "IBM367",
-    "WINDOWS-1256",
-    "CSISOLATIN4",
     "GEORGIAN-ACADEMY",
-    "WINDOWS-1255",
-    "WINDOWS-1254",
+    "SHIFT_JIS",
+    "EUCKR",
     "ASMO-708",
-    "CSPTCP154",
-    "ISO646-JP",
-    "WINDOWS-936",
-    "WINDOWS-1258",
-    "WINDOWS-1252",
-    "CSISOLATIN2",
+    "EUC-KR",
+    "HP-ROMAN8",
+    "EUCJPMS",
+    "CYRILLIC-ASIAN",
+    "EUCJP-MS",
+    "ISO-IR-57",
+    "EUC-JP-MS",
+    "ISO-IR-157",
+    "ISO-IR-127",
+    "ISO-IR-87",
+    "WINDOWS-31J",
+    "CN-GB-ISOIR165",
+    "WINDOWS-1257",
+    "UCS-4LE",
+    "UCS-2BE",
+    "CN-GB",
+    "ISO-2022-KR",
+    "MACROMAN",
+    "ISO_8859-6:1987",
+    "ISO_8859-1:1987",
+    "ISO_8859-2:1987",
+    "HEBREW",
+    "MS_KANJI",
+    "MULELAO-1",
+    "MACINTOSH",
     "IBM-CP1133",
-    "CSUCS4",
+    "KS_C_5601-1987",
+    "CSISO58GB231280",
     "CSKSC56011987",
-    "ISO-2022-CN-EXT",
-    "WINDOWS-1250",
-    "HP-ROMAN8",
-    "UTF-32LE",
-    "WINDOWS-1253",
-    "TIS620.2533-1",
+    "MACARABIC",
+    "LATIN7",
     "UCS-4BE",
-    "UCS-4-SWAPPED",
-    "UNICODE-1-1-UTF-7",
-    "UCS-4-INTERNAL",
-    "TCVN5712-1",
-    "CSIBM866",
-    "UTF-7",
-    "UCS-2BE",
-    "UCS-2-SWAPPED",
-    "MACICELAND",
-    "CSUNICODE11",
+    "HZ-GB-2312",
+    "CSSHIFTJIS",
+    "CSISO2022KR",
+    "GBK",
+    "STRK1048-2002",
+    "MS-CYRL",
+    "MACROMANIA",
+    "CSMACINTOSH",
+    "UTF-16LE",
+    "JOHAB",
     "UCS-2-INTERNAL",
-    "ARABIC",
-    "CSISOLATIN3",
-    "CSEUCKR",
-    "MACROMAN",
+    "CSHPROMAN8",
+    "MACCYRILLIC",
+    "JIS_X0212",
+    "UNICODE-1-1-UTF-7",
+    "ISO_8859-7:2003",
+    "CSUNICODE11UTF7",
     "KOI8-U",
-    "MACGREEK",
-    "KOI8-RU",
-    "TCVN-5712",
-    "WINDOWS-1257",
-    "EUCJP",
-    "CSUNICODE",
-    "CSISOLATINGREEK",
-    "EUC-JP",
-    "CN-GB",
-    "CSGB2312",
     "CSISO57GB1988",
-    "MS-HEBR",
-    "TIS620.2533-0",
+    "JISX0201-1976",
     "WINDOWS-874",
-    "ISO-CELTIC",
-    "BIGFIVE",
-    "BIG-FIVE",
+    "JIS_X0201",
+    "GEORGIAN-PS",
+    "IBM367",
     "UTF-16BE",
-    "CSISOLATINARABIC",
-    "ISO-2022-JP",
-    "ISO-2022-JP-1",
-    "ISO-2022-JP-MS",
-    "CSISO58GB231280",
-    "CSHPROMAN8",
-    "NEXTSTEP",
-    "JIS0208",
-    "CSISOLATINCYRILLIC",
-    "CSISO159JISX02121990",
-    "EXTENDED_UNIX_CODE_PACKED_FORMAT_FOR_JAPANESE",
-    "CSUNICODE11UTF7",
-    "HZ-GB-2312",
-    "ISO-2022-JP-2",
-    "MACCYRILLIC",
-    "BIG5HKSCS",
-    "BIG5-HKSCS",
-    "EUCTW",
-    "EUC-TW",
-    "MS-ARAB",
-    "MACROMANIA",
-    "UTF-32BE",
-    "JAVA",
-    "MS-TURK",
-    "SHIFT-JIS",
-    "SHIFT_JIS",
-    "CSISO14JISC6220RO",
-    "JIS_C6220-1969-RO",
-    "MACTHAI",
-    "JIS_C6226-1983",
-    "TCVN5712-1:1993",
-    "CSISO2022JP",
-    "MS_KANJI",
-    "MACUKRAINE",
-    "MACCROATIAN",
-    "HEBREW",
-    "UNICODEBIG",
-    "CSPC862LATINHEBREW",
-    "CSISO2022JP2",
-    "CSISOLATINHEBREW",
-    "WCHAR_T",
     "MACCENTRALEUROPE",
-    "BIG5-HKSCS:1999",
-    "BIG5-HKSCS:2001",
-    "JIS_X0201",
-    "UNICODELITTLE",
-    "JIS_X0212",
-    "BIG5-HKSCS:2004",
-    "JISX0201-1976",
-    "MACARABIC",
-    "BIG5-HKSCS:2008",
+    "UCS-4-INTERNAL",
     "JIS_X0212-1990",
+    "CSISOLATINGREEK",
     "JIS_X0208",
-    "MACINTOSH",
+    "GREEK",
+    "SHIFT_JIS-MS",
+    "CSEUCKR",
+    "UTF-32LE",
+    "UNICODELITTLE",
     "JIS_X0212.1990-0",
+    "ANSI_X3.4-1986",
     "JIS_X0208-1990",
+    "BIGFIVE",
+    "ANSI_X3.4-1968",
+    "BIG-FIVE",
+    "TCVN5712-1:1993",
+    "ISO_8859-7:1987",
+    "KOI8-RU",
+    "UTF-32BE",
     "JIS_X0208-1983",
+    "MS-ARAB",
+    "UTF-7",
+    "MACICELAND",
+    "MS-HEBR",
+    "UCS-2-SWAPPED",
+    "MACHEBREW",
     "CSISO87JISX0208",
+    "NEXTSTEP",
+    "EXTENDED_UNIX_CODE_PACKED_FORMAT_FOR_JAPANESE",
+    "UCS-4-SWAPPED",
+    "MACUKRAINE",
+    "BIG5HKSCS",
+    "BIG5-HKSCS",
+    "UNICODEBIG",
     "CSPC850MULTILINGUAL",
-    "WINBALTRIM",
-    "CSSHIFTJIS",
-    "CSEUCTW",
-    "CSEUCPKDFMTJAPANESE",
-    "JOHAB",
-    "CSMACINTOSH",
-    "MACHEBREW",
     "CSHALFWIDTHKATAKANA",
-    "MACTURKISH"
+    "WINBALTRIM",
+    "MS-GREEK",
+    "MACGREEK",
+    "MS-TURK",
+    "UTF7IMAP",
+    "UTF-7-IMAP",
+    "BIG5-HKSCS:2001",
+    "BIG5-HKSCS:2008",
+    "BIG5-HKSCS:1999",
+    "MACTURKISH",
+    "BIG5-HKSCS:2004",
+    "CSEUCPKDFMTJAPANESE"
   };
 #define stringpool ((const char *) &stringpool_contents)
 
 static const struct alias aliases[] =
   {
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-    {-1},
-#line 317 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str19, ei_sjis},
+    {-1}, {-1}, {-1}, {-1}, {-1},
+#line 299 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str14, ei_iso646_cn},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+#line 218 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str22, ei_cp866},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+#line 216 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str31, ei_cp866},
+    {-1}, {-1}, {-1}, {-1}, {-1},
+#line 200 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str37, ei_cp1256},
+#line 214 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str38, ei_cp862},
+#line 185 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str39, ei_cp1251},
+#line 54 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str40, ei_c99},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+#line 212 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str47, ei_cp862},
+#line 13 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str48, ei_ascii},
     {-1}, {-1},
-#line 61 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str22, ei_iso8859_1},
+#line 197 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str51, ei_cp1255},
+    {-1},
+#line 188 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str53, ei_cp1252},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-#line 142 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str29, ei_iso8859_10},
-    {-1}, {-1}, {-1}, {-1},
-#line 236 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str34, ei_hp_roman8},
+#line 60 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str60, ei_iso8859_1},
+    {-1}, {-1},
+#line 206 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str63, ei_cp1258},
+    {-1}, {-1}, {-1}, {-1}, {-1},
+#line 347 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str69, ei_euc_cn},
     {-1},
-#line 133 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str36, ei_iso8859_9},
-    {-1}, {-1}, {-1}, {-1},
-#line 87 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str41, ei_iso8859_4},
+#line 109 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str71, ei_iso8859_6},
+#line 346 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str72, ei_euc_cn},
+#line 66 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str73, ei_iso8859_1},
+#line 108 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str74, ei_iso8859_6},
     {-1},
-#line 157 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str43, ei_iso8859_14},
-    {-1}, {-1}, {-1}, {-1},
-#line 159 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str48, ei_iso8859_14},
+#line 65 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str76, ei_iso8859_1},
+#line 100 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str77, ei_iso8859_6},
+#line 177 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str78, ei_iso8859_16},
+#line 56 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str79, ei_iso8859_1},
+#line 149 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str80, ei_iso8859_11},
+#line 171 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str81, ei_iso8859_16},
+    {-1},
+#line 147 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str83, ei_iso8859_11},
+    {-1},
+#line 99 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str85, ei_iso8859_5},
+    {-1},
+#line 75 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str87, ei_iso8859_2},
+#line 98 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str88, ei_iso8859_5},
+#line 170 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str89, ei_iso8859_15},
+#line 74 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str90, ei_iso8859_2},
+#line 92 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str91, ei_iso8859_5},
+#line 169 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str92, ei_iso8859_15},
+#line 67 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str93, ei_iso8859_2},
+    {-1},
+#line 164 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str95, ei_iso8859_15},
+#line 345 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str96, ei_iso2022_jpms},
+#line 129 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str97, ei_iso8859_8},
+    {-1},
+#line 138 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str99, ei_iso8859_9},
+#line 128 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str100, ei_iso8859_8},
+#line 297 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str101, ei_iso646_cn},
+#line 137 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str102, ei_iso8859_9},
+#line 122 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str103, ei_iso8859_8},
+    {-1},
+#line 130 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str105, ei_iso8859_9},
+#line 384 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str106, ei_johab},
+#line 220 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str107, ei_cp1131},
+#line 22 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str108, ei_ascii},
+#line 101 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str109, ei_iso8859_6},
+    {-1},
+#line 57 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str111, ei_iso8859_1},
     {-1},
+#line 172 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str113, ei_iso8859_16},
+#line 353 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str114, ei_cp936},
+#line 148 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str115, ei_iso8859_11},
+#line 210 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str116, ei_cp850},
+#line 357 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str117, ei_iso2022_cn},
+    {-1},
+#line 173 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str119, ei_iso8859_16},
+    {-1},
+#line 381 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str121, ei_cp949},
+    {-1},
+#line 93 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str123, ei_iso8859_5},
+    {-1},
+#line 68 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str125, ei_iso8859_2},
+    {-1},
+#line 165 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str127, ei_iso8859_15},
+    {-1},
+#line 238 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str129, ei_hp_roman8},
+#line 330 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str130, ei_cp932},
+#line 182 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str131, ei_cp1250},
+#line 208 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str132, ei_cp850},
+#line 371 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str133, ei_cp950},
 #line 16 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str50, ei_ascii},
-    {-1}, {-1}, {-1},
-#line 70 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str54, ei_iso8859_2},
-#line 216 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str55, ei_cp866},
-    {-1}, {-1},
-#line 292 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str58, ei_jisx0212},
-    {-1}, {-1}, {-1}, {-1},
-#line 308 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str63, ei_ksc5601},
-    {-1}, {-1}, {-1},
-#line 261 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str67, ei_tis620},
-    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-#line 243 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str76, ei_pt154},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str134, ei_ascii},
+#line 123 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str135, ei_iso8859_8},
+#line 360 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str136, ei_hz},
+#line 131 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str137, ei_iso8859_9},
+#line 166 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str138, ei_iso8859_15},
     {-1}, {-1},
-#line 273 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str79, ei_iso646_jp},
-#line 79 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str80, ei_iso8859_3},
-#line 303 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str81, ei_isoir165},
-    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-    {-1},
-#line 112 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str92, ei_iso8859_7},
+#line 263 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str141, ei_tis620},
+    {-1}, {-1},
+#line 322 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str144, ei_cp51932},
     {-1}, {-1}, {-1},
-#line 77 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str96, ei_iso8859_3},
-    {-1},
-#line 68 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str98, ei_iso8859_2},
+#line 247 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str148, ei_pt154},
+#line 114 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str149, ei_iso8859_7},
+#line 144 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str150, ei_iso8859_10},
+#line 63 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str151, ei_iso8859_1},
+    {-1}, {-1}, {-1},
+#line 305 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str155, ei_isoir165},
+#line 174 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str156, ei_iso8859_16},
+#line 135 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str157, ei_iso8859_9},
+#line 72 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str158, ei_iso8859_2},
+#line 194 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str159, ei_cp1254},
+    {-1}, {-1},
+#line 359 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str162, ei_iso2022_cn_ext},
+#line 161 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str163, ei_iso8859_14},
     {-1},
-#line 176 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str100, ei_koi8_r},
+#line 327 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str165, ei_sjis},
     {-1}, {-1},
-#line 93 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str103, ei_iso8859_5},
+#line 351 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str168, ei_euc_cn},
     {-1},
-#line 212 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str105, ei_cp862},
-#line 136 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str106, ei_iso8859_9},
-#line 300 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str107, ei_gb2312},
-#line 64 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str108, ei_iso8859_1},
-#line 135 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str109, ei_iso8859_9},
-#line 52 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str110, ei_c99},
-#line 63 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str111, ei_iso8859_1},
-#line 128 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str112, ei_iso8859_9},
-#line 129 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str113, ei_iso8859_9},
-#line 54 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str114, ei_iso8859_1},
-#line 55 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str115, ei_iso8859_1},
-#line 147 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str116, ei_iso8859_11},
-#line 131 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str117, ei_iso8859_9},
-#line 152 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str118, ei_iso8859_13},
-#line 145 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str119, ei_iso8859_11},
+#line 302 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str170, ei_gb2312},
+#line 358 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str171, ei_iso2022_cn},
 #line 146 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str120, ei_iso8859_11},
-#line 297 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str121, ei_iso646_cn},
-#line 107 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str122, ei_iso8859_6},
-    {-1},
-#line 172 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str124, ei_iso8859_16},
-#line 106 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str125, ei_iso8859_6},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str172, ei_iso8859_10},
+#line 141 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str173, ei_iso8859_10},
+#line 334 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str174, ei_cp932},
+#line 139 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str175, ei_iso8859_10},
+#line 294 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str176, ei_jisx0212},
+#line 276 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str177, ei_iso646_jp},
+#line 363 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str178, ei_euc_tw},
     {-1}, {-1},
-#line 98 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str128, ei_iso8859_6},
-#line 99 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str129, ei_iso8859_6},
-#line 175 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str130, ei_iso8859_16},
-#line 174 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str131, ei_iso8859_16},
-#line 171 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str132, ei_iso8859_16},
-#line 169 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str133, ei_iso8859_16},
-#line 170 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str134, ei_iso8859_16},
+#line 362 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str181, ei_euc_tw},
     {-1},
-#line 97 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str136, ei_iso8859_5},
+#line 159 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str183, ei_iso8859_14},
+    {-1}, {-1}, {-1}, {-1},
+#line 116 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str188, ei_iso8859_7},
+#line 269 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str189, ei_tcvn},
+#line 70 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str190, ei_iso8859_2},
+    {-1},
+#line 158 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str192, ei_iso8859_14},
+#line 266 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str193, ei_viscii},
+#line 304 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str194, ei_gb2312},
     {-1},
-#line 363 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str138, ei_cp949},
-#line 96 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str139, ei_iso8859_5},
-#line 150 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str140, ei_iso8859_13},
-#line 168 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str141, ei_iso8859_15},
-#line 90 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str142, ei_iso8859_5},
 #line 91 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str143, ei_iso8859_5},
-#line 167 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str144, ei_iso8859_15},
-#line 208 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str145, ei_cp850},
-#line 58 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str146, ei_iso8859_1},
-#line 162 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str147, ei_iso8859_15},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str196, ei_iso8859_4},
+    {-1}, {-1},
+#line 84 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str199, ei_iso8859_4},
 #line 163 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str148, ei_iso8859_15},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str200, ei_iso8859_14},
+#line 191 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str201, ei_cp1253},
+#line 268 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str202, ei_viscii},
+#line 156 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str203, ei_iso8859_14},
+    {-1},
+#line 223 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str205, ei_mac_roman},
+    {-1},
+#line 140 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str207, ei_iso8859_10},
+    {-1},
+#line 382 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str209, ei_cp949},
+    {-1},
 #line 89 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str149, ei_iso8859_4},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str211, ei_iso8859_4},
+    {-1},
+#line 143 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str213, ei_iso8859_10},
+    {-1},
+#line 62 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str215, ei_iso8859_1},
+#line 79 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str216, ei_iso8859_3},
+#line 258 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str217, ei_tis620},
+    {-1}, {-1},
+#line 257 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str220, ei_tis620},
+#line 217 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str221, ei_cp866},
+    {-1}, {-1}, {-1}, {-1}, {-1},
+#line 134 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str227, ei_iso8859_9},
+#line 133 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str228, ei_iso8859_9},
+#line 71 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str229, ei_iso8859_2},
+#line 310 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str230, ei_ksc5601},
 #line 85 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str150, ei_iso8859_4},
-#line 248 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str151, ei_rk1048},
-#line 82 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str152, ei_iso8859_4},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str231, ei_iso8859_4},
+#line 81 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str232, ei_iso8859_3},
+    {-1}, {-1},
+#line 157 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str235, ei_iso8859_14},
+#line 87 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str236, ei_iso8859_4},
+#line 213 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str237, ei_cp862},
 #line 83 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str153, ei_iso8859_4},
-#line 161 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str154, ei_iso8859_14},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str238, ei_iso8859_3},
+#line 160 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str239, ei_iso8859_14},
     {-1},
-#line 123 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str156, ei_iso8859_8},
-#line 154 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str157, ei_iso8859_14},
+#line 76 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str241, ei_iso8859_3},
 #line 155 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str158, ei_iso8859_14},
-    {-1},
-#line 127 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str160, ei_iso8859_8},
-    {-1}, {-1},
-#line 126 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str163, ei_iso8859_8},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str242, ei_iso8859_13},
     {-1},
-#line 164 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str165, ei_iso8859_15},
-#line 120 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str166, ei_iso8859_8},
-#line 121 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str167, ei_iso8859_8},
+#line 168 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str244, ei_iso8859_15},
+#line 150 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str245, ei_iso8859_13},
     {-1},
-#line 214 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str169, ei_cp866},
-#line 156 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str170, ei_iso8859_14},
-#line 369 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str171, ei_local_char},
-#line 73 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str172, ei_iso8859_2},
-#line 183 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str173, ei_cp1251},
+#line 176 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str247, ei_iso8859_16},
+#line 273 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str248, ei_iso646_jp},
+#line 125 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str249, ei_iso8859_8},
+#line 61 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str250, ei_iso8859_1},
+#line 21 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str251, ei_ascii},
+#line 55 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str252, ei_java},
+#line 267 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str253, ei_viscii},
+    {-1}, {-1}, {-1},
 #line 245 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str174, ei_pt154},
-#line 72 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str175, ei_iso8859_2},
-#line 342 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str176, ei_hz},
-#line 13 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str177, ei_ascii},
-#line 65 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str178, ei_iso8859_2},
-#line 66 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str179, ei_iso8859_2},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str257, ei_pt154},
+    {-1},
+#line 285 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str259, ei_jisx0208},
+#line 275 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str260, ei_iso646_jp},
     {-1}, {-1},
-#line 244 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str182, ei_pt154},
+#line 250 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str263, ei_rk1048},
+#line 348 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str264, ei_euc_cn},
+#line 387 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str265, ei_local_char},
+#line 260 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str266, ei_tis620},
+#line 162 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str267, ei_iso8859_14},
+#line 277 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str268, ei_iso646_jp},
+#line 255 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str269, ei_cp1133},
+#line 259 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str270, ei_tis620},
     {-1}, {-1},
-#line 218 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str185, ei_cp1131},
+#line 77 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str273, ei_iso8859_3},
     {-1},
-#line 198 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str187, ei_cp1256},
-    {-1}, {-1}, {-1},
-#line 334 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str191, ei_ces_gbk},
-#line 366 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str192, ei_johab},
-#line 335 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str193, ei_cp936},
-    {-1}, {-1},
-#line 310 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str196, ei_ksc5601},
+#line 295 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str275, ei_jisx0212},
+#line 25 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str276, ei_ucs2},
+#line 151 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str277, ei_iso8859_13},
+#line 341 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str278, ei_iso2022_jp1},
+    {-1},
+#line 288 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str280, ei_jisx0208},
     {-1},
 #line 59 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str198, ei_iso8859_1},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str282, ei_iso8859_1},
+#line 106 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str283, ei_iso8859_6},
     {-1},
-#line 361 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str200, ei_euc_kr},
-#line 195 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str201, ei_cp1255},
-#line 57 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str202, ei_iso8859_1},
-#line 360 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str203, ei_euc_kr},
-#line 295 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str204, ei_iso646_cn},
-    {-1}, {-1},
-#line 250 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str207, ei_rk1048},
-#line 177 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str208, ei_koi8_r},
-#line 139 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str209, ei_iso8859_10},
+#line 342 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str285, ei_iso2022_jp2},
     {-1},
-#line 192 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str211, ei_cp1254},
-#line 60 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str212, ei_iso8859_1},
-#line 166 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str213, ei_iso8859_15},
-    {-1}, {-1},
-#line 21 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str216, ei_ascii},
-    {-1}, {-1},
-#line 210 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str219, ei_cp862},
-#line 144 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str220, ei_iso8859_10},
-#line 215 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str221, ei_cp866},
+#line 320 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str287, ei_eucjp_ms},
     {-1},
-#line 137 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str223, ei_iso8859_10},
-#line 138 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str224, ei_iso8859_10},
-#line 204 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str225, ei_cp1258},
-#line 141 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str226, ei_iso8859_10},
-#line 81 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str227, ei_iso8859_3},
-    {-1}, {-1},
-#line 74 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str230, ei_iso8859_3},
-#line 75 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str231, ei_iso8859_3},
-#line 153 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str232, ei_iso8859_13},
-#line 130 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str233, ei_iso8859_9},
+#line 333 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str289, ei_cp932},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+#line 190 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str297, ei_cp1252},
+    {-1}, {-1}, {-1},
+#line 354 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str301, ei_cp936},
+#line 12 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str302, ei_ascii},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+#line 115 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str310, ei_iso8859_7},
+#line 175 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str311, ei_iso8859_16},
+#line 145 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str312, ei_iso8859_10},
     {-1},
-#line 148 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str235, ei_iso8859_13},
-#line 149 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str236, ei_iso8859_13},
-#line 186 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str237, ei_cp1252},
-#line 302 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str238, ei_gb2312},
-#line 353 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str239, ei_cp950},
-#line 132 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str240, ei_iso8859_9},
+#line 64 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str314, ei_iso8859_1},
+    {-1}, {-1},
 #line 336 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str241, ei_cp936},
-#line 15 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str242, ei_ascii},
-#line 320 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str243, ei_cp932},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str317, ei_cp932},
+    {-1},
+#line 184 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str319, ei_cp1250},
     {-1}, {-1},
-#line 165 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str246, ei_iso8859_15},
-#line 296 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str247, ei_iso646_cn},
-#line 188 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str248, ei_cp1252},
-#line 367 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str249, ei_iso2022_kr},
-#line 86 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str250, ei_iso8859_4},
+#line 209 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str322, ei_cp850},
     {-1},
-#line 140 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str252, ei_iso8859_10},
+#line 95 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str324, ei_iso8859_5},
+#line 97 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str325, ei_iso8859_5},
+#line 136 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str326, ei_iso8859_9},
+#line 241 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str327, ei_armscii_8},
+#line 73 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str328, ei_iso8859_2},
+#line 344 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str329, ei_iso2022_jpms},
+    {-1},
+#line 324 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str331, ei_cp51932},
     {-1}, {-1}, {-1},
+#line 88 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str335, ei_iso8859_4},
+    {-1}, {-1},
+#line 343 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str338, ei_iso2022_jp2},
+#line 314 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str339, ei_euc_jp},
+    {-1}, {-1},
+#line 313 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str342, ei_euc_jp},
+#line 154 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str343, ei_iso8859_13},
+    {-1}, {-1},
 #line 264 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str256, ei_viscii},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str346, ei_cp874},
+#line 307 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str347, ei_ksc5601},
+#line 26 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str348, ei_ucs2},
+#line 296 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str349, ei_iso646_cn},
+#line 107 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str350, ei_iso8859_6},
+    {-1}, {-1},
+#line 201 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str353, ei_cp1256},
+#line 186 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str354, ei_cp1251},
+#line 244 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str355, ei_koi8_t},
+    {-1}, {-1}, {-1},
+#line 167 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str359, ei_iso8859_15},
+#line 198 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str360, ei_cp1255},
+#line 189 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str361, ei_cp1252},
+#line 152 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str362, ei_iso8859_13},
     {-1},
-#line 330 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str258, ei_euc_cn},
-#line 285 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str259, ei_jisx0208},
-#line 305 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str260, ei_ksc5601},
-#line 182 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str261, ei_cp1250},
-#line 327 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str262, ei_iso2022_jpms},
-#line 116 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str263, ei_iso8859_7},
-#line 158 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str264, ei_iso8859_14},
+#line 365 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str364, ei_ces_big5},
     {-1},
-#line 206 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str266, ei_cp850},
+#line 207 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str366, ei_cp1258},
+#line 366 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str367, ei_ces_big5},
+#line 323 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str368, ei_cp51932},
+    {-1}, {-1},
+#line 274 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str371, ei_iso646_jp},
+    {-1},
+#line 370 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str373, ei_ces_big5},
+    {-1}, {-1},
+#line 369 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str376, ei_ces_big5},
+#line 80 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str377, ei_iso8859_3},
+#line 246 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str378, ei_pt154},
+#line 237 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str379, ei_hp_roman8},
+    {-1},
+#line 364 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str381, ei_euc_tw},
 #line 34 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str267, ei_ucs4},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str382, ei_ucs4},
     {-1},
-#line 115 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str269, ei_iso8859_7},
-#line 101 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str270, ei_iso8859_6},
-#line 211 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str271, ei_cp862},
+#line 14 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str384, ei_ascii},
     {-1},
-#line 241 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str273, ei_georgian_ps},
-#line 307 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str274, ei_ksc5601},
-#line 92 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str275, ei_iso8859_5},
-#line 69 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str276, ei_iso8859_2},
-#line 180 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str277, ei_cp1250},
-#line 329 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str278, ei_euc_cn},
+#line 94 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str386, ei_iso8859_5},
+#line 339 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str387, ei_iso2022_jp},
+#line 252 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str388, ei_rk1048},
+    {-1}, {-1},
+#line 36 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str391, ei_ucs4},
+#line 124 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str392, ei_iso8859_8},
     {-1},
-#line 84 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str280, ei_iso8859_4},
-#line 328 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str281, ei_euc_cn},
-#line 262 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str282, ei_cp874},
+#line 132 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str394, ei_iso8859_9},
+#line 253 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str395, ei_rk1048},
     {-1},
-#line 22 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str284, ei_ascii},
-#line 14 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str285, ei_ascii},
+#line 356 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str397, ei_gb18030},
     {-1},
-#line 122 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str287, ei_iso8859_8},
-#line 347 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str288, ei_ces_big5},
-#line 189 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str289, ei_cp1253},
+#line 39 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str399, ei_utf16},
+#line 183 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str400, ei_cp1250},
+#line 35 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str401, ei_ucs4},
+#line 318 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str402, ei_eucjp_ms},
     {-1},
-#line 348 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str291, ei_ces_big5},
+#line 15 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str404, ei_ascii},
+#line 309 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str405, ei_ksc5601},
+#line 104 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str406, ei_iso8859_6},
+#line 301 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str407, ei_gb2312},
+#line 262 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str408, ei_tis620},
+    {-1}, {-1}, {-1}, {-1},
+#line 271 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str413, ei_tcvn},
+#line 195 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str414, ei_cp1254},
+#line 338 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str415, ei_cp932},
+#line 270 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str416, ei_tcvn},
     {-1},
-#line 25 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str293, ei_ucs2},
-    {-1}, {-1},
-#line 278 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str296, ei_jisx0201},
+#line 24 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str418, ei_utf8},
 #line 235 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str297, ei_hp_roman8},
-#line 265 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str298, ei_viscii},
-#line 185 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str299, ei_cp1251},
-#line 119 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str300, ei_iso8859_7},
-#line 253 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str301, ei_cp1133},
-#line 294 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str302, ei_iso646_cn},
-#line 118 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str303, ei_iso8859_7},
-    {-1},
-#line 252 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str305, ei_mulelao},
-#line 108 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str306, ei_iso8859_7},
-#line 109 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str307, ei_iso8859_7},
-#line 291 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str308, ei_jisx0212},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str419, ei_mac_thai},
     {-1},
-#line 102 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str310, ei_iso8859_6},
+#line 23 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str421, ei_utf8},
     {-1},
-#line 251 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str312, ei_rk1048},
+#line 203 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str423, ei_cp1257},
+    {-1}, {-1}, {-1}, {-1}, {-1},
+#line 219 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str429, ei_cp866},
     {-1},
-#line 114 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str314, ei_iso8859_7},
-    {-1}, {-1},
+#line 96 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str431, ei_iso8859_5},
+#line 355 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str432, ei_cp936},
 #line 249 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str317, ei_rk1048},
-#line 207 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str318, ei_cp850},
-#line 76 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str319, ei_iso8859_3},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str433, ei_pt154},
+#line 90 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str434, ei_iso8859_4},
+#line 192 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str435, ei_cp1253},
+#line 293 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str436, ei_jisx0212},
+#line 215 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str437, ei_cp862},
+#line 312 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str438, ei_ksc5601},
     {-1},
-#line 173 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str321, ei_iso8859_16},
-#line 39 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str322, ei_utf16},
+#line 86 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str440, ei_iso8859_4},
+#line 340 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str441, ei_iso2022_jp},
+#line 30 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str442, ei_ucs2be},
+    {-1}, {-1}, {-1}, {-1}, {-1},
+#line 335 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str448, ei_cp932},
     {-1},
-#line 113 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str324, ei_iso8859_7},
+#line 31 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str450, ei_ucs2be},
+    {-1},
+#line 388 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str452, ei_local_wchar_t},
+    {-1},
+#line 261 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str454, ei_tis620},
+#line 227 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str455, ei_mac_croatian},
+    {-1},
+#line 121 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str457, ei_iso8859_7},
     {-1}, {-1},
-#line 339 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str327, ei_iso2022_cn},
+#line 120 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str460, ei_iso8859_7},
 #line 78 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str328, ei_iso8859_3},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str461, ei_iso8859_3},
     {-1},
-#line 256 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str330, ei_tis620},
-#line 56 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str331, ei_iso8859_1},
-#line 38 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str332, ei_ucs4le},
-#line 255 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str333, ei_tis620},
-#line 333 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str334, ei_euc_cn},
+#line 110 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str463, ei_iso8859_7},
+    {-1}, {-1}, {-1}, {-1},
+#line 280 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str468, ei_jisx0201},
     {-1}, {-1},
-#line 267 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str337, ei_tcvn},
-#line 100 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str338, ei_iso8859_6},
+#line 326 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str471, ei_sjis},
+#line 350 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str472, ei_euc_cn},
     {-1}, {-1}, {-1},
-#line 246 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str342, ei_pt154},
+#line 82 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str476, ei_iso8859_3},
     {-1}, {-1},
-#line 32 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str345, ei_ucs2le},
+#line 27 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str479, ei_ucs2},
     {-1}, {-1},
-#line 284 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str348, ei_jisx0208},
-#line 338 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str349, ei_gb18030},
-#line 368 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str350, ei_iso2022_kr},
-#line 94 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str351, ei_iso8859_5},
-#line 24 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str352, ei_utf8},
-    {-1},
-#line 221 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str354, ei_mac_roman},
-#line 23 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str355, ei_utf8},
-    {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-#line 266 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str362, ei_viscii},
-#line 67 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str363, ei_iso8859_2},
+#line 332 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str482, ei_cp932},
+#line 178 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str483, ei_koi8_r},
+#line 127 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str484, ei_iso8859_8},
     {-1},
-#line 201 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str365, ei_cp1257},
-    {-1}, {-1},
-#line 35 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str368, ei_ucs4},
+#line 19 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str486, ei_ascii},
     {-1}, {-1},
-#line 306 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str371, ei_ksc5601},
+#line 179 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str489, ei_koi8_r},
     {-1},
-#line 299 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str373, ei_gb2312},
-    {-1}, {-1}, {-1}, {-1}, {-1},
-#line 19 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str379, ei_ascii},
-#line 274 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str380, ei_iso646_jp},
-#line 26 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str381, ei_ucs2},
-    {-1}, {-1}, {-1}, {-1}, {-1},
-#line 30 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str387, ei_ucs2be},
+#line 117 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str491, ei_iso8859_7},
+#line 286 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str492, ei_jisx0208},
     {-1},
+#line 32 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str494, ei_ucs2le},
 #line 111 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str389, ei_iso8859_7},
-#line 257 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str390, ei_tis620},
-    {-1}, {-1},
-#line 239 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str393, ei_armscii_8},
-#line 352 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str394, ei_ces_big5},
-#line 62 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str395, ei_iso8859_1},
-#line 12 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str396, ei_ascii},
-#line 351 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str397, ei_ces_big5},
-    {-1},
-#line 41 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str399, ei_utf16le},
-#line 258 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str400, ei_tis620},
-#line 18 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str401, ei_ascii},
-    {-1}, {-1},
-#line 151 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str404, ei_iso8859_13},
-#line 304 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str405, ei_isoir165},
-    {-1}, {-1}, {-1},
-#line 143 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str409, ei_iso8859_10},
-    {-1}, {-1}, {-1}, {-1}, {-1},
-#line 364 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str415, ei_cp949},
-    {-1}, {-1},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str495, ei_iso8859_7},
+#line 42 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str496, ei_utf32},
 #line 242 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str418, ei_koi8_t},
-#line 191 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str419, ei_cp1253},
-#line 17 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str420, ei_ascii},
-    {-1}, {-1},
-#line 134 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str423, ei_iso8859_9},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str497, ei_georgian_academy},
+    {-1}, {-1}, {-1}, {-1}, {-1},
+#line 325 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str503, ei_sjis},
+    {-1}, {-1}, {-1}, {-1},
+#line 379 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str508, ei_euc_kr},
     {-1},
-#line 184 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str425, ei_cp1251},
+#line 105 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str510, ei_iso8859_6},
+#line 378 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str511, ei_euc_kr},
+    {-1}, {-1}, {-1}, {-1}, {-1},
+#line 236 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str517, ei_hp_roman8},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+#line 321 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str525, ei_eucjp_ms},
+#line 248 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str526, ei_pt154},
     {-1},
-#line 110 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str427, ei_iso8859_7},
-#line 340 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str428, ei_iso2022_cn},
+#line 317 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str528, ei_eucjp_ms},
     {-1},
-#line 42 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str430, ei_utf32},
-#line 20 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str431, ei_ascii},
-#line 199 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str432, ei_cp1256},
-#line 88 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str433, ei_iso8859_4},
-    {-1}, {-1},
-#line 240 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str436, ei_georgian_academy},
+#line 298 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str530, ei_iso646_cn},
+#line 319 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str531, ei_eucjp_ms},
     {-1}, {-1},
-#line 196 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str439, ei_cp1255},
-    {-1}, {-1}, {-1}, {-1},
-#line 193 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str444, ei_cp1254},
+#line 142 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str534, ei_iso8859_10},
 #line 103 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str445, ei_iso8859_6},
-#line 247 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str446, ei_pt154},
-    {-1},
-#line 272 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str448, ei_iso646_jp},
-#line 337 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str449, ei_cp936},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str535, ei_iso8859_6},
+#line 287 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str536, ei_jisx0208},
+#line 331 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str537, ei_cp932},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+#line 306 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str545, ei_isoir165},
+#line 204 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str546, ei_cp1257},
+#line 38 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str547, ei_ucs4le},
     {-1},
-#line 205 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str451, ei_cp1258},
+#line 28 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str549, ei_ucs2be},
     {-1}, {-1}, {-1}, {-1}, {-1},
-#line 187 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str457, ei_cp1252},
+#line 349 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str555, ei_euc_cn},
+#line 385 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str556, ei_iso2022_kr},
+#line 221 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str557, ei_mac_roman},
     {-1},
-#line 71 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str459, ei_iso8859_2},
+#line 102 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str559, ei_iso8859_6},
+#line 58 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str560, ei_iso8859_1},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+#line 69 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str567, ei_iso8859_2},
     {-1}, {-1},
-#line 254 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str462, ei_cp1133},
-    {-1}, {-1}, {-1}, {-1}, {-1},
-#line 36 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str468, ei_ucs4},
+#line 126 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str570, ei_iso8859_8},
     {-1},
-#line 309 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str470, ei_ksc5601},
-    {-1}, {-1}, {-1},
-#line 341 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str474, ei_iso2022_cn_ext},
+#line 328 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str572, ei_sjis},
     {-1}, {-1},
-#line 181 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str477, ei_cp1250},
+#line 254 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str575, ei_mulelao},
+    {-1}, {-1}, {-1}, {-1},
+#line 222 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str580, ei_mac_roman},
+    {-1}, {-1},
+#line 256 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str583, ei_cp1133},
+#line 308 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str584, ei_ksc5601},
     {-1},
+#line 303 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str586, ei_gb2312},
+#line 311 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str587, ei_ksc5601},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
 #line 234 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str479, ei_hp_roman8},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str595, ei_mac_arabic},
+    {-1}, {-1}, {-1},
+#line 153 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str599, ei_iso8859_13},
     {-1}, {-1},
-#line 44 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str482, ei_utf32le},
-#line 190 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str483, ei_cp1253},
-    {-1},
-#line 260 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str485, ei_tis620},
 #line 37 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str486, ei_ucs4be},
-#line 51 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str487, ei_ucs4swapped},
-    {-1},
-#line 46 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str489, ei_utf7},
-#line 50 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str490, ei_ucs4internal},
-    {-1}, {-1},
-#line 269 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str493, ei_tcvn},
-#line 217 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str494, ei_cp866},
-#line 45 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str495, ei_utf7},
-    {-1}, {-1}, {-1},
-#line 28 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str499, ei_ucs2be},
-#line 49 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str500, ei_ucs2swapped},
-#line 224 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str501, ei_mac_iceland},
-#line 31 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str502, ei_ucs2be},
-#line 48 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str503, ei_ucs2internal},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str602, ei_ucs4be},
     {-1},
-#line 104 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str505, ei_iso8859_6},
-    {-1}, {-1}, {-1}, {-1}, {-1},
-#line 80 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str511, ei_iso8859_3},
+#line 361 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str604, ei_hz},
     {-1},
-#line 362 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str513, ei_euc_kr},
+#line 329 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str606, ei_sjis},
+    {-1}, {-1}, {-1},
+#line 386 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str610, ei_iso2022_kr},
     {-1},
-#line 219 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str515, ei_mac_roman},
-#line 178 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str516, ei_koi8_u},
+#line 352 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str612, ei_ces_gbk},
+#line 251 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str613, ei_rk1048},
     {-1},
+#line 187 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str615, ei_cp1251},
+    {-1}, {-1},
+#line 228 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str618, ei_mac_romania},
+#line 224 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str619, ei_mac_roman},
+    {-1}, {-1}, {-1}, {-1}, {-1},
+#line 41 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str625, ei_utf16le},
+    {-1}, {-1}, {-1}, {-1}, {-1},
+#line 383 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str631, ei_johab},
+#line 50 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str632, ei_ucs2internal},
+    {-1}, {-1},
+#line 239 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str635, ei_hp_roman8},
 #line 229 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str518, ei_mac_greek},
-#line 179 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str519, ei_koi8_ru},
-#line 268 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str520, ei_tcvn},
-#line 202 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str521, ei_cp1257},
-#line 312 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str522, ei_euc_jp},
-#line 27 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str523, ei_ucs2},
-#line 117 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str524, ei_iso8859_7},
-#line 311 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str525, ei_euc_jp},
-#line 331 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str526, ei_euc_cn},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str636, ei_mac_cyrillic},
+#line 290 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str637, ei_jisx0212},
+    {-1}, {-1},
+#line 46 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str640, ei_utf7},
+#line 113 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str641, ei_iso8859_7},
     {-1}, {-1}, {-1}, {-1},
-#line 332 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str531, ei_euc_cn},
-#line 298 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str532, ei_iso646_cn},
+#line 47 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str646, ei_utf7},
+    {-1}, {-1}, {-1}, {-1},
+#line 180 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str651, ei_koi8_u},
+    {-1}, {-1}, {-1},
+#line 300 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str655, ei_iso646_cn},
+    {-1}, {-1}, {-1},
+#line 279 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str659, ei_jisx0201},
+    {-1}, {-1}, {-1}, {-1},
+#line 265 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str664, ei_cp874},
+    {-1}, {-1}, {-1}, {-1},
+#line 278 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str669, ei_jisx0201},
+#line 243 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str670, ei_georgian_ps},
+    {-1}, {-1}, {-1}, {-1}, {-1},
+#line 20 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str676, ei_ascii},
     {-1}, {-1}, {-1},
-#line 197 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str536, ei_cp1255},
-#line 259 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str537, ei_tis620},
-#line 263 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str538, ei_cp874},
-    {-1}, {-1},
-#line 160 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str541, ei_iso8859_14},
-#line 350 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str542, ei_ces_big5},
-    {-1}, {-1},
-#line 349 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str545, ei_ces_big5},
-    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
 #line 40 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str553, ei_utf16be},
-    {-1},
-#line 105 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str555, ei_iso8859_6},
-    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-    {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-#line 321 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str571, ei_iso2022_jp},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str680, ei_utf16be},
     {-1}, {-1},
-#line 323 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str574, ei_iso2022_jp1},
-#line 326 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str575, ei_iso2022_jpms},
-    {-1}, {-1}, {-1}, {-1}, {-1},
-#line 301 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str581, ei_gb2312},
-#line 237 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str582, ei_hp_roman8},
+#line 225 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str683, ei_mac_centraleurope},
     {-1},
-#line 238 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str584, ei_nextstep},
+#line 52 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str685, ei_ucs4internal},
+#line 292 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str686, ei_jisx0212},
+#line 119 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str687, ei_iso8859_7},
+    {-1}, {-1}, {-1}, {-1}, {-1},
+#line 282 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str693, ei_jisx0208},
+#line 118 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str694, ei_iso8859_7},
+    {-1}, {-1}, {-1}, {-1}, {-1},
+#line 337 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str700, ei_cp932},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-#line 283 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str594, ei_jisx0208},
     {-1},
-#line 95 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str596, ei_iso8859_5},
-    {-1}, {-1},
-#line 293 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str599, ei_jisx0212},
-    {-1},
-#line 313 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str601, ei_euc_jp},
-#line 47 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str602, ei_utf7},
+#line 380 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str711, ei_euc_kr},
     {-1}, {-1},
-#line 343 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str605, ei_hz},
-#line 324 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str606, ei_iso2022_jp2},
-    {-1}, {-1}, {-1},
-#line 227 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str610, ei_mac_cyrillic},
+#line 44 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str714, ei_utf32le},
+#line 33 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str715, ei_ucs2le},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+    {-1}, {-1}, {-1}, {-1},
+#line 291 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str729, ei_jisx0212},
+#line 18 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str730, ei_ascii},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+#line 284 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str737, ei_jisx0208},
+    {-1}, {-1}, {-1}, {-1},
+#line 368 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str742, ei_ces_big5},
+#line 17 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str743, ei_ascii},
     {-1},
-#line 358 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str612, ei_big5hkscs2008},
-    {-1}, {-1},
-#line 357 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str615, ei_big5hkscs2008},
-    {-1}, {-1},
-#line 345 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str618, ei_euc_tw},
+#line 367 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str745, ei_ces_big5},
+    {-1}, {-1}, {-1}, {-1}, {-1},
+#line 272 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str751, ei_tcvn},
+#line 112 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str752, ei_iso8859_7},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
     {-1}, {-1},
-#line 344 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str621, ei_euc_tw},
+#line 181 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str764, ei_koi8_ru},
+    {-1}, {-1}, {-1}, {-1},
+#line 43 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str769, ei_utf32be},
     {-1}, {-1},
-#line 200 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str624, ei_cp1256},
+#line 283 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str772, ei_jisx0208},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+#line 202 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str779, ei_cp1256},
     {-1},
+#line 45 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str781, ei_utf7},
+    {-1}, {-1}, {-1},
 #line 226 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str626, ei_mac_romania},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str785, ei_mac_iceland},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-#line 43 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str636, ei_utf32be},
     {-1}, {-1},
-#line 53 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str639, ei_java},
-    {-1},
-#line 194 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str641, ei_cp1254},
-    {-1},
-#line 316 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str643, ei_sjis},
-#line 315 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str644, ei_sjis},
-    {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-#line 275 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str651, ei_iso646_jp},
-    {-1},
-#line 271 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str653, ei_iso646_jp},
-    {-1},
+#line 199 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str797, ei_cp1255},
+    {-1}, {-1}, {-1}, {-1},
+#line 51 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str802, ei_ucs2swapped},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
 #line 233 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str655, ei_mac_thai},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str810, ei_mac_hebrew},
+    {-1}, {-1}, {-1}, {-1}, {-1},
+#line 289 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str816, ei_jisx0208},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+    {-1}, {-1}, {-1}, {-1},
+#line 240 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str830, ei_nextstep},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
     {-1}, {-1}, {-1},
-#line 286 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str659, ei_jisx0208},
+#line 315 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str843, ei_euc_jp},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
     {-1}, {-1},
-#line 270 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str671, ei_tcvn},
-#line 322 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str672, ei_iso2022_jp},
-    {-1}, {-1}, {-1},
-#line 318 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str676, ei_sjis},
-    {-1}, {-1}, {-1},
-#line 228 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str680, ei_mac_ukraine},
+#line 53 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str855, ei_ucs4swapped},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-    {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-#line 225 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str696, ei_mac_croatian},
-    {-1},
-#line 124 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str698, ei_iso8859_8},
-#line 29 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str699, ei_ucs2be},
-#line 213 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str700, ei_cp862},
     {-1}, {-1}, {-1}, {-1}, {-1},
-#line 325 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str706, ei_iso2022_jp2},
+#line 230 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str870, ei_mac_ukraine},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-    {-1}, {-1}, {-1},
-#line 125 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str719, ei_iso8859_8},
-    {-1}, {-1}, {-1},
-#line 370 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str723, ei_local_wchar_t},
-    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-#line 223 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str731, ei_mac_centraleurope},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+#line 376 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str889, ei_big5hkscs2008},
     {-1}, {-1},
-#line 354 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str734, ei_big5hkscs1999},
-#line 355 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str735, ei_big5hkscs2001},
+#line 375 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str892, ei_big5hkscs2008},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
     {-1}, {-1},
-#line 276 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str738, ei_jisx0201},
+#line 29 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str913, ei_ucs2be},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-    {-1},
-#line 33 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str749, ei_ucs2le},
-#line 288 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str750, ei_jisx0212},
     {-1}, {-1}, {-1},
-#line 356 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str754, ei_big5hkscs2004},
-#line 277 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str755, ei_jisx0201},
-    {-1}, {-1}, {-1}, {-1},
-#line 232 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str760, ei_mac_arabic},
-#line 359 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str761, ei_big5hkscs2008},
+#line 211 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str944, ei_cp850},
+    {-1}, {-1},
+#line 281 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str947, ei_jisx0201},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-    {-1},
-#line 290 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str781, ei_jisx0212},
-    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-#line 280 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str790, ei_jisx0208},
-#line 220 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str791, ei_mac_roman},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+#line 205 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str982, ei_cp1257},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
     {-1}, {-1},
-#line 289 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str803, ei_jisx0212},
+#line 193 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str1003, ei_cp1253},
+    {-1}, {-1},
+#line 231 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str1006, ei_mac_greek},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+#line 196 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str1025, ei_cp1254},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+#line 49 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str1041, ei_utf7imap},
     {-1}, {-1}, {-1}, {-1}, {-1},
-#line 282 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str827, ei_jisx0208},
-    {-1}, {-1}, {-1}, {-1}, {-1},
-#line 281 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str833, ei_jisx0208},
+#line 48 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str1047, ei_utf7imap},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-    {-1}, {-1}, {-1},
-#line 287 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str864, ei_jisx0208},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-#line 209 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str880, ei_cp850},
+#line 373 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str1099, ei_big5hkscs2001},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-#line 203 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str898, ei_cp1257},
+    {-1}, {-1},
+#line 377 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str1111, ei_big5hkscs2008},
+#line 372 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str1112, ei_big5hkscs1999},
+    {-1},
+#line 232 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str1114, ei_mac_turkish},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-    {-1}, {-1}, {-1}, {-1},
-#line 319 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str912, ei_sjis},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-#line 346 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str931, ei_euc_tw},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+#line 374 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str1159, ei_big5hkscs2004},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-#line 314 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str950, ei_euc_jp},
-#line 365 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str951, ei_johab},
-    {-1}, {-1}, {-1}, {-1},
-#line 222 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str956, ei_mac_roman},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-    {-1}, {-1},
-#line 231 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str986, ei_mac_hebrew},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-    {-1}, {-1}, {-1}, {-1}, {-1},
-#line 279 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str1001, ei_jisx0201},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
     {-1}, {-1}, {-1}, {-1},
-#line 230 "lib/aliases_syshpux.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str1033, ei_mac_turkish}
+#line 316 "lib/aliases_syshpux.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str1254, ei_euc_jp}
   };
 
 #ifdef __GNUC__
 __inline
-#if defined __GNUC_STDC_INLINE__ || defined __GNUC_GNU_INLINE__
+#ifdef __GNUC_STDC_INLINE__
 __attribute__ ((__gnu_inline__))
 #endif
 #endif
diff -uprN libiconv-1.15-old/lib/aliases_sysosf1.gperf libiconv-1.15/lib/aliases_sysosf1.gperf
--- libiconv-1.15-old/lib/aliases_sysosf1.gperf	2017-01-02 08:03:11.000000000 +0900
+++ libiconv-1.15/lib/aliases_sysosf1.gperf	2017-09-17 06:32:20.998053000 +0900
@@ -44,6 +44,8 @@ UTF-32LE, ei_utf32le
 UTF-7, ei_utf7
 UNICODE-1-1-UTF-7, ei_utf7
 CSUNICODE11UTF7, ei_utf7
+UTF-7-IMAP, ei_utf7imap
+UTF7IMAP, ei_utf7imap
 UCS-2-INTERNAL, ei_ucs2internal
 UCS-2-SWAPPED, ei_ucs2swapped
 UCS-4-INTERNAL, ei_ucs4internal
@@ -305,12 +307,28 @@ EUCJP, ei_euc_jp
 EXTENDED_UNIX_CODE_PACKED_FORMAT_FOR_JAPANESE, ei_euc_jp
 CSEUCPKDFMTJAPANESE, ei_euc_jp
 SDECKANJI, ei_euc_jp
+EUCJP-MS, ei_eucjp_ms
+EUCJP-OPEN, ei_eucjp_ms
+EUC-JP-MS, ei_eucjp_ms
+EUCJP-WIN, ei_eucjp_ms
+EUCJPMS, ei_eucjp_ms
+CP51932, ei_cp51932
+WINDOWS-51932, ei_cp51932
+MS51932, ei_cp51932
 SHIFT_JIS, ei_sjis
 SHIFT-JIS, ei_sjis
 SJIS, ei_sjis
 MS_KANJI, ei_sjis
 CSSHIFTJIS, ei_sjis
 CP932, ei_cp932
+WINDOWS-31J, ei_cp932
+CSWINDOWS31J, ei_cp932
+SJIS-OPEN, ei_cp932
+SJIS-WIN, ei_cp932
+WINDOWS-932, ei_cp932
+MS932, ei_cp932
+SHIFT_JIS-MS, ei_cp932
+SJIS-MS, ei_cp932
 ISO-2022-JP, ei_iso2022_jp
 CSISO2022JP, ei_iso2022_jp
 ISO-2022-JP-1, ei_iso2022_jp1
diff -uprN libiconv-1.15-old/lib/aliases_sysosf1.h libiconv-1.15/lib/aliases_sysosf1.h
--- libiconv-1.15-old/lib/aliases_sysosf1.h	2017-01-02 08:03:11.000000000 +0900
+++ libiconv-1.15/lib/aliases_sysosf1.h	2017-09-17 06:32:21.303100000 +0900
@@ -1,4 +1,4 @@
-/* ANSI-C code produced by gperf version 3.0.4 */
+/* ANSI-C code produced by gperf version 3.0.3 */
 /* Command-line: gperf -m 10 lib/aliases_sysosf1.gperf  */
 /* Computed positions: -k'1,3-11,$' */
 
@@ -32,12 +32,12 @@
 #line 1 "lib/aliases_sysosf1.gperf"
 struct alias { int name; unsigned int encoding_index; };
 
-#define TOTAL_KEYWORDS 354
+#define TOTAL_KEYWORDS 372
 #define MIN_WORD_LENGTH 2
 #define MAX_WORD_LENGTH 45
-#define MIN_HASH_VALUE 15
-#define MAX_HASH_VALUE 981
-/* maximum key range = 967, duplicates = 0 */
+#define MIN_HASH_VALUE 9
+#define MAX_HASH_VALUE 1203
+/* maximum key range = 1195, duplicates = 0 */
 
 #ifdef __GNUC__
 __inline
@@ -51,19 +51,19 @@ aliases_hash (register const char *str,
 {
   static const unsigned short asso_values[] =
     {
-      982, 982, 982, 982, 982, 982, 982, 982, 982, 982,
-      982, 982, 982, 982, 982, 982, 982, 982, 982, 982,
-      982, 982, 982, 982, 982, 982, 982, 982, 982, 982,
-      982, 982, 982, 982, 982, 982, 982, 982, 982, 982,
-      982, 982, 982, 982, 982,   5,  96, 982,  97,   7,
-       33, 102,  15,  17,   5, 173,  23,  25, 298, 982,
-      982, 982, 982, 982, 982, 168, 248,  11,  26,  25,
-       17,  29,  29,   6, 139, 153,   8, 132,   7,   6,
-      114, 982,   5,   8,  30, 235, 185, 182, 225,   5,
-       18, 982, 982, 982, 982,   6, 982, 982, 982, 982,
-      982, 982, 982, 982, 982, 982, 982, 982, 982, 982,
-      982, 982, 982, 982, 982, 982, 982, 982, 982, 982,
-      982, 982, 982, 982, 982, 982, 982, 982
+      1204, 1204, 1204, 1204, 1204, 1204, 1204, 1204, 1204, 1204,
+      1204, 1204, 1204, 1204, 1204, 1204, 1204, 1204, 1204, 1204,
+      1204, 1204, 1204, 1204, 1204, 1204, 1204, 1204, 1204, 1204,
+      1204, 1204, 1204, 1204, 1204, 1204, 1204, 1204, 1204, 1204,
+      1204, 1204, 1204, 1204, 1204,   10,  135, 1204,   34,    0,
+         5,    4,   48,    2,    1,  251,   11,   14,   91, 1204,
+      1204, 1204, 1204, 1204, 1204,   35,  210,    0,  185,  104,
+        99,  163,   41,    0,    0,  193,  125,  197,    7,    0,
+       145, 1204,   80,   72,   21,  136,  111,    0,  298,    5,
+        45, 1204, 1204, 1204, 1204,   39, 1204, 1204, 1204, 1204,
+      1204, 1204, 1204, 1204, 1204, 1204, 1204, 1204, 1204, 1204,
+      1204, 1204, 1204, 1204, 1204, 1204, 1204, 1204, 1204, 1204,
+      1204, 1204, 1204, 1204, 1204, 1204, 1204, 1204
     };
   register int hval = len;
 
@@ -106,1624 +106,1724 @@ aliases_hash (register const char *str,
 
 struct stringpool_t
   {
-    char stringpool_str15[sizeof("L6")];
-    char stringpool_str17[sizeof("L1")];
-    char stringpool_str20[sizeof("CN")];
-    char stringpool_str25[sizeof("L4")];
-    char stringpool_str27[sizeof("L5")];
-    char stringpool_str30[sizeof("R8")];
-    char stringpool_str33[sizeof("L8")];
-    char stringpool_str34[sizeof("SJIS")];
-    char stringpool_str36[sizeof("866")];
-    char stringpool_str43[sizeof("L2")];
-    char stringpool_str49[sizeof("HZ")];
-    char stringpool_str51[sizeof("ISO-IR-6")];
-    char stringpool_str54[sizeof("CP866")];
-    char stringpool_str64[sizeof("C99")];
-    char stringpool_str65[sizeof("ISO-IR-166")];
-    char stringpool_str66[sizeof("EUCCN")];
-    char stringpool_str67[sizeof("LATIN6")];
-    char stringpool_str70[sizeof("CP154")];
-    char stringpool_str71[sizeof("LATIN1")];
-    char stringpool_str72[sizeof("EUC-CN")];
-    char stringpool_str74[sizeof("CYRILLIC")];
-    char stringpool_str76[sizeof("ISO646-CN")];
-    char stringpool_str79[sizeof("ISO-IR-14")];
-    char stringpool_str84[sizeof("CP1256")];
-    char stringpool_str87[sizeof("LATIN4")];
-    char stringpool_str88[sizeof("CP1251")];
-    char stringpool_str89[sizeof("ISO-IR-165")];
-    char stringpool_str91[sizeof("LATIN5")];
-    char stringpool_str92[sizeof("862")];
-    char stringpool_str93[sizeof("ISO-IR-126")];
-    char stringpool_str95[sizeof("ISO-IR-144")];
-    char stringpool_str96[sizeof("CP819")];
-    char stringpool_str99[sizeof("TACTIS")];
-    char stringpool_str103[sizeof("LATIN8")];
-    char stringpool_str104[sizeof("CP1254")];
-    char stringpool_str105[sizeof("ISO-IR-58")];
-    char stringpool_str106[sizeof("CP949")];
-    char stringpool_str108[sizeof("CP1255")];
-    char stringpool_str110[sizeof("CP862")];
-    char stringpool_str111[sizeof("ISO-IR-148")];
-    char stringpool_str112[sizeof("L3")];
-    char stringpool_str113[sizeof("LATIN-9")];
-    char stringpool_str114[sizeof("CHINESE")];
-    char stringpool_str115[sizeof("ISO-IR-149")];
-    char stringpool_str117[sizeof("ISO-IR-159")];
-    char stringpool_str119[sizeof("ISO-IR-226")];
-    char stringpool_str120[sizeof("CP1258")];
-    char stringpool_str123[sizeof("LATIN2")];
-    char stringpool_str124[sizeof("ISO8859-6")];
-    char stringpool_str125[sizeof("ISO-IR-199")];
-    char stringpool_str128[sizeof("ISO8859-1")];
-    char stringpool_str129[sizeof("ISO-CELTIC")];
-    char stringpool_str130[sizeof("ISO-8859-6")];
-    char stringpool_str131[sizeof("ISO_8859-6")];
-    char stringpool_str132[sizeof("ISO8859-16")];
-    char stringpool_str134[sizeof("ISO-8859-1")];
-    char stringpool_str135[sizeof("ISO_8859-1")];
-    char stringpool_str136[sizeof("ISO8859-11")];
-    char stringpool_str138[sizeof("ISO-8859-16")];
-    char stringpool_str139[sizeof("ISO_8859-16")];
-    char stringpool_str140[sizeof("CP1252")];
-    char stringpool_str142[sizeof("ISO-8859-11")];
-    char stringpool_str143[sizeof("ISO_8859-11")];
-    char stringpool_str144[sizeof("ISO8859-4")];
-    char stringpool_str145[sizeof("CP1361")];
-    char stringpool_str146[sizeof("ISO_8859-16:2001")];
-    char stringpool_str147[sizeof("CP1131")];
-    char stringpool_str148[sizeof("ISO8859-5")];
-    char stringpool_str150[sizeof("ISO-8859-4")];
-    char stringpool_str151[sizeof("ISO_8859-4")];
-    char stringpool_str152[sizeof("ISO8859-14")];
-    char stringpool_str153[sizeof("CP936")];
-    char stringpool_str154[sizeof("ISO-8859-5")];
-    char stringpool_str155[sizeof("ISO_8859-5")];
-    char stringpool_str156[sizeof("ISO8859-15")];
-    char stringpool_str157[sizeof("MAC")];
-    char stringpool_str158[sizeof("ISO-8859-14")];
-    char stringpool_str159[sizeof("ISO_8859-14")];
-    char stringpool_str160[sizeof("ISO8859-8")];
-    char stringpool_str161[sizeof("ISO-IR-101")];
-    char stringpool_str162[sizeof("ISO-8859-15")];
-    char stringpool_str163[sizeof("ISO_8859-15")];
-    char stringpool_str164[sizeof("ISO8859-9")];
-    char stringpool_str166[sizeof("ISO-8859-8")];
-    char stringpool_str167[sizeof("ISO_8859-8")];
-    char stringpool_str170[sizeof("ISO-8859-9")];
-    char stringpool_str171[sizeof("ISO_8859-9")];
-    char stringpool_str172[sizeof("ISO_8859-14:1998")];
-    char stringpool_str173[sizeof("PT154")];
-    char stringpool_str174[sizeof("ISO_8859-15:1998")];
-    char stringpool_str176[sizeof("RK1048")];
-    char stringpool_str179[sizeof("ELOT_928")];
-    char stringpool_str180[sizeof("ISO8859-2")];
-    char stringpool_str181[sizeof("MS-CYRL")];
-    char stringpool_str182[sizeof("IBM866")];
-    char stringpool_str183[sizeof("L7")];
-    char stringpool_str186[sizeof("ISO-8859-2")];
-    char stringpool_str187[sizeof("ISO_8859-2")];
-    char stringpool_str193[sizeof("CHAR")];
-    char stringpool_str197[sizeof("ISO-IR-109")];
-    char stringpool_str198[sizeof("ISO-IR-138")];
-    char stringpool_str202[sizeof("ASCII")];
-    char stringpool_str203[sizeof("KOI8-R")];
-    char stringpool_str204[sizeof("EUCKR")];
-    char stringpool_str205[sizeof("L10")];
-    char stringpool_str209[sizeof("CP932")];
-    char stringpool_str210[sizeof("EUC-KR")];
-    char stringpool_str212[sizeof("CP50221")];
-    char stringpool_str216[sizeof("CSKOI8R")];
-    char stringpool_str217[sizeof("MS-EE")];
-    char stringpool_str220[sizeof("850")];
-    char stringpool_str223[sizeof("CSASCII")];
-    char stringpool_str224[sizeof("IBM819")];
-    char stringpool_str225[sizeof("MACCYRILLIC")];
-    char stringpool_str228[sizeof("VISCII")];
-    char stringpool_str233[sizeof("TCVN")];
-    char stringpool_str236[sizeof("SHIFT-JIS")];
-    char stringpool_str237[sizeof("SHIFT_JIS")];
-    char stringpool_str238[sizeof("IBM862")];
-    char stringpool_str240[sizeof("CSISO14JISC6220RO")];
-    char stringpool_str242[sizeof("CP874")];
-    char stringpool_str243[sizeof("GB2312")];
-    char stringpool_str245[sizeof("US")];
-    char stringpool_str247[sizeof("CSVISCII")];
-    char stringpool_str250[sizeof("CP850")];
-    char stringpool_str251[sizeof("ISO-IR-110")];
-    char stringpool_str252[sizeof("CP950")];
-    char stringpool_str253[sizeof("KOI8-T")];
-    char stringpool_str254[sizeof("ISO-2022-CN")];
-    char stringpool_str255[sizeof("JP")];
-    char stringpool_str257[sizeof("CYRILLIC-ASIAN")];
-    char stringpool_str259[sizeof("LATIN10")];
-    char stringpool_str260[sizeof("UHC")];
-    char stringpool_str261[sizeof("LATIN3")];
-    char stringpool_str263[sizeof("CSISO2022CN")];
-    char stringpool_str264[sizeof("ISO_8859-10:1992")];
-    char stringpool_str267[sizeof("MACINTOSH")];
-    char stringpool_str268[sizeof("CP1250")];
-    char stringpool_str271[sizeof("CSISOLATIN6")];
-    char stringpool_str272[sizeof("CSSHIFTJIS")];
-    char stringpool_str273[sizeof("ISO-IR-179")];
-    char stringpool_str274[sizeof("MS936")];
-    char stringpool_str275[sizeof("CSISOLATIN1")];
-    char stringpool_str276[sizeof("TIS620")];
-    char stringpool_str278[sizeof("CP1253")];
-    char stringpool_str279[sizeof("DECHANZI")];
-    char stringpool_str280[sizeof("UTF-16")];
-    char stringpool_str281[sizeof("ISO-2022-CN-EXT")];
-    char stringpool_str282[sizeof("TIS-620")];
-    char stringpool_str283[sizeof("UCS-4")];
-    char stringpool_str284[sizeof("GREEK8")];
-    char stringpool_str290[sizeof("CSISOLATINCYRILLIC")];
-    char stringpool_str291[sizeof("CSISOLATIN4")];
-    char stringpool_str295[sizeof("CSISOLATIN5")];
-    char stringpool_str300[sizeof("PTCP154")];
-    char stringpool_str301[sizeof("CSUCS4")];
-    char stringpool_str302[sizeof("ISO646-US")];
-    char stringpool_str304[sizeof("KSC5601")];
-    char stringpool_str308[sizeof("UTF-8")];
-    char stringpool_str311[sizeof("KSC_5601")];
-    char stringpool_str315[sizeof("BIG5")];
-    char stringpool_str316[sizeof("ISO8859-10")];
-    char stringpool_str318[sizeof("ISO8859-3")];
-    char stringpool_str319[sizeof("UCS-2")];
-    char stringpool_str321[sizeof("BIG-5")];
-    char stringpool_str322[sizeof("ISO-8859-10")];
-    char stringpool_str323[sizeof("ISO_8859-10")];
-    char stringpool_str324[sizeof("ISO-8859-3")];
-    char stringpool_str325[sizeof("ISO_8859-3")];
-    char stringpool_str326[sizeof("ISO8859-13")];
-    char stringpool_str327[sizeof("CSISOLATIN2")];
-    char stringpool_str328[sizeof("UCS-4LE")];
-    char stringpool_str330[sizeof("KZ-1048")];
-    char stringpool_str332[sizeof("ISO-8859-13")];
-    char stringpool_str333[sizeof("ISO_8859-13")];
-    char stringpool_str334[sizeof("CSBIG5")];
-    char stringpool_str335[sizeof("UTF-16LE")];
-    char stringpool_str336[sizeof("X0212")];
-    char stringpool_str337[sizeof("CP1133")];
-    char stringpool_str338[sizeof("GBK")];
-    char stringpool_str339[sizeof("MS-ANSI")];
-    char stringpool_str340[sizeof("CN-BIG5")];
-    char stringpool_str341[sizeof("ISO-IR-100")];
-    char stringpool_str343[sizeof("CSPTCP154")];
-    char stringpool_str345[sizeof("GB_1988-80")];
-    char stringpool_str346[sizeof("UCS-2LE")];
-    char stringpool_str350[sizeof("CSISO159JISX02121990")];
-    char stringpool_str351[sizeof("UNICODE-1-1")];
-    char stringpool_str353[sizeof("KS_C_5601-1989")];
-    char stringpool_str355[sizeof("CSKZ1048")];
-    char stringpool_str356[sizeof("VISCII1.1-1")];
-    char stringpool_str358[sizeof("ISO_646.IRV:1991")];
-    char stringpool_str359[sizeof("CSUNICODE11")];
-    char stringpool_str360[sizeof("CN-GB-ISOIR165")];
-    char stringpool_str361[sizeof("CSUNICODE")];
-    char stringpool_str363[sizeof("UCS-4-INTERNAL")];
-    char stringpool_str364[sizeof("ROMAN8")];
-    char stringpool_str367[sizeof("JIS_C6220-1969-RO")];
-    char stringpool_str368[sizeof("JIS_C6226-1983")];
-    char stringpool_str371[sizeof("KOREAN")];
-    char stringpool_str374[sizeof("X0201")];
-    char stringpool_str375[sizeof("MULELAO-1")];
-    char stringpool_str377[sizeof("ISO-IR-203")];
-    char stringpool_str378[sizeof("IBM850")];
-    char stringpool_str380[sizeof("TIS620-0")];
-    char stringpool_str381[sizeof("UCS-2-INTERNAL")];
-    char stringpool_str382[sizeof("ECMA-114")];
-    char stringpool_str389[sizeof("MACTHAI")];
-    char stringpool_str390[sizeof("GREEK")];
-    char stringpool_str391[sizeof("ARMSCII-8")];
-    char stringpool_str392[sizeof("ISO-2022-KR")];
-    char stringpool_str396[sizeof("GEORGIAN-PS")];
-    char stringpool_str397[sizeof("TIS620.2529-1")];
-    char stringpool_str398[sizeof("ECMA-118")];
-    char stringpool_str401[sizeof("CSISO2022KR")];
-    char stringpool_str403[sizeof("LATIN7")];
-    char stringpool_str405[sizeof("ISO-IR-57")];
-    char stringpool_str406[sizeof("X0208")];
-    char stringpool_str407[sizeof("HP-ROMAN8")];
-    char stringpool_str408[sizeof("EUCJP")];
-    char stringpool_str411[sizeof("ISO-IR-87")];
-    char stringpool_str413[sizeof("ISO-IR-157")];
-    char stringpool_str414[sizeof("EUC-JP")];
-    char stringpool_str416[sizeof("ISO-10646-UCS-4")];
-    char stringpool_str417[sizeof("DECKOREAN")];
-    char stringpool_str418[sizeof("ISO646-JP")];
-    char stringpool_str420[sizeof("CP1257")];
-    char stringpool_str421[sizeof("UNICODELITTLE")];
-    char stringpool_str427[sizeof("JIS0208")];
-    char stringpool_str429[sizeof("ISO-IR-127")];
-    char stringpool_str430[sizeof("MACICELAND")];
-    char stringpool_str431[sizeof("UTF-32")];
-    char stringpool_str434[sizeof("ISO-10646-UCS-2")];
-    char stringpool_str435[sizeof("EUCTW")];
-    char stringpool_str441[sizeof("EUC-TW")];
-    char stringpool_str442[sizeof("GB_2312-80")];
-    char stringpool_str443[sizeof("CSIBM866")];
-    char stringpool_str445[sizeof("CSISOLATINARABIC")];
-    char stringpool_str447[sizeof("CSISOLATINGREEK")];
-    char stringpool_str448[sizeof("CSMACINTOSH")];
-    char stringpool_str452[sizeof("CSEUCKR")];
-    char stringpool_str453[sizeof("US-ASCII")];
-    char stringpool_str455[sizeof("GEORGIAN-ACADEMY")];
-    char stringpool_str456[sizeof("MS-HEBR")];
-    char stringpool_str457[sizeof("WCHAR_T")];
-    char stringpool_str458[sizeof("UTF-32LE")];
-    char stringpool_str459[sizeof("GB18030")];
-    char stringpool_str460[sizeof("ISO8859-7")];
-    char stringpool_str462[sizeof("ISO_8859-4:1988")];
-    char stringpool_str463[sizeof("MACCENTRALEUROPE")];
-    char stringpool_str464[sizeof("ISO_8859-5:1988")];
-    char stringpool_str465[sizeof("CSISOLATIN3")];
-    char stringpool_str466[sizeof("ISO-8859-7")];
-    char stringpool_str467[sizeof("ISO_8859-7")];
-    char stringpool_str469[sizeof("CP367")];
-    char stringpool_str470[sizeof("ISO_8859-8:1988")];
-    char stringpool_str474[sizeof("ISO_8859-9:1989")];
-    char stringpool_str476[sizeof("MACROMAN")];
-    char stringpool_str477[sizeof("CSISOLATINHEBREW")];
-    char stringpool_str481[sizeof("TCVN5712-1")];
-    char stringpool_str482[sizeof("EXTENDED_UNIX_CODE_PACKED_FORMAT_FOR_JAPANESE")];
-    char stringpool_str489[sizeof("STRK1048-2002")];
-    char stringpool_str490[sizeof("WINDOWS-1256")];
-    char stringpool_str491[sizeof("ISO-2022-JP-1")];
-    char stringpool_str492[sizeof("WINDOWS-1251")];
-    char stringpool_str493[sizeof("ISO-2022-JP-MS")];
-    char stringpool_str499[sizeof("TCVN-5712")];
-    char stringpool_str500[sizeof("WINDOWS-1254")];
-    char stringpool_str501[sizeof("KS_C_5601-1987")];
-    char stringpool_str502[sizeof("WINDOWS-1255")];
-    char stringpool_str504[sizeof("CSGB2312")];
-    char stringpool_str508[sizeof("WINDOWS-1258")];
-    char stringpool_str517[sizeof("ISO-2022-JP-2")];
-    char stringpool_str518[sizeof("WINDOWS-1252")];
-    char stringpool_str520[sizeof("BIG5HKSCS")];
-    char stringpool_str523[sizeof("UNICODE-1-1-UTF-7")];
-    char stringpool_str525[sizeof("CSISO2022JP2")];
-    char stringpool_str526[sizeof("BIG5-HKSCS")];
-    char stringpool_str527[sizeof("CSKSC56011987")];
-    char stringpool_str528[sizeof("CSHPROMAN8")];
-    char stringpool_str529[sizeof("CSUNICODE11UTF7")];
-    char stringpool_str532[sizeof("SDECKANJI")];
-    char stringpool_str534[sizeof("HZ-GB-2312")];
-    char stringpool_str535[sizeof("MS-GREEK")];
-    char stringpool_str541[sizeof("MACGREEK")];
-    char stringpool_str542[sizeof("BIGFIVE")];
-    char stringpool_str543[sizeof("TIS620.2533-1")];
-    char stringpool_str546[sizeof("CN-GB")];
-    char stringpool_str548[sizeof("BIG-FIVE")];
-    char stringpool_str549[sizeof("ISO_8859-3:1988")];
-    char stringpool_str561[sizeof("NEXTSTEP")];
-    char stringpool_str562[sizeof("MACCROATIAN")];
-    char stringpool_str564[sizeof("WINDOWS-936")];
-    char stringpool_str566[sizeof("CSISO57GB1988")];
-    char stringpool_str568[sizeof("UCS-4BE")];
-    char stringpool_str575[sizeof("UTF-16BE")];
-    char stringpool_str582[sizeof("WINDOWS-1250")];
-    char stringpool_str586[sizeof("UCS-2BE")];
-    char stringpool_str587[sizeof("WINDOWS-1253")];
-    char stringpool_str590[sizeof("JIS_X0212")];
-    char stringpool_str595[sizeof("CSISO58GB231280")];
-    char stringpool_str596[sizeof("ISO-2022-JP")];
-    char stringpool_str597[sizeof("IBM367")];
-    char stringpool_str598[sizeof("IBM-CP1133")];
-    char stringpool_str602[sizeof("ISO_8859-6:1987")];
-    char stringpool_str604[sizeof("ISO_8859-1:1987")];
-    char stringpool_str605[sizeof("CSISO2022JP")];
-    char stringpool_str608[sizeof("UTF-7")];
-    char stringpool_str609[sizeof("CSPC862LATINHEBREW")];
-    char stringpool_str618[sizeof("ARABIC")];
-    char stringpool_str625[sizeof("MS_KANJI")];
-    char stringpool_str628[sizeof("JIS_X0201")];
-    char stringpool_str630[sizeof("ISO_8859-2:1987")];
-    char stringpool_str631[sizeof("UNICODEBIG")];
-    char stringpool_str633[sizeof("TIS620.2533-0")];
-    char stringpool_str635[sizeof("ASMO-708")];
-    char stringpool_str643[sizeof("CSISO87JISX0208")];
-    char stringpool_str648[sizeof("MACTURKISH")];
-    char stringpool_str653[sizeof("WINDOWS-874")];
-    char stringpool_str657[sizeof("ANSI_X3.4-1986")];
-    char stringpool_str658[sizeof("WINDOWS-1257")];
-    char stringpool_str660[sizeof("JIS_X0208")];
-    char stringpool_str661[sizeof("JISX0201-1976")];
-    char stringpool_str663[sizeof("KOI8-U")];
-    char stringpool_str664[sizeof("JAVA")];
-    char stringpool_str669[sizeof("KOI8-RU")];
-    char stringpool_str671[sizeof("JIS_X0212-1990")];
-    char stringpool_str675[sizeof("ANSI_X3.4-1968")];
-    char stringpool_str677[sizeof("HEBREW")];
-    char stringpool_str683[sizeof("CSEUCTW")];
-    char stringpool_str693[sizeof("CSHALFWIDTHKATAKANA")];
-    char stringpool_str698[sizeof("UTF-32BE")];
-    char stringpool_str699[sizeof("ISO_8859-7:2003")];
-    char stringpool_str705[sizeof("CSPC850MULTILINGUAL")];
-    char stringpool_str720[sizeof("MS-TURK")];
-    char stringpool_str751[sizeof("JIS_X0208-1990")];
-    char stringpool_str756[sizeof("JIS_X0208-1983")];
-    char stringpool_str764[sizeof("JIS_X0212.1990-0")];
-    char stringpool_str769[sizeof("MACARABIC")];
-    char stringpool_str770[sizeof("ISO_8859-7:1987")];
-    char stringpool_str777[sizeof("MACUKRAINE")];
-    char stringpool_str798[sizeof("CSEUCPKDFMTJAPANESE")];
-    char stringpool_str813[sizeof("MACROMANIA")];
-    char stringpool_str828[sizeof("BIG5-HKSCS:2001")];
-    char stringpool_str836[sizeof("BIG5-HKSCS:2004")];
-    char stringpool_str837[sizeof("JOHAB")];
-    char stringpool_str844[sizeof("BIG5-HKSCS:2008")];
-    char stringpool_str846[sizeof("BIG5-HKSCS:1999")];
-    char stringpool_str848[sizeof("MACHEBREW")];
-    char stringpool_str879[sizeof("TCVN5712-1:1993")];
-    char stringpool_str893[sizeof("UCS-4-SWAPPED")];
-    char stringpool_str911[sizeof("UCS-2-SWAPPED")];
-    char stringpool_str928[sizeof("WINBALTRIM")];
-    char stringpool_str981[sizeof("MS-ARAB")];
+    char stringpool_str9[sizeof("CN")];
+    char stringpool_str10[sizeof("CP1131")];
+    char stringpool_str11[sizeof("CP1361")];
+    char stringpool_str13[sizeof("CP1251")];
+    char stringpool_str15[sizeof("CP1256")];
+    char stringpool_str16[sizeof("866")];
+    char stringpool_str17[sizeof("CP1255")];
+    char stringpool_str18[sizeof("CP1133")];
+    char stringpool_str19[sizeof("CP866")];
+    char stringpool_str21[sizeof("CP1253")];
+    char stringpool_str23[sizeof("CP1252")];
+    char stringpool_str24[sizeof("862")];
+    char stringpool_str25[sizeof("CP936")];
+    char stringpool_str27[sizeof("CP862")];
+    char stringpool_str31[sizeof("C99")];
+    char stringpool_str33[sizeof("CP932")];
+    char stringpool_str35[sizeof("CP1258")];
+    char stringpool_str37[sizeof("CP51932")];
+    char stringpool_str40[sizeof("ASCII")];
+    char stringpool_str44[sizeof("CP819")];
+    char stringpool_str53[sizeof("CP50221")];
+    char stringpool_str57[sizeof("ISO8859-1")];
+    char stringpool_str58[sizeof("ISO8859-11")];
+    char stringpool_str59[sizeof("ISO8859-6")];
+    char stringpool_str60[sizeof("ISO8859-16")];
+    char stringpool_str61[sizeof("ISO8859-5")];
+    char stringpool_str62[sizeof("ISO8859-15")];
+    char stringpool_str65[sizeof("ISO8859-3")];
+    char stringpool_str66[sizeof("ISO8859-13")];
+    char stringpool_str67[sizeof("ISO8859-2")];
+    char stringpool_str68[sizeof("ISO-8859-1")];
+    char stringpool_str69[sizeof("ISO-8859-11")];
+    char stringpool_str70[sizeof("ISO-8859-6")];
+    char stringpool_str71[sizeof("ISO-8859-16")];
+    char stringpool_str72[sizeof("ISO-8859-5")];
+    char stringpool_str73[sizeof("ISO-8859-15")];
+    char stringpool_str76[sizeof("ISO-8859-3")];
+    char stringpool_str77[sizeof("ISO-8859-13")];
+    char stringpool_str78[sizeof("ISO-8859-2")];
+    char stringpool_str79[sizeof("ISO8859-8")];
+    char stringpool_str81[sizeof("CP1250")];
+    char stringpool_str82[sizeof("850")];
+    char stringpool_str83[sizeof("ISO646-CN")];
+    char stringpool_str85[sizeof("ISO8859-9")];
+    char stringpool_str86[sizeof("CP850")];
+    char stringpool_str88[sizeof("HZ")];
+    char stringpool_str89[sizeof("CP950")];
+    char stringpool_str90[sizeof("ISO-8859-8")];
+    char stringpool_str93[sizeof("R8")];
+    char stringpool_str94[sizeof("ISO-2022-CN")];
+    char stringpool_str95[sizeof("CP949")];
+    char stringpool_str96[sizeof("ISO-8859-9")];
+    char stringpool_str97[sizeof("ISO_8859-1")];
+    char stringpool_str98[sizeof("ISO_8859-11")];
+    char stringpool_str99[sizeof("ISO_8859-6")];
+    char stringpool_str100[sizeof("ISO_8859-16")];
+    char stringpool_str101[sizeof("ISO_8859-5")];
+    char stringpool_str102[sizeof("ISO_8859-15")];
+    char stringpool_str103[sizeof("CP154")];
+    char stringpool_str104[sizeof("ISO_8859-16:2001")];
+    char stringpool_str105[sizeof("ISO_8859-3")];
+    char stringpool_str106[sizeof("ISO_8859-13")];
+    char stringpool_str107[sizeof("ISO_8859-2")];
+    char stringpool_str109[sizeof("CP1254")];
+    char stringpool_str110[sizeof("ISO-IR-6")];
+    char stringpool_str112[sizeof("ISO-2022-CN-EXT")];
+    char stringpool_str113[sizeof("ISO-IR-166")];
+    char stringpool_str114[sizeof("CSASCII")];
+    char stringpool_str115[sizeof("ISO-IR-165")];
+    char stringpool_str116[sizeof("ISO_8859-15:1998")];
+    char stringpool_str117[sizeof("ISO-IR-126")];
+    char stringpool_str119[sizeof("ISO_8859-8")];
+    char stringpool_str122[sizeof("ISO-IR-226")];
+    char stringpool_str123[sizeof("EUCCN")];
+    char stringpool_str125[sizeof("ISO_8859-9")];
+    char stringpool_str126[sizeof("ISO8859-10")];
+    char stringpool_str127[sizeof("L1")];
+    char stringpool_str128[sizeof("L6")];
+    char stringpool_str129[sizeof("L5")];
+    char stringpool_str130[sizeof("EUCTW")];
+    char stringpool_str131[sizeof("L3")];
+    char stringpool_str132[sizeof("L2")];
+    char stringpool_str133[sizeof("ISO-IR-58")];
+    char stringpool_str134[sizeof("EUC-CN")];
+    char stringpool_str136[sizeof("ISO-IR-138")];
+    char stringpool_str137[sizeof("ISO-8859-10")];
+    char stringpool_str138[sizeof("L8")];
+    char stringpool_str139[sizeof("UHC")];
+    char stringpool_str140[sizeof("ISO-IR-159")];
+    char stringpool_str141[sizeof("EUC-TW")];
+    char stringpool_str142[sizeof("ISO_8859-10:1992")];
+    char stringpool_str144[sizeof("ISO-IR-101")];
+    char stringpool_str146[sizeof("CSISO2022CN")];
+    char stringpool_str147[sizeof("JP")];
+    char stringpool_str150[sizeof("TCVN")];
+    char stringpool_str151[sizeof("JIS_C6226-1983")];
+    char stringpool_str152[sizeof("ISO-IR-199")];
+    char stringpool_str153[sizeof("ISO8859-4")];
+    char stringpool_str154[sizeof("ISO8859-14")];
+    char stringpool_str157[sizeof("ISO-IR-203")];
+    char stringpool_str159[sizeof("LATIN1")];
+    char stringpool_str161[sizeof("LATIN6")];
+    char stringpool_str162[sizeof("ISO_8859-14:1998")];
+    char stringpool_str163[sizeof("LATIN5")];
+    char stringpool_str164[sizeof("ISO-8859-4")];
+    char stringpool_str165[sizeof("ISO-8859-14")];
+    char stringpool_str166[sizeof("ISO_8859-10")];
+    char stringpool_str167[sizeof("LATIN3")];
+    char stringpool_str169[sizeof("LATIN2")];
+    char stringpool_str172[sizeof("ISO-IR-109")];
+    char stringpool_str173[sizeof("TIS620")];
+    char stringpool_str174[sizeof("JIS0208")];
+    char stringpool_str175[sizeof("L4")];
+    char stringpool_str176[sizeof("SJIS-WIN")];
+    char stringpool_str178[sizeof("ISO-IR-110")];
+    char stringpool_str180[sizeof("ISO-IR-148")];
+    char stringpool_str181[sizeof("LATIN8")];
+    char stringpool_str183[sizeof("JIS_C6220-1969-RO")];
+    char stringpool_str184[sizeof("TIS-620")];
+    char stringpool_str185[sizeof("JAVA")];
+    char stringpool_str186[sizeof("ISO-IR-149")];
+    char stringpool_str188[sizeof("GB2312")];
+    char stringpool_str189[sizeof("VISCII")];
+    char stringpool_str190[sizeof("RK1048")];
+    char stringpool_str191[sizeof("CSVISCII")];
+    char stringpool_str192[sizeof("TACTIS")];
+    char stringpool_str193[sizeof("ISO_8859-4")];
+    char stringpool_str194[sizeof("ISO_8859-14")];
+    char stringpool_str196[sizeof("L10")];
+    char stringpool_str198[sizeof("LATIN-9")];
+    char stringpool_str199[sizeof("CHAR")];
+    char stringpool_str200[sizeof("MAC")];
+    char stringpool_str205[sizeof("ISO-IR-14")];
+    char stringpool_str206[sizeof("ISO_8859-5:1988")];
+    char stringpool_str208[sizeof("ISO_8859-3:1988")];
+    char stringpool_str209[sizeof("CSISO14JISC6220RO")];
+    char stringpool_str210[sizeof("US")];
+    char stringpool_str212[sizeof("ISO-IR-100")];
+    char stringpool_str213[sizeof("ELOT_928")];
+    char stringpool_str214[sizeof("CSISO159JISX02121990")];
+    char stringpool_str215[sizeof("ISO_8859-8:1988")];
+    char stringpool_str217[sizeof("IBM866")];
+    char stringpool_str219[sizeof("TIS620-0")];
+    char stringpool_str220[sizeof("SJIS")];
+    char stringpool_str221[sizeof("ISO_8859-9:1989")];
+    char stringpool_str222[sizeof("MS936")];
+    char stringpool_str225[sizeof("IBM862")];
+    char stringpool_str227[sizeof("ISO-2022-JP-1")];
+    char stringpool_str228[sizeof("LATIN10")];
+    char stringpool_str230[sizeof("MS932")];
+    char stringpool_str232[sizeof("ISO-2022-JP-2")];
+    char stringpool_str233[sizeof("UCS-2")];
+    char stringpool_str234[sizeof("MS51932")];
+    char stringpool_str237[sizeof("KSC5601")];
+    char stringpool_str242[sizeof("IBM819")];
+    char stringpool_str244[sizeof("WCHAR_T")];
+    char stringpool_str248[sizeof("PT154")];
+    char stringpool_str252[sizeof("ISO_8859-4:1988")];
+    char stringpool_str253[sizeof("UTF-16")];
+    char stringpool_str254[sizeof("ISO-IR-144")];
+    char stringpool_str255[sizeof("LATIN4")];
+    char stringpool_str260[sizeof("ISO-10646-UCS-2")];
+    char stringpool_str261[sizeof("US-ASCII")];
+    char stringpool_str262[sizeof("KOI8-T")];
+    char stringpool_str265[sizeof("UTF-32")];
+    char stringpool_str268[sizeof("CSEUCTW")];
+    char stringpool_str270[sizeof("ISO-CELTIC")];
+    char stringpool_str271[sizeof("CSISOLATIN1")];
+    char stringpool_str272[sizeof("UTF-8")];
+    char stringpool_str273[sizeof("CSISOLATIN6")];
+    char stringpool_str275[sizeof("CSISOLATIN5")];
+    char stringpool_str277[sizeof("KSC_5601")];
+    char stringpool_str278[sizeof("CSISOLATINCYRILLIC")];
+    char stringpool_str279[sizeof("CSISOLATIN3")];
+    char stringpool_str280[sizeof("CSWINDOWS31J")];
+    char stringpool_str281[sizeof("CSISOLATIN2")];
+    char stringpool_str282[sizeof("EUCJP-WIN")];
+    char stringpool_str283[sizeof("CSISO2022JP2")];
+    char stringpool_str284[sizeof("IBM850")];
+    char stringpool_str286[sizeof("ARABIC")];
+    char stringpool_str287[sizeof("GB18030")];
+    char stringpool_str289[sizeof("WINDOWS-31J")];
+    char stringpool_str293[sizeof("WINDOWS-1251")];
+    char stringpool_str294[sizeof("WINDOWS-1256")];
+    char stringpool_str295[sizeof("WINDOWS-1255")];
+    char stringpool_str296[sizeof("TIS620.2533-1")];
+    char stringpool_str297[sizeof("WINDOWS-1253")];
+    char stringpool_str298[sizeof("WINDOWS-1252")];
+    char stringpool_str300[sizeof("ISO-2022-JP-MS")];
+    char stringpool_str301[sizeof("MACTHAI")];
+    char stringpool_str303[sizeof("ISO-10646-UCS-4")];
+    char stringpool_str304[sizeof("WINDOWS-1258")];
+    char stringpool_str305[sizeof("WINDOWS-936")];
+    char stringpool_str307[sizeof("TIS620.2529-1")];
+    char stringpool_str308[sizeof("WINDOWS-51932")];
+    char stringpool_str310[sizeof("CSUCS4")];
+    char stringpool_str311[sizeof("CSISOLATINARABIC")];
+    char stringpool_str313[sizeof("WINDOWS-932")];
+    char stringpool_str314[sizeof("KZ-1048")];
+    char stringpool_str315[sizeof("GB_2312-80")];
+    char stringpool_str317[sizeof("CSISOLATINHEBREW")];
+    char stringpool_str318[sizeof("X0212")];
+    char stringpool_str319[sizeof("UCS-4")];
+    char stringpool_str321[sizeof("DECHANZI")];
+    char stringpool_str327[sizeof("WINDOWS-1250")];
+    char stringpool_str328[sizeof("MS-ANSI")];
+    char stringpool_str330[sizeof("TIS620.2533-0")];
+    char stringpool_str337[sizeof("GB_1988-80")];
+    char stringpool_str338[sizeof("CYRILLIC")];
+    char stringpool_str339[sizeof("VISCII1.1-1")];
+    char stringpool_str341[sizeof("WINDOWS-1254")];
+    char stringpool_str342[sizeof("X0201")];
+    char stringpool_str345[sizeof("ARMSCII-8")];
+    char stringpool_str346[sizeof("KS_C_5601-1989")];
+    char stringpool_str347[sizeof("ROMAN8")];
+    char stringpool_str349[sizeof("ISO646-US")];
+    char stringpool_str350[sizeof("CSKZ1048")];
+    char stringpool_str355[sizeof("SHIFT-JIS")];
+    char stringpool_str359[sizeof("ISO646-JP")];
+    char stringpool_str361[sizeof("CSPC862LATINHEBREW")];
+    char stringpool_str363[sizeof("CP874")];
+    char stringpool_str364[sizeof("X0208")];
+    char stringpool_str367[sizeof("CSISOLATIN4")];
+    char stringpool_str370[sizeof("ISO-2022-JP")];
+    char stringpool_str371[sizeof("CSKOI8R")];
+    char stringpool_str374[sizeof("IBM-CP1133")];
+    char stringpool_str376[sizeof("ECMA-118")];
+    char stringpool_str378[sizeof("L7")];
+    char stringpool_str380[sizeof("KOI8-R")];
+    char stringpool_str381[sizeof("BIG5")];
+    char stringpool_str383[sizeof("CSBIG5")];
+    char stringpool_str384[sizeof("SHIFT_JIS")];
+    char stringpool_str387[sizeof("CSSHIFTJIS")];
+    char stringpool_str388[sizeof("MACINTOSH")];
+    char stringpool_str389[sizeof("ISO-IR-179")];
+    char stringpool_str392[sizeof("BIG-5")];
+    char stringpool_str393[sizeof("MACCROATIAN")];
+    char stringpool_str394[sizeof("CN-BIG5")];
+    char stringpool_str395[sizeof("PTCP154")];
+    char stringpool_str398[sizeof("CHINESE")];
+    char stringpool_str399[sizeof("EUCJP")];
+    char stringpool_str400[sizeof("CSGB2312")];
+    char stringpool_str401[sizeof("HP-ROMAN8")];
+    char stringpool_str410[sizeof("EUC-JP")];
+    char stringpool_str417[sizeof("TCVN5712-1")];
+    char stringpool_str418[sizeof("CSPTCP154")];
+    char stringpool_str420[sizeof("SDECKANJI")];
+    char stringpool_str421[sizeof("TCVN-5712")];
+    char stringpool_str422[sizeof("CSISO2022JP")];
+    char stringpool_str425[sizeof("CSMACINTOSH")];
+    char stringpool_str426[sizeof("SJIS-OPEN")];
+    char stringpool_str429[sizeof("CSIBM866")];
+    char stringpool_str431[sizeof("ISO_646.IRV:1991")];
+    char stringpool_str432[sizeof("KOREAN")];
+    char stringpool_str433[sizeof("ISO-2022-KR")];
+    char stringpool_str441[sizeof("HEBREW")];
+    char stringpool_str443[sizeof("CSUNICODE11")];
+    char stringpool_str444[sizeof("ISO_8859-1:1987")];
+    char stringpool_str445[sizeof("ISO_8859-6:1987")];
+    char stringpool_str448[sizeof("ISO_8859-7:2003")];
+    char stringpool_str449[sizeof("ISO_8859-2:1987")];
+    char stringpool_str450[sizeof("ECMA-114")];
+    char stringpool_str456[sizeof("UNICODE-1-1")];
+    char stringpool_str462[sizeof("EUCKR")];
+    char stringpool_str463[sizeof("HZ-GB-2312")];
+    char stringpool_str467[sizeof("JIS_X0212")];
+    char stringpool_str468[sizeof("CYRILLIC-ASIAN")];
+    char stringpool_str473[sizeof("EUC-KR")];
+    char stringpool_str479[sizeof("MS_KANJI")];
+    char stringpool_str481[sizeof("JISX0201-1976")];
+    char stringpool_str485[sizeof("CSISO2022KR")];
+    char stringpool_str491[sizeof("JIS_X0201")];
+    char stringpool_str492[sizeof("KOI8-U")];
+    char stringpool_str501[sizeof("JOHAB")];
+    char stringpool_str502[sizeof("SJIS-MS")];
+    char stringpool_str505[sizeof("STRK1048-2002")];
+    char stringpool_str511[sizeof("JIS_X0212-1990")];
+    char stringpool_str512[sizeof("CP367")];
+    char stringpool_str513[sizeof("JIS_X0208")];
+    char stringpool_str514[sizeof("GEORGIAN-ACADEMY")];
+    char stringpool_str515[sizeof("CP1257")];
+    char stringpool_str516[sizeof("CSISO58GB231280")];
+    char stringpool_str517[sizeof("TCVN5712-1:1993")];
+    char stringpool_str521[sizeof("JIS_X0208-1983")];
+    char stringpool_str524[sizeof("MS-EE")];
+    char stringpool_str531[sizeof("MACROMAN")];
+    char stringpool_str532[sizeof("EUCJP-OPEN")];
+    char stringpool_str537[sizeof("CSHPROMAN8")];
+    char stringpool_str543[sizeof("MACCYRILLIC")];
+    char stringpool_str544[sizeof("WINDOWS-1257")];
+    char stringpool_str545[sizeof("CSUNICODE")];
+    char stringpool_str549[sizeof("MS-CYRL")];
+    char stringpool_str551[sizeof("JIS_X0208-1990")];
+    char stringpool_str552[sizeof("GBK")];
+    char stringpool_str557[sizeof("ASMO-708")];
+    char stringpool_str559[sizeof("ISO8859-7")];
+    char stringpool_str561[sizeof("CN-GB-ISOIR165")];
+    char stringpool_str563[sizeof("UCS-2LE")];
+    char stringpool_str566[sizeof("MACARABIC")];
+    char stringpool_str570[sizeof("ISO-8859-7")];
+    char stringpool_str573[sizeof("KOI8-RU")];
+    char stringpool_str580[sizeof("CSKSC56011987")];
+    char stringpool_str583[sizeof("KS_C_5601-1987")];
+    char stringpool_str584[sizeof("UCS-2-INTERNAL")];
+    char stringpool_str587[sizeof("UTF-16LE")];
+    char stringpool_str592[sizeof("GREEK8")];
+    char stringpool_str594[sizeof("SHIFT_JIS-MS")];
+    char stringpool_str595[sizeof("UTF-32LE")];
+    char stringpool_str596[sizeof("MACROMANIA")];
+    char stringpool_str597[sizeof("EUCJPMS")];
+    char stringpool_str598[sizeof("CN-GB")];
+    char stringpool_str599[sizeof("ISO_8859-7")];
+    char stringpool_str600[sizeof("CSEUCKR")];
+    char stringpool_str601[sizeof("CSHALFWIDTHKATAKANA")];
+    char stringpool_str605[sizeof("MULELAO-1")];
+    char stringpool_str606[sizeof("UCS-4LE")];
+    char stringpool_str608[sizeof("EUCJP-MS")];
+    char stringpool_str613[sizeof("ISO-IR-57")];
+    char stringpool_str614[sizeof("ISO-IR-157")];
+    char stringpool_str617[sizeof("ISO-IR-127")];
+    char stringpool_str619[sizeof("EUC-JP-MS")];
+    char stringpool_str620[sizeof("DECKOREAN")];
+    char stringpool_str622[sizeof("ISO-IR-87")];
+    char stringpool_str627[sizeof("UCS-4-INTERNAL")];
+    char stringpool_str631[sizeof("CSISOLATINGREEK")];
+    char stringpool_str638[sizeof("JIS_X0212.1990-0")];
+    char stringpool_str643[sizeof("WINDOWS-874")];
+    char stringpool_str648[sizeof("UCS-2BE")];
+    char stringpool_str656[sizeof("ANSI_X3.4-1986")];
+    char stringpool_str661[sizeof("LATIN7")];
+    char stringpool_str666[sizeof("ANSI_X3.4-1968")];
+    char stringpool_str672[sizeof("UTF-16BE")];
+    char stringpool_str680[sizeof("UTF-32BE")];
+    char stringpool_str691[sizeof("UCS-4BE")];
+    char stringpool_str695[sizeof("ISO_8859-7:1987")];
+    char stringpool_str698[sizeof("CSUNICODE11UTF7")];
+    char stringpool_str709[sizeof("UNICODELITTLE")];
+    char stringpool_str710[sizeof("IBM367")];
+    char stringpool_str713[sizeof("UNICODE-1-1-UTF-7")];
+    char stringpool_str729[sizeof("MS-HEBR")];
+    char stringpool_str730[sizeof("CSISO87JISX0208")];
+    char stringpool_str736[sizeof("CSISO57GB1988")];
+    char stringpool_str745[sizeof("MACHEBREW")];
+    char stringpool_str752[sizeof("UTF-7")];
+    char stringpool_str758[sizeof("GEORGIAN-PS")];
+    char stringpool_str762[sizeof("GREEK")];
+    char stringpool_str784[sizeof("MS-ARAB")];
+    char stringpool_str791[sizeof("MACTURKISH")];
+    char stringpool_str793[sizeof("MACCENTRALEUROPE")];
+    char stringpool_str798[sizeof("BIGFIVE")];
+    char stringpool_str809[sizeof("BIG-FIVE")];
+    char stringpool_str815[sizeof("CSPC850MULTILINGUAL")];
+    char stringpool_str821[sizeof("NEXTSTEP")];
+    char stringpool_str828[sizeof("UCS-2-SWAPPED")];
+    char stringpool_str834[sizeof("BIG5HKSCS")];
+    char stringpool_str837[sizeof("MS-TURK")];
+    char stringpool_str845[sizeof("BIG5-HKSCS")];
+    char stringpool_str848[sizeof("MACICELAND")];
+    char stringpool_str866[sizeof("MACUKRAINE")];
+    char stringpool_str869[sizeof("BIG5-HKSCS:2001")];
+    char stringpool_str871[sizeof("UCS-4-SWAPPED")];
+    char stringpool_str880[sizeof("BIG5-HKSCS:2008")];
+    char stringpool_str882[sizeof("WINBALTRIM")];
+    char stringpool_str883[sizeof("BIG5-HKSCS:1999")];
+    char stringpool_str917[sizeof("BIG5-HKSCS:2004")];
+    char stringpool_str971[sizeof("UNICODEBIG")];
+    char stringpool_str1016[sizeof("UTF7IMAP")];
+    char stringpool_str1038[sizeof("UTF-7-IMAP")];
+    char stringpool_str1041[sizeof("EXTENDED_UNIX_CODE_PACKED_FORMAT_FOR_JAPANESE")];
+    char stringpool_str1042[sizeof("MACGREEK")];
+    char stringpool_str1052[sizeof("MS-GREEK")];
+    char stringpool_str1203[sizeof("CSEUCPKDFMTJAPANESE")];
   };
 static const struct stringpool_t stringpool_contents =
   {
-    "L6",
-    "L1",
     "CN",
-    "L4",
-    "L5",
-    "R8",
-    "L8",
-    "SJIS",
+    "CP1131",
+    "CP1361",
+    "CP1251",
+    "CP1256",
     "866",
-    "L2",
-    "HZ",
-    "ISO-IR-6",
+    "CP1255",
+    "CP1133",
     "CP866",
-    "C99",
-    "ISO-IR-166",
-    "EUCCN",
-    "LATIN6",
-    "CP154",
-    "LATIN1",
-    "EUC-CN",
-    "CYRILLIC",
-    "ISO646-CN",
-    "ISO-IR-14",
-    "CP1256",
-    "LATIN4",
-    "CP1251",
-    "ISO-IR-165",
-    "LATIN5",
+    "CP1253",
+    "CP1252",
     "862",
-    "ISO-IR-126",
-    "ISO-IR-144",
-    "CP819",
-    "TACTIS",
-    "LATIN8",
-    "CP1254",
-    "ISO-IR-58",
-    "CP949",
-    "CP1255",
+    "CP936",
     "CP862",
-    "ISO-IR-148",
-    "L3",
-    "LATIN-9",
-    "CHINESE",
-    "ISO-IR-149",
-    "ISO-IR-159",
-    "ISO-IR-226",
+    "C99",
+    "CP932",
     "CP1258",
-    "LATIN2",
-    "ISO8859-6",
-    "ISO-IR-199",
+    "CP51932",
+    "ASCII",
+    "CP819",
+    "CP50221",
     "ISO8859-1",
-    "ISO-CELTIC",
-    "ISO-8859-6",
-    "ISO_8859-6",
+    "ISO8859-11",
+    "ISO8859-6",
     "ISO8859-16",
+    "ISO8859-5",
+    "ISO8859-15",
+    "ISO8859-3",
+    "ISO8859-13",
+    "ISO8859-2",
     "ISO-8859-1",
-    "ISO_8859-1",
-    "ISO8859-11",
-    "ISO-8859-16",
-    "ISO_8859-16",
-    "CP1252",
     "ISO-8859-11",
-    "ISO_8859-11",
-    "ISO8859-4",
-    "CP1361",
-    "ISO_8859-16:2001",
-    "CP1131",
-    "ISO8859-5",
-    "ISO-8859-4",
-    "ISO_8859-4",
-    "ISO8859-14",
-    "CP936",
+    "ISO-8859-6",
+    "ISO-8859-16",
     "ISO-8859-5",
-    "ISO_8859-5",
-    "ISO8859-15",
-    "MAC",
-    "ISO-8859-14",
-    "ISO_8859-14",
-    "ISO8859-8",
-    "ISO-IR-101",
     "ISO-8859-15",
-    "ISO_8859-15",
+    "ISO-8859-3",
+    "ISO-8859-13",
+    "ISO-8859-2",
+    "ISO8859-8",
+    "CP1250",
+    "850",
+    "ISO646-CN",
     "ISO8859-9",
+    "CP850",
+    "HZ",
+    "CP950",
     "ISO-8859-8",
-    "ISO_8859-8",
+    "R8",
+    "ISO-2022-CN",
+    "CP949",
     "ISO-8859-9",
+    "ISO_8859-1",
+    "ISO_8859-11",
+    "ISO_8859-6",
+    "ISO_8859-16",
+    "ISO_8859-5",
+    "ISO_8859-15",
+    "CP154",
+    "ISO_8859-16:2001",
+    "ISO_8859-3",
+    "ISO_8859-13",
+    "ISO_8859-2",
+    "CP1254",
+    "ISO-IR-6",
+    "ISO-2022-CN-EXT",
+    "ISO-IR-166",
+    "CSASCII",
+    "ISO-IR-165",
+    "ISO_8859-15:1998",
+    "ISO-IR-126",
+    "ISO_8859-8",
+    "ISO-IR-226",
+    "EUCCN",
     "ISO_8859-9",
+    "ISO8859-10",
+    "L1",
+    "L6",
+    "L5",
+    "EUCTW",
+    "L3",
+    "L2",
+    "ISO-IR-58",
+    "EUC-CN",
+    "ISO-IR-138",
+    "ISO-8859-10",
+    "L8",
+    "UHC",
+    "ISO-IR-159",
+    "EUC-TW",
+    "ISO_8859-10:1992",
+    "ISO-IR-101",
+    "CSISO2022CN",
+    "JP",
+    "TCVN",
+    "JIS_C6226-1983",
+    "ISO-IR-199",
+    "ISO8859-4",
+    "ISO8859-14",
+    "ISO-IR-203",
+    "LATIN1",
+    "LATIN6",
     "ISO_8859-14:1998",
-    "PT154",
-    "ISO_8859-15:1998",
-    "RK1048",
-    "ELOT_928",
-    "ISO8859-2",
-    "MS-CYRL",
-    "IBM866",
-    "L7",
-    "ISO-8859-2",
-    "ISO_8859-2",
-    "CHAR",
+    "LATIN5",
+    "ISO-8859-4",
+    "ISO-8859-14",
+    "ISO_8859-10",
+    "LATIN3",
+    "LATIN2",
     "ISO-IR-109",
-    "ISO-IR-138",
-    "ASCII",
-    "KOI8-R",
-    "EUCKR",
-    "L10",
-    "CP932",
-    "EUC-KR",
-    "CP50221",
-    "CSKOI8R",
-    "MS-EE",
-    "850",
-    "CSASCII",
-    "IBM819",
-    "MACCYRILLIC",
+    "TIS620",
+    "JIS0208",
+    "L4",
+    "SJIS-WIN",
+    "ISO-IR-110",
+    "ISO-IR-148",
+    "LATIN8",
+    "JIS_C6220-1969-RO",
+    "TIS-620",
+    "JAVA",
+    "ISO-IR-149",
+    "GB2312",
     "VISCII",
-    "TCVN",
-    "SHIFT-JIS",
-    "SHIFT_JIS",
-    "IBM862",
+    "RK1048",
+    "CSVISCII",
+    "TACTIS",
+    "ISO_8859-4",
+    "ISO_8859-14",
+    "L10",
+    "LATIN-9",
+    "CHAR",
+    "MAC",
+    "ISO-IR-14",
+    "ISO_8859-5:1988",
+    "ISO_8859-3:1988",
     "CSISO14JISC6220RO",
-    "CP874",
-    "GB2312",
     "US",
-    "CSVISCII",
-    "CP850",
-    "ISO-IR-110",
-    "CP950",
-    "KOI8-T",
-    "ISO-2022-CN",
-    "JP",
-    "CYRILLIC-ASIAN",
-    "LATIN10",
-    "UHC",
-    "LATIN3",
-    "CSISO2022CN",
-    "ISO_8859-10:1992",
-    "MACINTOSH",
-    "CP1250",
-    "CSISOLATIN6",
-    "CSSHIFTJIS",
-    "ISO-IR-179",
+    "ISO-IR-100",
+    "ELOT_928",
+    "CSISO159JISX02121990",
+    "ISO_8859-8:1988",
+    "IBM866",
+    "TIS620-0",
+    "SJIS",
+    "ISO_8859-9:1989",
     "MS936",
-    "CSISOLATIN1",
-    "TIS620",
-    "CP1253",
-    "DECHANZI",
-    "UTF-16",
-    "ISO-2022-CN-EXT",
-    "TIS-620",
-    "UCS-4",
-    "GREEK8",
-    "CSISOLATINCYRILLIC",
-    "CSISOLATIN4",
-    "CSISOLATIN5",
-    "PTCP154",
-    "CSUCS4",
-    "ISO646-US",
+    "IBM862",
+    "ISO-2022-JP-1",
+    "LATIN10",
+    "MS932",
+    "ISO-2022-JP-2",
+    "UCS-2",
+    "MS51932",
     "KSC5601",
+    "IBM819",
+    "WCHAR_T",
+    "PT154",
+    "ISO_8859-4:1988",
+    "UTF-16",
+    "ISO-IR-144",
+    "LATIN4",
+    "ISO-10646-UCS-2",
+    "US-ASCII",
+    "KOI8-T",
+    "UTF-32",
+    "CSEUCTW",
+    "ISO-CELTIC",
+    "CSISOLATIN1",
     "UTF-8",
+    "CSISOLATIN6",
+    "CSISOLATIN5",
     "KSC_5601",
-    "BIG5",
-    "ISO8859-10",
-    "ISO8859-3",
-    "UCS-2",
-    "BIG-5",
-    "ISO-8859-10",
-    "ISO_8859-10",
-    "ISO-8859-3",
-    "ISO_8859-3",
-    "ISO8859-13",
+    "CSISOLATINCYRILLIC",
+    "CSISOLATIN3",
+    "CSWINDOWS31J",
     "CSISOLATIN2",
-    "UCS-4LE",
+    "EUCJP-WIN",
+    "CSISO2022JP2",
+    "IBM850",
+    "ARABIC",
+    "GB18030",
+    "WINDOWS-31J",
+    "WINDOWS-1251",
+    "WINDOWS-1256",
+    "WINDOWS-1255",
+    "TIS620.2533-1",
+    "WINDOWS-1253",
+    "WINDOWS-1252",
+    "ISO-2022-JP-MS",
+    "MACTHAI",
+    "ISO-10646-UCS-4",
+    "WINDOWS-1258",
+    "WINDOWS-936",
+    "TIS620.2529-1",
+    "WINDOWS-51932",
+    "CSUCS4",
+    "CSISOLATINARABIC",
+    "WINDOWS-932",
     "KZ-1048",
-    "ISO-8859-13",
-    "ISO_8859-13",
-    "CSBIG5",
-    "UTF-16LE",
+    "GB_2312-80",
+    "CSISOLATINHEBREW",
     "X0212",
-    "CP1133",
-    "GBK",
+    "UCS-4",
+    "DECHANZI",
+    "WINDOWS-1250",
     "MS-ANSI",
-    "CN-BIG5",
-    "ISO-IR-100",
-    "CSPTCP154",
+    "TIS620.2533-0",
     "GB_1988-80",
-    "UCS-2LE",
-    "CSISO159JISX02121990",
-    "UNICODE-1-1",
-    "KS_C_5601-1989",
-    "CSKZ1048",
+    "CYRILLIC",
     "VISCII1.1-1",
-    "ISO_646.IRV:1991",
-    "CSUNICODE11",
-    "CN-GB-ISOIR165",
-    "CSUNICODE",
-    "UCS-4-INTERNAL",
-    "ROMAN8",
-    "JIS_C6220-1969-RO",
-    "JIS_C6226-1983",
-    "KOREAN",
+    "WINDOWS-1254",
     "X0201",
-    "MULELAO-1",
-    "ISO-IR-203",
-    "IBM850",
-    "TIS620-0",
-    "UCS-2-INTERNAL",
-    "ECMA-114",
-    "MACTHAI",
-    "GREEK",
     "ARMSCII-8",
-    "ISO-2022-KR",
-    "GEORGIAN-PS",
-    "TIS620.2529-1",
-    "ECMA-118",
-    "CSISO2022KR",
-    "LATIN7",
-    "ISO-IR-57",
-    "X0208",
-    "HP-ROMAN8",
-    "EUCJP",
-    "ISO-IR-87",
-    "ISO-IR-157",
-    "EUC-JP",
-    "ISO-10646-UCS-4",
-    "DECKOREAN",
+    "KS_C_5601-1989",
+    "ROMAN8",
+    "ISO646-US",
+    "CSKZ1048",
+    "SHIFT-JIS",
     "ISO646-JP",
-    "CP1257",
-    "UNICODELITTLE",
-    "JIS0208",
-    "ISO-IR-127",
-    "MACICELAND",
-    "UTF-32",
-    "ISO-10646-UCS-2",
-    "EUCTW",
-    "EUC-TW",
-    "GB_2312-80",
-    "CSIBM866",
-    "CSISOLATINARABIC",
-    "CSISOLATINGREEK",
-    "CSMACINTOSH",
-    "CSEUCKR",
-    "US-ASCII",
-    "GEORGIAN-ACADEMY",
-    "MS-HEBR",
-    "WCHAR_T",
-    "UTF-32LE",
-    "GB18030",
-    "ISO8859-7",
-    "ISO_8859-4:1988",
-    "MACCENTRALEUROPE",
-    "ISO_8859-5:1988",
-    "CSISOLATIN3",
-    "ISO-8859-7",
-    "ISO_8859-7",
-    "CP367",
-    "ISO_8859-8:1988",
-    "ISO_8859-9:1989",
-    "MACROMAN",
-    "CSISOLATINHEBREW",
-    "TCVN5712-1",
-    "EXTENDED_UNIX_CODE_PACKED_FORMAT_FOR_JAPANESE",
-    "STRK1048-2002",
-    "WINDOWS-1256",
-    "ISO-2022-JP-1",
-    "WINDOWS-1251",
-    "ISO-2022-JP-MS",
-    "TCVN-5712",
-    "WINDOWS-1254",
-    "KS_C_5601-1987",
-    "WINDOWS-1255",
-    "CSGB2312",
-    "WINDOWS-1258",
-    "ISO-2022-JP-2",
-    "WINDOWS-1252",
-    "BIG5HKSCS",
-    "UNICODE-1-1-UTF-7",
-    "CSISO2022JP2",
-    "BIG5-HKSCS",
-    "CSKSC56011987",
-    "CSHPROMAN8",
-    "CSUNICODE11UTF7",
-    "SDECKANJI",
-    "HZ-GB-2312",
-    "MS-GREEK",
-    "MACGREEK",
-    "BIGFIVE",
-    "TIS620.2533-1",
-    "CN-GB",
-    "BIG-FIVE",
-    "ISO_8859-3:1988",
-    "NEXTSTEP",
-    "MACCROATIAN",
-    "WINDOWS-936",
-    "CSISO57GB1988",
-    "UCS-4BE",
-    "UTF-16BE",
-    "WINDOWS-1250",
-    "UCS-2BE",
-    "WINDOWS-1253",
-    "JIS_X0212",
-    "CSISO58GB231280",
+    "CSPC862LATINHEBREW",
+    "CP874",
+    "X0208",
+    "CSISOLATIN4",
     "ISO-2022-JP",
-    "IBM367",
+    "CSKOI8R",
     "IBM-CP1133",
-    "ISO_8859-6:1987",
-    "ISO_8859-1:1987",
+    "ECMA-118",
+    "L7",
+    "KOI8-R",
+    "BIG5",
+    "CSBIG5",
+    "SHIFT_JIS",
+    "CSSHIFTJIS",
+    "MACINTOSH",
+    "ISO-IR-179",
+    "BIG-5",
+    "MACCROATIAN",
+    "CN-BIG5",
+    "PTCP154",
+    "CHINESE",
+    "EUCJP",
+    "CSGB2312",
+    "HP-ROMAN8",
+    "EUC-JP",
+    "TCVN5712-1",
+    "CSPTCP154",
+    "SDECKANJI",
+    "TCVN-5712",
     "CSISO2022JP",
-    "UTF-7",
-    "CSPC862LATINHEBREW",
-    "ARABIC",
+    "CSMACINTOSH",
+    "SJIS-OPEN",
+    "CSIBM866",
+    "ISO_646.IRV:1991",
+    "KOREAN",
+    "ISO-2022-KR",
+    "HEBREW",
+    "CSUNICODE11",
+    "ISO_8859-1:1987",
+    "ISO_8859-6:1987",
+    "ISO_8859-7:2003",
+    "ISO_8859-2:1987",
+    "ECMA-114",
+    "UNICODE-1-1",
+    "EUCKR",
+    "HZ-GB-2312",
+    "JIS_X0212",
+    "CYRILLIC-ASIAN",
+    "EUC-KR",
     "MS_KANJI",
+    "JISX0201-1976",
+    "CSISO2022KR",
     "JIS_X0201",
-    "ISO_8859-2:1987",
-    "UNICODEBIG",
-    "TIS620.2533-0",
+    "KOI8-U",
+    "JOHAB",
+    "SJIS-MS",
+    "STRK1048-2002",
+    "JIS_X0212-1990",
+    "CP367",
+    "JIS_X0208",
+    "GEORGIAN-ACADEMY",
+    "CP1257",
+    "CSISO58GB231280",
+    "TCVN5712-1:1993",
+    "JIS_X0208-1983",
+    "MS-EE",
+    "MACROMAN",
+    "EUCJP-OPEN",
+    "CSHPROMAN8",
+    "MACCYRILLIC",
+    "WINDOWS-1257",
+    "CSUNICODE",
+    "MS-CYRL",
+    "JIS_X0208-1990",
+    "GBK",
     "ASMO-708",
-    "CSISO87JISX0208",
-    "MACTURKISH",
+    "ISO8859-7",
+    "CN-GB-ISOIR165",
+    "UCS-2LE",
+    "MACARABIC",
+    "ISO-8859-7",
+    "KOI8-RU",
+    "CSKSC56011987",
+    "KS_C_5601-1987",
+    "UCS-2-INTERNAL",
+    "UTF-16LE",
+    "GREEK8",
+    "SHIFT_JIS-MS",
+    "UTF-32LE",
+    "MACROMANIA",
+    "EUCJPMS",
+    "CN-GB",
+    "ISO_8859-7",
+    "CSEUCKR",
+    "CSHALFWIDTHKATAKANA",
+    "MULELAO-1",
+    "UCS-4LE",
+    "EUCJP-MS",
+    "ISO-IR-57",
+    "ISO-IR-157",
+    "ISO-IR-127",
+    "EUC-JP-MS",
+    "DECKOREAN",
+    "ISO-IR-87",
+    "UCS-4-INTERNAL",
+    "CSISOLATINGREEK",
+    "JIS_X0212.1990-0",
     "WINDOWS-874",
+    "UCS-2BE",
     "ANSI_X3.4-1986",
-    "WINDOWS-1257",
-    "JIS_X0208",
-    "JISX0201-1976",
-    "KOI8-U",
-    "JAVA",
-    "KOI8-RU",
-    "JIS_X0212-1990",
+    "LATIN7",
     "ANSI_X3.4-1968",
-    "HEBREW",
-    "CSEUCTW",
-    "CSHALFWIDTHKATAKANA",
+    "UTF-16BE",
     "UTF-32BE",
-    "ISO_8859-7:2003",
+    "UCS-4BE",
+    "ISO_8859-7:1987",
+    "CSUNICODE11UTF7",
+    "UNICODELITTLE",
+    "IBM367",
+    "UNICODE-1-1-UTF-7",
+    "MS-HEBR",
+    "CSISO87JISX0208",
+    "CSISO57GB1988",
+    "MACHEBREW",
+    "UTF-7",
+    "GEORGIAN-PS",
+    "GREEK",
+    "MS-ARAB",
+    "MACTURKISH",
+    "MACCENTRALEUROPE",
+    "BIGFIVE",
+    "BIG-FIVE",
     "CSPC850MULTILINGUAL",
+    "NEXTSTEP",
+    "UCS-2-SWAPPED",
+    "BIG5HKSCS",
     "MS-TURK",
-    "JIS_X0208-1990",
-    "JIS_X0208-1983",
-    "JIS_X0212.1990-0",
-    "MACARABIC",
-    "ISO_8859-7:1987",
+    "BIG5-HKSCS",
+    "MACICELAND",
     "MACUKRAINE",
-    "CSEUCPKDFMTJAPANESE",
-    "MACROMANIA",
     "BIG5-HKSCS:2001",
-    "BIG5-HKSCS:2004",
-    "JOHAB",
-    "BIG5-HKSCS:2008",
-    "BIG5-HKSCS:1999",
-    "MACHEBREW",
-    "TCVN5712-1:1993",
     "UCS-4-SWAPPED",
-    "UCS-2-SWAPPED",
+    "BIG5-HKSCS:2008",
     "WINBALTRIM",
-    "MS-ARAB"
+    "BIG5-HKSCS:1999",
+    "BIG5-HKSCS:2004",
+    "UNICODEBIG",
+    "UTF7IMAP",
+    "UTF-7-IMAP",
+    "EXTENDED_UNIX_CODE_PACKED_FORMAT_FOR_JAPANESE",
+    "MACGREEK",
+    "MS-GREEK",
+    "CSEUCPKDFMTJAPANESE"
   };
 #define stringpool ((const char *) &stringpool_contents)
 
 static const struct alias aliases[] =
   {
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-    {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-#line 134 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str15, ei_iso8859_10},
+#line 291 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str9, ei_iso646_cn},
+#line 211 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str10, ei_cp1131},
+#line 379 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str11, ei_johab},
     {-1},
-#line 60 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str17, ei_iso8859_1},
+#line 176 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str13, ei_cp1251},
+    {-1},
+#line 191 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str15, ei_cp1256},
+#line 209 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str16, ei_cp866},
+#line 188 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str17, ei_cp1255},
+#line 246 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str18, ei_cp1133},
+#line 207 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str19, ei_cp866},
+    {-1},
+#line 182 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str21, ei_cp1253},
+    {-1},
+#line 179 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str23, ei_cp1252},
+#line 205 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str24, ei_cp862},
+#line 346 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str25, ei_cp936},
+    {-1},
+#line 203 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str27, ei_cp862},
+    {-1}, {-1}, {-1},
+#line 53 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str31, ei_c99},
+    {-1},
+#line 323 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str33, ei_cp932},
+    {-1},
+#line 197 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str35, ei_cp1258},
+    {-1},
+#line 315 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str37, ei_cp51932},
+    {-1}, {-1},
+#line 13 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str40, ei_ascii},
+    {-1}, {-1}, {-1},
+#line 59 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str44, ei_iso8859_1},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+#line 338 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str53, ei_iso2022_jpms},
+    {-1}, {-1}, {-1},
+#line 64 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str57, ei_iso8859_1},
+#line 141 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str58, ei_iso8859_11},
+#line 104 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str59, ei_iso8859_6},
+#line 168 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str60, ei_iso8859_16},
+#line 95 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str61, ei_iso8859_5},
+#line 161 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str62, ei_iso8859_15},
+    {-1}, {-1},
+#line 80 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str65, ei_iso8859_3},
+#line 147 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str66, ei_iso8859_13},
+#line 72 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str67, ei_iso8859_2},
+#line 55 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str68, ei_iso8859_1},
+#line 139 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str69, ei_iso8859_11},
+#line 96 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str70, ei_iso8859_6},
+#line 162 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str71, ei_iso8859_16},
+#line 89 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str72, ei_iso8859_5},
+#line 156 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str73, ei_iso8859_15},
     {-1}, {-1},
+#line 73 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str76, ei_iso8859_3},
+#line 142 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str77, ei_iso8859_13},
+#line 65 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str78, ei_iso8859_2},
+#line 122 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str79, ei_iso8859_8},
+    {-1},
+#line 173 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str81, ei_cp1250},
+#line 201 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str82, ei_cp850},
 #line 289 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str20, ei_iso646_cn},
-    {-1}, {-1}, {-1}, {-1},
-#line 84 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str25, ei_iso8859_4},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str83, ei_iso646_cn},
     {-1},
-#line 126 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str27, ei_iso8859_9},
-    {-1}, {-1},
-#line 227 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str30, ei_hp_roman8},
+#line 130 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str85, ei_iso8859_9},
+#line 199 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str86, ei_cp850},
+    {-1},
+#line 353 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str88, ei_hz},
+#line 364 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str89, ei_cp950},
+#line 116 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str90, ei_iso8859_8},
     {-1}, {-1},
-#line 151 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str33, ei_iso8859_14},
-#line 310 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str34, ei_sjis},
+#line 229 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str93, ei_hp_roman8},
+#line 350 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str94, ei_iso2022_cn},
+#line 375 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str95, ei_cp949},
+#line 123 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str96, ei_iso8859_9},
+#line 56 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str97, ei_iso8859_1},
+#line 140 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str98, ei_iso8859_11},
+#line 97 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str99, ei_iso8859_6},
+#line 163 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str100, ei_iso8859_16},
+#line 90 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str101, ei_iso8859_5},
+#line 157 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str102, ei_iso8859_15},
+#line 238 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str103, ei_pt154},
+#line 164 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str104, ei_iso8859_16},
+#line 74 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str105, ei_iso8859_3},
+#line 143 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str106, ei_iso8859_13},
+#line 66 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str107, ei_iso8859_2},
     {-1},
-#line 207 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str36, ei_cp866},
-    {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-#line 68 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str43, ei_iso8859_2},
-    {-1}, {-1}, {-1}, {-1}, {-1},
-#line 335 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str49, ei_hz},
+#line 185 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str109, ei_cp1254},
+#line 16 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str110, ei_ascii},
+    {-1},
+#line 352 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str112, ei_iso2022_cn_ext},
+#line 254 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str113, ei_tis620},
+#line 22 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str114, ei_ascii},
+#line 297 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str115, ei_isoir165},
+#line 158 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str116, ei_iso8859_15},
+#line 109 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str117, ei_iso8859_7},
     {-1},
-#line 16 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str51, ei_ascii},
+#line 117 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str119, ei_iso8859_8},
     {-1}, {-1},
-#line 205 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str54, ei_cp866},
-    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-#line 51 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str64, ei_c99},
-#line 252 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str65, ei_tis620},
-#line 322 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str66, ei_euc_cn},
+#line 165 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str122, ei_iso8859_16},
+#line 340 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str123, ei_euc_cn},
+    {-1},
+#line 124 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str125, ei_iso8859_9},
+#line 138 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str126, ei_iso8859_10},
+#line 62 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str127, ei_iso8859_1},
+#line 136 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str128, ei_iso8859_10},
+#line 128 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str129, ei_iso8859_9},
+#line 356 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str130, ei_euc_tw},
+#line 78 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str131, ei_iso8859_3},
+#line 70 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str132, ei_iso8859_2},
+#line 294 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str133, ei_gb2312},
+#line 339 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str134, ei_euc_cn},
+    {-1},
+#line 119 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str136, ei_iso8859_8},
+#line 131 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str137, ei_iso8859_10},
+#line 153 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str138, ei_iso8859_14},
+#line 376 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str139, ei_cp949},
+#line 286 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str140, ei_jisx0212},
+#line 355 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str141, ei_euc_tw},
 #line 133 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str67, ei_iso8859_10},
-    {-1}, {-1},
-#line 236 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str70, ei_pt154},
-#line 59 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str71, ei_iso8859_1},
-#line 321 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str72, ei_euc_cn},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str142, ei_iso8859_10},
     {-1},
-#line 91 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str74, ei_iso8859_5},
+#line 68 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str144, ei_iso8859_2},
     {-1},
-#line 287 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str76, ei_iso646_cn},
+#line 351 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str146, ei_iso2022_cn},
+#line 268 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str147, ei_iso646_jp},
     {-1}, {-1},
-#line 265 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str79, ei_iso646_jp},
-    {-1}, {-1}, {-1}, {-1},
-#line 189 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str84, ei_cp1256},
+#line 261 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str150, ei_tcvn},
+#line 280 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str151, ei_jisx0208},
+#line 151 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str152, ei_iso8859_14},
+#line 88 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str153, ei_iso8859_4},
+#line 155 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str154, ei_iso8859_14},
     {-1}, {-1},
-#line 83 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str87, ei_iso8859_4},
-#line 174 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str88, ei_cp1251},
-#line 295 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str89, ei_isoir165},
+#line 159 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str157, ei_iso8859_15},
     {-1},
-#line 125 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str91, ei_iso8859_9},
-#line 203 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str92, ei_cp862},
-#line 107 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str93, ei_iso8859_7},
+#line 61 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str159, ei_iso8859_1},
     {-1},
-#line 90 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str95, ei_iso8859_5},
-#line 57 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str96, ei_iso8859_1},
-    {-1}, {-1},
-#line 253 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str99, ei_tis620},
-    {-1}, {-1}, {-1},
+#line 135 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str161, ei_iso8859_10},
 #line 150 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str103, ei_iso8859_14},
-#line 183 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str104, ei_cp1254},
-#line 292 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str105, ei_gb2312},
-#line 357 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str106, ei_cp949},
-    {-1},
-#line 186 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str108, ei_cp1255},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str162, ei_iso8859_14},
+#line 127 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str163, ei_iso8859_9},
+#line 81 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str164, ei_iso8859_4},
+#line 148 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str165, ei_iso8859_14},
+#line 132 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str166, ei_iso8859_10},
+#line 77 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str167, ei_iso8859_3},
     {-1},
-#line 201 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str110, ei_cp862},
-#line 124 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str111, ei_iso8859_9},
+#line 69 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str169, ei_iso8859_2},
+    {-1}, {-1},
 #line 76 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str112, ei_iso8859_3},
-#line 158 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str113, ei_iso8859_15},
-#line 294 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str114, ei_gb2312},
-#line 300 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str115, ei_ksc5601},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str172, ei_iso8859_3},
+#line 249 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str173, ei_tis620},
+#line 277 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str174, ei_jisx0208},
+#line 86 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str175, ei_iso8859_4},
+#line 327 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str176, ei_cp932},
     {-1},
-#line 284 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str117, ei_jisx0212},
+#line 84 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str178, ei_iso8859_4},
     {-1},
-#line 163 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str119, ei_iso8859_16},
-#line 195 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str120, ei_cp1258},
-    {-1}, {-1},
-#line 67 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str123, ei_iso8859_2},
-#line 102 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str124, ei_iso8859_6},
-#line 149 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str125, ei_iso8859_14},
-    {-1}, {-1},
-#line 62 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str128, ei_iso8859_1},
+#line 126 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str180, ei_iso8859_9},
 #line 152 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str129, ei_iso8859_14},
-#line 94 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str130, ei_iso8859_6},
-#line 95 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str131, ei_iso8859_6},
-#line 166 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str132, ei_iso8859_16},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str181, ei_iso8859_14},
     {-1},
-#line 53 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str134, ei_iso8859_1},
+#line 265 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str183, ei_iso646_jp},
+#line 248 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str184, ei_tis620},
 #line 54 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str135, ei_iso8859_1},
-#line 139 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str136, ei_iso8859_11},
-    {-1},
-#line 160 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str138, ei_iso8859_16},
-#line 161 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str139, ei_iso8859_16},
-#line 177 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str140, ei_cp1252},
-    {-1},
-#line 137 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str142, ei_iso8859_11},
-#line 138 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str143, ei_iso8859_11},
-#line 86 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str144, ei_iso8859_4},
-#line 361 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str145, ei_johab},
-#line 162 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str146, ei_iso8859_16},
-#line 209 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str147, ei_cp1131},
-#line 93 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str148, ei_iso8859_5},
-    {-1},
-#line 79 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str150, ei_iso8859_4},
-#line 80 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str151, ei_iso8859_4},
-#line 153 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str152, ei_iso8859_14},
-#line 328 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str153, ei_cp936},
-#line 87 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str154, ei_iso8859_5},
-#line 88 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str155, ei_iso8859_5},
-#line 159 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str156, ei_iso8859_15},
-#line 212 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str157, ei_mac_roman},
-#line 146 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str158, ei_iso8859_14},
-#line 147 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str159, ei_iso8859_14},
-#line 120 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str160, ei_iso8859_8},
-#line 66 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str161, ei_iso8859_2},
-#line 154 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str162, ei_iso8859_15},
-#line 155 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str163, ei_iso8859_15},
-#line 128 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str164, ei_iso8859_9},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str185, ei_java},
+#line 302 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str186, ei_ksc5601},
     {-1},
-#line 114 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str166, ei_iso8859_8},
-#line 115 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str167, ei_iso8859_8},
-    {-1}, {-1},
-#line 121 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str170, ei_iso8859_9},
-#line 122 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str171, ei_iso8859_9},
-#line 148 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str172, ei_iso8859_14},
-#line 234 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str173, ei_pt154},
-#line 156 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str174, ei_iso8859_15},
+#line 341 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str188, ei_euc_cn},
+#line 258 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str189, ei_viscii},
+#line 241 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str190, ei_rk1048},
+#line 260 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str191, ei_viscii},
+#line 255 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str192, ei_tis620},
+#line 82 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str193, ei_iso8859_4},
+#line 149 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str194, ei_iso8859_14},
     {-1},
-#line 239 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str176, ei_rk1048},
-    {-1}, {-1},
-#line 109 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str179, ei_iso8859_7},
-#line 70 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str180, ei_iso8859_2},
-#line 176 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str181, ei_cp1251},
-#line 206 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str182, ei_cp866},
-#line 144 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str183, ei_iso8859_13},
-    {-1}, {-1},
-#line 63 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str186, ei_iso8859_2},
-#line 64 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str187, ei_iso8859_2},
-    {-1}, {-1}, {-1}, {-1}, {-1},
-#line 364 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str193, ei_local_char},
-    {-1}, {-1}, {-1},
-#line 74 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str197, ei_iso8859_3},
-#line 117 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str198, ei_iso8859_8},
-    {-1}, {-1}, {-1},
-#line 13 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str202, ei_ascii},
 #line 167 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str203, ei_koi8_r},
-#line 354 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str204, ei_euc_kr},
-#line 165 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str205, ei_iso8859_16},
-    {-1}, {-1}, {-1},
-#line 313 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str209, ei_cp932},
-#line 353 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str210, ei_euc_kr},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str196, ei_iso8859_16},
     {-1},
-#line 320 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str212, ei_iso2022_jpms},
-    {-1}, {-1}, {-1},
-#line 168 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str216, ei_koi8_r},
-#line 173 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str217, ei_cp1250},
-    {-1}, {-1},
-#line 199 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str220, ei_cp850},
-    {-1}, {-1},
-#line 22 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str223, ei_ascii},
-#line 58 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str224, ei_iso8859_1},
-#line 218 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str225, ei_mac_cyrillic},
-    {-1}, {-1},
-#line 256 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str228, ei_viscii},
+#line 160 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str198, ei_iso8859_15},
+#line 382 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str199, ei_local_char},
+#line 214 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str200, ei_mac_roman},
     {-1}, {-1}, {-1}, {-1},
-#line 259 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str233, ei_tcvn},
-    {-1}, {-1},
-#line 309 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str236, ei_sjis},
-#line 308 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str237, ei_sjis},
-#line 202 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str238, ei_cp862},
-    {-1},
 #line 267 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str240, ei_iso646_jp},
-    {-1},
-#line 254 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str242, ei_cp874},
-#line 323 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str243, ei_euc_cn},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str205, ei_iso646_jp},
+#line 91 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str206, ei_iso8859_5},
     {-1},
+#line 75 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str208, ei_iso8859_3},
+#line 269 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str209, ei_iso646_jp},
 #line 21 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str245, ei_ascii},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str210, ei_ascii},
     {-1},
-#line 258 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str247, ei_viscii},
+#line 58 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str212, ei_iso8859_1},
+#line 111 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str213, ei_iso8859_7},
+#line 287 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str214, ei_jisx0212},
+#line 118 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str215, ei_iso8859_8},
+    {-1},
+#line 208 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str217, ei_cp866},
+    {-1},
+#line 250 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str219, ei_tis620},
+#line 320 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str220, ei_sjis},
+#line 125 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str221, ei_iso8859_9},
+#line 347 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str222, ei_cp936},
     {-1}, {-1},
-#line 197 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str250, ei_cp850},
-#line 82 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str251, ei_iso8859_4},
-#line 346 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str252, ei_cp950},
-#line 233 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str253, ei_koi8_t},
-#line 332 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str254, ei_iso2022_cn},
-#line 266 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str255, ei_iso646_jp},
+#line 204 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str225, ei_cp862},
     {-1},
-#line 237 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str257, ei_pt154},
+#line 334 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str227, ei_iso2022_jp1},
+#line 166 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str228, ei_iso8859_16},
     {-1},
-#line 164 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str259, ei_iso8859_16},
-#line 358 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str260, ei_cp949},
-#line 75 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str261, ei_iso8859_3},
+#line 329 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str230, ei_cp932},
     {-1},
-#line 333 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str263, ei_iso2022_cn},
-#line 131 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str264, ei_iso8859_10},
-    {-1}, {-1},
-#line 211 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str267, ei_mac_roman},
-#line 171 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str268, ei_cp1250},
+#line 335 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str232, ei_iso2022_jp2},
+#line 24 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str233, ei_ucs2},
+#line 317 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str234, ei_cp51932},
     {-1}, {-1},
-#line 135 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str271, ei_iso8859_10},
-#line 312 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str272, ei_sjis},
-#line 142 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str273, ei_iso8859_13},
-#line 329 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str274, ei_cp936},
-#line 61 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str275, ei_iso8859_1},
-#line 247 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str276, ei_tis620},
+#line 377 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str237, ei_cp949},
+    {-1}, {-1}, {-1}, {-1},
+#line 60 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str242, ei_iso8859_1},
     {-1},
-#line 180 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str278, ei_cp1253},
-#line 326 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str279, ei_euc_cn},
+#line 383 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str244, ei_local_wchar_t},
+    {-1}, {-1}, {-1},
+#line 236 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str248, ei_pt154},
+    {-1}, {-1}, {-1},
+#line 83 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str252, ei_iso8859_4},
 #line 38 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str280, ei_utf16},
-#line 334 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str281, ei_iso2022_cn_ext},
-#line 246 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str282, ei_tis620},
-#line 33 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str283, ei_ucs4},
-#line 110 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str284, ei_iso8859_7},
-    {-1}, {-1}, {-1}, {-1}, {-1},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str253, ei_utf16},
 #line 92 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str290, ei_iso8859_5},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str254, ei_iso8859_5},
 #line 85 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str291, ei_iso8859_4},
-    {-1}, {-1}, {-1},
-#line 127 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str295, ei_iso8859_9},
-    {-1}, {-1}, {-1}, {-1},
-#line 235 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str300, ei_pt154},
-#line 35 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str301, ei_ucs4},
-#line 14 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str302, ei_ascii},
-    {-1},
-#line 359 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str304, ei_cp949},
-    {-1}, {-1}, {-1},
-#line 23 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str308, ei_utf8},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str255, ei_iso8859_4},
+    {-1}, {-1}, {-1}, {-1},
+#line 25 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str260, ei_ucs2},
+#line 12 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str261, ei_ascii},
+#line 235 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str262, ei_koi8_t},
     {-1}, {-1},
-#line 297 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str311, ei_ksc5601},
-    {-1}, {-1}, {-1},
-#line 340 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str315, ei_ces_big5},
-#line 136 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str316, ei_iso8859_10},
+#line 41 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str265, ei_utf32},
+    {-1}, {-1},
+#line 357 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str268, ei_euc_tw},
     {-1},
-#line 78 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str318, ei_iso8859_3},
-#line 24 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str319, ei_ucs2},
+#line 154 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str270, ei_iso8859_14},
+#line 63 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str271, ei_iso8859_1},
+#line 23 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str272, ei_utf8},
+#line 137 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str273, ei_iso8859_10},
     {-1},
-#line 341 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str321, ei_ces_big5},
 #line 129 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str322, ei_iso8859_10},
-#line 130 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str323, ei_iso8859_10},
-#line 71 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str324, ei_iso8859_3},
-#line 72 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str325, ei_iso8859_3},
-#line 145 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str326, ei_iso8859_13},
-#line 69 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str327, ei_iso8859_2},
-#line 37 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str328, ei_ucs4le},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str275, ei_iso8859_9},
     {-1},
-#line 241 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str330, ei_rk1048},
-    {-1},
-#line 140 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str332, ei_iso8859_13},
-#line 141 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str333, ei_iso8859_13},
-#line 345 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str334, ei_ces_big5},
-#line 40 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str335, ei_utf16le},
-#line 283 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str336, ei_jisx0212},
-#line 244 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str337, ei_cp1133},
-#line 327 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str338, ei_ces_gbk},
-#line 179 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str339, ei_cp1252},
-#line 344 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str340, ei_ces_big5},
-#line 56 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str341, ei_iso8859_1},
+#line 299 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str277, ei_ksc5601},
+#line 94 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str278, ei_iso8859_5},
+#line 79 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str279, ei_iso8859_3},
+#line 325 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str280, ei_cp932},
+#line 71 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str281, ei_iso8859_2},
+#line 313 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str282, ei_eucjp_ms},
+#line 336 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str283, ei_iso2022_jp2},
+#line 200 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str284, ei_cp850},
     {-1},
-#line 238 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str343, ei_pt154},
+#line 102 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str286, ei_iso8859_6},
+#line 349 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str287, ei_gb18030},
     {-1},
-#line 286 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str345, ei_iso646_cn},
-#line 31 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str346, ei_ucs2le},
+#line 324 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str289, ei_cp932},
     {-1}, {-1}, {-1},
-#line 285 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str350, ei_jisx0212},
-#line 29 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str351, ei_ucs2be},
+#line 177 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str293, ei_cp1251},
+#line 192 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str294, ei_cp1256},
+#line 189 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str295, ei_cp1255},
+#line 253 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str296, ei_tis620},
+#line 183 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str297, ei_cp1253},
+#line 180 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str298, ei_cp1252},
     {-1},
-#line 299 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str353, ei_ksc5601},
+#line 337 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str300, ei_iso2022_jpms},
+#line 226 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str301, ei_mac_thai},
     {-1},
-#line 242 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str355, ei_rk1048},
-#line 257 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str356, ei_viscii},
+#line 34 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str303, ei_ucs4},
+#line 198 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str304, ei_cp1258},
+#line 348 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str305, ei_cp936},
     {-1},
-#line 15 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str358, ei_ascii},
-#line 30 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str359, ei_ucs2be},
-#line 296 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str360, ei_isoir165},
-#line 26 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str361, ei_ucs2},
+#line 251 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str307, ei_tis620},
+#line 316 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str308, ei_cp51932},
     {-1},
-#line 49 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str363, ei_ucs4internal},
-#line 226 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str364, ei_hp_roman8},
-    {-1}, {-1},
-#line 263 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str367, ei_iso646_jp},
-#line 278 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str368, ei_jisx0208},
-    {-1}, {-1},
-#line 302 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str371, ei_ksc5601},
-    {-1}, {-1},
-#line 270 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str374, ei_jisx0201},
+#line 35 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str310, ei_ucs4},
+#line 103 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str311, ei_iso8859_6},
+    {-1},
+#line 328 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str313, ei_cp932},
 #line 243 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str375, ei_mulelao},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str314, ei_rk1048},
+#line 293 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str315, ei_gb2312},
     {-1},
-#line 157 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str377, ei_iso8859_15},
-#line 198 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str378, ei_cp850},
+#line 121 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str317, ei_iso8859_8},
+#line 285 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str318, ei_jisx0212},
+#line 33 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str319, ei_ucs4},
     {-1},
-#line 248 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str380, ei_tis620},
-#line 47 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str381, ei_ucs2internal},
-#line 98 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str382, ei_iso8859_6},
+#line 344 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str321, ei_euc_cn},
+    {-1}, {-1}, {-1}, {-1}, {-1},
+#line 174 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str327, ei_cp1250},
+#line 181 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str328, ei_cp1252},
+    {-1},
+#line 252 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str330, ei_tis620},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-#line 224 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str389, ei_mac_thai},
-#line 111 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str390, ei_iso8859_7},
-#line 230 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str391, ei_armscii_8},
-#line 362 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str392, ei_iso2022_kr},
-    {-1}, {-1}, {-1},
-#line 232 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str396, ei_georgian_ps},
-#line 249 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str397, ei_tis620},
-#line 108 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str398, ei_iso8859_7},
+#line 288 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str337, ei_iso646_cn},
+#line 93 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str338, ei_iso8859_5},
+#line 259 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str339, ei_viscii},
+    {-1},
+#line 186 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str341, ei_cp1254},
+#line 272 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str342, ei_jisx0201},
     {-1}, {-1},
-#line 363 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str401, ei_iso2022_kr},
+#line 232 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str345, ei_armscii_8},
+#line 301 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str346, ei_ksc5601},
+#line 228 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str347, ei_hp_roman8},
     {-1},
-#line 143 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str403, ei_iso8859_13},
+#line 14 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str349, ei_ascii},
+#line 244 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str350, ei_rk1048},
+    {-1}, {-1}, {-1}, {-1},
+#line 319 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str355, ei_sjis},
+    {-1}, {-1}, {-1},
+#line 266 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str359, ei_iso646_jp},
     {-1},
-#line 288 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str405, ei_iso646_cn},
-#line 276 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str406, ei_jisx0208},
-#line 225 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str407, ei_hp_roman8},
-#line 304 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str408, ei_euc_jp},
+#line 206 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str361, ei_cp862},
+    {-1},
+#line 256 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str363, ei_cp874},
+#line 278 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str364, ei_jisx0208},
     {-1}, {-1},
-#line 277 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str411, ei_jisx0208},
+#line 87 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str367, ei_iso8859_4},
+    {-1}, {-1},
+#line 332 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str370, ei_iso2022_jp},
+#line 170 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str371, ei_koi8_r},
+    {-1}, {-1},
+#line 247 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str374, ei_cp1133},
     {-1},
-#line 132 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str413, ei_iso8859_10},
-#line 303 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str414, ei_euc_jp},
+#line 110 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str376, ei_iso8859_7},
     {-1},
-#line 34 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str416, ei_ucs4},
-#line 356 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str417, ei_euc_kr},
-#line 264 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str418, ei_iso646_jp},
+#line 146 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str378, ei_iso8859_13},
     {-1},
-#line 192 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str420, ei_cp1257},
-#line 32 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str421, ei_ucs2le},
-    {-1}, {-1}, {-1}, {-1}, {-1},
-#line 275 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str427, ei_jisx0208},
+#line 169 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str380, ei_koi8_r},
+#line 358 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str381, ei_ces_big5},
     {-1},
-#line 97 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str429, ei_iso8859_6},
+#line 363 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str383, ei_ces_big5},
+#line 318 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str384, ei_sjis},
+    {-1}, {-1},
+#line 322 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str387, ei_sjis},
+#line 213 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str388, ei_mac_roman},
+#line 144 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str389, ei_iso8859_13},
+    {-1}, {-1},
+#line 359 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str392, ei_ces_big5},
+#line 218 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str393, ei_mac_croatian},
+#line 362 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str394, ei_ces_big5},
+#line 237 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str395, ei_pt154},
+    {-1}, {-1},
+#line 296 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str398, ei_gb2312},
+#line 306 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str399, ei_euc_jp},
+#line 343 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str400, ei_euc_cn},
+#line 227 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str401, ei_hp_roman8},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+#line 305 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str410, ei_euc_jp},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+#line 263 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str417, ei_tcvn},
+#line 240 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str418, ei_pt154},
+    {-1},
+#line 309 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str420, ei_euc_jp},
+#line 262 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str421, ei_tcvn},
+#line 333 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str422, ei_iso2022_jp},
+    {-1}, {-1},
 #line 215 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str430, ei_mac_iceland},
-#line 41 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str431, ei_utf32},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str425, ei_mac_roman},
+#line 326 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str426, ei_cp932},
     {-1}, {-1},
-#line 25 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str434, ei_ucs2},
-#line 338 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str435, ei_euc_tw},
-    {-1}, {-1}, {-1}, {-1}, {-1},
-#line 337 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str441, ei_euc_tw},
-#line 291 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str442, ei_gb2312},
-#line 208 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str443, ei_cp866},
+#line 210 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str429, ei_cp866},
     {-1},
-#line 101 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str445, ei_iso8859_6},
+#line 15 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str431, ei_ascii},
+#line 304 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str432, ei_ksc5601},
+#line 380 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str433, ei_iso2022_kr},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+#line 120 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str441, ei_iso8859_8},
     {-1},
-#line 112 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str447, ei_iso8859_7},
-#line 213 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str448, ei_mac_roman},
+#line 30 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str443, ei_ucs2be},
+#line 57 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str444, ei_iso8859_1},
+#line 98 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str445, ei_iso8859_6},
+    {-1}, {-1},
+#line 108 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str448, ei_iso8859_7},
+#line 67 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str449, ei_iso8859_2},
+#line 100 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str450, ei_iso8859_6},
+    {-1}, {-1}, {-1}, {-1}, {-1},
+#line 29 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str456, ei_ucs2be},
+    {-1}, {-1}, {-1}, {-1}, {-1},
+#line 372 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str462, ei_euc_kr},
+#line 354 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str463, ei_hz},
     {-1}, {-1}, {-1},
-#line 355 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str452, ei_euc_kr},
-#line 12 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str453, ei_ascii},
+#line 282 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str467, ei_jisx0212},
+#line 239 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str468, ei_pt154},
+    {-1}, {-1}, {-1}, {-1},
+#line 371 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str473, ei_euc_kr},
+    {-1}, {-1}, {-1}, {-1}, {-1},
+#line 321 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str479, ei_sjis},
     {-1},
-#line 231 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str455, ei_georgian_academy},
-#line 188 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str456, ei_cp1255},
-#line 365 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str457, ei_local_wchar_t},
-#line 43 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str458, ei_utf32le},
+#line 271 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str481, ei_jisx0201},
+    {-1}, {-1}, {-1},
+#line 381 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str485, ei_iso2022_kr},
+    {-1}, {-1}, {-1}, {-1}, {-1},
+#line 270 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str491, ei_jisx0201},
+#line 171 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str492, ei_koi8_u},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+#line 378 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str501, ei_johab},
 #line 331 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str459, ei_gb18030},
-#line 113 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str460, ei_iso8859_7},
-    {-1},
-#line 81 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str462, ei_iso8859_4},
-#line 214 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str463, ei_mac_centraleurope},
-#line 89 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str464, ei_iso8859_5},
-#line 77 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str465, ei_iso8859_3},
-#line 103 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str466, ei_iso8859_7},
-#line 104 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str467, ei_iso8859_7},
-    {-1},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str502, ei_cp932},
+    {-1}, {-1},
+#line 242 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str505, ei_rk1048},
+    {-1}, {-1}, {-1}, {-1}, {-1},
+#line 284 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str511, ei_jisx0212},
 #line 19 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str469, ei_ascii},
-#line 116 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str470, ei_iso8859_8},
-    {-1}, {-1}, {-1},
-#line 123 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str474, ei_iso8859_9},
-    {-1},
-#line 210 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str476, ei_mac_roman},
-#line 119 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str477, ei_iso8859_8},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str512, ei_ascii},
+#line 274 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str513, ei_jisx0208},
+#line 233 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str514, ei_georgian_academy},
+#line 194 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str515, ei_cp1257},
+#line 295 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str516, ei_gb2312},
+#line 264 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str517, ei_tcvn},
     {-1}, {-1}, {-1},
-#line 261 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str481, ei_tcvn},
-#line 305 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str482, ei_euc_jp},
-    {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-#line 240 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str489, ei_rk1048},
-#line 190 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str490, ei_cp1256},
-#line 316 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str491, ei_iso2022_jp1},
+#line 275 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str521, ei_jisx0208},
+    {-1}, {-1},
 #line 175 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str492, ei_cp1251},
-#line 319 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str493, ei_iso2022_jpms},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str524, ei_cp1250},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+#line 212 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str531, ei_mac_roman},
+#line 311 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str532, ei_eucjp_ms},
+    {-1}, {-1}, {-1}, {-1},
+#line 230 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str537, ei_hp_roman8},
     {-1}, {-1}, {-1}, {-1}, {-1},
-#line 260 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str499, ei_tcvn},
-#line 184 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str500, ei_cp1254},
-#line 298 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str501, ei_ksc5601},
-#line 187 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str502, ei_cp1255},
-    {-1},
-#line 325 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str504, ei_euc_cn},
+#line 220 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str543, ei_mac_cyrillic},
+#line 195 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str544, ei_cp1257},
+#line 26 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str545, ei_ucs2},
     {-1}, {-1}, {-1},
-#line 196 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str508, ei_cp1258},
-    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-#line 317 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str517, ei_iso2022_jp2},
 #line 178 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str518, ei_cp1252},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str549, ei_cp1251},
     {-1},
-#line 351 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str520, ei_big5hkscs2008},
-    {-1}, {-1},
-#line 45 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str523, ei_utf7},
+#line 276 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str551, ei_jisx0208},
+#line 345 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str552, ei_ces_gbk},
+    {-1}, {-1}, {-1}, {-1},
+#line 101 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str557, ei_iso8859_6},
     {-1},
-#line 318 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str525, ei_iso2022_jp2},
-#line 350 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str526, ei_big5hkscs2008},
-#line 301 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str527, ei_ksc5601},
-#line 228 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str528, ei_hp_roman8},
-#line 46 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str529, ei_utf7},
-    {-1}, {-1},
-#line 307 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str532, ei_euc_jp},
+#line 115 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str559, ei_iso8859_7},
     {-1},
-#line 336 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str534, ei_hz},
-#line 182 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str535, ei_cp1253},
-    {-1}, {-1}, {-1}, {-1}, {-1},
-#line 220 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str541, ei_mac_greek},
-#line 343 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str542, ei_ces_big5},
-#line 251 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str543, ei_tis620},
-    {-1}, {-1},
-#line 324 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str546, ei_euc_cn},
+#line 298 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str561, ei_isoir165},
     {-1},
-#line 342 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str548, ei_ces_big5},
-#line 73 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str549, ei_iso8859_3},
-    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+#line 31 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str563, ei_ucs2le},
     {-1}, {-1},
-#line 229 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str561, ei_nextstep},
-#line 216 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str562, ei_mac_croatian},
-    {-1},
-#line 330 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str564, ei_cp936},
-    {-1},
-#line 290 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str566, ei_iso646_cn},
-    {-1},
-#line 36 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str568, ei_ucs4be},
-    {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-#line 39 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str575, ei_utf16be},
-    {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-#line 172 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str582, ei_cp1250},
+#line 225 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str566, ei_mac_arabic},
     {-1}, {-1}, {-1},
-#line 27 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str586, ei_ucs2be},
-#line 181 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str587, ei_cp1253},
+#line 105 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str570, ei_iso8859_7},
     {-1}, {-1},
-#line 280 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str590, ei_jisx0212},
+#line 172 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str573, ei_koi8_ru},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+#line 303 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str580, ei_ksc5601},
+    {-1}, {-1},
+#line 300 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str583, ei_ksc5601},
+#line 49 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str584, ei_ucs2internal},
+    {-1}, {-1},
+#line 40 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str587, ei_utf16le},
     {-1}, {-1}, {-1}, {-1},
-#line 293 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str595, ei_gb2312},
+#line 112 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str592, ei_iso8859_7},
+    {-1},
+#line 330 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str594, ei_cp932},
+#line 43 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str595, ei_utf32le},
+#line 219 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str596, ei_mac_romania},
 #line 314 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str596, ei_iso2022_jp},
-#line 20 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str597, ei_ascii},
-#line 245 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str598, ei_cp1133},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str597, ei_eucjp_ms},
+#line 342 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str598, ei_euc_cn},
+#line 106 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str599, ei_iso8859_7},
+#line 373 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str600, ei_euc_kr},
+#line 273 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str601, ei_jisx0201},
     {-1}, {-1}, {-1},
-#line 96 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str602, ei_iso8859_6},
+#line 245 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str605, ei_mulelao},
+#line 37 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str606, ei_ucs4le},
     {-1},
-#line 55 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str604, ei_iso8859_1},
-#line 315 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str605, ei_iso2022_jp},
-    {-1}, {-1},
-#line 44 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str608, ei_utf7},
-#line 204 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str609, ei_cp862},
-    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-#line 100 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str618, ei_iso8859_6},
-    {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-#line 311 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str625, ei_sjis},
+#line 310 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str608, ei_eucjp_ms},
+    {-1}, {-1}, {-1}, {-1},
+#line 290 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str613, ei_iso646_cn},
+#line 134 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str614, ei_iso8859_10},
     {-1}, {-1},
-#line 268 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str628, ei_jisx0201},
-    {-1},
-#line 65 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str630, ei_iso8859_2},
-#line 28 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str631, ei_ucs2be},
+#line 99 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str617, ei_iso8859_6},
     {-1},
-#line 250 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str633, ei_tis620},
+#line 312 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str619, ei_eucjp_ms},
+#line 374 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str620, ei_euc_kr},
     {-1},
-#line 99 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str635, ei_iso8859_6},
-    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
 #line 279 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str643, ei_jisx0208},
-    {-1}, {-1}, {-1}, {-1},
-#line 221 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str648, ei_mac_turkish},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str622, ei_jisx0208},
     {-1}, {-1}, {-1}, {-1},
-#line 255 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str653, ei_cp874},
+#line 51 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str627, ei_ucs4internal},
     {-1}, {-1}, {-1},
+#line 114 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str631, ei_iso8859_7},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+#line 283 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str638, ei_jisx0212},
+    {-1}, {-1}, {-1}, {-1},
+#line 257 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str643, ei_cp874},
+    {-1}, {-1}, {-1}, {-1},
+#line 27 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str648, ei_ucs2be},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
 #line 18 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str657, ei_ascii},
-#line 193 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str658, ei_cp1257},
-    {-1},
-#line 272 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str660, ei_jisx0208},
-#line 269 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str661, ei_jisx0201},
-    {-1},
-#line 169 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str663, ei_koi8_u},
-#line 52 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str664, ei_java},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str656, ei_ascii},
+    {-1}, {-1}, {-1}, {-1},
+#line 145 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str661, ei_iso8859_13},
     {-1}, {-1}, {-1}, {-1},
-#line 170 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str669, ei_koi8_ru},
-    {-1},
-#line 282 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str671, ei_jisx0212},
-    {-1}, {-1}, {-1},
 #line 17 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str675, ei_ascii},
-    {-1},
-#line 118 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str677, ei_iso8859_8},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str666, ei_ascii},
     {-1}, {-1}, {-1}, {-1}, {-1},
-#line 339 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str683, ei_euc_tw},
-    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-#line 271 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str693, ei_jisx0201},
-    {-1}, {-1}, {-1}, {-1},
+#line 39 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str672, ei_utf16be},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
 #line 42 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str698, ei_utf32be},
-#line 106 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str699, ei_iso8859_7},
-    {-1}, {-1}, {-1}, {-1}, {-1},
-#line 200 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str705, ei_cp850},
-    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-    {-1}, {-1}, {-1}, {-1}, {-1},
-#line 185 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str720, ei_cp1254},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str680, ei_utf32be},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+    {-1},
+#line 36 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str691, ei_ucs4be},
+    {-1}, {-1}, {-1},
+#line 107 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str695, ei_iso8859_7},
+    {-1}, {-1},
+#line 46 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str698, ei_utf7},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+    {-1},
+#line 32 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str709, ei_ucs2le},
+#line 20 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str710, ei_ascii},
+    {-1}, {-1},
+#line 45 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str713, ei_utf7},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-    {-1}, {-1}, {-1},
-#line 274 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str751, ei_jisx0208},
-    {-1}, {-1}, {-1}, {-1},
-#line 273 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str756, ei_jisx0208},
-    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+#line 190 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str729, ei_cp1255},
 #line 281 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str764, ei_jisx0212},
-    {-1}, {-1}, {-1}, {-1},
-#line 223 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str769, ei_mac_arabic},
-#line 105 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str770, ei_iso8859_7},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str730, ei_jisx0208},
+    {-1}, {-1}, {-1}, {-1}, {-1},
+#line 292 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str736, ei_iso646_cn},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+#line 224 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str745, ei_mac_hebrew},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-#line 219 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str777, ei_mac_ukraine},
+#line 44 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str752, ei_utf7},
+    {-1}, {-1}, {-1}, {-1}, {-1},
+#line 234 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str758, ei_georgian_ps},
+    {-1}, {-1}, {-1},
+#line 113 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str762, ei_iso8859_7},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-    {-1}, {-1},
-#line 306 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str798, ei_euc_jp},
+    {-1}, {-1}, {-1},
+#line 193 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str784, ei_cp1256},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+#line 223 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str791, ei_mac_turkish},
+    {-1},
+#line 216 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str793, ei_mac_centraleurope},
+    {-1}, {-1}, {-1}, {-1},
+#line 361 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str798, ei_ces_big5},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+    {-1},
+#line 360 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str809, ei_ces_big5},
     {-1}, {-1}, {-1}, {-1}, {-1},
-#line 217 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str813, ei_mac_romania},
-    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+#line 202 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str815, ei_cp850},
     {-1}, {-1}, {-1}, {-1}, {-1},
-#line 348 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str828, ei_big5hkscs2001},
-    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-#line 349 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str836, ei_big5hkscs2004},
-#line 360 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str837, ei_johab},
+#line 231 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str821, ei_nextstep},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-#line 352 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str844, ei_big5hkscs2008},
+#line 50 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str828, ei_ucs2swapped},
+    {-1}, {-1}, {-1}, {-1}, {-1},
+#line 369 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str834, ei_big5hkscs2008},
+    {-1}, {-1},
+#line 187 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str837, ei_cp1254},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+#line 368 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str845, ei_big5hkscs2008},
+    {-1}, {-1},
+#line 217 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str848, ei_mac_iceland},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+#line 221 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str866, ei_mac_ukraine},
+    {-1}, {-1},
+#line 366 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str869, ei_big5hkscs2001},
     {-1},
-#line 347 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str846, ei_big5hkscs1999},
+#line 52 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str871, ei_ucs4swapped},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+#line 370 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str880, ei_big5hkscs2008},
     {-1},
-#line 222 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str848, ei_mac_hebrew},
+#line 196 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str882, ei_cp1257},
+#line 365 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str883, ei_big5hkscs1999},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-    {-1}, {-1}, {-1},
-#line 262 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str879, ei_tcvn},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+#line 367 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str917, ei_big5hkscs2004},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+#line 28 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str971, ei_ucs2be},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-    {-1}, {-1}, {-1}, {-1},
-#line 50 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str893, ei_ucs4swapped},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
 #line 48 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str911, ei_ucs2swapped},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str1016, ei_utf7imap},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-#line 194 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str928, ei_cp1257},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+    {-1}, {-1}, {-1},
+#line 47 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str1038, ei_utf7imap},
+    {-1}, {-1},
+#line 307 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str1041, ei_euc_jp},
+#line 222 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str1042, ei_mac_greek},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+#line 184 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str1052, ei_cp1253},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-#line 191 "lib/aliases_sysosf1.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str981, ei_cp1256}
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+#line 308 "lib/aliases_sysosf1.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str1203, ei_euc_jp}
   };
 
 #ifdef __GNUC__
 __inline
-#if defined __GNUC_STDC_INLINE__ || defined __GNUC_GNU_INLINE__
+#ifdef __GNUC_STDC_INLINE__
 __attribute__ ((__gnu_inline__))
 #endif
 #endif
diff -uprN libiconv-1.15-old/lib/aliases_syssolaris.gperf libiconv-1.15/lib/aliases_syssolaris.gperf
--- libiconv-1.15-old/lib/aliases_syssolaris.gperf	2017-01-02 08:03:16.000000000 +0900
+++ libiconv-1.15/lib/aliases_syssolaris.gperf	2017-09-17 06:32:21.643526000 +0900
@@ -45,6 +45,8 @@ UTF-32LE, ei_utf32le
 UTF-7, ei_utf7
 UNICODE-1-1-UTF-7, ei_utf7
 CSUNICODE11UTF7, ei_utf7
+UTF-7-IMAP, ei_utf7imap
+UTF7IMAP, ei_utf7imap
 UCS-2-INTERNAL, ei_ucs2internal
 UCS-2-SWAPPED, ei_ucs2swapped
 UCS-4-INTERNAL, ei_ucs4internal
@@ -306,6 +308,14 @@ EUC-JP, ei_euc_jp
 EUCJP, ei_euc_jp
 EXTENDED_UNIX_CODE_PACKED_FORMAT_FOR_JAPANESE, ei_euc_jp
 CSEUCPKDFMTJAPANESE, ei_euc_jp
+EUCJP-MS, ei_eucjp_ms
+EUCJP-OPEN, ei_eucjp_ms
+EUC-JP-MS, ei_eucjp_ms
+EUCJP-WIN, ei_eucjp_ms
+EUCJPMS, ei_eucjp_ms
+CP51932, ei_cp51932
+WINDOWS-51932, ei_cp51932
+MS51932, ei_cp51932
 SHIFT_JIS, ei_sjis
 SHIFT-JIS, ei_sjis
 SJIS, ei_sjis
@@ -313,6 +323,14 @@ MS_KANJI, ei_sjis
 CSSHIFTJIS, ei_sjis
 PCK, ei_sjis
 CP932, ei_cp932
+WINDOWS-31J, ei_cp932
+CSWINDOWS31J, ei_cp932
+SJIS-OPEN, ei_cp932
+SJIS-WIN, ei_cp932
+WINDOWS-932, ei_cp932
+MS932, ei_cp932
+SHIFT_JIS-MS, ei_cp932
+SJIS-MS, ei_cp932
 ISO-2022-JP, ei_iso2022_jp
 CSISO2022JP, ei_iso2022_jp
 ISO-2022-JP-1, ei_iso2022_jp1
diff -uprN libiconv-1.15-old/lib/aliases_syssolaris.h libiconv-1.15/lib/aliases_syssolaris.h
--- libiconv-1.15-old/lib/aliases_syssolaris.h	2017-01-02 08:03:16.000000000 +0900
+++ libiconv-1.15/lib/aliases_syssolaris.h	2017-09-17 06:32:21.947612000 +0900
@@ -1,4 +1,4 @@
-/* ANSI-C code produced by gperf version 3.0.4 */
+/* ANSI-C code produced by gperf version 3.0.3 */
 /* Command-line: gperf -m 10 lib/aliases_syssolaris.gperf  */
 /* Computed positions: -k'1,3-11,$' */
 
@@ -32,12 +32,12 @@
 #line 1 "lib/aliases_syssolaris.gperf"
 struct alias { int name; unsigned int encoding_index; };
 
-#define TOTAL_KEYWORDS 356
+#define TOTAL_KEYWORDS 374
 #define MIN_WORD_LENGTH 2
 #define MAX_WORD_LENGTH 45
-#define MIN_HASH_VALUE 8
-#define MAX_HASH_VALUE 956
-/* maximum key range = 949, duplicates = 0 */
+#define MIN_HASH_VALUE 6
+#define MAX_HASH_VALUE 1188
+/* maximum key range = 1183, duplicates = 0 */
 
 #ifdef __GNUC__
 __inline
@@ -51,19 +51,19 @@ aliases_hash (register const char *str,
 {
   static const unsigned short asso_values[] =
     {
-      957, 957, 957, 957, 957, 957, 957, 957, 957, 957,
-      957, 957, 957, 957, 957, 957, 957, 957, 957, 957,
-      957, 957, 957, 957, 957, 957, 957, 957, 957, 957,
-      957, 957, 957, 957, 957, 957, 957, 957, 957, 957,
-      957, 957, 957, 957, 957,  10, 110, 957,  34,   2,
-        8,  85,  31,   4,   3, 170,   6,   7, 192, 957,
-      957, 957, 957, 957, 957,  26, 164,   2,  39,  78,
-      125,  98, 118,   2, 168, 103, 149, 143,   4,   2,
-      139, 957,  40,  64,  28, 123, 106, 162, 190,   5,
-        4, 957, 957, 957, 957,  82, 957, 957, 957, 957,
-      957, 957, 957, 957, 957, 957, 957, 957, 957, 957,
-      957, 957, 957, 957, 957, 957, 957, 957, 957, 957,
-      957, 957, 957, 957, 957, 957, 957, 957
+      1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189,
+      1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189,
+      1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189,
+      1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189,
+      1189, 1189, 1189, 1189, 1189,   10,   43, 1189,   34,    0,
+         5,    4,   48,    2,    1,  171,   11,   14,  202, 1189,
+      1189, 1189, 1189, 1189, 1189,    9,  264,    0,  110,  104,
+       123,   50,   97,    0,    5,  245,  125,  181,    7,    0,
+       138, 1189,   80,   76,   21,  143,  289,   19,  340,    0,
+        15, 1189, 1189, 1189, 1189,   39, 1189, 1189, 1189, 1189,
+      1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189,
+      1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189,
+      1189, 1189, 1189, 1189, 1189, 1189, 1189, 1189
     };
   register int hval = len;
 
@@ -106,1634 +106,1736 @@ aliases_hash (register const char *str,
 
 struct stringpool_t
   {
-    char stringpool_str8[sizeof("CN")];
-    char stringpool_str12[sizeof("646")];
-    char stringpool_str15[sizeof("866")];
-    char stringpool_str19[sizeof("C99")];
-    char stringpool_str22[sizeof("CP866")];
-    char stringpool_str25[sizeof("862")];
-    char stringpool_str26[sizeof("CP1251")];
-    char stringpool_str28[sizeof("CP1256")];
-    char stringpool_str29[sizeof("CP819")];
-    char stringpool_str30[sizeof("CP1255")];
-    char stringpool_str32[sizeof("CP862")];
-    char stringpool_str34[sizeof("CP1258")];
-    char stringpool_str38[sizeof("CP1252")];
-    char stringpool_str39[sizeof("ASCII")];
-    char stringpool_str46[sizeof("5601")];
-    char stringpool_str48[sizeof("R8")];
-    char stringpool_str50[sizeof("ISO8859-1")];
-    char stringpool_str52[sizeof("ISO8859-6")];
-    char stringpool_str53[sizeof("ISO8859-11")];
-    char stringpool_str54[sizeof("ISO8859-5")];
-    char stringpool_str55[sizeof("ISO8859-16")];
-    char stringpool_str57[sizeof("ISO8859-15")];
-    char stringpool_str58[sizeof("ISO8859-8")];
-    char stringpool_str59[sizeof("CP949")];
-    char stringpool_str60[sizeof("ISO8859-9")];
-    char stringpool_str61[sizeof("ISO-8859-1")];
-    char stringpool_str62[sizeof("ISO8859-2")];
-    char stringpool_str63[sizeof("ISO-8859-6")];
-    char stringpool_str64[sizeof("ISO-8859-11")];
-    char stringpool_str65[sizeof("ISO-8859-5")];
-    char stringpool_str66[sizeof("ISO-8859-16")];
-    char stringpool_str67[sizeof("CP50221")];
-    char stringpool_str68[sizeof("ISO-8859-15")];
-    char stringpool_str69[sizeof("ISO-8859-8")];
-    char stringpool_str70[sizeof("ISO646-CN")];
-    char stringpool_str71[sizeof("ISO-8859-9")];
-    char stringpool_str73[sizeof("ISO-8859-2")];
-    char stringpool_str75[sizeof("CP154")];
-    char stringpool_str77[sizeof("850")];
-    char stringpool_str80[sizeof("ISO-IR-6")];
-    char stringpool_str84[sizeof("CP1254")];
-    char stringpool_str85[sizeof("CP850")];
-    char stringpool_str86[sizeof("CP950")];
-    char stringpool_str87[sizeof("ISO-IR-166")];
-    char stringpool_str89[sizeof("ISO-IR-165")];
-    char stringpool_str90[sizeof("CP1250")];
-    char stringpool_str91[sizeof("ISO-IR-58")];
-    char stringpool_str92[sizeof("ISO-IR-126")];
-    char stringpool_str95[sizeof("EUCCN")];
-    char stringpool_str96[sizeof("ISO-IR-159")];
-    char stringpool_str98[sizeof("ISO-IR-226")];
-    char stringpool_str99[sizeof("ISO-IR-199")];
-    char stringpool_str101[sizeof("CP1131")];
-    char stringpool_str102[sizeof("CP1361")];
-    char stringpool_str103[sizeof("ISO-2022-CN")];
-    char stringpool_str105[sizeof("CP936")];
-    char stringpool_str106[sizeof("EUC-CN")];
-    char stringpool_str107[sizeof("CSASCII")];
-    char stringpool_str108[sizeof("ISO8859-4")];
-    char stringpool_str111[sizeof("ISO8859-14")];
-    char stringpool_str112[sizeof("CHAR")];
-    char stringpool_str115[sizeof("CP932")];
-    char stringpool_str116[sizeof("ISO-IR-101")];
-    char stringpool_str117[sizeof("ISO8859-10")];
-    char stringpool_str119[sizeof("ISO-8859-4")];
-    char stringpool_str121[sizeof("ISO-IR-148")];
-    char stringpool_str122[sizeof("ISO-8859-14")];
-    char stringpool_str123[sizeof("ISO-IR-149")];
-    char stringpool_str124[sizeof("HZ")];
-    char stringpool_str125[sizeof("RK1048")];
-    char stringpool_str126[sizeof("ISO-IR-109")];
-    char stringpool_str128[sizeof("ISO-8859-10")];
-    char stringpool_str129[sizeof("ANSI-1251")];
-    char stringpool_str130[sizeof("UHC")];
-    char stringpool_str131[sizeof("ISO-2022-CN-EXT")];
-    char stringpool_str133[sizeof("ISO_8859-1")];
-    char stringpool_str135[sizeof("ISO_8859-6")];
-    char stringpool_str136[sizeof("ISO_8859-11")];
-    char stringpool_str137[sizeof("ISO_8859-5")];
-    char stringpool_str138[sizeof("ISO_8859-16")];
-    char stringpool_str139[sizeof("ISO-IR-14")];
-    char stringpool_str140[sizeof("ISO_8859-15")];
-    char stringpool_str141[sizeof("ISO_8859-8")];
-    char stringpool_str142[sizeof("ISO_8859-16:2001")];
-    char stringpool_str143[sizeof("ISO_8859-9")];
-    char stringpool_str145[sizeof("ISO_8859-2")];
-    char stringpool_str146[sizeof("TCVN")];
-    char stringpool_str147[sizeof("ISO_8859-15:1998")];
-    char stringpool_str148[sizeof("ISO-IR-110")];
-    char stringpool_str149[sizeof("CSISO2022CN")];
-    char stringpool_str150[sizeof("MAC")];
-    char stringpool_str153[sizeof("L1")];
-    char stringpool_str154[sizeof("L6")];
-    char stringpool_str155[sizeof("L5")];
-    char stringpool_str157[sizeof("L8")];
-    char stringpool_str159[sizeof("L2")];
-    char stringpool_str166[sizeof("IBM866")];
-    char stringpool_str171[sizeof("ISO-IR-144")];
-    char stringpool_str173[sizeof("IBM819")];
-    char stringpool_str174[sizeof("ISO_8859-14:1998")];
-    char stringpool_str175[sizeof("ISO-IR-138")];
-    char stringpool_str176[sizeof("IBM862")];
+    char stringpool_str6[sizeof("646")];
+    char stringpool_str9[sizeof("CN")];
+    char stringpool_str10[sizeof("CP1131")];
+    char stringpool_str11[sizeof("CP1361")];
+    char stringpool_str13[sizeof("CP1251")];
+    char stringpool_str14[sizeof("ASCII")];
+    char stringpool_str15[sizeof("CP1256")];
+    char stringpool_str16[sizeof("866")];
+    char stringpool_str17[sizeof("CP1255")];
+    char stringpool_str18[sizeof("CP1133")];
+    char stringpool_str19[sizeof("CP866")];
+    char stringpool_str21[sizeof("CP1253")];
+    char stringpool_str23[sizeof("CP1252")];
+    char stringpool_str24[sizeof("862")];
+    char stringpool_str25[sizeof("CP936")];
+    char stringpool_str27[sizeof("CP862")];
+    char stringpool_str31[sizeof("C99")];
+    char stringpool_str33[sizeof("CP932")];
+    char stringpool_str35[sizeof("CP1258")];
+    char stringpool_str37[sizeof("CP51932")];
+    char stringpool_str40[sizeof("5601")];
+    char stringpool_str44[sizeof("CP819")];
+    char stringpool_str53[sizeof("CP50221")];
+    char stringpool_str57[sizeof("ISO8859-1")];
+    char stringpool_str58[sizeof("ISO8859-11")];
+    char stringpool_str59[sizeof("ISO8859-6")];
+    char stringpool_str60[sizeof("ISO8859-16")];
+    char stringpool_str61[sizeof("ISO8859-5")];
+    char stringpool_str62[sizeof("ISO8859-15")];
+    char stringpool_str65[sizeof("ISO8859-3")];
+    char stringpool_str66[sizeof("ISO8859-13")];
+    char stringpool_str67[sizeof("ISO8859-2")];
+    char stringpool_str68[sizeof("ISO-8859-1")];
+    char stringpool_str69[sizeof("ISO-8859-11")];
+    char stringpool_str70[sizeof("ISO-8859-6")];
+    char stringpool_str71[sizeof("ISO-8859-16")];
+    char stringpool_str72[sizeof("ISO-8859-5")];
+    char stringpool_str73[sizeof("ISO-8859-15")];
+    char stringpool_str75[sizeof("GB2312")];
+    char stringpool_str76[sizeof("ISO-8859-3")];
+    char stringpool_str77[sizeof("ISO-8859-13")];
+    char stringpool_str78[sizeof("ISO-8859-2")];
+    char stringpool_str79[sizeof("ISO8859-8")];
+    char stringpool_str81[sizeof("CP1250")];
+    char stringpool_str82[sizeof("850")];
+    char stringpool_str83[sizeof("ISO646-CN")];
+    char stringpool_str85[sizeof("ISO8859-9")];
+    char stringpool_str86[sizeof("CP850")];
+    char stringpool_str89[sizeof("CP950")];
+    char stringpool_str90[sizeof("ISO-8859-8")];
+    char stringpool_str92[sizeof("CSASCII")];
+    char stringpool_str93[sizeof("R8")];
+    char stringpool_str94[sizeof("ISO-2022-CN")];
+    char stringpool_str95[sizeof("CP949")];
+    char stringpool_str96[sizeof("ISO-8859-9")];
+    char stringpool_str97[sizeof("ISO_8859-1")];
+    char stringpool_str98[sizeof("ISO_8859-11")];
+    char stringpool_str99[sizeof("ISO_8859-6")];
+    char stringpool_str100[sizeof("ISO_8859-16")];
+    char stringpool_str101[sizeof("ISO_8859-5")];
+    char stringpool_str102[sizeof("ISO_8859-15")];
+    char stringpool_str103[sizeof("CP154")];
+    char stringpool_str104[sizeof("ISO_8859-16:2001")];
+    char stringpool_str105[sizeof("ISO_8859-3")];
+    char stringpool_str106[sizeof("ISO_8859-13")];
+    char stringpool_str107[sizeof("ISO_8859-2")];
+    char stringpool_str109[sizeof("CP1254")];
+    char stringpool_str110[sizeof("ISO-IR-6")];
+    char stringpool_str111[sizeof("ANSI-1251")];
+    char stringpool_str112[sizeof("ISO-2022-CN-EXT")];
+    char stringpool_str113[sizeof("ISO-IR-166")];
+    char stringpool_str114[sizeof("HZ")];
+    char stringpool_str115[sizeof("ISO-IR-165")];
+    char stringpool_str116[sizeof("ISO_8859-15:1998")];
+    char stringpool_str117[sizeof("ISO-IR-126")];
+    char stringpool_str119[sizeof("ISO_8859-8")];
+    char stringpool_str122[sizeof("ISO-IR-226")];
+    char stringpool_str123[sizeof("EUCCN")];
+    char stringpool_str125[sizeof("ISO_8859-9")];
+    char stringpool_str126[sizeof("ISO8859-10")];
+    char stringpool_str127[sizeof("L1")];
+    char stringpool_str128[sizeof("L6")];
+    char stringpool_str129[sizeof("L5")];
+    char stringpool_str131[sizeof("L3")];
+    char stringpool_str132[sizeof("L2")];
+    char stringpool_str133[sizeof("ISO-IR-58")];
+    char stringpool_str134[sizeof("EUC-CN")];
+    char stringpool_str136[sizeof("ISO-IR-138")];
+    char stringpool_str137[sizeof("ISO-8859-10")];
+    char stringpool_str138[sizeof("L8")];
+    char stringpool_str140[sizeof("ISO-IR-159")];
+    char stringpool_str141[sizeof("CNS11643")];
+    char stringpool_str142[sizeof("ISO_8859-10:1992")];
+    char stringpool_str144[sizeof("ISO-IR-101")];
+    char stringpool_str145[sizeof("JP")];
+    char stringpool_str146[sizeof("UHC")];
+    char stringpool_str150[sizeof("CSISO2022CN")];
+    char stringpool_str152[sizeof("ISO-IR-199")];
+    char stringpool_str153[sizeof("ISO8859-4")];
+    char stringpool_str154[sizeof("ISO8859-14")];
+    char stringpool_str157[sizeof("ISO-IR-203")];
+    char stringpool_str159[sizeof("LATIN1")];
+    char stringpool_str160[sizeof("JIS_C6226-1983")];
+    char stringpool_str161[sizeof("LATIN6")];
+    char stringpool_str162[sizeof("ISO_8859-14:1998")];
+    char stringpool_str163[sizeof("LATIN5")];
+    char stringpool_str164[sizeof("ISO-8859-4")];
+    char stringpool_str165[sizeof("ISO-8859-14")];
+    char stringpool_str166[sizeof("ISO_8859-10")];
+    char stringpool_str167[sizeof("LATIN3")];
+    char stringpool_str168[sizeof("EUCTW")];
+    char stringpool_str169[sizeof("LATIN2")];
+    char stringpool_str172[sizeof("ISO-IR-109")];
+    char stringpool_str173[sizeof("CHAR")];
+    char stringpool_str174[sizeof("GB18030")];
+    char stringpool_str175[sizeof("L4")];
     char stringpool_str177[sizeof("TIS620")];
-    char stringpool_str179[sizeof("ISO_8859-10:1992")];
-    char stringpool_str180[sizeof("ISO-IR-100")];
-    char stringpool_str182[sizeof("L4")];
-    char stringpool_str183[sizeof("KOI8-T")];
-    char stringpool_str184[sizeof("VISCII")];
+    char stringpool_str178[sizeof("ISO-IR-110")];
+    char stringpool_str179[sizeof("EUC-TW")];
+    char stringpool_str180[sizeof("ISO-IR-148")];
+    char stringpool_str181[sizeof("LATIN8")];
+    char stringpool_str183[sizeof("JIS0208")];
+    char stringpool_str184[sizeof("MAC")];
+    char stringpool_str186[sizeof("ISO-IR-149")];
     char stringpool_str188[sizeof("TIS-620")];
-    char stringpool_str189[sizeof("US")];
-    char stringpool_str190[sizeof("CSVISCII")];
-    char stringpool_str191[sizeof("ISO_8859-4")];
-    char stringpool_str192[sizeof("CP1253")];
-    char stringpool_str193[sizeof("LATIN1")];
+    char stringpool_str190[sizeof("RK1048")];
+    char stringpool_str192[sizeof("JIS_C6220-1969-RO")];
+    char stringpool_str193[sizeof("ISO_8859-4")];
     char stringpool_str194[sizeof("ISO_8859-14")];
-    char stringpool_str195[sizeof("LATIN6")];
-    char stringpool_str196[sizeof("CSKZ1048")];
-    char stringpool_str197[sizeof("LATIN5")];
-    char stringpool_str198[sizeof("SJIS")];
-    char stringpool_str199[sizeof("KZ-1048")];
-    char stringpool_str200[sizeof("ISO_8859-10")];
-    char stringpool_str201[sizeof("LATIN8")];
-    char stringpool_str202[sizeof("CSKOI8R")];
-    char stringpool_str205[sizeof("LATIN2")];
-    char stringpool_str207[sizeof("KOI8-R")];
-    char stringpool_str212[sizeof("PT154")];
-    char stringpool_str214[sizeof("LATIN-9")];
-    char stringpool_str215[sizeof("GB2312")];
-    char stringpool_str216[sizeof("ISO8859-3")];
-    char stringpool_str218[sizeof("UCS-2")];
-    char stringpool_str219[sizeof("ISO8859-13")];
-    char stringpool_str220[sizeof("L10")];
-    char stringpool_str221[sizeof("X0212")];
+    char stringpool_str196[sizeof("L10")];
+    char stringpool_str198[sizeof("LATIN-9")];
+    char stringpool_str201[sizeof("IBM866")];
+    char stringpool_str202[sizeof("GB_2312-80")];
+    char stringpool_str203[sizeof("SJIS-WIN")];
+    char stringpool_str205[sizeof("ISO-IR-14")];
+    char stringpool_str206[sizeof("MS936")];
+    char stringpool_str208[sizeof("TIS620.2533-1")];
+    char stringpool_str209[sizeof("IBM862")];
+    char stringpool_str210[sizeof("TIS620.2533")];
+    char stringpool_str212[sizeof("ISO-IR-100")];
+    char stringpool_str213[sizeof("ELOT_928")];
+    char stringpool_str214[sizeof("MS932")];
+    char stringpool_str218[sizeof("MS51932")];
+    char stringpool_str219[sizeof("TIS620.2529-1")];
+    char stringpool_str221[sizeof("US")];
+    char stringpool_str222[sizeof("CSISO14JISC6220RO")];
     char stringpool_str223[sizeof("TIS620-0")];
-    char stringpool_str225[sizeof("ELOT_928")];
-    char stringpool_str227[sizeof("ISO-8859-3")];
-    char stringpool_str228[sizeof("ARABIC")];
-    char stringpool_str229[sizeof("IBM850")];
-    char stringpool_str230[sizeof("ISO-8859-13")];
-    char stringpool_str231[sizeof("ROMAN8")];
-    char stringpool_str236[sizeof("L3")];
-    char stringpool_str239[sizeof("US-ASCII")];
-    char stringpool_str240[sizeof("KSC_5601")];
-    char stringpool_str241[sizeof("X0201")];
-    char stringpool_str243[sizeof("ISO-10646-UCS-2")];
-    char stringpool_str245[sizeof("CP874")];
-    char stringpool_str246[sizeof("MS936")];
-    char stringpool_str249[sizeof("X0208")];
-    char stringpool_str251[sizeof("LATIN4")];
-    char stringpool_str258[sizeof("MS-ANSI")];
-    char stringpool_str259[sizeof("CSUCS4")];
-    char stringpool_str260[sizeof("LATIN10")];
-    char stringpool_str261[sizeof("KOREAN")];
-    char stringpool_str262[sizeof("ISO-IR-179")];
-    char stringpool_str264[sizeof("UCS-4")];
-    char stringpool_str266[sizeof("ISO-10646-UCS-4")];
-    char stringpool_str267[sizeof("CP1133")];
-    char stringpool_str268[sizeof("EUCKR")];
-    char stringpool_str269[sizeof("CSUNICODE11")];
-    char stringpool_str270[sizeof("ARMSCII-8")];
-    char stringpool_str272[sizeof("UTF-16")];
-    char stringpool_str274[sizeof("BIG5")];
-    char stringpool_str275[sizeof("UTF-8")];
-    char stringpool_str276[sizeof("ISO-2022-KR")];
-    char stringpool_str279[sizeof("EUC-KR")];
-    char stringpool_str280[sizeof("CSBIG5")];
-    char stringpool_str281[sizeof("ECMA-118")];
-    char stringpool_str282[sizeof("CNS11643")];
-    char stringpool_str283[sizeof("UNICODE-1-1")];
-    char stringpool_str285[sizeof("BIG-5")];
-    char stringpool_str287[sizeof("ISO-CELTIC")];
-    char stringpool_str288[sizeof("ISO-IR-203")];
-    char stringpool_str289[sizeof("TIS620.2529-1")];
-    char stringpool_str290[sizeof("MACCROATIAN")];
-    char stringpool_str291[sizeof("CN-BIG5")];
-    char stringpool_str294[sizeof("CSISOLATIN1")];
-    char stringpool_str295[sizeof("GB_1988-80")];
-    char stringpool_str296[sizeof("CSISOLATIN6")];
-    char stringpool_str298[sizeof("CSISOLATIN5")];
-    char stringpool_str299[sizeof("ISO_8859-3")];
-    char stringpool_str300[sizeof("GB18030")];
-    char stringpool_str301[sizeof("CSISOLATINCYRILLIC")];
-    char stringpool_str302[sizeof("ISO_8859-13")];
-    char stringpool_str306[sizeof("CSISOLATIN2")];
-    char stringpool_str307[sizeof("GBK")];
-    char stringpool_str309[sizeof("JP")];
-    char stringpool_str311[sizeof("ISO646-US")];
-    char stringpool_str313[sizeof("CHINESE")];
-    char stringpool_str315[sizeof("VISCII1.1-1")];
-    char stringpool_str321[sizeof("L7")];
-    char stringpool_str322[sizeof("CSISO2022KR")];
-    char stringpool_str323[sizeof("CSISOLATINARABIC")];
-    char stringpool_str327[sizeof("JIS0208")];
-    char stringpool_str328[sizeof("MACTHAI")];
-    char stringpool_str329[sizeof("GEORGIAN-ACADEMY")];
-    char stringpool_str330[sizeof("JAVA")];
-    char stringpool_str331[sizeof("ECMA-114")];
-    char stringpool_str334[sizeof("CSIBM866")];
-    char stringpool_str336[sizeof("ISO_8859-5:1988")];
-    char stringpool_str338[sizeof("ISO_8859-8:1988")];
-    char stringpool_str339[sizeof("CSUNICODE")];
-    char stringpool_str340[sizeof("ISO_8859-9:1989")];
-    char stringpool_str345[sizeof("KS_C_5601-1989")];
-    char stringpool_str346[sizeof("TCVN5712-1")];
-    char stringpool_str348[sizeof("PCK")];
-    char stringpool_str349[sizeof("TCVN-5712")];
-    char stringpool_str352[sizeof("CSISOLATIN4")];
-    char stringpool_str353[sizeof("STRK1048-2002")];
-    char stringpool_str355[sizeof("PTCP154")];
-    char stringpool_str356[sizeof("CYRILLIC")];
-    char stringpool_str358[sizeof("CSISO14JISC6220RO")];
-    char stringpool_str359[sizeof("LATIN3")];
-    char stringpool_str362[sizeof("CP1257")];
+    char stringpool_str224[sizeof("GB_1988-80")];
+    char stringpool_str225[sizeof("ISO-2022-JP-1")];
+    char stringpool_str226[sizeof("IBM819")];
+    char stringpool_str227[sizeof("CSISO159JISX02121990")];
+    char stringpool_str228[sizeof("LATIN10")];
+    char stringpool_str230[sizeof("ISO-2022-JP-2")];
+    char stringpool_str231[sizeof("GEORGIAN-ACADEMY")];
+    char stringpool_str232[sizeof("SJIS")];
+    char stringpool_str241[sizeof("PT154")];
+    char stringpool_str242[sizeof("TIS620.2533-0")];
+    char stringpool_str244[sizeof("UCS-2")];
+    char stringpool_str246[sizeof("US-ASCII")];
+    char stringpool_str249[sizeof("CSISOLATIN1")];
+    char stringpool_str251[sizeof("CSISOLATIN6")];
+    char stringpool_str252[sizeof("CSWINDOWS31J")];
+    char stringpool_str253[sizeof("CSISOLATIN5")];
+    char stringpool_str254[sizeof("ISO-IR-144")];
+    char stringpool_str255[sizeof("LATIN4")];
+    char stringpool_str256[sizeof("CSISOLATINCYRILLIC")];
+    char stringpool_str257[sizeof("CSISOLATIN3")];
+    char stringpool_str259[sizeof("CSISOLATIN2")];
+    char stringpool_str260[sizeof("WINDOWS-1251")];
+    char stringpool_str261[sizeof("WINDOWS-1256")];
+    char stringpool_str262[sizeof("WINDOWS-1255")];
+    char stringpool_str263[sizeof("CSISOLATINARABIC")];
+    char stringpool_str264[sizeof("WINDOWS-1253")];
+    char stringpool_str265[sizeof("WINDOWS-1252")];
+    char stringpool_str266[sizeof("WINDOWS-31J")];
+    char stringpool_str267[sizeof("ISO-10646-UCS-2")];
+    char stringpool_str268[sizeof("IBM850")];
+    char stringpool_str270[sizeof("ISO-CELTIC")];
+    char stringpool_str271[sizeof("WINDOWS-1258")];
+    char stringpool_str272[sizeof("WINDOWS-936")];
+    char stringpool_str275[sizeof("WINDOWS-51932")];
+    char stringpool_str280[sizeof("WINDOWS-932")];
+    char stringpool_str283[sizeof("CP874")];
+    char stringpool_str284[sizeof("UTF-16")];
+    char stringpool_str285[sizeof("CSISO2022JP2")];
+    char stringpool_str288[sizeof("ARABIC")];
+    char stringpool_str290[sizeof("MS-ANSI")];
+    char stringpool_str293[sizeof("WCHAR_T")];
+    char stringpool_str294[sizeof("WINDOWS-1250")];
+    char stringpool_str296[sizeof("UTF-32")];
+    char stringpool_str298[sizeof("L7")];
+    char stringpool_str299[sizeof("EUCJP-WIN")];
+    char stringpool_str302[sizeof("ISO-2022-JP-MS")];
+    char stringpool_str303[sizeof("UTF-8")];
+    char stringpool_str305[sizeof("ROMAN8")];
+    char stringpool_str307[sizeof("ARMSCII-8")];
+    char stringpool_str308[sizeof("WINDOWS-1254")];
+    char stringpool_str309[sizeof("ISO-IR-179")];
+    char stringpool_str310[sizeof("ISO-10646-UCS-4")];
+    char stringpool_str313[sizeof("CSEUCTW")];
+    char stringpool_str314[sizeof("KOI8-T")];
+    char stringpool_str315[sizeof("MACTHAI")];
+    char stringpool_str316[sizeof("JAVA")];
+    char stringpool_str317[sizeof("ISO_8859-5:1988")];
+    char stringpool_str319[sizeof("ISO_8859-3:1988")];
+    char stringpool_str321[sizeof("CSUCS4")];
+    char stringpool_str322[sizeof("BIG5")];
+    char stringpool_str324[sizeof("CSBIG5")];
+    char stringpool_str325[sizeof("MACCROATIAN")];
+    char stringpool_str326[sizeof("ISO_8859-8:1988")];
+    char stringpool_str328[sizeof("TCVN")];
+    char stringpool_str329[sizeof("KSC_5601")];
+    char stringpool_str330[sizeof("UCS-4")];
+    char stringpool_str332[sizeof("ISO_8859-9:1989")];
+    char stringpool_str333[sizeof("BIG-5")];
+    char stringpool_str334[sizeof("ECMA-118")];
+    char stringpool_str335[sizeof("CN-BIG5")];
+    char stringpool_str338[sizeof("CYRILLIC")];
+    char stringpool_str341[sizeof("CSGB2312")];
+    char stringpool_str345[sizeof("CSISOLATIN4")];
+    char stringpool_str347[sizeof("CSPC862LATINHEBREW")];
+    char stringpool_str350[sizeof("ISO646-JP")];
+    char stringpool_str351[sizeof("IBM-CP1133")];
+    char stringpool_str352[sizeof("CP367")];
+    char stringpool_str355[sizeof("CP1257")];
+    char stringpool_str360[sizeof("X0212")];
+    char stringpool_str361[sizeof("ISO-2022-JP")];
     char stringpool_str363[sizeof("ISO_8859-4:1988")];
-    char stringpool_str364[sizeof("HP-ROMAN8")];
-    char stringpool_str365[sizeof("UTF-32")];
-    char stringpool_str371[sizeof("CSISO159JISX02121990")];
-    char stringpool_str372[sizeof("MACROMAN")];
-    char stringpool_str373[sizeof("KOI8-U")];
-    char stringpool_str375[sizeof("GREEK8")];
-    char stringpool_str377[sizeof("GB_2312-80")];
-    char stringpool_str383[sizeof("CSGB2312")];
-    char stringpool_str386[sizeof("ISO8859-7")];
-    char stringpool_str387[sizeof("CSPTCP154")];
-    char stringpool_str392[sizeof("MS-EE")];
-    char stringpool_str395[sizeof("CSEUCKR")];
-    char stringpool_str397[sizeof("ISO-8859-7")];
-    char stringpool_str399[sizeof("ISO_646.IRV:1991")];
-    char stringpool_str400[sizeof("JIS_C6220-1969-RO")];
-    char stringpool_str404[sizeof("ISO-2022-JP-1")];
-    char stringpool_str405[sizeof("ASMO-708")];
-    char stringpool_str406[sizeof("CSKSC56011987")];
-    char stringpool_str410[sizeof("ISO-2022-JP-2")];
-    char stringpool_str412[sizeof("CN-GB-ISOIR165")];
-    char stringpool_str414[sizeof("KOI8-RU")];
-    char stringpool_str416[sizeof("MACARABIC")];
-    char stringpool_str417[sizeof("ISO_8859-3:1988")];
-    char stringpool_str419[sizeof("ISO-IR-57")];
-    char stringpool_str421[sizeof("ISO-IR-87")];
-    char stringpool_str422[sizeof("ISO-IR-157")];
-    char stringpool_str424[sizeof("MACROMANIA")];
-    char stringpool_str426[sizeof("ISO-IR-127")];
-    char stringpool_str435[sizeof("CP367")];
-    char stringpool_str437[sizeof("EUCTW")];
-    char stringpool_str441[sizeof("CSUNICODE11UTF7")];
-    char stringpool_str443[sizeof("CN-GB")];
-    char stringpool_str444[sizeof("TIS620.2533-1")];
-    char stringpool_str448[sizeof("EUC-TW")];
-    char stringpool_str449[sizeof("JIS_C6226-1983")];
-    char stringpool_str455[sizeof("CSISO2022JP2")];
-    char stringpool_str457[sizeof("UNICODE-1-1-UTF-7")];
-    char stringpool_str460[sizeof("CSISOLATIN3")];
-    char stringpool_str464[sizeof("CYRILLIC-ASIAN")];
-    char stringpool_str465[sizeof("GREEK")];
-    char stringpool_str467[sizeof("ISO-2022-JP-MS")];
-    char stringpool_str469[sizeof("ISO_8859-7")];
-    char stringpool_str471[sizeof("WINDOWS-1251")];
-    char stringpool_str472[sizeof("WINDOWS-1256")];
-    char stringpool_str473[sizeof("WINDOWS-1255")];
-    char stringpool_str475[sizeof("WINDOWS-1258")];
-    char stringpool_str476[sizeof("TIS620.2533-0")];
-    char stringpool_str477[sizeof("WINDOWS-1252")];
-    char stringpool_str484[sizeof("CSISO58GB231280")];
-    char stringpool_str490[sizeof("MACINTOSH")];
-    char stringpool_str491[sizeof("WCHAR_T")];
-    char stringpool_str494[sizeof("MACICELAND")];
-    char stringpool_str495[sizeof("CSISOLATINGREEK")];
-    char stringpool_str496[sizeof("CSHPROMAN8")];
-    char stringpool_str498[sizeof("ISO_8859-1:1987")];
-    char stringpool_str499[sizeof("ISO_8859-6:1987")];
-    char stringpool_str500[sizeof("WINDOWS-1254")];
-    char stringpool_str503[sizeof("WINDOWS-1250")];
-    char stringpool_str504[sizeof("ISO_8859-2:1987")];
-    char stringpool_str505[sizeof("MS-CYRL")];
-    char stringpool_str506[sizeof("ISO646-JP")];
-    char stringpool_str508[sizeof("KS_C_5601-1987")];
-    char stringpool_str509[sizeof("MACCYRILLIC")];
-    char stringpool_str517[sizeof("UCS-2LE")];
-    char stringpool_str520[sizeof("CSMACINTOSH")];
-    char stringpool_str521[sizeof("HZ-GB-2312")];
-    char stringpool_str525[sizeof("TIS620.2533")];
-    char stringpool_str529[sizeof("LATIN7")];
-    char stringpool_str530[sizeof("UCS-2-INTERNAL")];
-    char stringpool_str531[sizeof("EUCJP")];
-    char stringpool_str532[sizeof("UCS-2BE")];
-    char stringpool_str534[sizeof("CSISO57GB1988")];
-    char stringpool_str535[sizeof("JISX0201-1976")];
-    char stringpool_str536[sizeof("SHIFT-JIS")];
-    char stringpool_str538[sizeof("MS_KANJI")];
-    char stringpool_str539[sizeof("ISO-2022-JP")];
-    char stringpool_str540[sizeof("UCS-4LE")];
-    char stringpool_str542[sizeof("EUC-JP")];
-    char stringpool_str544[sizeof("UNICODELITTLE")];
-    char stringpool_str545[sizeof("CSPC862LATINHEBREW")];
-    char stringpool_str552[sizeof("WINDOWS-936")];
-    char stringpool_str553[sizeof("UCS-4-INTERNAL")];
-    char stringpool_str554[sizeof("WINDOWS-1253")];
-    char stringpool_str555[sizeof("UCS-4BE")];
-    char stringpool_str557[sizeof("MS-TURK")];
-    char stringpool_str558[sizeof("GEORGIAN-PS")];
-    char stringpool_str564[sizeof("CSEUCTW")];
-    char stringpool_str565[sizeof("IBM-CP1133")];
-    char stringpool_str570[sizeof("MULELAO-1")];
-    char stringpool_str573[sizeof("JIS_X0212")];
-    char stringpool_str575[sizeof("CSISOLATINHEBREW")];
-    char stringpool_str576[sizeof("UTF-16LE")];
-    char stringpool_str579[sizeof("IBM367")];
-    char stringpool_str580[sizeof("MS-ARAB")];
-    char stringpool_str581[sizeof("ISO_8859-7:2003")];
-    char stringpool_str585[sizeof("CSISO2022JP")];
-    char stringpool_str591[sizeof("UTF-16BE")];
-    char stringpool_str593[sizeof("JIS_X0201")];
-    char stringpool_str600[sizeof("MS-HEBR")];
-    char stringpool_str601[sizeof("JIS_X0208")];
-    char stringpool_str603[sizeof("UTF-7")];
-    char stringpool_str608[sizeof("SHIFT_JIS")];
-    char stringpool_str609[sizeof("MACUKRAINE")];
-    char stringpool_str616[sizeof("JIS_X0212-1990")];
-    char stringpool_str618[sizeof("UNICODEBIG")];
-    char stringpool_str619[sizeof("ANSI_X3.4-1986")];
-    char stringpool_str622[sizeof("ANSI_X3.4-1968")];
-    char stringpool_str626[sizeof("TCVN5712-1:1993")];
-    char stringpool_str639[sizeof("WINDOWS-1257")];
-    char stringpool_str644[sizeof("MACCENTRALEUROPE")];
-    char stringpool_str645[sizeof("JOHAB")];
-    char stringpool_str646[sizeof("JIS_X0208-1990")];
-    char stringpool_str647[sizeof("CSSHIFTJIS")];
-    char stringpool_str653[sizeof("MACGREEK")];
-    char stringpool_str658[sizeof("BIGFIVE")];
-    char stringpool_str661[sizeof("MS-GREEK")];
-    char stringpool_str664[sizeof("UTF-32LE")];
-    char stringpool_str666[sizeof("ISO_8859-7:1987")];
-    char stringpool_str669[sizeof("BIG-FIVE")];
-    char stringpool_str676[sizeof("EXTENDED_UNIX_CODE_PACKED_FORMAT_FOR_JAPANESE")];
-    char stringpool_str678[sizeof("NEXTSTEP")];
-    char stringpool_str679[sizeof("UTF-32BE")];
-    char stringpool_str690[sizeof("BIG5HKSCS")];
-    char stringpool_str691[sizeof("CSISO87JISX0208")];
-    char stringpool_str692[sizeof("WINDOWS-874")];
-    char stringpool_str697[sizeof("JIS_X0208-1983")];
-    char stringpool_str701[sizeof("BIG5-HKSCS")];
-    char stringpool_str718[sizeof("JIS_X0212.1990-0")];
-    char stringpool_str730[sizeof("HEBREW")];
-    char stringpool_str751[sizeof("MACTURKISH")];
-    char stringpool_str797[sizeof("UCS-2-SWAPPED")];
-    char stringpool_str798[sizeof("CSPC850MULTILINGUAL")];
-    char stringpool_str814[sizeof("CSHALFWIDTHKATAKANA")];
-    char stringpool_str820[sizeof("UCS-4-SWAPPED")];
-    char stringpool_str836[sizeof("BIG5-HKSCS:2001")];
-    char stringpool_str840[sizeof("BIG5-HKSCS:2008")];
-    char stringpool_str841[sizeof("BIG5-HKSCS:1999")];
-    char stringpool_str865[sizeof("BIG5-HKSCS:2004")];
-    char stringpool_str871[sizeof("WINBALTRIM")];
-    char stringpool_str879[sizeof("CSEUCPKDFMTJAPANESE")];
-    char stringpool_str912[sizeof("KO_KR.JOHAP92")];
-    char stringpool_str956[sizeof("MACHEBREW")];
+    char stringpool_str364[sizeof("ISO646-US")];
+    char stringpool_str366[sizeof("KZ-1048")];
+    char stringpool_str370[sizeof("CSISOLATINHEBREW")];
+    char stringpool_str371[sizeof("VISCII")];
+    char stringpool_str372[sizeof("CSKZ1048")];
+    char stringpool_str373[sizeof("CSVISCII")];
+    char stringpool_str375[sizeof("CSUNICODE11")];
+    char stringpool_str381[sizeof("PTCP154")];
+    char stringpool_str384[sizeof("X0201")];
+    char stringpool_str388[sizeof("UNICODE-1-1")];
+    char stringpool_str390[sizeof("EUCJP")];
+    char stringpool_str396[sizeof("SHIFT-JIS")];
+    char stringpool_str398[sizeof("KS_C_5601-1989")];
+    char stringpool_str399[sizeof("ISO8859-7")];
+    char stringpool_str401[sizeof("EUC-JP")];
+    char stringpool_str402[sizeof("CHINESE")];
+    char stringpool_str404[sizeof("CSPTCP154")];
+    char stringpool_str406[sizeof("X0208")];
+    char stringpool_str408[sizeof("ECMA-114")];
+    char stringpool_str410[sizeof("ISO-8859-7")];
+    char stringpool_str415[sizeof("HP-ROMAN8")];
+    char stringpool_str417[sizeof("CSISO2022JP")];
+    char stringpool_str423[sizeof("CSKOI8R")];
+    char stringpool_str425[sizeof("SHIFT_JIS")];
+    char stringpool_str427[sizeof("SJIS-OPEN")];
+    char stringpool_str429[sizeof("VISCII1.1-1")];
+    char stringpool_str431[sizeof("WINDOWS-1257")];
+    char stringpool_str432[sizeof("KOI8-R")];
+    char stringpool_str435[sizeof("ASMO-708")];
+    char stringpool_str439[sizeof("ISO_8859-7")];
+    char stringpool_str446[sizeof("CYRILLIC-ASIAN")];
+    char stringpool_str453[sizeof("ISO-IR-57")];
+    char stringpool_str454[sizeof("ISO-IR-157")];
+    char stringpool_str457[sizeof("ISO-IR-127")];
+    char stringpool_str458[sizeof("KOREAN")];
+    char stringpool_str460[sizeof("HZ-GB-2312")];
+    char stringpool_str461[sizeof("CSISO58GB231280")];
+    char stringpool_str462[sizeof("ISO-IR-87")];
+    char stringpool_str467[sizeof("CSIBM866")];
+    char stringpool_str473[sizeof("MACROMAN")];
+    char stringpool_str475[sizeof("ISO_8859-1:1987")];
+    char stringpool_str476[sizeof("ISO_8859-6:1987")];
+    char stringpool_str477[sizeof("CSUNICODE")];
+    char stringpool_str479[sizeof("ISO_8859-7:2003")];
+    char stringpool_str480[sizeof("ISO_8859-2:1987")];
+    char stringpool_str484[sizeof("CSSHIFTJIS")];
+    char stringpool_str485[sizeof("ISO-2022-KR")];
+    char stringpool_str486[sizeof("MACROMANIA")];
+    char stringpool_str488[sizeof("MACINTOSH")];
+    char stringpool_str494[sizeof("MS_KANJI")];
+    char stringpool_str499[sizeof("CSMACINTOSH")];
+    char stringpool_str501[sizeof("LATIN7")];
+    char stringpool_str502[sizeof("SJIS-MS")];
+    char stringpool_str506[sizeof("CN-GB-ISOIR165")];
+    char stringpool_str507[sizeof("GEORGIAN-PS")];
+    char stringpool_str508[sizeof("MS-EE")];
+    char stringpool_str514[sizeof("EUCKR")];
+    char stringpool_str515[sizeof("TCVN5712-1")];
+    char stringpool_str517[sizeof("ISO_646.IRV:1991")];
+    char stringpool_str518[sizeof("JIS_X0212")];
+    char stringpool_str519[sizeof("TCVN-5712")];
+    char stringpool_str522[sizeof("MACCYRILLIC")];
+    char stringpool_str523[sizeof("EUCJP-OPEN")];
+    char stringpool_str525[sizeof("EUC-KR")];
+    char stringpool_str528[sizeof("MS-CYRL")];
+    char stringpool_str530[sizeof("WINDOWS-874")];
+    char stringpool_str531[sizeof("GREEK8")];
+    char stringpool_str532[sizeof("JISX0201-1976")];
+    char stringpool_str534[sizeof("IBM367")];
+    char stringpool_str541[sizeof("CSISO2022KR")];
+    char stringpool_str542[sizeof("JIS_X0201")];
+    char stringpool_str543[sizeof("GBK")];
+    char stringpool_str544[sizeof("CSHPROMAN8")];
+    char stringpool_str548[sizeof("CSISOLATINGREEK")];
+    char stringpool_str550[sizeof("CSUNICODE11UTF7")];
+    char stringpool_str552[sizeof("MACARABIC")];
+    char stringpool_str555[sizeof("KS_C_5601-1987")];
+    char stringpool_str556[sizeof("CSKSC56011987")];
+    char stringpool_str558[sizeof("KOI8-U")];
+    char stringpool_str561[sizeof("STRK1048-2002")];
+    char stringpool_str562[sizeof("JIS_X0212-1990")];
+    char stringpool_str563[sizeof("MULELAO-1")];
+    char stringpool_str564[sizeof("JIS_X0208")];
+    char stringpool_str565[sizeof("UNICODE-1-1-UTF-7")];
+    char stringpool_str572[sizeof("JIS_X0208-1983")];
+    char stringpool_str574[sizeof("UCS-2LE")];
+    char stringpool_str584[sizeof("ANSI_X3.4-1986")];
+    char stringpool_str587[sizeof("EUCJPMS")];
+    char stringpool_str589[sizeof("HEBREW")];
+    char stringpool_str593[sizeof("CN-GB")];
+    char stringpool_str594[sizeof("ANSI_X3.4-1968")];
+    char stringpool_str595[sizeof("UCS-2-INTERNAL")];
+    char stringpool_str597[sizeof("JIS_X0212.1990-0")];
+    char stringpool_str598[sizeof("EUCJP-MS")];
+    char stringpool_str601[sizeof("CSISO57GB1988")];
+    char stringpool_str602[sizeof("JIS_X0208-1990")];
+    char stringpool_str609[sizeof("EUC-JP-MS")];
+    char stringpool_str617[sizeof("UCS-4LE")];
+    char stringpool_str618[sizeof("UTF-16LE")];
+    char stringpool_str619[sizeof("SHIFT_JIS-MS")];
+    char stringpool_str623[sizeof("UTF-7")];
+    char stringpool_str626[sizeof("UTF-32LE")];
+    char stringpool_str629[sizeof("CSHALFWIDTHKATAKANA")];
+    char stringpool_str631[sizeof("PCK")];
+    char stringpool_str638[sizeof("UCS-4-INTERNAL")];
+    char stringpool_str639[sizeof("KOI8-RU")];
+    char stringpool_str641[sizeof("UNICODELITTLE")];
+    char stringpool_str644[sizeof("JOHAB")];
+    char stringpool_str646[sizeof("ISO_8859-7:1987")];
+    char stringpool_str656[sizeof("MACICELAND")];
+    char stringpool_str659[sizeof("CSEUCKR")];
+    char stringpool_str705[sizeof("CSISO87JISX0208")];
+    char stringpool_str713[sizeof("UCS-2BE")];
+    char stringpool_str726[sizeof("TCVN5712-1:1993")];
+    char stringpool_str731[sizeof("UNICODEBIG")];
+    char stringpool_str747[sizeof("UCS-2-SWAPPED")];
+    char stringpool_str751[sizeof("MACCENTRALEUROPE")];
+    char stringpool_str753[sizeof("GREEK")];
+    char stringpool_str756[sizeof("UCS-4BE")];
+    char stringpool_str757[sizeof("UTF-16BE")];
+    char stringpool_str765[sizeof("UTF-32BE")];
+    char stringpool_str790[sizeof("UCS-4-SWAPPED")];
+    char stringpool_str799[sizeof("CSPC850MULTILINGUAL")];
+    char stringpool_str823[sizeof("MS-HEBR")];
+    char stringpool_str824[sizeof("MS-ARAB")];
+    char stringpool_str853[sizeof("NEXTSTEP")];
+    char stringpool_str877[sizeof("MACHEBREW")];
+    char stringpool_str883[sizeof("MACUKRAINE")];
+    char stringpool_str895[sizeof("BIG5HKSCS")];
+    char stringpool_str897[sizeof("WINBALTRIM")];
+    char stringpool_str898[sizeof("EXTENDED_UNIX_CODE_PACKED_FORMAT_FOR_JAPANESE")];
+    char stringpool_str906[sizeof("BIG5-HKSCS")];
+    char stringpool_str911[sizeof("UTF7IMAP")];
+    char stringpool_str919[sizeof("KO_KR.JOHAP92")];
+    char stringpool_str932[sizeof("MS-TURK")];
+    char stringpool_str933[sizeof("UTF-7-IMAP")];
+    char stringpool_str941[sizeof("BIGFIVE")];
+    char stringpool_str950[sizeof("MACTURKISH")];
+    char stringpool_str952[sizeof("BIG-FIVE")];
+    char stringpool_str1017[sizeof("MACGREEK")];
+    char stringpool_str1027[sizeof("MS-GREEK")];
+    char stringpool_str1037[sizeof("BIG5-HKSCS:2001")];
+    char stringpool_str1048[sizeof("BIG5-HKSCS:2008")];
+    char stringpool_str1051[sizeof("BIG5-HKSCS:1999")];
+    char stringpool_str1085[sizeof("BIG5-HKSCS:2004")];
+    char stringpool_str1188[sizeof("CSEUCPKDFMTJAPANESE")];
   };
 static const struct stringpool_t stringpool_contents =
   {
-    "CN",
     "646",
-    "866",
-    "C99",
-    "CP866",
-    "862",
+    "CN",
+    "CP1131",
+    "CP1361",
     "CP1251",
+    "ASCII",
     "CP1256",
-    "CP819",
+    "866",
     "CP1255",
+    "CP1133",
+    "CP866",
+    "CP1253",
+    "CP1252",
+    "862",
+    "CP936",
     "CP862",
+    "C99",
+    "CP932",
     "CP1258",
-    "CP1252",
-    "ASCII",
+    "CP51932",
     "5601",
-    "R8",
+    "CP819",
+    "CP50221",
     "ISO8859-1",
-    "ISO8859-6",
     "ISO8859-11",
-    "ISO8859-5",
+    "ISO8859-6",
     "ISO8859-16",
+    "ISO8859-5",
     "ISO8859-15",
-    "ISO8859-8",
-    "CP949",
-    "ISO8859-9",
-    "ISO-8859-1",
+    "ISO8859-3",
+    "ISO8859-13",
     "ISO8859-2",
-    "ISO-8859-6",
+    "ISO-8859-1",
     "ISO-8859-11",
-    "ISO-8859-5",
+    "ISO-8859-6",
     "ISO-8859-16",
-    "CP50221",
+    "ISO-8859-5",
     "ISO-8859-15",
-    "ISO-8859-8",
-    "ISO646-CN",
-    "ISO-8859-9",
+    "GB2312",
+    "ISO-8859-3",
+    "ISO-8859-13",
     "ISO-8859-2",
-    "CP154",
+    "ISO8859-8",
+    "CP1250",
     "850",
-    "ISO-IR-6",
-    "CP1254",
+    "ISO646-CN",
+    "ISO8859-9",
     "CP850",
     "CP950",
-    "ISO-IR-166",
-    "ISO-IR-165",
-    "CP1250",
-    "ISO-IR-58",
-    "ISO-IR-126",
-    "EUCCN",
-    "ISO-IR-159",
-    "ISO-IR-226",
-    "ISO-IR-199",
-    "CP1131",
-    "CP1361",
-    "ISO-2022-CN",
-    "CP936",
-    "EUC-CN",
+    "ISO-8859-8",
     "CSASCII",
-    "ISO8859-4",
-    "ISO8859-14",
-    "CHAR",
-    "CP932",
-    "ISO-IR-101",
-    "ISO8859-10",
-    "ISO-8859-4",
-    "ISO-IR-148",
-    "ISO-8859-14",
-    "ISO-IR-149",
-    "HZ",
-    "RK1048",
-    "ISO-IR-109",
-    "ISO-8859-10",
-    "ANSI-1251",
-    "UHC",
-    "ISO-2022-CN-EXT",
+    "R8",
+    "ISO-2022-CN",
+    "CP949",
+    "ISO-8859-9",
     "ISO_8859-1",
-    "ISO_8859-6",
     "ISO_8859-11",
-    "ISO_8859-5",
+    "ISO_8859-6",
     "ISO_8859-16",
-    "ISO-IR-14",
+    "ISO_8859-5",
     "ISO_8859-15",
-    "ISO_8859-8",
+    "CP154",
     "ISO_8859-16:2001",
-    "ISO_8859-9",
+    "ISO_8859-3",
+    "ISO_8859-13",
     "ISO_8859-2",
-    "TCVN",
+    "CP1254",
+    "ISO-IR-6",
+    "ANSI-1251",
+    "ISO-2022-CN-EXT",
+    "ISO-IR-166",
+    "HZ",
+    "ISO-IR-165",
     "ISO_8859-15:1998",
-    "ISO-IR-110",
-    "CSISO2022CN",
-    "MAC",
+    "ISO-IR-126",
+    "ISO_8859-8",
+    "ISO-IR-226",
+    "EUCCN",
+    "ISO_8859-9",
+    "ISO8859-10",
     "L1",
     "L6",
     "L5",
-    "L8",
+    "L3",
     "L2",
-    "IBM866",
-    "ISO-IR-144",
-    "IBM819",
-    "ISO_8859-14:1998",
+    "ISO-IR-58",
+    "EUC-CN",
     "ISO-IR-138",
-    "IBM862",
-    "TIS620",
+    "ISO-8859-10",
+    "L8",
+    "ISO-IR-159",
+    "CNS11643",
     "ISO_8859-10:1992",
-    "ISO-IR-100",
-    "L4",
-    "KOI8-T",
-    "VISCII",
-    "TIS-620",
-    "US",
-    "CSVISCII",
-    "ISO_8859-4",
-    "CP1253",
+    "ISO-IR-101",
+    "JP",
+    "UHC",
+    "CSISO2022CN",
+    "ISO-IR-199",
+    "ISO8859-4",
+    "ISO8859-14",
+    "ISO-IR-203",
     "LATIN1",
-    "ISO_8859-14",
+    "JIS_C6226-1983",
     "LATIN6",
-    "CSKZ1048",
+    "ISO_8859-14:1998",
     "LATIN5",
-    "SJIS",
-    "KZ-1048",
+    "ISO-8859-4",
+    "ISO-8859-14",
     "ISO_8859-10",
-    "LATIN8",
-    "CSKOI8R",
+    "LATIN3",
+    "EUCTW",
     "LATIN2",
-    "KOI8-R",
-    "PT154",
-    "LATIN-9",
-    "GB2312",
-    "ISO8859-3",
-    "UCS-2",
-    "ISO8859-13",
+    "ISO-IR-109",
+    "CHAR",
+    "GB18030",
+    "L4",
+    "TIS620",
+    "ISO-IR-110",
+    "EUC-TW",
+    "ISO-IR-148",
+    "LATIN8",
+    "JIS0208",
+    "MAC",
+    "ISO-IR-149",
+    "TIS-620",
+    "RK1048",
+    "JIS_C6220-1969-RO",
+    "ISO_8859-4",
+    "ISO_8859-14",
     "L10",
-    "X0212",
-    "TIS620-0",
-    "ELOT_928",
-    "ISO-8859-3",
-    "ARABIC",
-    "IBM850",
-    "ISO-8859-13",
-    "ROMAN8",
-    "L3",
-    "US-ASCII",
-    "KSC_5601",
-    "X0201",
-    "ISO-10646-UCS-2",
-    "CP874",
+    "LATIN-9",
+    "IBM866",
+    "GB_2312-80",
+    "SJIS-WIN",
+    "ISO-IR-14",
     "MS936",
-    "X0208",
-    "LATIN4",
-    "MS-ANSI",
-    "CSUCS4",
-    "LATIN10",
-    "KOREAN",
-    "ISO-IR-179",
-    "UCS-4",
-    "ISO-10646-UCS-4",
-    "CP1133",
-    "EUCKR",
-    "CSUNICODE11",
-    "ARMSCII-8",
-    "UTF-16",
-    "BIG5",
-    "UTF-8",
-    "ISO-2022-KR",
-    "EUC-KR",
-    "CSBIG5",
-    "ECMA-118",
-    "CNS11643",
-    "UNICODE-1-1",
-    "BIG-5",
-    "ISO-CELTIC",
-    "ISO-IR-203",
+    "TIS620.2533-1",
+    "IBM862",
+    "TIS620.2533",
+    "ISO-IR-100",
+    "ELOT_928",
+    "MS932",
+    "MS51932",
     "TIS620.2529-1",
-    "MACCROATIAN",
-    "CN-BIG5",
-    "CSISOLATIN1",
+    "US",
+    "CSISO14JISC6220RO",
+    "TIS620-0",
     "GB_1988-80",
+    "ISO-2022-JP-1",
+    "IBM819",
+    "CSISO159JISX02121990",
+    "LATIN10",
+    "ISO-2022-JP-2",
+    "GEORGIAN-ACADEMY",
+    "SJIS",
+    "PT154",
+    "TIS620.2533-0",
+    "UCS-2",
+    "US-ASCII",
+    "CSISOLATIN1",
     "CSISOLATIN6",
+    "CSWINDOWS31J",
     "CSISOLATIN5",
-    "ISO_8859-3",
-    "GB18030",
+    "ISO-IR-144",
+    "LATIN4",
     "CSISOLATINCYRILLIC",
-    "ISO_8859-13",
+    "CSISOLATIN3",
     "CSISOLATIN2",
-    "GBK",
-    "JP",
-    "ISO646-US",
-    "CHINESE",
-    "VISCII1.1-1",
-    "L7",
-    "CSISO2022KR",
+    "WINDOWS-1251",
+    "WINDOWS-1256",
+    "WINDOWS-1255",
     "CSISOLATINARABIC",
-    "JIS0208",
+    "WINDOWS-1253",
+    "WINDOWS-1252",
+    "WINDOWS-31J",
+    "ISO-10646-UCS-2",
+    "IBM850",
+    "ISO-CELTIC",
+    "WINDOWS-1258",
+    "WINDOWS-936",
+    "WINDOWS-51932",
+    "WINDOWS-932",
+    "CP874",
+    "UTF-16",
+    "CSISO2022JP2",
+    "ARABIC",
+    "MS-ANSI",
+    "WCHAR_T",
+    "WINDOWS-1250",
+    "UTF-32",
+    "L7",
+    "EUCJP-WIN",
+    "ISO-2022-JP-MS",
+    "UTF-8",
+    "ROMAN8",
+    "ARMSCII-8",
+    "WINDOWS-1254",
+    "ISO-IR-179",
+    "ISO-10646-UCS-4",
+    "CSEUCTW",
+    "KOI8-T",
     "MACTHAI",
-    "GEORGIAN-ACADEMY",
     "JAVA",
-    "ECMA-114",
-    "CSIBM866",
     "ISO_8859-5:1988",
+    "ISO_8859-3:1988",
+    "CSUCS4",
+    "BIG5",
+    "CSBIG5",
+    "MACCROATIAN",
     "ISO_8859-8:1988",
-    "CSUNICODE",
+    "TCVN",
+    "KSC_5601",
+    "UCS-4",
     "ISO_8859-9:1989",
-    "KS_C_5601-1989",
-    "TCVN5712-1",
-    "PCK",
-    "TCVN-5712",
-    "CSISOLATIN4",
-    "STRK1048-2002",
-    "PTCP154",
+    "BIG-5",
+    "ECMA-118",
+    "CN-BIG5",
     "CYRILLIC",
-    "CSISO14JISC6220RO",
-    "LATIN3",
+    "CSGB2312",
+    "CSISOLATIN4",
+    "CSPC862LATINHEBREW",
+    "ISO646-JP",
+    "IBM-CP1133",
+    "CP367",
     "CP1257",
+    "X0212",
+    "ISO-2022-JP",
     "ISO_8859-4:1988",
-    "HP-ROMAN8",
-    "UTF-32",
-    "CSISO159JISX02121990",
-    "MACROMAN",
-    "KOI8-U",
-    "GREEK8",
-    "GB_2312-80",
-    "CSGB2312",
+    "ISO646-US",
+    "KZ-1048",
+    "CSISOLATINHEBREW",
+    "VISCII",
+    "CSKZ1048",
+    "CSVISCII",
+    "CSUNICODE11",
+    "PTCP154",
+    "X0201",
+    "UNICODE-1-1",
+    "EUCJP",
+    "SHIFT-JIS",
+    "KS_C_5601-1989",
     "ISO8859-7",
+    "EUC-JP",
+    "CHINESE",
     "CSPTCP154",
-    "MS-EE",
-    "CSEUCKR",
+    "X0208",
+    "ECMA-114",
     "ISO-8859-7",
-    "ISO_646.IRV:1991",
-    "JIS_C6220-1969-RO",
-    "ISO-2022-JP-1",
+    "HP-ROMAN8",
+    "CSISO2022JP",
+    "CSKOI8R",
+    "SHIFT_JIS",
+    "SJIS-OPEN",
+    "VISCII1.1-1",
+    "WINDOWS-1257",
+    "KOI8-R",
     "ASMO-708",
-    "CSKSC56011987",
-    "ISO-2022-JP-2",
-    "CN-GB-ISOIR165",
-    "KOI8-RU",
-    "MACARABIC",
-    "ISO_8859-3:1988",
+    "ISO_8859-7",
+    "CYRILLIC-ASIAN",
     "ISO-IR-57",
-    "ISO-IR-87",
     "ISO-IR-157",
-    "MACROMANIA",
     "ISO-IR-127",
-    "CP367",
-    "EUCTW",
-    "CSUNICODE11UTF7",
-    "CN-GB",
-    "TIS620.2533-1",
-    "EUC-TW",
-    "JIS_C6226-1983",
-    "CSISO2022JP2",
-    "UNICODE-1-1-UTF-7",
-    "CSISOLATIN3",
-    "CYRILLIC-ASIAN",
-    "GREEK",
-    "ISO-2022-JP-MS",
-    "ISO_8859-7",
-    "WINDOWS-1251",
-    "WINDOWS-1256",
-    "WINDOWS-1255",
-    "WINDOWS-1258",
-    "TIS620.2533-0",
-    "WINDOWS-1252",
+    "KOREAN",
+    "HZ-GB-2312",
     "CSISO58GB231280",
-    "MACINTOSH",
-    "WCHAR_T",
-    "MACICELAND",
-    "CSISOLATINGREEK",
-    "CSHPROMAN8",
+    "ISO-IR-87",
+    "CSIBM866",
+    "MACROMAN",
     "ISO_8859-1:1987",
     "ISO_8859-6:1987",
-    "WINDOWS-1254",
-    "WINDOWS-1250",
+    "CSUNICODE",
+    "ISO_8859-7:2003",
     "ISO_8859-2:1987",
-    "MS-CYRL",
-    "ISO646-JP",
-    "KS_C_5601-1987",
-    "MACCYRILLIC",
-    "UCS-2LE",
+    "CSSHIFTJIS",
+    "ISO-2022-KR",
+    "MACROMANIA",
+    "MACINTOSH",
+    "MS_KANJI",
     "CSMACINTOSH",
-    "HZ-GB-2312",
-    "TIS620.2533",
     "LATIN7",
-    "UCS-2-INTERNAL",
-    "EUCJP",
-    "UCS-2BE",
-    "CSISO57GB1988",
-    "JISX0201-1976",
-    "SHIFT-JIS",
-    "MS_KANJI",
-    "ISO-2022-JP",
-    "UCS-4LE",
-    "EUC-JP",
-    "UNICODELITTLE",
-    "CSPC862LATINHEBREW",
-    "WINDOWS-936",
-    "UCS-4-INTERNAL",
-    "WINDOWS-1253",
-    "UCS-4BE",
-    "MS-TURK",
+    "SJIS-MS",
+    "CN-GB-ISOIR165",
     "GEORGIAN-PS",
-    "CSEUCTW",
-    "IBM-CP1133",
-    "MULELAO-1",
+    "MS-EE",
+    "EUCKR",
+    "TCVN5712-1",
+    "ISO_646.IRV:1991",
     "JIS_X0212",
-    "CSISOLATINHEBREW",
-    "UTF-16LE",
+    "TCVN-5712",
+    "MACCYRILLIC",
+    "EUCJP-OPEN",
+    "EUC-KR",
+    "MS-CYRL",
+    "WINDOWS-874",
+    "GREEK8",
+    "JISX0201-1976",
     "IBM367",
-    "MS-ARAB",
-    "ISO_8859-7:2003",
-    "CSISO2022JP",
-    "UTF-16BE",
+    "CSISO2022KR",
     "JIS_X0201",
-    "MS-HEBR",
-    "JIS_X0208",
-    "UTF-7",
-    "SHIFT_JIS",
-    "MACUKRAINE",
+    "GBK",
+    "CSHPROMAN8",
+    "CSISOLATINGREEK",
+    "CSUNICODE11UTF7",
+    "MACARABIC",
+    "KS_C_5601-1987",
+    "CSKSC56011987",
+    "KOI8-U",
+    "STRK1048-2002",
     "JIS_X0212-1990",
-    "UNICODEBIG",
+    "MULELAO-1",
+    "JIS_X0208",
+    "UNICODE-1-1-UTF-7",
+    "JIS_X0208-1983",
+    "UCS-2LE",
     "ANSI_X3.4-1986",
+    "EUCJPMS",
+    "HEBREW",
+    "CN-GB",
     "ANSI_X3.4-1968",
-    "TCVN5712-1:1993",
-    "WINDOWS-1257",
-    "MACCENTRALEUROPE",
-    "JOHAB",
+    "UCS-2-INTERNAL",
+    "JIS_X0212.1990-0",
+    "EUCJP-MS",
+    "CSISO57GB1988",
     "JIS_X0208-1990",
-    "CSSHIFTJIS",
-    "MACGREEK",
-    "BIGFIVE",
-    "MS-GREEK",
+    "EUC-JP-MS",
+    "UCS-4LE",
+    "UTF-16LE",
+    "SHIFT_JIS-MS",
+    "UTF-7",
     "UTF-32LE",
+    "CSHALFWIDTHKATAKANA",
+    "PCK",
+    "UCS-4-INTERNAL",
+    "KOI8-RU",
+    "UNICODELITTLE",
+    "JOHAB",
     "ISO_8859-7:1987",
-    "BIG-FIVE",
-    "EXTENDED_UNIX_CODE_PACKED_FORMAT_FOR_JAPANESE",
-    "NEXTSTEP",
+    "MACICELAND",
+    "CSEUCKR",
+    "CSISO87JISX0208",
+    "UCS-2BE",
+    "TCVN5712-1:1993",
+    "UNICODEBIG",
+    "UCS-2-SWAPPED",
+    "MACCENTRALEUROPE",
+    "GREEK",
+    "UCS-4BE",
+    "UTF-16BE",
     "UTF-32BE",
+    "UCS-4-SWAPPED",
+    "CSPC850MULTILINGUAL",
+    "MS-HEBR",
+    "MS-ARAB",
+    "NEXTSTEP",
+    "MACHEBREW",
+    "MACUKRAINE",
     "BIG5HKSCS",
-    "CSISO87JISX0208",
-    "WINDOWS-874",
-    "JIS_X0208-1983",
+    "WINBALTRIM",
+    "EXTENDED_UNIX_CODE_PACKED_FORMAT_FOR_JAPANESE",
     "BIG5-HKSCS",
-    "JIS_X0212.1990-0",
-    "HEBREW",
+    "UTF7IMAP",
+    "KO_KR.JOHAP92",
+    "MS-TURK",
+    "UTF-7-IMAP",
+    "BIGFIVE",
     "MACTURKISH",
-    "UCS-2-SWAPPED",
-    "CSPC850MULTILINGUAL",
-    "CSHALFWIDTHKATAKANA",
-    "UCS-4-SWAPPED",
+    "BIG-FIVE",
+    "MACGREEK",
+    "MS-GREEK",
     "BIG5-HKSCS:2001",
     "BIG5-HKSCS:2008",
     "BIG5-HKSCS:1999",
     "BIG5-HKSCS:2004",
-    "WINBALTRIM",
-    "CSEUCPKDFMTJAPANESE",
-    "KO_KR.JOHAP92",
-    "MACHEBREW"
+    "CSEUCPKDFMTJAPANESE"
   };
 #define stringpool ((const char *) &stringpool_contents)
 
 static const struct alias aliases[] =
   {
-    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-#line 291 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str8, ei_iso646_cn},
-    {-1}, {-1}, {-1},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
 #line 23 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str12, ei_ascii},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str6, ei_ascii},
     {-1}, {-1},
+#line 293 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str9, ei_iso646_cn},
+#line 213 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str10, ei_cp1131},
+#line 380 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str11, ei_johab},
+    {-1},
+#line 177 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str13, ei_cp1251},
+#line 13 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str14, ei_ascii},
+#line 193 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str15, ei_cp1256},
+#line 211 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str16, ei_cp866},
+#line 190 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str17, ei_cp1255},
+#line 248 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str18, ei_cp1133},
 #line 209 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str15, ei_cp866},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str19, ei_cp866},
+    {-1},
+#line 184 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str21, ei_cp1253},
+    {-1},
+#line 181 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str23, ei_cp1252},
+#line 207 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str24, ei_cp862},
+#line 347 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str25, ei_cp936},
+    {-1},
+#line 205 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str27, ei_cp862},
     {-1}, {-1}, {-1},
-#line 52 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str19, ei_c99},
+#line 54 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str31, ei_c99},
+    {-1},
+#line 325 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str33, ei_cp932},
+    {-1},
+#line 199 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str35, ei_cp1258},
+    {-1},
+#line 316 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str37, ei_cp51932},
     {-1}, {-1},
-#line 207 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str22, ei_cp866},
+#line 376 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str40, ei_euc_kr},
+    {-1}, {-1}, {-1},
+#line 60 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str44, ei_iso8859_1},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+#line 340 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str53, ei_iso2022_jpms},
+    {-1}, {-1}, {-1},
+#line 65 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str57, ei_iso8859_1},
+#line 142 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str58, ei_iso8859_11},
+#line 105 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str59, ei_iso8859_6},
+#line 169 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str60, ei_iso8859_16},
+#line 96 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str61, ei_iso8859_5},
+#line 162 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str62, ei_iso8859_15},
     {-1}, {-1},
-#line 205 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str25, ei_cp862},
-#line 175 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str26, ei_cp1251},
+#line 81 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str65, ei_iso8859_3},
+#line 148 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str66, ei_iso8859_13},
+#line 73 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str67, ei_iso8859_2},
+#line 56 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str68, ei_iso8859_1},
+#line 140 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str69, ei_iso8859_11},
+#line 97 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str70, ei_iso8859_6},
+#line 163 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str71, ei_iso8859_16},
+#line 90 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str72, ei_iso8859_5},
+#line 157 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str73, ei_iso8859_15},
     {-1},
-#line 191 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str28, ei_cp1256},
-#line 58 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str29, ei_iso8859_1},
-#line 188 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str30, ei_cp1255},
+#line 343 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str75, ei_euc_cn},
+#line 74 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str76, ei_iso8859_3},
+#line 143 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str77, ei_iso8859_13},
+#line 66 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str78, ei_iso8859_2},
+#line 123 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str79, ei_iso8859_8},
     {-1},
+#line 174 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str81, ei_cp1250},
 #line 203 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str32, ei_cp862},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str82, ei_cp850},
+#line 291 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str83, ei_iso646_cn},
+    {-1},
+#line 131 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str85, ei_iso8859_9},
+#line 201 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str86, ei_cp850},
+    {-1}, {-1},
+#line 366 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str89, ei_cp950},
+#line 117 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str90, ei_iso8859_8},
+    {-1},
+#line 22 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str92, ei_ascii},
+#line 231 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str93, ei_hp_roman8},
+#line 351 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str94, ei_iso2022_cn},
+#line 377 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str95, ei_cp949},
+#line 124 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str96, ei_iso8859_9},
+#line 57 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str97, ei_iso8859_1},
+#line 141 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str98, ei_iso8859_11},
+#line 98 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str99, ei_iso8859_6},
+#line 164 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str100, ei_iso8859_16},
+#line 91 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str101, ei_iso8859_5},
+#line 158 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str102, ei_iso8859_15},
+#line 240 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str103, ei_pt154},
+#line 165 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str104, ei_iso8859_16},
+#line 75 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str105, ei_iso8859_3},
+#line 144 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str106, ei_iso8859_13},
+#line 67 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str107, ei_iso8859_2},
     {-1},
-#line 197 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str34, ei_cp1258},
-    {-1}, {-1}, {-1},
-#line 179 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str38, ei_cp1252},
-#line 13 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str39, ei_ascii},
-    {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-#line 358 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str46, ei_euc_kr},
+#line 187 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str109, ei_cp1254},
+#line 16 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str110, ei_ascii},
+#line 180 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str111, ei_cp1251},
+#line 353 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str112, ei_iso2022_cn_ext},
+#line 256 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str113, ei_tis620},
+#line 354 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str114, ei_hz},
+#line 299 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str115, ei_isoir165},
+#line 159 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str116, ei_iso8859_15},
+#line 110 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str117, ei_iso8859_7},
     {-1},
-#line 229 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str48, ei_hp_roman8},
+#line 118 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str119, ei_iso8859_8},
+    {-1}, {-1},
+#line 166 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str122, ei_iso8859_16},
+#line 342 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str123, ei_euc_cn},
     {-1},
+#line 125 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str125, ei_iso8859_9},
+#line 139 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str126, ei_iso8859_10},
 #line 63 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str50, ei_iso8859_1},
-    {-1},
-#line 103 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str52, ei_iso8859_6},
-#line 140 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str53, ei_iso8859_11},
-#line 94 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str54, ei_iso8859_5},
-#line 167 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str55, ei_iso8859_16},
-    {-1},
-#line 160 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str57, ei_iso8859_15},
-#line 121 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str58, ei_iso8859_8},
-#line 359 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str59, ei_cp949},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str127, ei_iso8859_1},
+#line 137 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str128, ei_iso8859_10},
 #line 129 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str60, ei_iso8859_9},
-#line 54 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str61, ei_iso8859_1},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str129, ei_iso8859_9},
+    {-1},
+#line 79 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str131, ei_iso8859_3},
 #line 71 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str62, ei_iso8859_2},
-#line 95 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str63, ei_iso8859_6},
-#line 138 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str64, ei_iso8859_11},
-#line 88 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str65, ei_iso8859_5},
-#line 161 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str66, ei_iso8859_16},
-#line 322 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str67, ei_iso2022_jpms},
-#line 155 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str68, ei_iso8859_15},
-#line 115 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str69, ei_iso8859_8},
-#line 289 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str70, ei_iso646_cn},
-#line 122 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str71, ei_iso8859_9},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str132, ei_iso8859_2},
+#line 296 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str133, ei_gb2312},
+#line 341 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str134, ei_euc_cn},
     {-1},
-#line 64 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str73, ei_iso8859_2},
+#line 120 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str136, ei_iso8859_8},
+#line 132 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str137, ei_iso8859_10},
+#line 154 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str138, ei_iso8859_14},
     {-1},
-#line 238 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str75, ei_pt154},
+#line 288 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str140, ei_jisx0212},
+#line 359 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str141, ei_euc_tw},
+#line 134 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str142, ei_iso8859_10},
     {-1},
-#line 201 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str77, ei_cp850},
-    {-1}, {-1},
-#line 16 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str80, ei_ascii},
+#line 69 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str144, ei_iso8859_2},
+#line 270 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str145, ei_iso646_jp},
+#line 378 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str146, ei_cp949},
     {-1}, {-1}, {-1},
-#line 185 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str84, ei_cp1254},
-#line 199 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str85, ei_cp850},
-#line 348 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str86, ei_cp950},
-#line 254 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str87, ei_tis620},
+#line 352 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str150, ei_iso2022_cn},
     {-1},
-#line 297 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str89, ei_isoir165},
-#line 172 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str90, ei_cp1250},
-#line 294 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str91, ei_gb2312},
-#line 108 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str92, ei_iso8859_7},
+#line 152 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str152, ei_iso8859_14},
+#line 89 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str153, ei_iso8859_4},
+#line 156 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str154, ei_iso8859_14},
     {-1}, {-1},
-#line 324 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str95, ei_euc_cn},
-#line 286 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str96, ei_jisx0212},
-    {-1},
-#line 164 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str98, ei_iso8859_16},
-#line 150 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str99, ei_iso8859_14},
-    {-1},
-#line 211 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str101, ei_cp1131},
-#line 362 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str102, ei_johab},
-#line 333 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str103, ei_iso2022_cn},
+#line 160 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str157, ei_iso8859_15},
     {-1},
-#line 329 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str105, ei_cp936},
-#line 323 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str106, ei_euc_cn},
-#line 22 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str107, ei_ascii},
-#line 87 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str108, ei_iso8859_4},
-    {-1}, {-1},
-#line 154 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str111, ei_iso8859_14},
-#line 366 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str112, ei_local_char},
+#line 62 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str159, ei_iso8859_1},
+#line 282 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str160, ei_jisx0208},
+#line 136 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str161, ei_iso8859_10},
+#line 151 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str162, ei_iso8859_14},
+#line 128 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str163, ei_iso8859_9},
+#line 82 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str164, ei_iso8859_4},
+#line 149 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str165, ei_iso8859_14},
+#line 133 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str166, ei_iso8859_10},
+#line 78 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str167, ei_iso8859_3},
+#line 357 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str168, ei_euc_tw},
+#line 70 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str169, ei_iso8859_2},
     {-1}, {-1},
-#line 315 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str115, ei_cp932},
-#line 67 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str116, ei_iso8859_2},
-#line 137 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str117, ei_iso8859_10},
+#line 77 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str172, ei_iso8859_3},
+#line 384 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str173, ei_local_char},
+#line 350 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str174, ei_gb18030},
+#line 87 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str175, ei_iso8859_4},
     {-1},
-#line 80 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str119, ei_iso8859_4},
+#line 251 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str177, ei_tis620},
+#line 85 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str178, ei_iso8859_4},
+#line 356 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str179, ei_euc_tw},
+#line 127 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str180, ei_iso8859_9},
+#line 153 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str181, ei_iso8859_14},
     {-1},
-#line 125 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str121, ei_iso8859_9},
-#line 147 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str122, ei_iso8859_14},
-#line 302 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str123, ei_ksc5601},
-#line 336 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str124, ei_hz},
-#line 241 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str125, ei_rk1048},
-#line 75 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str126, ei_iso8859_3},
+#line 279 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str183, ei_jisx0208},
+#line 216 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str184, ei_mac_roman},
     {-1},
-#line 130 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str128, ei_iso8859_10},
-#line 178 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str129, ei_cp1251},
-#line 360 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str130, ei_cp949},
-#line 335 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str131, ei_iso2022_cn_ext},
+#line 304 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str186, ei_ksc5601},
     {-1},
-#line 55 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str133, ei_iso8859_1},
+#line 250 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str188, ei_tis620},
     {-1},
-#line 96 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str135, ei_iso8859_6},
-#line 139 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str136, ei_iso8859_11},
-#line 89 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str137, ei_iso8859_5},
-#line 162 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str138, ei_iso8859_16},
-#line 267 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str139, ei_iso646_jp},
-#line 156 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str140, ei_iso8859_15},
-#line 116 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str141, ei_iso8859_8},
-#line 163 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str142, ei_iso8859_16},
-#line 123 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str143, ei_iso8859_9},
+#line 243 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str190, ei_rk1048},
     {-1},
-#line 65 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str145, ei_iso8859_2},
-#line 261 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str146, ei_tcvn},
-#line 157 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str147, ei_iso8859_15},
+#line 267 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str192, ei_iso646_jp},
 #line 83 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str148, ei_iso8859_4},
-#line 334 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str149, ei_iso2022_cn},
-#line 214 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str150, ei_mac_roman},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str193, ei_iso8859_4},
+#line 150 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str194, ei_iso8859_14},
+    {-1},
+#line 168 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str196, ei_iso8859_16},
+    {-1},
+#line 161 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str198, ei_iso8859_15},
     {-1}, {-1},
-#line 61 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str153, ei_iso8859_1},
-#line 135 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str154, ei_iso8859_10},
-#line 127 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str155, ei_iso8859_9},
+#line 210 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str201, ei_cp866},
+#line 295 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str202, ei_gb2312},
+#line 329 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str203, ei_cp932},
     {-1},
-#line 152 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str157, ei_iso8859_14},
+#line 269 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str205, ei_iso646_jp},
+#line 348 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str206, ei_cp936},
     {-1},
-#line 69 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str159, ei_iso8859_2},
-    {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-#line 208 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str166, ei_cp866},
-    {-1}, {-1}, {-1}, {-1},
-#line 91 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str171, ei_iso8859_5},
+#line 255 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str208, ei_tis620},
+#line 206 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str209, ei_cp862},
+#line 257 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str210, ei_tis620},
     {-1},
 #line 59 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str173, ei_iso8859_1},
-#line 149 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str174, ei_iso8859_14},
-#line 118 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str175, ei_iso8859_8},
-#line 204 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str176, ei_cp862},
-#line 249 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str177, ei_tis620},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str212, ei_iso8859_1},
+#line 112 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str213, ei_iso8859_7},
+#line 331 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str214, ei_cp932},
+    {-1}, {-1}, {-1},
+#line 318 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str218, ei_cp51932},
+#line 253 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str219, ei_tis620},
     {-1},
-#line 132 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str179, ei_iso8859_10},
-#line 57 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str180, ei_iso8859_1},
+#line 21 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str221, ei_ascii},
+#line 271 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str222, ei_iso646_jp},
+#line 252 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str223, ei_tis620},
+#line 290 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str224, ei_iso646_cn},
+#line 336 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str225, ei_iso2022_jp1},
+#line 61 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str226, ei_iso8859_1},
+#line 289 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str227, ei_jisx0212},
+#line 167 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str228, ei_iso8859_16},
     {-1},
-#line 85 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str182, ei_iso8859_4},
+#line 337 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str230, ei_iso2022_jp2},
 #line 235 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str183, ei_koi8_t},
-#line 258 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str184, ei_viscii},
-    {-1}, {-1}, {-1},
-#line 248 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str188, ei_tis620},
-#line 21 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str189, ei_ascii},
-#line 260 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str190, ei_viscii},
-#line 81 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str191, ei_iso8859_4},
-#line 182 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str192, ei_cp1253},
-#line 60 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str193, ei_iso8859_1},
-#line 148 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str194, ei_iso8859_14},
-#line 134 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str195, ei_iso8859_10},
-#line 244 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str196, ei_rk1048},
-#line 126 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str197, ei_iso8859_9},
-#line 311 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str198, ei_sjis},
-#line 243 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str199, ei_rk1048},
-#line 131 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str200, ei_iso8859_10},
-#line 151 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str201, ei_iso8859_14},
-#line 169 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str202, ei_koi8_r},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str231, ei_georgian_academy},
+#line 321 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str232, ei_sjis},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+#line 238 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str241, ei_pt154},
+#line 254 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str242, ei_tis620},
+    {-1},
+#line 25 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str244, ei_ucs2},
+    {-1},
+#line 12 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str246, ei_ascii},
     {-1}, {-1},
-#line 68 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str205, ei_iso8859_2},
+#line 64 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str249, ei_iso8859_1},
     {-1},
-#line 168 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str207, ei_koi8_r},
-    {-1}, {-1}, {-1}, {-1},
-#line 236 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str212, ei_pt154},
+#line 138 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str251, ei_iso8859_10},
+#line 327 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str252, ei_cp932},
+#line 130 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str253, ei_iso8859_9},
+#line 93 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str254, ei_iso8859_5},
+#line 86 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str255, ei_iso8859_4},
+#line 95 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str256, ei_iso8859_5},
+#line 80 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str257, ei_iso8859_3},
     {-1},
-#line 159 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str214, ei_iso8859_15},
-#line 325 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str215, ei_euc_cn},
-#line 79 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str216, ei_iso8859_3},
+#line 72 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str259, ei_iso8859_2},
+#line 178 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str260, ei_cp1251},
+#line 194 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str261, ei_cp1256},
+#line 191 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str262, ei_cp1255},
+#line 104 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str263, ei_iso8859_6},
+#line 185 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str264, ei_cp1253},
+#line 182 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str265, ei_cp1252},
+#line 326 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str266, ei_cp932},
+#line 26 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str267, ei_ucs2},
+#line 202 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str268, ei_cp850},
     {-1},
-#line 25 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str218, ei_ucs2},
-#line 146 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str219, ei_iso8859_13},
-#line 166 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str220, ei_iso8859_16},
-#line 285 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str221, ei_jisx0212},
+#line 155 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str270, ei_iso8859_14},
+#line 200 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str271, ei_cp1258},
+#line 349 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str272, ei_cp936},
+    {-1}, {-1},
+#line 317 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str275, ei_cp51932},
+    {-1}, {-1}, {-1}, {-1},
+#line 330 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str280, ei_cp932},
+    {-1}, {-1},
+#line 258 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str283, ei_cp874},
+#line 39 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str284, ei_utf16},
+#line 338 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str285, ei_iso2022_jp2},
+    {-1}, {-1},
+#line 103 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str288, ei_iso8859_6},
     {-1},
-#line 250 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str223, ei_tis620},
+#line 183 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str290, ei_cp1252},
+    {-1}, {-1},
+#line 385 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str293, ei_local_wchar_t},
+#line 175 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str294, ei_cp1250},
     {-1},
-#line 110 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str225, ei_iso8859_7},
+#line 42 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str296, ei_utf32},
     {-1},
-#line 72 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str227, ei_iso8859_3},
-#line 101 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str228, ei_iso8859_6},
-#line 200 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str229, ei_cp850},
-#line 141 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str230, ei_iso8859_13},
-#line 228 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str231, ei_hp_roman8},
-    {-1}, {-1}, {-1}, {-1},
-#line 77 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str236, ei_iso8859_3},
+#line 147 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str298, ei_iso8859_13},
+#line 314 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str299, ei_eucjp_ms},
     {-1}, {-1},
-#line 12 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str239, ei_ascii},
-#line 299 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str240, ei_ksc5601},
-#line 272 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str241, ei_jisx0201},
+#line 339 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str302, ei_iso2022_jpms},
+#line 24 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str303, ei_utf8},
     {-1},
-#line 26 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str243, ei_ucs2},
+#line 230 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str305, ei_hp_roman8},
     {-1},
-#line 256 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str245, ei_cp874},
-#line 330 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str246, ei_cp936},
+#line 234 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str307, ei_armscii_8},
+#line 188 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str308, ei_cp1254},
+#line 145 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str309, ei_iso8859_13},
+#line 35 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str310, ei_ucs4},
     {-1}, {-1},
-#line 278 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str249, ei_jisx0208},
+#line 358 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str313, ei_euc_tw},
+#line 237 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str314, ei_koi8_t},
+#line 228 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str315, ei_mac_thai},
+#line 55 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str316, ei_java},
+#line 92 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str317, ei_iso8859_5},
     {-1},
-#line 84 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str251, ei_iso8859_4},
-    {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-#line 181 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str258, ei_cp1252},
-#line 36 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str259, ei_ucs4},
-#line 165 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str260, ei_iso8859_16},
-#line 304 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str261, ei_ksc5601},
-#line 143 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str262, ei_iso8859_13},
+#line 76 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str319, ei_iso8859_3},
     {-1},
-#line 34 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str264, ei_ucs4},
+#line 36 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str321, ei_ucs4},
+#line 360 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str322, ei_ces_big5},
     {-1},
-#line 35 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str266, ei_ucs4},
-#line 246 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str267, ei_cp1133},
-#line 356 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str268, ei_euc_kr},
-#line 31 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str269, ei_ucs2be},
-#line 232 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str270, ei_armscii_8},
+#line 365 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str324, ei_ces_big5},
+#line 220 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str325, ei_mac_croatian},
+#line 119 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str326, ei_iso8859_8},
     {-1},
-#line 39 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str272, ei_utf16},
+#line 263 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str328, ei_tcvn},
+#line 301 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str329, ei_ksc5601},
+#line 34 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str330, ei_ucs4},
     {-1},
-#line 342 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str274, ei_ces_big5},
-#line 24 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str275, ei_utf8},
+#line 126 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str332, ei_iso8859_9},
+#line 361 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str333, ei_ces_big5},
+#line 111 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str334, ei_iso8859_7},
 #line 364 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str276, ei_iso2022_kr},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str335, ei_ces_big5},
     {-1}, {-1},
-#line 355 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str279, ei_euc_kr},
-#line 347 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str280, ei_ces_big5},
-#line 109 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str281, ei_iso8859_7},
-#line 341 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str282, ei_euc_tw},
-#line 30 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str283, ei_ucs2be},
-    {-1},
-#line 343 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str285, ei_ces_big5},
-    {-1},
-#line 153 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str287, ei_iso8859_14},
-#line 158 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str288, ei_iso8859_15},
-#line 251 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str289, ei_tis620},
-#line 218 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str290, ei_mac_croatian},
-#line 346 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str291, ei_ces_big5},
+#line 94 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str338, ei_iso8859_5},
     {-1}, {-1},
-#line 62 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str294, ei_iso8859_1},
-#line 288 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str295, ei_iso646_cn},
-#line 136 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str296, ei_iso8859_10},
-    {-1},
-#line 128 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str298, ei_iso8859_9},
-#line 73 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str299, ei_iso8859_3},
-#line 332 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str300, ei_gb18030},
-#line 93 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str301, ei_iso8859_5},
-#line 142 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str302, ei_iso8859_13},
+#line 345 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str341, ei_euc_cn},
     {-1}, {-1}, {-1},
-#line 70 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str306, ei_iso8859_2},
-#line 328 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str307, ei_ces_gbk},
+#line 88 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str345, ei_iso8859_4},
     {-1},
+#line 208 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str347, ei_cp862},
+    {-1}, {-1},
 #line 268 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str309, ei_iso646_jp},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str350, ei_iso646_jp},
+#line 249 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str351, ei_cp1133},
+#line 19 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str352, ei_ascii},
+    {-1}, {-1},
+#line 196 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str355, ei_cp1257},
+    {-1}, {-1}, {-1}, {-1},
+#line 287 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str360, ei_jisx0212},
+#line 334 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str361, ei_iso2022_jp},
     {-1},
+#line 84 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str363, ei_iso8859_4},
 #line 14 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str311, ei_ascii},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str364, ei_ascii},
     {-1},
-#line 296 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str313, ei_gb2312},
+#line 245 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str366, ei_rk1048},
+    {-1}, {-1}, {-1},
+#line 122 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str370, ei_iso8859_8},
+#line 260 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str371, ei_viscii},
+#line 246 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str372, ei_rk1048},
+#line 262 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str373, ei_viscii},
     {-1},
-#line 259 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str315, ei_viscii},
+#line 31 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str375, ei_ucs2be},
     {-1}, {-1}, {-1}, {-1}, {-1},
-#line 145 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str321, ei_iso8859_13},
-#line 365 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str322, ei_iso2022_kr},
-#line 102 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str323, ei_iso8859_6},
-    {-1}, {-1}, {-1},
-#line 277 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str327, ei_jisx0208},
-#line 226 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str328, ei_mac_thai},
-#line 233 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str329, ei_georgian_academy},
-#line 53 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str330, ei_java},
-#line 99 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str331, ei_iso8859_6},
+#line 239 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str381, ei_pt154},
     {-1}, {-1},
-#line 210 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str334, ei_cp866},
+#line 274 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str384, ei_jisx0201},
+    {-1}, {-1}, {-1},
+#line 30 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str388, ei_ucs2be},
     {-1},
-#line 90 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str336, ei_iso8859_5},
+#line 308 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str390, ei_euc_jp},
+    {-1}, {-1}, {-1}, {-1}, {-1},
+#line 320 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str396, ei_sjis},
     {-1},
-#line 117 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str338, ei_iso8859_8},
-#line 27 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str339, ei_ucs2},
-#line 124 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str340, ei_iso8859_9},
-    {-1}, {-1}, {-1}, {-1},
-#line 301 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str345, ei_ksc5601},
-#line 263 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str346, ei_tcvn},
+#line 303 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str398, ei_ksc5601},
+#line 116 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str399, ei_iso8859_7},
     {-1},
-#line 314 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str348, ei_sjis},
-#line 262 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str349, ei_tcvn},
-    {-1}, {-1},
-#line 86 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str352, ei_iso8859_4},
-#line 242 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str353, ei_rk1048},
+#line 307 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str401, ei_euc_jp},
+#line 298 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str402, ei_gb2312},
     {-1},
-#line 237 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str355, ei_pt154},
-#line 92 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str356, ei_iso8859_5},
+#line 242 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str404, ei_pt154},
     {-1},
-#line 269 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str358, ei_iso646_jp},
-#line 76 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str359, ei_iso8859_3},
-    {-1}, {-1},
-#line 194 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str362, ei_cp1257},
-#line 82 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str363, ei_iso8859_4},
-#line 227 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str364, ei_hp_roman8},
-#line 42 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str365, ei_utf32},
-    {-1}, {-1}, {-1}, {-1}, {-1},
-#line 287 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str371, ei_jisx0212},
-#line 212 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str372, ei_mac_roman},
-#line 170 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str373, ei_koi8_u},
+#line 280 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str406, ei_jisx0208},
     {-1},
-#line 111 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str375, ei_iso8859_7},
+#line 101 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str408, ei_iso8859_6},
     {-1},
-#line 293 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str377, ei_gb2312},
-    {-1}, {-1}, {-1}, {-1}, {-1},
-#line 327 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str383, ei_euc_cn},
-    {-1}, {-1},
-#line 114 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str386, ei_iso8859_7},
-#line 240 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str387, ei_pt154},
+#line 106 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str410, ei_iso8859_7},
     {-1}, {-1}, {-1}, {-1},
-#line 174 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str392, ei_cp1250},
-    {-1}, {-1},
-#line 357 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str395, ei_euc_kr},
+#line 229 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str415, ei_hp_roman8},
     {-1},
-#line 104 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str397, ei_iso8859_7},
+#line 335 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str417, ei_iso2022_jp},
+    {-1}, {-1}, {-1}, {-1}, {-1},
+#line 171 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str423, ei_koi8_r},
     {-1},
-#line 15 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str399, ei_ascii},
-#line 265 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str400, ei_iso646_jp},
-    {-1}, {-1}, {-1},
-#line 318 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str404, ei_iso2022_jp1},
-#line 100 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str405, ei_iso8859_6},
-#line 303 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str406, ei_ksc5601},
-    {-1}, {-1}, {-1},
 #line 319 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str410, ei_iso2022_jp2},
-    {-1},
-#line 298 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str412, ei_isoir165},
-    {-1},
-#line 171 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str414, ei_koi8_ru},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str425, ei_sjis},
     {-1},
-#line 225 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str416, ei_mac_arabic},
-#line 74 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str417, ei_iso8859_3},
+#line 328 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str427, ei_cp932},
     {-1},
-#line 290 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str419, ei_iso646_cn},
+#line 261 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str429, ei_viscii},
     {-1},
-#line 279 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str421, ei_jisx0208},
-#line 133 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str422, ei_iso8859_10},
+#line 197 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str431, ei_cp1257},
+#line 170 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str432, ei_koi8_r},
+    {-1}, {-1},
+#line 102 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str435, ei_iso8859_6},
+    {-1}, {-1}, {-1},
+#line 107 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str439, ei_iso8859_7},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+#line 241 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str446, ei_pt154},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+#line 292 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str453, ei_iso646_cn},
+#line 135 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str454, ei_iso8859_10},
+    {-1}, {-1},
+#line 100 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str457, ei_iso8859_6},
+#line 306 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str458, ei_ksc5601},
     {-1},
-#line 219 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str424, ei_mac_romania},
+#line 355 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str460, ei_hz},
+#line 297 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str461, ei_gb2312},
+#line 281 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str462, ei_jisx0208},
+    {-1}, {-1}, {-1}, {-1},
+#line 212 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str467, ei_cp866},
+    {-1}, {-1}, {-1}, {-1}, {-1},
+#line 214 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str473, ei_mac_roman},
     {-1},
-#line 98 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str426, ei_iso8859_6},
-    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-#line 19 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str435, ei_ascii},
+#line 58 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str475, ei_iso8859_1},
+#line 99 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str476, ei_iso8859_6},
+#line 27 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str477, ei_ucs2},
     {-1},
-#line 339 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str437, ei_euc_tw},
+#line 109 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str479, ei_iso8859_7},
+#line 68 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str480, ei_iso8859_2},
     {-1}, {-1}, {-1},
-#line 47 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str441, ei_utf7},
+#line 323 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str484, ei_sjis},
+#line 382 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str485, ei_iso2022_kr},
+#line 221 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str486, ei_mac_romania},
     {-1},
-#line 326 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str443, ei_euc_cn},
-#line 253 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str444, ei_tis620},
+#line 215 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str488, ei_mac_roman},
+    {-1}, {-1}, {-1}, {-1}, {-1},
+#line 322 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str494, ei_sjis},
+    {-1}, {-1}, {-1}, {-1},
+#line 217 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str499, ei_mac_roman},
+    {-1},
+#line 146 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str501, ei_iso8859_13},
+#line 333 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str502, ei_cp932},
     {-1}, {-1}, {-1},
-#line 338 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str448, ei_euc_tw},
-#line 280 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str449, ei_jisx0208},
+#line 300 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str506, ei_isoir165},
+#line 236 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str507, ei_georgian_ps},
+#line 176 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str508, ei_cp1250},
     {-1}, {-1}, {-1}, {-1}, {-1},
-#line 320 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str455, ei_iso2022_jp2},
+#line 374 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str514, ei_euc_kr},
+#line 265 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str515, ei_tcvn},
+    {-1},
+#line 15 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str517, ei_ascii},
+#line 284 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str518, ei_jisx0212},
+#line 264 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str519, ei_tcvn},
+    {-1}, {-1},
+#line 222 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str522, ei_mac_cyrillic},
+#line 312 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str523, ei_eucjp_ms},
     {-1},
-#line 46 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str457, ei_utf7},
+#line 373 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str525, ei_euc_kr},
     {-1}, {-1},
-#line 78 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str460, ei_iso8859_3},
-    {-1}, {-1}, {-1},
-#line 239 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str464, ei_pt154},
-#line 112 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str465, ei_iso8859_7},
+#line 179 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str528, ei_cp1251},
     {-1},
-#line 321 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str467, ei_iso2022_jpms},
+#line 259 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str530, ei_cp874},
+#line 113 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str531, ei_iso8859_7},
+#line 273 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str532, ei_jisx0201},
     {-1},
-#line 105 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str469, ei_iso8859_7},
+#line 20 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str534, ei_ascii},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+#line 383 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str541, ei_iso2022_kr},
+#line 272 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str542, ei_jisx0201},
+#line 346 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str543, ei_ces_gbk},
+#line 232 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str544, ei_hp_roman8},
+    {-1}, {-1}, {-1},
+#line 115 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str548, ei_iso8859_7},
     {-1},
-#line 176 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str471, ei_cp1251},
-#line 192 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str472, ei_cp1256},
-#line 189 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str473, ei_cp1255},
+#line 47 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str550, ei_utf7},
     {-1},
-#line 198 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str475, ei_cp1258},
-#line 252 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str476, ei_tis620},
-#line 180 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str477, ei_cp1252},
-    {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-#line 295 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str484, ei_gb2312},
-    {-1}, {-1}, {-1}, {-1}, {-1},
-#line 213 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str490, ei_mac_roman},
-#line 367 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str491, ei_local_wchar_t},
+#line 227 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str552, ei_mac_arabic},
     {-1}, {-1},
-#line 217 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str494, ei_mac_iceland},
-#line 113 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str495, ei_iso8859_7},
-#line 230 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str496, ei_hp_roman8},
+#line 302 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str555, ei_ksc5601},
+#line 305 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str556, ei_ksc5601},
     {-1},
-#line 56 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str498, ei_iso8859_1},
-#line 97 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str499, ei_iso8859_6},
-#line 186 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str500, ei_cp1254},
+#line 172 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str558, ei_koi8_u},
     {-1}, {-1},
-#line 173 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str503, ei_cp1250},
-#line 66 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str504, ei_iso8859_2},
-#line 177 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str505, ei_cp1251},
-#line 266 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str506, ei_iso646_jp},
+#line 244 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str561, ei_rk1048},
+#line 286 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str562, ei_jisx0212},
+#line 247 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str563, ei_mulelao},
+#line 276 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str564, ei_jisx0208},
+#line 46 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str565, ei_utf7},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+#line 277 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str572, ei_jisx0208},
     {-1},
-#line 300 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str508, ei_ksc5601},
-#line 220 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str509, ei_mac_cyrillic},
-    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
 #line 32 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str517, ei_ucs2le},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str574, ei_ucs2le},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+#line 18 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str584, ei_ascii},
     {-1}, {-1},
-#line 215 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str520, ei_mac_roman},
-#line 337 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str521, ei_hz},
-    {-1}, {-1}, {-1},
-#line 255 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str525, ei_tis620},
-    {-1}, {-1}, {-1},
-#line 144 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str529, ei_iso8859_13},
-#line 48 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str530, ei_ucs2internal},
-#line 306 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str531, ei_euc_jp},
-#line 28 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str532, ei_ucs2be},
-    {-1},
-#line 292 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str534, ei_iso646_cn},
-#line 271 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str535, ei_jisx0201},
-#line 310 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str536, ei_sjis},
-    {-1},
-#line 312 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str538, ei_sjis},
-#line 316 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str539, ei_iso2022_jp},
-#line 38 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str540, ei_ucs4le},
-    {-1},
-#line 305 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str542, ei_euc_jp},
+#line 315 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str587, ei_eucjp_ms},
     {-1},
-#line 33 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str544, ei_ucs2le},
-#line 206 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str545, ei_cp862},
-    {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-#line 331 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str552, ei_cp936},
+#line 121 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str589, ei_iso8859_8},
+    {-1}, {-1}, {-1},
+#line 344 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str593, ei_euc_cn},
+#line 17 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str594, ei_ascii},
 #line 50 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str553, ei_ucs4internal},
-#line 183 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str554, ei_cp1253},
-#line 37 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str555, ei_ucs4be},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str595, ei_ucs2internal},
     {-1},
-#line 187 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str557, ei_cp1254},
-#line 234 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str558, ei_georgian_ps},
-    {-1}, {-1}, {-1}, {-1}, {-1},
-#line 340 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str564, ei_euc_tw},
-#line 247 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str565, ei_cp1133},
-    {-1}, {-1}, {-1}, {-1},
-#line 245 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str570, ei_mulelao},
+#line 285 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str597, ei_jisx0212},
+#line 311 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str598, ei_eucjp_ms},
     {-1}, {-1},
-#line 282 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str573, ei_jisx0212},
-    {-1},
-#line 120 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str575, ei_iso8859_8},
+#line 294 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str601, ei_iso646_cn},
+#line 278 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str602, ei_jisx0208},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+#line 313 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str609, ei_eucjp_ms},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+#line 38 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str617, ei_ucs4le},
 #line 41 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str576, ei_utf16le},
-    {-1}, {-1},
-#line 20 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str579, ei_ascii},
-#line 193 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str580, ei_cp1256},
-#line 107 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str581, ei_iso8859_7},
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str618, ei_utf16le},
+#line 332 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str619, ei_cp932},
     {-1}, {-1}, {-1},
-#line 317 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str585, ei_iso2022_jp},
-    {-1}, {-1}, {-1}, {-1}, {-1},
-#line 40 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str591, ei_utf16be},
+#line 45 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str623, ei_utf7},
+    {-1}, {-1},
+#line 44 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str626, ei_utf32le},
+    {-1}, {-1},
+#line 275 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str629, ei_jisx0201},
     {-1},
-#line 270 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str593, ei_jisx0201},
+#line 324 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str631, ei_sjis},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-#line 190 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str600, ei_cp1255},
-#line 274 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str601, ei_jisx0208},
+#line 52 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str638, ei_ucs4internal},
+#line 173 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str639, ei_koi8_ru},
     {-1},
-#line 45 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str603, ei_utf7},
-    {-1}, {-1}, {-1}, {-1},
-#line 309 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str608, ei_sjis},
-#line 221 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str609, ei_mac_ukraine},
-    {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-#line 284 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str616, ei_jisx0212},
+#line 33 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str641, ei_ucs2le},
+    {-1}, {-1},
+#line 379 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str644, ei_johab},
     {-1},
-#line 29 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str618, ei_ucs2be},
-#line 18 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str619, ei_ascii},
+#line 108 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str646, ei_iso8859_7},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+#line 219 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str656, ei_mac_iceland},
     {-1}, {-1},
-#line 17 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str622, ei_ascii},
-    {-1}, {-1}, {-1},
-#line 264 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str626, ei_tcvn},
+#line 375 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str659, ei_euc_kr},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+#line 283 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str705, ei_jisx0208},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+#line 28 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str713, ei_ucs2be},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
     {-1}, {-1}, {-1},
-#line 195 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str639, ei_cp1257},
-    {-1}, {-1}, {-1}, {-1},
-#line 216 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str644, ei_mac_centraleurope},
-#line 361 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str645, ei_johab},
-#line 276 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str646, ei_jisx0208},
-#line 313 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str647, ei_sjis},
-    {-1}, {-1}, {-1}, {-1}, {-1},
-#line 222 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str653, ei_mac_greek},
+#line 266 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str726, ei_tcvn},
     {-1}, {-1}, {-1}, {-1},
-#line 345 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str658, ei_ces_big5},
-    {-1}, {-1},
-#line 184 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str661, ei_cp1253},
-    {-1}, {-1},
-#line 44 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str664, ei_utf32le},
+#line 29 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str731, ei_ucs2be},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+#line 51 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str747, ei_ucs2swapped},
+    {-1}, {-1}, {-1},
+#line 218 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str751, ei_mac_centraleurope},
     {-1},
-#line 106 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str666, ei_iso8859_7},
+#line 114 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str753, ei_iso8859_7},
     {-1}, {-1},
-#line 344 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str669, ei_ces_big5},
+#line 37 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str756, ei_ucs4be},
+#line 40 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str757, ei_utf16be},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+#line 43 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str765, ei_utf32be},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-#line 307 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str676, ei_euc_jp},
+#line 53 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str790, ei_ucs4swapped},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+#line 204 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str799, ei_cp850},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+    {-1}, {-1}, {-1}, {-1}, {-1},
+#line 192 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str823, ei_cp1255},
+#line 195 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str824, ei_cp1256},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
     {-1},
-#line 231 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str678, ei_nextstep},
-#line 43 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str679, ei_utf32be},
+#line 233 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str853, ei_nextstep},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+    {-1}, {-1}, {-1}, {-1}, {-1},
+#line 226 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str877, ei_mac_hebrew},
+    {-1}, {-1}, {-1}, {-1}, {-1},
+#line 223 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str883, ei_mac_ukraine},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+    {-1}, {-1},
+#line 371 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str895, ei_big5hkscs2008},
     {-1},
-#line 353 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str690, ei_big5hkscs2008},
-#line 281 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str691, ei_jisx0208},
-#line 257 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str692, ei_cp874},
+#line 198 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str897, ei_cp1257},
+#line 309 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str898, ei_euc_jp},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+#line 370 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str906, ei_big5hkscs2008},
     {-1}, {-1}, {-1}, {-1},
-#line 275 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str697, ei_jisx0208},
-    {-1}, {-1}, {-1},
-#line 352 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str701, ei_big5hkscs2008},
+#line 49 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str911, ei_utf7imap},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+#line 381 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str919, ei_johab},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+    {-1}, {-1}, {-1},
+#line 189 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str932, ei_cp1254},
+#line 48 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str933, ei_utf7imap},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-#line 283 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str718, ei_jisx0212},
+#line 363 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str941, ei_ces_big5},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+#line 225 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str950, ei_mac_turkish},
+    {-1},
+#line 362 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str952, ei_ces_big5},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-    {-1}, {-1},
-#line 119 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str730, ei_iso8859_8},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-    {-1}, {-1},
-#line 223 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str751, ei_mac_turkish},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+    {-1},
+#line 224 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str1017, ei_mac_greek},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+#line 186 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str1027, ei_cp1253},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+#line 368 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str1037, ei_big5hkscs2001},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+    {-1},
+#line 372 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str1048, ei_big5hkscs2008},
+    {-1}, {-1},
+#line 367 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str1051, ei_big5hkscs1999},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-#line 49 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str797, ei_ucs2swapped},
-#line 202 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str798, ei_cp850},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-    {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-#line 273 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str814, ei_jisx0201},
-    {-1}, {-1}, {-1}, {-1}, {-1},
-#line 51 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str820, ei_ucs4swapped},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-#line 350 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str836, ei_big5hkscs2001},
-    {-1}, {-1}, {-1},
-#line 354 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str840, ei_big5hkscs2008},
-#line 349 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str841, ei_big5hkscs1999},
+#line 369 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str1085, ei_big5hkscs2004},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-    {-1}, {-1}, {-1}, {-1}, {-1},
-#line 351 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str865, ei_big5hkscs2004},
-    {-1}, {-1}, {-1}, {-1}, {-1},
-#line 196 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str871, ei_cp1257},
-    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-#line 308 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str879, ei_euc_jp},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-    {-1}, {-1}, {-1}, {-1}, {-1},
-#line 363 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str912, ei_johab},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
     {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
-#line 224 "lib/aliases_syssolaris.gperf"
-    {(int)(long)&((struct stringpool_t *)0)->stringpool_str956, ei_mac_hebrew}
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+    {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+    {-1}, {-1}, {-1},
+#line 310 "lib/aliases_syssolaris.gperf"
+    {(int)(long)&((struct stringpool_t *)0)->stringpool_str1188, ei_euc_jp}
   };
 
 #ifdef __GNUC__
 __inline
-#if defined __GNUC_STDC_INLINE__ || defined __GNUC_GNU_INLINE__
+#ifdef __GNUC_STDC_INLINE__
 __attribute__ ((__gnu_inline__))
 #endif
 #endif
diff -uprN libiconv-1.15-old/lib/canonical.h libiconv-1.15/lib/canonical.h
--- libiconv-1.15-old/lib/canonical.h	2017-01-02 08:03:01.000000000 +0900
+++ libiconv-1.15/lib/canonical.h	2017-09-17 06:32:19.595066000 +0900
@@ -1,111 +1,114 @@
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str392,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str389,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str261,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str378,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str233,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str639,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str477,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str319,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str682,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str520,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str359,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str769,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str607,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str371,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str777,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str615,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str732,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str1035,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str541,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str767,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str584,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str810,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str31,
   (int)(long)&((struct stringpool_t *)0)->stringpool_str258,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str436,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str285,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str222,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str418,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str267,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str361,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str567,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str416,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str68,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str78,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str76,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str164,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str72,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str70,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str444,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str90,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str96,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str137,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str69,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str77,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str165,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str73,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str71,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str400,
   (int)(long)&((struct stringpool_t *)0)->stringpool_str512,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str690,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str539,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str689,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str320,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str750,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str302,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str732,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str64,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str811,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str134,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str186,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str324,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str150,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str154,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str130,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str466,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str166,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str170,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str322,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str142,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str332,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str158,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str162,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str138,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str236,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str574,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str593,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str81,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str13,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str23,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str21,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str109,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str17,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str15,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str389,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str35,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str86,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str27,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str19,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str10,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str515,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str656,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str667,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str385,
   (int)(long)&((struct stringpool_t *)0)->stringpool_str580,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str268,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str88,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str140,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str278,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str104,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str108,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str84,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str420,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str120,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str250,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str110,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str54,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str147,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str476,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str463,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str442,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str562,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str813,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str248,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str749,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str591,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str702,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str796,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str680,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str430,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str448,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str311,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str391,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str446,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str312,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str286,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str121,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str176,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str375,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str532,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str792,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str941,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str889,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str855,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str635,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str336,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str436,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str601,
   (int)(long)&((struct stringpool_t *)0)->stringpool_str337,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str417,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str645,
   (int)(long)&((struct stringpool_t *)0)->stringpool_str282,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str242,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str229,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str190,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str554,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str18,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str184,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str300,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str239,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str200,
   (int)(long)&((struct stringpool_t *)0)->stringpool_str206,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str211,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str536,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str651,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str683,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str613,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str329,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str426,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str375,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str397,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str351,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str290,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str268,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str115,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str297,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str352,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str561,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str37,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str513,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str33,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str355,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str231,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str236,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str304,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str91,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str545,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str25,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str240,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str94,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str112,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str92,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str182,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str411,
   (int)(long)&((struct stringpool_t *)0)->stringpool_str89,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str344,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str479,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str548,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str209,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str661,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str608,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str634,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str610,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str72,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str388,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str153,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str443,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str254,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str281,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str78,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str437,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str210,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str252,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str710,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str692,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str700,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str495,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str243,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str106,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str869,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str425,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str1054,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str1040,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str1088,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str938,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str450,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str95,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str721,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str453,
diff -uprN libiconv-1.15-old/lib/canonical_local.h libiconv-1.15/lib/canonical_local.h
--- libiconv-1.15-old/lib/canonical_local.h	2017-01-02 08:03:01.000000000 +0900
+++ libiconv-1.15/lib/canonical_local.h	2017-09-17 06:32:19.600751000 +0900
@@ -1,2 +1,2 @@
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str193,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str496,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str199,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str329,
diff -uprN libiconv-1.15-old/lib/canonical_local_sysaix.h libiconv-1.15/lib/canonical_local_sysaix.h
--- libiconv-1.15-old/lib/canonical_local_sysaix.h	2017-01-02 08:03:06.000000000 +0900
+++ libiconv-1.15/lib/canonical_local_sysaix.h	2017-09-17 06:32:20.245248000 +0900
@@ -1,2 +1,2 @@
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str15,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str484,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str338,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str752,
diff -uprN libiconv-1.15-old/lib/canonical_local_syshpux.h libiconv-1.15/lib/canonical_local_syshpux.h
--- libiconv-1.15-old/lib/canonical_local_syshpux.h	2017-01-02 08:03:11.000000000 +0900
+++ libiconv-1.15/lib/canonical_local_syshpux.h	2017-09-17 06:32:20.891177000 +0900
@@ -1,2 +1,2 @@
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str171,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str723,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str265,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str452,
diff -uprN libiconv-1.15-old/lib/canonical_local_sysosf1.h libiconv-1.15/lib/canonical_local_sysosf1.h
--- libiconv-1.15-old/lib/canonical_local_sysosf1.h	2017-01-02 08:03:16.000000000 +0900
+++ libiconv-1.15/lib/canonical_local_sysosf1.h	2017-09-17 06:32:21.537034000 +0900
@@ -1,2 +1,2 @@
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str193,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str457,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str199,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str244,
diff -uprN libiconv-1.15-old/lib/canonical_local_syssolaris.h libiconv-1.15/lib/canonical_local_syssolaris.h
--- libiconv-1.15-old/lib/canonical_local_syssolaris.h	2017-01-02 08:03:21.000000000 +0900
+++ libiconv-1.15/lib/canonical_local_syssolaris.h	2017-09-17 06:32:22.184030000 +0900
@@ -1,2 +1,2 @@
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str112,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str491,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str173,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str293,
diff -uprN libiconv-1.15-old/lib/canonical_sysaix.h libiconv-1.15/lib/canonical_sysaix.h
--- libiconv-1.15-old/lib/canonical_sysaix.h	2017-01-02 08:03:06.000000000 +0900
+++ libiconv-1.15/lib/canonical_sysaix.h	2017-09-17 06:32:20.239124000 +0900
@@ -1,111 +1,114 @@
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str391,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str282,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str145,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str452,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str267,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str131,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str445,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str260,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str255,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str573,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str388,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str303,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str610,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str425,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str618,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str418,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str469,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str411,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str462,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str5,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str457,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str155,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str183,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str207,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str169,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str177,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str161,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str527,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str191,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str151,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str242,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str158,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str210,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str172,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str180,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str164,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str313,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str507,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str508,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str127,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str43,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str71,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str95,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str57,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str65,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str49,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str415,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str79,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str128,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str64,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str42,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str44,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str437,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str557,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str429,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str451,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str542,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str426,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str744,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str809,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str815,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str958,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str518,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str560,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str309,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str275,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str215,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str157,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str523,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str330,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str357,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str623,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str430,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str201,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str574,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str381,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str222,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str588,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str395,
   (int)(long)&((struct stringpool_t *)0)->stringpool_str647,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str453,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str270,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str315,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str549,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str90,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str101,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str305,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str890,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str400,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str769,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str500,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str869,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str65,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str375,
   (int)(long)&((struct stringpool_t *)0)->stringpool_str96,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str245,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str233,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str342,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str187,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str490,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str725,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str761,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str711,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str226,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str246,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str219,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str276,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str553,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str853,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str67,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str671,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str623,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str637,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str633,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str81,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str466,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str112,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str110,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str312,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str104,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str98,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str548,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str116,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str148,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str200,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str100,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str114,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str316,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str108,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str102,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str444,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str462,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str566,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str137,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str37,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str53,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str51,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str253,
   (int)(long)&((struct stringpool_t *)0)->stringpool_str45,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str254,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str199,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str318,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str39,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str489,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str57,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str135,
   (int)(long)&((struct stringpool_t *)0)->stringpool_str48,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str569,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str286,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str108,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str719,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str721,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str728,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str555,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str272,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str16,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str814,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str390,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str34,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str32,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str488,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str678,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str693,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str537,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str738,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str280,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str863,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str864,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str935,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str962,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str696,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str459,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str557,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str622,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str307,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str464,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str454,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str308,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str344,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str302,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str371,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str46,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str181,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str473,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str124,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str138,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str345,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str593,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str613,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str559,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str419,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str396,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str155,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str483,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str347,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str386,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str82,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str373,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str70,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str359,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str257,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str265,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str267,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str113,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str458,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str56,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str227,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str125,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str161,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str176,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str326,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str254,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str151,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str830,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str804,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str912,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str672,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str519,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str207,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str724,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str531,
diff -uprN libiconv-1.15-old/lib/canonical_syshpux.h libiconv-1.15/lib/canonical_syshpux.h
--- libiconv-1.15-old/lib/canonical_syshpux.h	2017-01-02 08:03:11.000000000 +0900
+++ libiconv-1.15/lib/canonical_syshpux.h	2017-09-17 06:32:20.885434000 +0900
@@ -1,111 +1,114 @@
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str396,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str355,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str293,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str499,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str345,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str267,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str486,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str332,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str322,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str553,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str302,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str421,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str276,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str549,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str494,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str382,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str602,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str547,
   (int)(long)&((struct stringpool_t *)0)->stringpool_str399,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str430,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str636,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str482,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str495,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str503,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str500,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str490,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str487,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str110,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str639,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str114,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str178,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str230,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str152,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str142,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str128,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str306,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str166,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str112,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str223,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str119,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str235,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str157,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str147,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str133,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str100,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str516,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str519,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str277,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str173,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str237,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str289,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str211,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str201,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str187,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str365,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str225,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str266,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str219,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str169,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str185,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str515,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str731,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str501,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str696,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str626,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str610,
   (int)(long)&((struct stringpool_t *)0)->stringpool_str680,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str518,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str1033,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str986,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str760,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str655,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str479,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str584,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str393,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str436,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str273,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str418,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str76,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str151,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str305,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str301,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str333,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str282,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str256,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str337,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str653,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str738,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str790,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str750,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str302,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str373,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str625,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str496,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str769,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str714,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str781,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str1047,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str632,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str802,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str685,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str855,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str40,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str252,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str79,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str93,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str241,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str199,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str91,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str77,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str463,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str103,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str105,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str175,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str83,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str245,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str203,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str95,
   (int)(long)&((struct stringpool_t *)0)->stringpool_str81,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str260,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str525,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str644,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str243,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str571,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str574,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str606,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str483,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str651,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str764,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str131,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str39,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str53,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str201,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str159,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str51,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str37,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str423,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str63,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str132,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str47,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str31,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str107,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str557,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str683,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str785,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str455,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str618,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str636,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str870,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str1006,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str1114,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str810,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str595,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str419,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str517,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str830,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str327,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str497,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str670,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str355,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str257,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str263,
   (int)(long)&((struct stringpool_t *)0)->stringpool_str575,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str281,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str191,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str269,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str220,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str346,
   (int)(long)&((struct stringpool_t *)0)->stringpool_str193,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str189,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str248,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str669,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str693,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str637,
   (int)(long)&((struct stringpool_t *)0)->stringpool_str349,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str327,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str474,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str176,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str621,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str288,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str239,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str734,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str735,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str754,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str615,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str203,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str138,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str951,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str249,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str407,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str155,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str347,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str342,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str528,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str144,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str503,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str130,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str387,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str278,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str285,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str329,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str72,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str612,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str114,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str397,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str117,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str162,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str136,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str181,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str364,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str133,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str1112,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str1099,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str1159,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str892,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str511,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str121,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str631,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str556,
diff -uprN libiconv-1.15-old/lib/canonical_sysosf1.h libiconv-1.15/lib/canonical_sysosf1.h
--- libiconv-1.15-old/lib/canonical_sysosf1.h	2017-01-02 08:03:16.000000000 +0900
+++ libiconv-1.15/lib/canonical_sysosf1.h	2017-09-17 06:32:21.531394000 +0900
@@ -1,111 +1,114 @@
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str453,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str308,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str319,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str586,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str346,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str283,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str568,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str328,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str280,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str575,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str335,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str431,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str698,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str458,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str608,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str381,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str911,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str363,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str893,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str64,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str664,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str134,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str186,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str324,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str150,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str154,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str130,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str466,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str166,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str170,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str322,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str142,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str332,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str158,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str162,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str138,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str203,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str663,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str669,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str268,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str88,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str140,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str278,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str104,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str108,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str84,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str420,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str120,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str250,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str110,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str54,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str147,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str476,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str463,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str430,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str562,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str813,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str225,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str777,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str541,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str261,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str272,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str233,
   (int)(long)&((struct stringpool_t *)0)->stringpool_str648,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str848,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str769,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str389,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str407,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str561,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str391,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str455,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str396,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str563,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str319,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str691,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str606,
   (int)(long)&((struct stringpool_t *)0)->stringpool_str253,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str173,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str176,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str375,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str337,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str282,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str242,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str228,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str233,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str367,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str628,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str660,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str590,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str345,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str442,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str89,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str311,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str414,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str237,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str209,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str672,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str587,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str265,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str680,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str595,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str752,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str1038,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str584,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str828,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str627,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str871,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str31,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str185,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str68,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str78,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str76,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str164,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str72,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str70,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str570,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str90,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str96,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str137,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str69,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str77,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str165,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str73,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str71,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str380,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str492,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str573,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str81,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str13,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str23,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str21,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str109,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str17,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str15,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str515,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str35,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str86,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str27,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str19,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str10,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str531,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str793,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str848,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str393,
   (int)(long)&((struct stringpool_t *)0)->stringpool_str596,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str543,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str866,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str1042,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str791,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str745,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str566,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str301,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str401,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str821,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str345,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str514,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str758,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str262,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str248,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str190,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str605,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str18,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str184,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str363,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str189,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str150,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str183,
   (int)(long)&((struct stringpool_t *)0)->stringpool_str491,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str517,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str493,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str72,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str338,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str153,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str459,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str254,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str281,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str49,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str441,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str513,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str467,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str337,
   (int)(long)&((struct stringpool_t *)0)->stringpool_str315,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str252,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str846,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str828,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str836,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str526,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str210,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str106,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str837,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str392,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str115,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str277,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str410,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str608,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str37,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str384,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str33,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str370,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str227,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str232,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str300,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str134,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str552,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str25,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str287,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str94,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str112,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str88,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str141,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str381,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str89,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str883,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str869,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str917,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str845,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str473,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str95,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str501,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str433,
diff -uprN libiconv-1.15-old/lib/canonical_syssolaris.h libiconv-1.15/lib/canonical_syssolaris.h
--- libiconv-1.15-old/lib/canonical_syssolaris.h	2017-01-02 08:03:21.000000000 +0900
+++ libiconv-1.15/lib/canonical_syssolaris.h	2017-09-17 06:32:22.177610000 +0900
@@ -1,111 +1,114 @@
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str239,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str275,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str218,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str532,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str517,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str264,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str555,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str540,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str272,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str591,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str576,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str365,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str679,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str664,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str603,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str530,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str797,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str553,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str820,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str19,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str246,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str303,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str244,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str713,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str574,
   (int)(long)&((struct stringpool_t *)0)->stringpool_str330,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str61,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str73,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str227,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str119,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str65,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str63,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str397,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str69,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str71,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str128,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str64,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str230,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str122,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str756,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str617,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str284,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str757,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str618,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str296,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str765,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str626,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str623,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str933,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str595,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str747,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str638,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str790,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str31,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str316,
   (int)(long)&((struct stringpool_t *)0)->stringpool_str68,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str66,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str207,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str373,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str414,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str78,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str76,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str164,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str72,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str70,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str410,
   (int)(long)&((struct stringpool_t *)0)->stringpool_str90,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str26,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str38,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str192,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str84,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str30,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str28,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str362,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str34,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str85,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str32,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str22,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str101,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str372,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str644,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str494,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str290,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str424,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str509,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str609,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str653,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str751,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str956,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str416,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str328,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str364,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str678,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str270,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str329,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str96,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str137,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str69,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str77,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str165,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str73,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str71,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str432,
   (int)(long)&((struct stringpool_t *)0)->stringpool_str558,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str183,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str212,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str125,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str570,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str267,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str639,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str81,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str13,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str23,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str21,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str109,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str17,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str15,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str355,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str35,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str86,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str27,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str19,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str10,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str473,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str751,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str656,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str325,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str486,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str522,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str883,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str1017,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str950,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str877,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str552,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str315,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str415,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str853,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str307,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str231,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str507,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str314,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str241,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str190,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str563,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str18,
   (int)(long)&((struct stringpool_t *)0)->stringpool_str188,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str245,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str184,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str146,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str400,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str593,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str601,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str573,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str295,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str377,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str89,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str240,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str283,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str371,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str328,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str192,
   (int)(long)&((struct stringpool_t *)0)->stringpool_str542,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str608,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str564,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str518,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str224,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str202,
   (int)(long)&((struct stringpool_t *)0)->stringpool_str115,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str539,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str404,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str410,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str467,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str106,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str307,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str105,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str300,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str103,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str131,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str124,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str448,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str274,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str86,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str841,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str836,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str865,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str701,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str279,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str59,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str645,
-  (int)(long)&((struct stringpool_t *)0)->stringpool_str276,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str329,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str401,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str598,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str37,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str425,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str33,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str361,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str225,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str230,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str302,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str134,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str543,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str25,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str174,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str94,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str112,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str114,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str179,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str322,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str89,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str1051,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str1037,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str1085,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str906,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str525,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str95,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str644,
+  (int)(long)&((struct stringpool_t *)0)->stringpool_str485,
diff -uprN libiconv-1.15-old/lib/config.h libiconv-1.15/lib/config.h
--- libiconv-1.15-old/lib/config.h	1970-01-01 09:00:00.000000000 +0900
+++ libiconv-1.15/lib/config.h	2017-08-02 10:12:51.000000000 +0900
@@ -0,0 +1,83 @@
+/* lib/config.h.  Generated from config.h.in by configure.  */
+/* Copyright (C) 1999-2003, 2005, 2007, 2010, 2012 Free Software Foundation, Inc.
+   This file is part of the GNU LIBICONV Library.
+
+   The GNU LIBICONV Library is free software; you can redistribute it
+   and/or modify it under the terms of the GNU Library General Public
+   License as published by the Free Software Foundation; either version 2
+   of the License, or (at your option) any later version.
+
+   The GNU LIBICONV Library is distributed in the hope that it will be
+   useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+   Library General Public License for more details.
+
+   You should have received a copy of the GNU Library General Public
+   License along with the GNU LIBICONV Library; see the file COPYING.LIB.
+   If not, see <http://www.gnu.org/licenses/>.  */
+
+
+/* Define to 1 to enable a few rarely used encodings. */
+#define ENABLE_EXTRA 1
+
+/* Define to 1 if the package shall run at any location in the filesystem. */
+/* #undef ENABLE_RELOCATABLE */
+
+/* Define to a type if <wchar.h> does not define. */
+/* #undef mbstate_t */
+
+/* Define if you have <iconv.h>, the iconv_t type, and the
+   iconv_open, iconv, iconv_close functions. */
+#define HAVE_ICONV 1
+/* Define as const if the declaration of iconv() needs const. */
+#define ICONV_CONST 
+
+/* Define to 1 if you have the getc_unlocked() function. */
+#define HAVE_GETC_UNLOCKED 1
+
+/* Define if you have <langinfo.h> and nl_langinfo(CODESET). */
+#define HAVE_LANGINFO_CODESET 1
+
+/* Define if you have the mbrtowc() function. */
+#define HAVE_MBRTOWC 1
+
+/* Define to 1 if you have the setlocale() function. */
+#define HAVE_SETLOCALE 1
+
+/* Define to 1 if you have the <stddef.h> header file. */
+/* #undef HAVE_STDDEF_H */
+
+/* Define to 1 if you have the <stdlib.h> header file. */
+#define HAVE_STDLIB_H 1
+
+/* Define to 1 if you have the <string.h> header file. */
+#define HAVE_STRING_H 1
+
+/* Define to 1 or 0, depending whether the compiler supports simple visibility
+   declarations. */
+#define HAVE_VISIBILITY 1
+
+/* Define if you have the wcrtomb() function. */
+#define HAVE_WCRTOMB 1
+
+/* Define to 1 if O_NOFOLLOW works. */
+#define HAVE_WORKING_O_NOFOLLOW 1
+
+/* Define if the machine's byte ordering is little endian. */
+#define WORDS_LITTLEENDIAN 1
+
+/* Define to the value of ${prefix}, as a string. */
+#define INSTALLPREFIX "/usr/local"
+
+/* Define to '__inline__' or '__inline' if that's what the C compiler
+   calls it, or to nothing if 'inline' is not supported under any name.  */
+#ifndef __cplusplus
+/* #undef inline */
+#endif
+
+/* Define to 'int' if <sys/types.h> does not define. */
+/* #undef mode_t */
+
+/* Define as a signed type of the same size as size_t. */
+/* #undef ssize_t */
+
diff -uprN libiconv-1.15-old/lib/converters.h libiconv-1.15/lib/converters.h
--- libiconv-1.15-old/lib/converters.h	2016-10-14 09:31:28.000000000 +0900
+++ libiconv-1.15/lib/converters.h	2017-09-17 06:30:24.953296000 +0900
@@ -134,6 +134,7 @@ struct conv_struct {
 #include "utf32be.h"
 #include "utf32le.h"
 #include "utf7.h"
+#include "utf7imap.h"
 #include "ucs2internal.h"
 #include "ucs2swapped.h"
 #include "ucs4internal.h"
@@ -227,10 +228,12 @@ typedef struct {
 
 #include "euc_jp.h"
 #include "sjis.h"
-#include "cp932.h"
 #include "iso2022_jp.h"
 #include "iso2022_jp1.h"
 #include "iso2022_jp2.h"
+#include "cp932.h"
+#include "cp51932.h"
+#include "eucjp_ms.h"
 #include "iso2022_jpms.h"
 
 #include "euc_cn.h"
diff -uprN libiconv-1.15-old/lib/cp51932.h libiconv-1.15/lib/cp51932.h
--- libiconv-1.15-old/lib/cp51932.h	1970-01-01 09:00:00.000000000 +0900
+++ libiconv-1.15/lib/cp51932.h	2017-09-17 06:26:42.644330000 +0900
@@ -0,0 +1,161 @@
+/*
+ * Copyright (C) 1999-2004 Free Software Foundation, Inc.
+ * This file is part of the GNU LIBICONV Library.
+ *
+ * The GNU LIBICONV Library is free software; you can redistribute it
+ * and/or modify it under the terms of the GNU Library General Public
+ * License as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * The GNU LIBICONV Library is distributed in the hope that it will be
+ * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Library General Public License for more details.
+ *
+ * You should have received a copy of the GNU Library General Public
+ * License along with the GNU LIBICONV Library; see the file COPYING.LIB.
+ * If not, write to the Free Software Foundation, Inc., 59 Temple Place -
+ * Suite 330, Boston, MA 02111-1307, USA.
+ */
+
+/*
+ * cp51932
+ */
+
+static int
+cp51932_mbtowc (conv_t conv, ucs4_t *pwc, const unsigned char *s, size_t n)
+{
+  unsigned char c = *s;
+  /* Code set 0 (ASCII or JIS X 0201-1976 Roman) */
+  if (c < 0x80)
+    return ascii_mbtowc(conv,pwc,s,n);
+
+  /* Code set 1 (JIS X 0208) */
+  if (c >= 0xa1 && c < 0xff) {
+    if (n < 2)
+      return RET_TOOFEW(0);
+    if (c == 0xa1 || c == 0xa2 || c == 0xad || (c >= 0xf9 && c < 0xfd)) {
+      /* Code set 1 (cp51932 Rows 1,2,13,89-92) */
+      unsigned char c1 = c;
+      unsigned char c2 = s[1];
+      if (c2 >= 0xa1 && c2 < 0xff) {
+        unsigned char t1 = (c1 - 0xa1) >> 1;
+        unsigned char t2 = (((c1 - 0xa1) & 1) ? 0x5e : 0) + (c2 - 0xa1);
+        unsigned char buf[2];
+        buf[0] = (t1 < 0x1f ? t1+0x81 : t1+0xc1);
+        buf[1] = (t2 < 0x3f ? t2+0x40 : t2+0x41);
+        return cp932ext_mbtowc(conv,pwc,buf,2);
+      } else
+        return RET_ILSEQ;
+    }
+    else if (c < 0xf5) {
+      unsigned char c2 = s[1];
+      if (c2 >= 0xa1 && c2 < 0xff) {
+        unsigned char buf[2];
+        buf[0] = c-0x80; buf[1] = c2-0x80;
+        return jisx0208_mbtowc(conv,pwc,buf,2);
+      } else
+        return RET_ILSEQ;
+    }
+  }
+  /* Code set 2 (half-width katakana) */
+  if (c == 0x8e) {
+    if (n < 2)
+      return RET_TOOFEW(0);
+    {
+      unsigned char c2 = s[1];
+      if (c2 >= 0xa1 && c2 < 0xe0) {
+        int ret = jisx0201_mbtowc(conv,pwc,s+1,n-1);
+        if (ret == RET_ILSEQ)
+          return RET_ILSEQ;
+        if (ret != 1) abort();
+        return 2;
+      } else
+        return RET_ILSEQ;
+    }
+  }
+  return RET_ILSEQ;
+}
+
+static int
+cp51932_wctomb (conv_t conv, unsigned char *r, ucs4_t wc, size_t n)
+{
+  unsigned char buf[2];
+  int ret;
+
+  /* Code set 0 (ASCII or JIS X 0201-1976 Roman) */
+  ret = ascii_wctomb(conv,r,wc,n);
+  if (ret != RET_ILUNI)
+    return ret;
+
+  /* Code set 1 (JIS X 0208) */
+  ret = jisx0208_wctomb(conv,buf,wc,2);
+  if (ret != RET_ILUNI) {
+    if (ret != 2) abort();
+    if (n < 2)
+      return RET_TOOSMALL;
+    r[0] = buf[0]+0x80;
+    r[1] = buf[1]+0x80;
+    return 2;
+  }
+
+  /* Code set 1 (cp51932 Rows 1,2,13,89-92) */
+  ret = cp932ext_wctomb(conv,buf,wc,2);
+  if (ret != RET_ILUNI) {
+    unsigned char s1, s2;
+    if (ret != 2) abort();
+    if (n < 2)
+      return RET_TOOSMALL;
+    s1 = buf[0];
+    s2 = buf[1];
+    if (s1 < 0xf0) {
+      unsigned char t1 = (s1 < 0xe0 ? s1-0x81 : s1-0xc1);
+      unsigned char t2 = (s2 < 0x80 ? s2-0x40 : s2-0x41);
+      r[0] = 2*t1 + (t2 < 0x5e ? 0 : 1) + 0xa1;
+      r[1] = (t2 < 0x5e ? t2 : t2-0x5e) + 0xa1;
+      return 2;
+    }
+    else if (s1 >= 0xfa) {
+      unsigned short linear = 188 * s1 + (s2 < 0x7f ? s2-0x40 : s2-0x41);
+      if (0xb7b4 <= linear)
+        linear -= 0xb7b4 - 0xae0c;
+      else if (0xb7ad <= linear)
+        linear -= 0xb7ad - 0xaf81;
+      else
+        linear -= 0xb798 - 0xaf76;
+      r[0] = (linear - 0x819e) / 94 + 0x80;
+      r[1] = linear % 94 + 0xa1;
+      return 2;
+    }
+    else
+      return RET_ILUNI;
+  }
+
+  /* Code set 2 (half-width katakana) */
+  ret = jisx0201_wctomb(conv,buf,wc,1);
+  if (ret != RET_ILUNI && buf[0] >= 0x80) {
+    if (ret != 1) abort();
+    if (n < 2)
+      return RET_TOOSMALL;
+    r[0] = 0x8e;
+    r[1] = buf[0];
+    return 2;
+  }
+
+  /* Extra compatibility with Shift_JIS.  */
+  if (wc == 0x00a5) {
+    r[0] = 0x5c;
+    return 1;
+  }
+  if (wc == 0x203e) {
+    r[0] = 0x7e;
+    return 1;
+  }
+
+  if (wc == 0xffe4) {
+    r[0] = 0x8f; r[1] = 0xa2; r[2] = 0xc3;
+    return 3;
+  }
+
+  return RET_ILUNI;
+}
diff -uprN libiconv-1.15-old/lib/cp932.h libiconv-1.15/lib/cp932.h
--- libiconv-1.15-old/lib/cp932.h	2016-10-14 08:00:55.000000000 +0900
+++ libiconv-1.15/lib/cp932.h	2017-09-17 05:38:53.934266000 +0900
@@ -40,11 +40,8 @@
  *    0x8192  0x00A3 # POUND SIGN            0xFFE1 # FULLWIDTH POUND SIGN
  *    0x81CA  0x00AC # NOT SIGN              0xFFE2 # FULLWIDTH NOT SIGN
  *
- *    We don't implement the latter 6 of these changes, only the first one.
- *    SHIFTJIS.TXT makes more sense. However, as a compromise with user
- *    expectation, we implement the middle 5 of these changes in the
- *    Unicode to CP932 direction. We don't implement the last one at all,
- *    because it would collide with the mapping of 0xFA54.
+ *    We implement these changes. See Windows-31J.xml at the japanese XML
+ *    profile [http://www.w3.org/TR/japanese-xml/].
  *
  * 3. A few new rows. See cp932ext.h.
  *
@@ -95,7 +92,7 @@ cp932_mbtowc (conv_t conv, ucs4_t *pwc,
   else {
     unsigned char s1, s2;
     s1 = c;
-    if ((s1 >= 0x81 && s1 <= 0x9f && s1 != 0x87) || (s1 >= 0xe0 && s1 <= 0xea)) {
+    if ((s1 >= 0x82 && s1 <= 0x9f && s1 != 0x87) || (s1 >= 0xe0 && s1 <= 0xea)) {
       if (n < 2)
         return RET_TOOFEW(0);
       s2 = s[1];
@@ -107,7 +104,7 @@ cp932_mbtowc (conv_t conv, ucs4_t *pwc,
         buf[1] = (t2 < 0x5e ? t2 : t2-0x5e) + 0x21;
         return jisx0208_mbtowc(conv,pwc,buf,2);
       }
-    } else if ((s1 == 0x87) || (s1 >= 0xed && s1 <= 0xee) || (s1 >= 0xfa)) {
+    } else if ((s1 == 0x81) || (s1 == 0x87) || (s1 >= 0xed && s1 <= 0xee) || (s1 >= 0xfa)) {
       if (n < 2)
         return RET_TOOFEW(0);
       return cp932ext_mbtowc(conv,pwc,s,2);
@@ -132,6 +129,10 @@ cp932_wctomb (conv_t conv, unsigned char
   unsigned char buf[2];
   int ret;
 
+  switch (wc) {
+    case 0x2014: wc = 0x2015; break;
+  }
+
   /* Try ASCII. */
   ret = ascii_wctomb(conv,buf,wc,1);
   if (ret != RET_ILUNI) {
@@ -198,42 +199,5 @@ cp932_wctomb (conv_t conv, unsigned char
     return 2;
   }
 
-  /* Irreversible mappings.  */
-  if (wc == 0xff5e) {
-    if (n < 2)
-      return RET_TOOSMALL;
-    r[0] = 0x81;
-    r[1] = 0x60;
-    return 2;
-  }
-  if (wc == 0x2225) {
-    if (n < 2)
-      return RET_TOOSMALL;
-    r[0] = 0x81;
-    r[1] = 0x61;
-    return 2;
-  }
-  if (wc == 0xff0d) {
-    if (n < 2)
-      return RET_TOOSMALL;
-    r[0] = 0x81;
-    r[1] = 0x7c;
-    return 2;
-  }
-  if (wc == 0xffe0) {
-    if (n < 2)
-      return RET_TOOSMALL;
-    r[0] = 0x81;
-    r[1] = 0x91;
-    return 2;
-  }
-  if (wc == 0xffe1) {
-    if (n < 2)
-      return RET_TOOSMALL;
-    r[0] = 0x81;
-    r[1] = 0x92;
-    return 2;
-  }
-
   return RET_ILUNI;
 }
diff -uprN libiconv-1.15-old/lib/cp932ext.h libiconv-1.15/lib/cp932ext.h
--- libiconv-1.15-old/lib/cp932ext.h	2016-10-14 08:01:16.000000000 +0900
+++ libiconv-1.15/lib/cp932ext.h	2017-09-17 07:54:22.490655000 +0900
@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2001, 2012, 2016 Free Software Foundation, Inc.
+ * Copyright (C) 1999-2002 Free Software Foundation, Inc.
  * This file is part of the GNU LIBICONV Library.
  *
  * The GNU LIBICONV Library is free software; you can redistribute it
@@ -14,13 +14,41 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with the GNU LIBICONV Library; see the file COPYING.LIB.
- * If not, see <http://www.gnu.org/licenses/>.
+ * If not, write to the Free Software Foundation, Inc., 51 Franklin Street,
+ * Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 /*
  * CP932 extensions
  */
 
+static const unsigned short cp932ext_2uni_page81[188] = {
+  /* 0x81 */
+  0x3000, 0x3001, 0x3002, 0xff0c, 0xff0e, 0x30fb, 0xff1a, 0xff1b,
+  0xff1f, 0xff01, 0x309b, 0x309c, 0x00b4, 0xff40, 0x00a8, 0xff3e,
+  0xffe3, 0xff3f, 0x30fd, 0x30fe, 0x309d, 0x309e, 0x3003, 0x4edd,
+  0x3005, 0x3006, 0x3007, 0x30fc, 0x2015, 0x2010, 0xff0f, 0xff3c,
+  0xff5e, 0x2225, 0xff5c, 0x2026, 0x2025, 0x2018, 0x2019, 0x201c,
+  0x201d, 0xff08, 0xff09, 0x3014, 0x3015, 0xff3b, 0xff3d, 0xff5b,
+  0xff5d, 0x3008, 0x3009, 0x300a, 0x300b, 0x300c, 0x300d, 0x300e,
+  0x300f, 0x3010, 0x3011, 0xff0b, 0xff0d, 0x00b1, 0x00d7, 0x00f7,
+  0xff1d, 0x2260, 0xff1c, 0xff1e, 0x2266, 0x2267, 0x221e, 0x2234,
+  0x2642, 0x2640, 0x00b0, 0x2032, 0x2033, 0x2103, 0xffe5, 0xff04,
+  0xffe0, 0xffe1, 0xff05, 0xff03, 0xff06, 0xff0a, 0xff20, 0x00a7,
+  0x2606, 0x2605, 0x25cb, 0x25cf, 0x25ce, 0x25c7, 0x25c6, 0x25a1,
+  0x25a0, 0x25b3, 0x25b2, 0x25bd, 0x25bc, 0x203b, 0x3012, 0x2192,
+  0x2190, 0x2191, 0x2193, 0x3013, 0xfffd, 0xfffd, 0xfffd, 0xfffd,
+  0xfffd, 0xfffd, 0xfffd, 0xfffd, 0xfffd, 0xfffd, 0xfffd, 0x2208,
+  0x220b, 0x2286, 0x2287, 0x2282, 0x2283, 0x222a, 0x2229, 0xfffd,
+  0xfffd, 0xfffd, 0xfffd, 0xfffd, 0xfffd, 0xfffd, 0xfffd, 0x2227,
+  0x2228, 0xffe2, 0x21d2, 0x21d4, 0x2200, 0x2203, 0xfffd, 0xfffd,
+  0xfffd, 0xfffd, 0xfffd, 0xfffd, 0xfffd, 0xfffd, 0xfffd, 0xfffd,
+  0xfffd, 0x2220, 0x22a5, 0x2312, 0x2202, 0x2207, 0x2261, 0x2252,
+  0x226a, 0x226b, 0x221a, 0x223d, 0x221d, 0x2235, 0x222b, 0x222c,
+  0xfffd, 0xfffd, 0xfffd, 0xfffd, 0xfffd, 0xfffd, 0xfffd, 0x212b,
+  0x2030, 0x266f, 0x266d, 0x266a, 0x2020, 0x2021, 0x00b6, 0xfffd,
+  0xfffd, 0xfffd, 0xfffd, 0x25ef,
+};
 static const unsigned short cp932ext_2uni_page87[92] = {
   /* 0x87 */
   0x2460, 0x2461, 0x2462, 0x2463, 0x2464, 0x2465, 0x2466, 0x2467,
@@ -145,16 +173,19 @@ static const unsigned short cp932ext_2un
 };
 
 static int
-cp932ext_mbtowc (conv_t conv, ucs4_t *pwc, const unsigned char *s, size_t n)
+cp932ext_mbtowc (conv_t conv, ucs4_t *pwc, const unsigned char *s, int n)
 {
   unsigned char c1 = s[0];
-  if ((c1 == 0x87) || (c1 >= 0xed && c1 <= 0xee) || (c1 >= 0xfa && c1 <= 0xfc)) {
+  if ((c1 == 0x81) || (c1 == 0x87) || (c1 >= 0xed && c1 <= 0xee) || (c1 >= 0xfa && c1 <= 0xfc)) {
     if (n >= 2) {
       unsigned char c2 = s[1];
       if ((c2 >= 0x40 && c2 < 0x7f) || (c2 >= 0x80 && c2 < 0xfd)) {
         unsigned int i = 188 * (c1 - (c1 >= 0xe0 ? 0xc1 : 0x81)) + (c2 - (c2 >= 0x80 ? 0x41 : 0x40));
         unsigned short wc = 0xfffd;
-        if (i < 8272) {
+        if (i < 1128) {
+          if (i < 188)
+            wc = cp932ext_2uni_page81[i];
+        } else if (i < 8272) {
           if (i < 1220)
             wc = cp932ext_2uni_page87[i-1128];
         } else if (i < 10716) {
@@ -176,492 +207,538 @@ cp932ext_mbtowc (conv_t conv, ucs4_t *pw
   return RET_ILSEQ;
 }
 
-static const unsigned short cp932ext_2charset[457] = {
-  0xfa59, 0xfa5a, 0xfa4a, 0xfa4b, 0xfa4c, 0xfa4d, 0xfa4e, 0xfa4f,
-  0xfa50, 0xfa51, 0xfa52, 0xfa53, 0xfa40, 0xfa41, 0xfa42, 0xfa43,
-  0xfa44, 0xfa45, 0xfa46, 0xfa47, 0xfa48, 0xfa49, 0x8794, 0x8795,
-  0x8798, 0x8797, 0x879b, 0x879c, 0x8792, 0x8793, 0xfa5b, 0x8790,
-  0x8791, 0x8796, 0x8799, 0x8740, 0x8741, 0x8742, 0x8743, 0x8744,
-  0x8745, 0x8746, 0x8747, 0x8748, 0x8749, 0x874a, 0x874b, 0x874c,
-  0x874d, 0x874e, 0x874f, 0x8750, 0x8751, 0x8752, 0x8753, 0x8780,
-  0x8781, 0xfa58, 0x878b, 0x878c, 0x8785, 0x8786, 0x8787, 0x8788,
-  0x8789, 0x8765, 0x8769, 0x8760, 0x8763, 0x8761, 0x876b, 0x876a,
-  0x8764, 0x876c, 0x8766, 0x876e, 0x875f, 0x876d, 0x8762, 0x8767,
-  0x8768, 0x877e, 0x878f, 0x878e, 0x878d, 0x8772, 0x8773, 0x876f,
-  0x8770, 0x8771, 0x8775, 0x8774, 0x8783, 0xfa68, 0xfa69, 0xfa6a,
-  0xfa6b, 0xfa6c, 0xfa6d, 0xfa6e, 0xfa70, 0xfa6f, 0xfa72, 0xfa71,
-  0xfa61, 0xfa73, 0xfa76, 0xfa77, 0xfa75, 0xfa74, 0xfa7a, 0xfa78,
-  0xfa79, 0xfa7b, 0xfa7d, 0xfa7c, 0xfa7e, 0xfa80, 0xfa81, 0xfa82,
-  0xfa83, 0xfa84, 0xfa85, 0xfa86, 0xfb77, 0xfa87, 0xfa88, 0xfa89,
-  0xfa8a, 0xfa8b, 0xfa8c, 0xfa8d, 0xfa8e, 0xfa8f, 0xfa92, 0xfa91,
-  0xfa93, 0xfa94, 0xfa95, 0xfa96, 0xfa97, 0xfa98, 0xfa9a, 0xfa99,
-  0xfa9d, 0xfa9e, 0xfa9f, 0xfaa0, 0xfaa1, 0xfaa2, 0xfaa3, 0xfaa4,
-  0xfaa5, 0xfaa6, 0xfaa7, 0xfaa9, 0xfaaa, 0xfaab, 0xfaac, 0xfaad,
-  0xfaae, 0xfaaf, 0xfab2, 0xfab0, 0xfab3, 0xfab4, 0xfab5, 0xfab6,
-  0xfab7, 0xfab8, 0xfa67, 0xfab9, 0xfaba, 0xfabb, 0xfabc, 0xfabd,
-  0xfabe, 0xfac0, 0xfabf, 0xfac2, 0xfac3, 0xfac1, 0xfac5, 0xfac4,
-  0xfac6, 0xfac7, 0xfac8, 0xfac9, 0xfaca, 0xfacb, 0xfacc, 0xfacd,
-  0xface, 0xfad1, 0xfacf, 0xfad3, 0xfad4, 0xfad2, 0xfa63, 0xfad0,
-  0xfad6, 0xfad7, 0xfad5, 0xfad9, 0xfada, 0xfadb, 0xfadc, 0xfadd,
-  0xfade, 0xfa66, 0xfadf, 0xfae1, 0xfae2, 0xfae4, 0xfae5, 0xfae6,
-  0xfae3, 0xfa64, 0xfae7, 0xfae9, 0xfaeb, 0xfaec, 0xfaed, 0xfaef,
-  0xfaee, 0xfaf0, 0xfaf1, 0xfaf2, 0xfaf3, 0xfaf4, 0xfaf5, 0xfaf6,
-  0xfaf8, 0xfaf7, 0xfaf9, 0xfafa, 0xfafc, 0xfafb, 0xfb40, 0xfb41,
-  0xfb42, 0xfb44, 0xfb43, 0xfb45, 0xfb48, 0xfb46, 0xfb49, 0xfb47,
-  0xfb4a, 0xfb4b, 0xfb4c, 0xfb4d, 0xfb4e, 0xfb4f, 0xfb50, 0xfb51,
-  0xfb52, 0xfa62, 0xfb54, 0xfb53, 0xfb56, 0xfb57, 0xfb55, 0xfb59,
-  0xfb5a, 0xfb5b, 0xfb5c, 0xfb5d, 0xfb5f, 0xfb60, 0xfb61, 0xfb64,
-  0xfb62, 0xfb63, 0xfb66, 0xfb65, 0xfb67, 0xfb69, 0xfb68, 0xfb6a,
-  0xfb6b, 0xfb6c, 0xfb6d, 0xfb6e, 0xfaa8, 0xfb6f, 0xfb70, 0xfb73,
-  0xfb71, 0xfb72, 0xfb74, 0xfb76, 0xfb78, 0xfb79, 0xfb7a, 0xfb7b,
-  0xfb7c, 0xfb81, 0xfb83, 0xfb84, 0xfb85, 0xfb87, 0xfb88, 0xfb8a,
-  0xfb8b, 0xfb8d, 0xfb8c, 0xfb8e, 0xfb8f, 0xfa5c, 0xfb90, 0xfb91,
-  0xfb93, 0xfb94, 0xfb95, 0xfb96, 0xfb97, 0xfb98, 0xfb99, 0xfa60,
-  0xfb9a, 0xfb9b, 0xfb9c, 0xfb9e, 0xfba1, 0xfba2, 0xfa5d, 0xfba3,
-  0xfba4, 0xfba5, 0xfba6, 0xfba7, 0xfba8, 0xfbaa, 0xfbab, 0xfbac,
-  0xfbad, 0xfbae, 0xfbaf, 0xfbb0, 0xfbb2, 0xfbb5, 0xfbb6, 0xfbb8,
-  0xfbb9, 0xfbbb, 0xfbba, 0xfbbc, 0xfbbf, 0xfbc0, 0xfbbd, 0xfbbe,
-  0xfbc1, 0xfbc3, 0xfbc2, 0xfbca, 0xfbc4, 0xfbc6, 0xfbc5, 0xfbc7,
-  0xfbc9, 0xfbc8, 0xfbcb, 0xfbcd, 0xfbce, 0xfa5f, 0xfbcc, 0xfbd2,
-  0xfbd6, 0xfbd4, 0xfbd0, 0xfbd1, 0xfbd5, 0xfbcf, 0xfa65, 0xfbd9,
-  0xfbdc, 0xfbde, 0xfbdd, 0xfbdb, 0xfbd8, 0xfbd7, 0xfa5e, 0xfbe0,
-  0xfbdf, 0xfbe1, 0xfbe2, 0xfbe3, 0xfbe4, 0xfbe5, 0xfbe6, 0xfbe7,
-  0xfbe8, 0xfbeb, 0xfbec, 0xfbed, 0xfbee, 0xfbef, 0xfbf0, 0xfbf1,
-  0xfbf2, 0xfbf3, 0xfbf4, 0xfbf5, 0xfbf8, 0xfbfa, 0xfbfb, 0xfbfc,
-  0xfc40, 0xfc42, 0xfc41, 0xfc43, 0xfc44, 0xfc45, 0xfc46, 0xfc48,
-  0xfc47, 0xfc4a, 0xfc4b, 0xfae0, 0xfbe9, 0xfa90, 0xfa9b, 0xfa9c,
-  0xfab1, 0xfad8, 0xfae8, 0xfaea, 0xfb58, 0xfb5e, 0xfb75, 0xfb7d,
-  0xfb7e, 0xfb80, 0xfb82, 0xfb86, 0xfb89, 0xfb92, 0xfb9d, 0xfb9f,
-  0xfba0, 0xfba9, 0xfbb1, 0xfbb3, 0xfbb4, 0xfbb7, 0xfbd3, 0xfbda,
-  0xfbea, 0xfbf6, 0xfbf7, 0xfbf9, 0xfc49, 0xfa57, 0xfa56, 0xfa54,
-  0xfa55,
+static const unsigned short cp932ext_2charset[594] = {
+  0x8198, 0x814e, 0x818b, 0x817d, 0x814c, 0x81f7, 0x817e, 0x8180,
+  0x815d, 0x815c, 0x8165, 0x8166, 0x8167, 0x8168, 0x81f5, 0x81f6,
+  0x8164, 0x8163, 0x81f1, 0x818c, 0x818d, 0x81a6, 0x818e, 0x8782,
+  0x8784, 0x81f0, 0x8754, 0x8755, 0x8756, 0x8757, 0x8758, 0x8759,
+  0x875a, 0x875b, 0x875c, 0x875d, 0xfa40, 0xfa41, 0xfa42, 0xfa43,
+  0xfa44, 0xfa45, 0xfa46, 0xfa47, 0xfa48, 0xfa49, 0x81a9, 0x81aa,
+  0x81a8, 0x81ab, 0x81cb, 0x81cc, 0x81cd, 0x81dd, 0x81ce, 0x81de,
+  0x81b8, 0x81b9, 0x8794, 0x81e3, 0x81e5, 0x8187, 0x8798, 0x81da,
+  0x8161, 0x81c8, 0x81c9, 0x81bf, 0x81be, 0x81e7, 0x81e8, 0x8793,
+  0x8188, 0x81e6, 0x81e4, 0x81e0, 0x8182, 0x81df, 0x8185, 0x8186,
+  0x81e1, 0x81e2, 0x81bc, 0x81bd, 0x81ba, 0x81bb, 0x81db, 0x8799,
+  0x81dc, 0x8740, 0x8741, 0x8742, 0x8743, 0x8744, 0x8745, 0x8746,
+  0x8747, 0x8748, 0x8749, 0x874a, 0x874b, 0x874c, 0x874d, 0x874e,
+  0x874f, 0x8750, 0x8751, 0x8752, 0x8753, 0x81a1, 0x81a0, 0x81a3,
+  0x81a2, 0x81a5, 0x81a4, 0x819f, 0x819e, 0x819b, 0x819d, 0x819c,
+  0x81fc, 0x819a, 0x8199, 0x818a, 0x8189, 0x81f4, 0x81f3, 0x81f2,
+  0x8140, 0x8141, 0x8142, 0x8156, 0x8158, 0x8159, 0x815a, 0x8171,
+  0x8172, 0x8173, 0x8174, 0x8175, 0x8176, 0x8177, 0x8178, 0x8179,
+  0x817a, 0x81a7, 0x81ac, 0x816b, 0x816c, 0x8780, 0x8781, 0x814a,
+  0x814b, 0x8154, 0x8155, 0x8145, 0x815b, 0x8152, 0x8153, 0x878a,
+  0x878b, 0x878c, 0x8785, 0x8786, 0x8787, 0x8788, 0x8789, 0x8765,
+  0x8769, 0x8760, 0x8763, 0x8761, 0x876b, 0x876a, 0x8764, 0x876c,
+  0x8766, 0x876e, 0x875f, 0x876d, 0x8762, 0x8767, 0x8768, 0x877e,
+  0x878f, 0x878e, 0x878d, 0x8772, 0x8773, 0x876f, 0x8770, 0x8771,
+  0x8775, 0x8774, 0x8783, 0xfa68, 0x8157, 0xfa69, 0xfa6a, 0xfa6b,
+  0xfa6c, 0xfa6d, 0xfa6e, 0xfa70, 0xfa6f, 0xfa72, 0xfa71, 0xfa61,
+  0xfa73, 0xfa76, 0xfa77, 0xfa75, 0xfa74, 0xfa7a, 0xfa78, 0xfa79,
+  0xfa7b, 0xfa7d, 0xfa7c, 0xfa7e, 0xfa80, 0xfa81, 0xfa82, 0xfa83,
+  0xfa84, 0xfa85, 0xfa86, 0xfb77, 0xfa87, 0xfa88, 0xfa89, 0xfa8a,
+  0xfa8b, 0xfa8c, 0xfa8d, 0xfa8e, 0xfa8f, 0xfa92, 0xfa91, 0xfa93,
+  0xfa94, 0xfa95, 0xfa96, 0xfa97, 0xfa98, 0xfa9a, 0xfa99, 0xfa9d,
+  0xfa9e, 0xfa9f, 0xfaa0, 0xfaa1, 0xfaa2, 0xfaa3, 0xfaa4, 0xfaa5,
+  0xfaa6, 0xfaa7, 0xfaa9, 0xfaaa, 0xfaab, 0xfaac, 0xfaad, 0xfaae,
+  0xfaaf, 0xfab2, 0xfab0, 0xfab3, 0xfab4, 0xfab5, 0xfab6, 0xfab7,
+  0xfab8, 0xfa67, 0xfab9, 0xfaba, 0xfabb, 0xfabc, 0xfabd, 0xfabe,
+  0xfac0, 0xfabf, 0xfac2, 0xfac3, 0xfac1, 0xfac5, 0xfac4, 0xfac6,
+  0xfac7, 0xfac8, 0xfac9, 0xfaca, 0xfacb, 0xfacc, 0xfacd, 0xface,
+  0xfad1, 0xfacf, 0xfad3, 0xfad4, 0xfad2, 0xfa63, 0xfad0, 0xfad6,
+  0xfad7, 0xfad5, 0xfad9, 0xfada, 0xfadb, 0xfadc, 0xfadd, 0xfade,
+  0xfa66, 0xfadf, 0xfae1, 0xfae2, 0xfae4, 0xfae5, 0xfae6, 0xfae3,
+  0xfa64, 0xfae7, 0xfae9, 0xfaeb, 0xfaec, 0xfaed, 0xfaef, 0xfaee,
+  0xfaf0, 0xfaf1, 0xfaf2, 0xfaf3, 0xfaf4, 0xfaf5, 0xfaf6, 0xfaf8,
+  0xfaf7, 0xfaf9, 0xfafa, 0xfafc, 0xfafb, 0xfb40, 0xfb41, 0xfb42,
+  0xfb44, 0xfb43, 0xfb45, 0xfb48, 0xfb46, 0xfb49, 0xfb47, 0xfb4a,
+  0xfb4b, 0xfb4c, 0xfb4d, 0xfb4e, 0xfb4f, 0xfb50, 0xfb51, 0xfb52,
+  0xfa62, 0xfb54, 0xfb53, 0xfb56, 0xfb57, 0xfb55, 0xfb59, 0xfb5a,
+  0xfb5b, 0xfb5c, 0xfb5d, 0xfb5f, 0xfb60, 0xfb61, 0xfb64, 0xfb62,
+  0xfb63, 0xfb66, 0xfb65, 0xfb67, 0xfb69, 0xfb68, 0xfb6a, 0xfb6b,
+  0xfb6c, 0xfb6d, 0xfb6e, 0xfaa8, 0xfb6f, 0xfb70, 0xfb73, 0xfb71,
+  0xfb72, 0xfb74, 0xfb76, 0xfb78, 0xfb79, 0xfb7a, 0xfb7b, 0xfb7c,
+  0xfb81, 0xfb83, 0xfb84, 0xfb85, 0xfb87, 0xfb88, 0xfb8a, 0xfb8b,
+  0xfb8d, 0xfb8c, 0xfb8e, 0xfb8f, 0xfa5c, 0xfb90, 0xfb91, 0xfb93,
+  0xfb94, 0xfb95, 0xfb96, 0xfb97, 0xfb98, 0xfb99, 0xfa60, 0xfb9a,
+  0xfb9b, 0xfb9c, 0xfb9e, 0xfba1, 0xfba2, 0xfa5d, 0xfba3, 0xfba4,
+  0xfba5, 0xfba6, 0xfba7, 0xfba8, 0xfbaa, 0xfbab, 0xfbac, 0xfbad,
+  0xfbae, 0xfbaf, 0xfbb0, 0xfbb2, 0xfbb5, 0xfbb6, 0xfbb8, 0xfbb9,
+  0xfbbb, 0xfbba, 0xfbbc, 0xfbbf, 0xfbc0, 0xfbbd, 0xfbbe, 0xfbc1,
+  0xfbc3, 0xfbc2, 0xfbca, 0xfbc4, 0xfbc6, 0xfbc5, 0xfbc7, 0xfbc9,
+  0xfbc8, 0xfbcb, 0xfbcd, 0xfbce, 0xfa5f, 0xfbcc, 0xfbd2, 0xfbd6,
+  0xfbd4, 0xfbd0, 0xfbd1, 0xfbd5, 0xfbcf, 0xfa65, 0xfbd9, 0xfbdc,
+  0xfbde, 0xfbdd, 0xfbdb, 0xfbd8, 0xfbd7, 0xfa5e, 0xfbe0, 0xfbdf,
+  0xfbe1, 0xfbe2, 0xfbe3, 0xfbe4, 0xfbe5, 0xfbe6, 0xfbe7, 0xfbe8,
+  0xfbeb, 0xfbec, 0xfbed, 0xfbee, 0xfbef, 0xfbf0, 0xfbf1, 0xfbf2,
+  0xfbf3, 0xfbf4, 0xfbf5, 0xfbf8, 0xfbfa, 0xfbfb, 0xfbfc, 0xfc40,
+  0xfc42, 0xfc41, 0xfc43, 0xfc44, 0xfc45, 0xfc46, 0xfc48, 0xfc47,
+  0xfc4a, 0xfc4b, 0xfae0, 0xfbe9, 0xfa90, 0xfa9b, 0xfa9c, 0xfab1,
+  0xfad8, 0xfae8, 0xfaea, 0xfb58, 0xfb5e, 0xfb75, 0xfb7d, 0xfb7e,
+  0xfb80, 0xfb82, 0xfb86, 0xfb89, 0xfb92, 0xfb9d, 0xfb9f, 0xfba0,
+  0xfba9, 0xfbb1, 0xfbb3, 0xfbb4, 0xfbb7, 0xfbd3, 0xfbda, 0xfbea,
+  0xfbf6, 0xfbf7, 0xfbf9, 0xfc49, 0x8149, 0xfa57, 0x8194, 0x8190,
+  0x8193, 0x8195, 0xfa56, 0x8169, 0x816a, 0x8196, 0x817b, 0x8143,
+  0x817c, 0x8144, 0x815e, 0x8146, 0x8147, 0x8183, 0x8181, 0x8184,
+  0x8148, 0x8197, 0x816d, 0x815f, 0x816e, 0x814f, 0x8151, 0x814d,
+  0x816f, 0x8162, 0x8170, 0x8160, 0x8191, 0x8192, 0x81ca, 0x8150,
+  0xfa55, 0x818f,
 };
 
-static const Summary16 cp932ext_uni2indx_page21[28] = {
-  /* 0x2100 */
-  {    0, 0x0000 }, {    0, 0x0040 }, {    1, 0x0002 }, {    2, 0x0000 },
-  {    2, 0x0000 }, {    2, 0x0000 }, {    2, 0x03ff }, {   12, 0x03ff },
+static const Summary16 cp932ext_uni2indx_page00[16] = {
+  /* 0x0000 */
+  {    0, 0x0000 }, {    0, 0x0000 }, {    0, 0x0000 }, {    0, 0x0000 },
+  {    0, 0x0000 }, {    0, 0x0000 }, {    0, 0x0000 }, {    0, 0x0000 },
+  {    0, 0x0000 }, {    0, 0x0000 }, {    0, 0x0180 }, {    2, 0x0053 },
+  {    6, 0x0000 }, {    6, 0x0080 }, {    7, 0x0000 }, {    7, 0x0080 },
+};
+static const Summary16 cp932ext_uni2indx_page20[103] = {
+  /* 0x2000 */
+  {    8, 0x0000 }, {    8, 0x3321 }, {   14, 0x0063 }, {   18, 0x080d },
+  {   22, 0x0000 }, {   22, 0x0000 }, {   22, 0x0000 }, {   22, 0x0000 },
   {   22, 0x0000 }, {   22, 0x0000 }, {   22, 0x0000 }, {   22, 0x0000 },
   {   22, 0x0000 }, {   22, 0x0000 }, {   22, 0x0000 }, {   22, 0x0000 },
+  /* 0x2100 */
+  {   22, 0x0008 }, {   23, 0x0040 }, {   24, 0x0802 }, {   26, 0x0000 },
+  {   26, 0x0000 }, {   26, 0x0000 }, {   26, 0x03ff }, {   36, 0x03ff },
+  {   46, 0x0000 }, {   46, 0x000f }, {   50, 0x0000 }, {   50, 0x0000 },
+  {   50, 0x0000 }, {   50, 0x0014 }, {   52, 0x0000 }, {   52, 0x0000 },
   /* 0x2200 */
-  {   22, 0x0000 }, {   22, 0x8402 }, {   25, 0x4e01 }, {   30, 0x0020 },
-  {   31, 0x0000 }, {   31, 0x0004 }, {   32, 0x0002 }, {   33, 0x0000 },
-  {   33, 0x0000 }, {   33, 0x0000 }, {   33, 0x0020 }, {   34, 0x8000 },
-};
-static const Summary16 cp932ext_uni2indx_page24[8] = {
+  {   52, 0x098d }, {   58, 0xe402 }, {   63, 0x5fa1 }, {   72, 0x2030 },
+  {   75, 0x0000 }, {   75, 0x0004 }, {   76, 0x0cc3 }, {   82, 0x0000 },
+  {   82, 0x00cc }, {   86, 0x0000 }, {   86, 0x0020 }, {   87, 0x8000 },
+  {   88, 0x0000 }, {   88, 0x0000 }, {   88, 0x0000 }, {   88, 0x0000 },
+  /* 0x2300 */
+  {   88, 0x0000 }, {   88, 0x0004 }, {   89, 0x0000 }, {   89, 0x0000 },
+  {   89, 0x0000 }, {   89, 0x0000 }, {   89, 0x0000 }, {   89, 0x0000 },
+  {   89, 0x0000 }, {   89, 0x0000 }, {   89, 0x0000 }, {   89, 0x0000 },
+  {   89, 0x0000 }, {   89, 0x0000 }, {   89, 0x0000 }, {   89, 0x0000 },
   /* 0x2400 */
-  {   35, 0x0000 }, {   35, 0x0000 }, {   35, 0x0000 }, {   35, 0x0000 },
-  {   35, 0x0000 }, {   35, 0x0000 }, {   35, 0xffff }, {   51, 0x000f },
+  {   89, 0x0000 }, {   89, 0x0000 }, {   89, 0x0000 }, {   89, 0x0000 },
+  {   89, 0x0000 }, {   89, 0x0000 }, {   89, 0xffff }, {  105, 0x000f },
+  {  109, 0x0000 }, {  109, 0x0000 }, {  109, 0x0000 }, {  109, 0x0000 },
+  {  109, 0x0000 }, {  109, 0x0000 }, {  109, 0x0000 }, {  109, 0x0000 },
+  /* 0x2500 */
+  {  109, 0x0000 }, {  109, 0x0000 }, {  109, 0x0000 }, {  109, 0x0000 },
+  {  109, 0x0000 }, {  109, 0x0000 }, {  109, 0x0000 }, {  109, 0x0000 },
+  {  109, 0x0000 }, {  109, 0x0000 }, {  109, 0x0003 }, {  111, 0x300c },
+  {  115, 0xc8c0 }, {  120, 0x0000 }, {  120, 0x8000 }, {  121, 0x0000 },
+  /* 0x2600 */
+  {  121, 0x0060 }, {  123, 0x0000 }, {  123, 0x0000 }, {  123, 0x0000 },
+  {  123, 0x0005 }, {  125, 0x0000 }, {  125, 0xa400 },
 };
-static const Summary16 cp932ext_uni2indx_page30[2] = {
+static const Summary16 cp932ext_uni2indx_page30[16] = {
   /* 0x3000 */
-  {   55, 0x0000 }, {   55, 0xa000 },
+  {  128, 0xffef }, {  143, 0xa03f }, {  151, 0x0000 }, {  151, 0x0000 },
+  {  151, 0x0000 }, {  151, 0x0000 }, {  151, 0x0000 }, {  151, 0x0000 },
+  {  151, 0x0000 }, {  151, 0x7800 }, {  155, 0x0000 }, {  155, 0x0000 },
+  {  155, 0x0000 }, {  155, 0x0000 }, {  155, 0x0000 }, {  155, 0x7800 },
 };
 static const Summary16 cp932ext_uni2indx_page32[29] = {
   /* 0x3200 */
-  {   57, 0x0000 }, {   57, 0x0000 }, {   57, 0x0000 }, {   57, 0x0206 },
-  {   60, 0x0000 }, {   60, 0x0000 }, {   60, 0x0000 }, {   60, 0x0000 },
-  {   60, 0x0000 }, {   60, 0x0000 }, {   60, 0x01f0 }, {   65, 0x0000 },
-  {   65, 0x0000 }, {   65, 0x0000 }, {   65, 0x0000 }, {   65, 0x0000 },
+  {  159, 0x0000 }, {  159, 0x0000 }, {  159, 0x0000 }, {  159, 0x0206 },
+  {  162, 0x0000 }, {  162, 0x0000 }, {  162, 0x0000 }, {  162, 0x0000 },
+  {  162, 0x0000 }, {  162, 0x0000 }, {  162, 0x01f0 }, {  167, 0x0000 },
+  {  167, 0x0000 }, {  167, 0x0000 }, {  167, 0x0000 }, {  167, 0x0000 },
   /* 0x3300 */
-  {   65, 0x2008 }, {   67, 0x0110 }, {   69, 0x08cc }, {   74, 0x0840 },
-  {   76, 0x2600 }, {   79, 0x0082 }, {   81, 0x0000 }, {   81, 0x7800 },
-  {   85, 0xc000 }, {   87, 0x7000 }, {   90, 0x0002 }, {   91, 0x0000 },
-  {   91, 0x2010 },
+  {  167, 0x2008 }, {  169, 0x0110 }, {  171, 0x08cc }, {  176, 0x0840 },
+  {  178, 0x2600 }, {  181, 0x0082 }, {  183, 0x0000 }, {  183, 0x7800 },
+  {  187, 0xc000 }, {  189, 0x7000 }, {  192, 0x0002 }, {  193, 0x0000 },
+  {  193, 0x2010 },
 };
 static const Summary16 cp932ext_uni2indx_page4e[121] = {
   /* 0x4e00 */
-  {   93, 0x0000 }, {   93, 0x0000 }, {   93, 0x0100 }, {   94, 0x0000 },
-  {   94, 0x0000 }, {   94, 0x0000 }, {   94, 0x0000 }, {   94, 0x0000 },
-  {   94, 0x0000 }, {   94, 0x0000 }, {   94, 0x0000 }, {   94, 0x0000 },
-  {   94, 0x0000 }, {   94, 0x0000 }, {   94, 0x0002 }, {   95, 0x1000 },
+  {  195, 0x0000 }, {  195, 0x0000 }, {  195, 0x0100 }, {  196, 0x0000 },
+  {  196, 0x0000 }, {  196, 0x0000 }, {  196, 0x0000 }, {  196, 0x0000 },
+  {  196, 0x0000 }, {  196, 0x0000 }, {  196, 0x0000 }, {  196, 0x0000 },
+  {  196, 0x0000 }, {  196, 0x2000 }, {  197, 0x0002 }, {  198, 0x1000 },
   /* 0x4f00 */
-  {   96, 0x0009 }, {   98, 0x0000 }, {   98, 0x0000 }, {   98, 0x0200 },
-  {   99, 0x0000 }, {   99, 0x0040 }, {  100, 0x0000 }, {  100, 0x0000 },
-  {  100, 0x0400 }, {  101, 0x0414 }, {  104, 0x0000 }, {  104, 0x0000 },
-  {  104, 0x2200 }, {  106, 0x0000 }, {  106, 0x0000 }, {  106, 0x8000 },
+  {  199, 0x0009 }, {  201, 0x0000 }, {  201, 0x0000 }, {  201, 0x0200 },
+  {  202, 0x0000 }, {  202, 0x0040 }, {  203, 0x0000 }, {  203, 0x0000 },
+  {  203, 0x0400 }, {  204, 0x0414 }, {  207, 0x0000 }, {  207, 0x0000 },
+  {  207, 0x2200 }, {  209, 0x0000 }, {  209, 0x0000 }, {  209, 0x8000 },
   /* 0x5000 */
-  {  107, 0x0000 }, {  107, 0x4000 }, {  108, 0x0004 }, {  109, 0x0000 },
-  {  109, 0x0045 }, {  112, 0x0000 }, {  112, 0x0000 }, {  112, 0x0001 },
-  {  113, 0x0000 }, {  113, 0x0010 }, {  114, 0x0000 }, {  114, 0x0000 },
-  {  114, 0x0000 }, {  114, 0x0100 }, {  115, 0x0000 }, {  115, 0x0010 },
+  {  210, 0x0000 }, {  210, 0x4000 }, {  211, 0x0004 }, {  212, 0x0000 },
+  {  212, 0x0045 }, {  215, 0x0000 }, {  215, 0x0000 }, {  215, 0x0001 },
+  {  216, 0x0000 }, {  216, 0x0010 }, {  217, 0x0000 }, {  217, 0x0000 },
+  {  217, 0x0000 }, {  217, 0x0100 }, {  218, 0x0000 }, {  218, 0x0010 },
   /* 0x5100 */
-  {  116, 0x0000 }, {  116, 0x0000 }, {  116, 0x0000 }, {  116, 0x0000 },
-  {  116, 0x0400 }, {  117, 0x0000 }, {  117, 0x0010 }, {  118, 0x0000 },
-  {  118, 0x0000 }, {  118, 0x2000 }, {  119, 0x0000 }, {  119, 0x4000 },
-  {  120, 0x0000 }, {  120, 0x0000 }, {  120, 0x1000 }, {  121, 0x0000 },
+  {  219, 0x0000 }, {  219, 0x0000 }, {  219, 0x0000 }, {  219, 0x0000 },
+  {  219, 0x0400 }, {  220, 0x0000 }, {  220, 0x0010 }, {  221, 0x0000 },
+  {  221, 0x0000 }, {  221, 0x2000 }, {  222, 0x0000 }, {  222, 0x4000 },
+  {  223, 0x0000 }, {  223, 0x0000 }, {  223, 0x1000 }, {  224, 0x0000 },
   /* 0x5200 */
-  {  121, 0x0000 }, {  121, 0x0020 }, {  122, 0x0000 }, {  122, 0x0000 },
-  {  122, 0x0000 }, {  122, 0x0000 }, {  122, 0x0000 }, {  122, 0x0000 },
-  {  122, 0x0000 }, {  122, 0x1000 }, {  123, 0x8040 }, {  125, 0x0000 },
-  {  125, 0x0001 }, {  126, 0x0800 }, {  127, 0x0000 }, {  127, 0x0000 },
+  {  224, 0x0000 }, {  224, 0x0020 }, {  225, 0x0000 }, {  225, 0x0000 },
+  {  225, 0x0000 }, {  225, 0x0000 }, {  225, 0x0000 }, {  225, 0x0000 },
+  {  225, 0x0000 }, {  225, 0x1000 }, {  226, 0x8040 }, {  228, 0x0000 },
+  {  228, 0x0001 }, {  229, 0x0800 }, {  230, 0x0000 }, {  230, 0x0000 },
   /* 0x5300 */
-  {  127, 0x0081 }, {  129, 0x0000 }, {  129, 0x0010 }, {  130, 0x0000 },
-  {  130, 0x0000 }, {  130, 0x0000 }, {  130, 0x0000 }, {  130, 0x0004 },
-  {  131, 0x0000 }, {  131, 0x0008 }, {  132, 0x0000 }, {  132, 0x0004 },
-  {  133, 0x0000 }, {  133, 0x2000 }, {  134, 0x0000 }, {  134, 0x0000 },
+  {  230, 0x0081 }, {  232, 0x0000 }, {  232, 0x0010 }, {  233, 0x0000 },
+  {  233, 0x0000 }, {  233, 0x0000 }, {  233, 0x0000 }, {  233, 0x0004 },
+  {  234, 0x0000 }, {  234, 0x0008 }, {  235, 0x0000 }, {  235, 0x0004 },
+  {  236, 0x0000 }, {  236, 0x2000 }, {  237, 0x0000 }, {  237, 0x0000 },
   /* 0x5400 */
-  {  134, 0x0000 }, {  134, 0x0000 }, {  134, 0x0000 }, {  134, 0x0000 },
-  {  134, 0x0000 }, {  134, 0x0000 }, {  134, 0x0000 }, {  134, 0x0000 },
-  {  134, 0x0400 }, {  135, 0x1000 }, {  136, 0x0200 }, {  137, 0x0000 },
-  {  137, 0x0000 }, {  137, 0x0000 }, {  137, 0x0000 }, {  137, 0x8000 },
+  {  237, 0x0000 }, {  237, 0x0000 }, {  237, 0x0000 }, {  237, 0x0000 },
+  {  237, 0x0000 }, {  237, 0x0000 }, {  237, 0x0000 }, {  237, 0x0000 },
+  {  237, 0x0400 }, {  238, 0x1000 }, {  239, 0x0200 }, {  240, 0x0000 },
+  {  240, 0x0000 }, {  240, 0x0000 }, {  240, 0x0000 }, {  240, 0x8000 },
   /* 0x5500 */
-  {  138, 0x0000 }, {  138, 0x0000 }, {  138, 0x0000 }, {  138, 0x0000 },
-  {  138, 0x0000 }, {  138, 0x0000 }, {  138, 0x0000 }, {  138, 0x0000 },
-  {  138, 0x0040 },
+  {  241, 0x0000 }, {  241, 0x0000 }, {  241, 0x0000 }, {  241, 0x0000 },
+  {  241, 0x0000 }, {  241, 0x0000 }, {  241, 0x0000 }, {  241, 0x0000 },
+  {  241, 0x0040 },
 };
 static const Summary16 cp932ext_uni2indx_page57[44] = {
   /* 0x5700 */
-  {  139, 0x0000 }, {  139, 0x0000 }, {  139, 0x0000 }, {  139, 0x0000 },
-  {  139, 0x0000 }, {  139, 0x0200 }, {  140, 0x0020 }, {  141, 0x0000 },
-  {  141, 0x0000 }, {  141, 0x0000 }, {  141, 0x1000 }, {  142, 0x0000 },
-  {  142, 0x0180 }, {  144, 0x0000 }, {  144, 0x0000 }, {  144, 0x0000 },
+  {  242, 0x0000 }, {  242, 0x0000 }, {  242, 0x0000 }, {  242, 0x0000 },
+  {  242, 0x0000 }, {  242, 0x0200 }, {  243, 0x0020 }, {  244, 0x0000 },
+  {  244, 0x0000 }, {  244, 0x0000 }, {  244, 0x1000 }, {  245, 0x0000 },
+  {  245, 0x0180 }, {  247, 0x0000 }, {  247, 0x0000 }, {  247, 0x0000 },
   /* 0x5800 */
-  {  144, 0x0000 }, {  144, 0x0000 }, {  144, 0x0000 }, {  144, 0x0000 },
-  {  144, 0x0000 }, {  144, 0x0000 }, {  144, 0x0000 }, {  144, 0x0000 },
-  {  144, 0x0000 }, {  144, 0x4000 }, {  145, 0x0000 }, {  145, 0x0004 },
-  {  146, 0x0000 }, {  146, 0x0000 }, {  146, 0x0000 }, {  146, 0x0000 },
+  {  247, 0x0000 }, {  247, 0x0000 }, {  247, 0x0000 }, {  247, 0x0000 },
+  {  247, 0x0000 }, {  247, 0x0000 }, {  247, 0x0000 }, {  247, 0x0000 },
+  {  247, 0x0000 }, {  247, 0x4000 }, {  248, 0x0000 }, {  248, 0x0004 },
+  {  249, 0x0000 }, {  249, 0x0000 }, {  249, 0x0000 }, {  249, 0x0000 },
   /* 0x5900 */
-  {  146, 0x0800 }, {  147, 0x0000 }, {  147, 0x0000 }, {  147, 0x0000 },
-  {  147, 0x0000 }, {  147, 0x2808 }, {  150, 0x0008 }, {  151, 0x0000 },
-  {  151, 0x0000 }, {  151, 0x0000 }, {  151, 0x0010 }, {  152, 0x0400 },
+  {  249, 0x0800 }, {  250, 0x0000 }, {  250, 0x0000 }, {  250, 0x0000 },
+  {  250, 0x0000 }, {  250, 0x2808 }, {  253, 0x0008 }, {  254, 0x0000 },
+  {  254, 0x0000 }, {  254, 0x0000 }, {  254, 0x0010 }, {  255, 0x0400 },
 };
 static const Summary16 cp932ext_uni2indx_page5b[46] = {
   /* 0x5b00 */
-  {  153, 0x0000 }, {  153, 0x0000 }, {  153, 0x0000 }, {  153, 0x0000 },
-  {  153, 0x0000 }, {  153, 0x0040 }, {  154, 0x0000 }, {  154, 0x0000 },
-  {  154, 0x0000 }, {  154, 0x0000 }, {  154, 0x0000 }, {  154, 0x0000 },
-  {  154, 0x0001 }, {  155, 0x0100 }, {  156, 0x1000 }, {  157, 0x0000 },
+  {  256, 0x0000 }, {  256, 0x0000 }, {  256, 0x0000 }, {  256, 0x0000 },
+  {  256, 0x0000 }, {  256, 0x0040 }, {  257, 0x0000 }, {  257, 0x0000 },
+  {  257, 0x0000 }, {  257, 0x0000 }, {  257, 0x0000 }, {  257, 0x0000 },
+  {  257, 0x0001 }, {  258, 0x0100 }, {  259, 0x1000 }, {  260, 0x0000 },
   /* 0x5c00 */
-  {  157, 0x0000 }, {  157, 0x4000 }, {  158, 0x0000 }, {  158, 0x0000 },
-  {  158, 0x0000 }, {  158, 0x0000 }, {  158, 0x0000 }, {  158, 0x0000 },
-  {  158, 0x0000 }, {  158, 0x0000 }, {  158, 0x0040 }, {  159, 0x0400 },
-  {  160, 0x0000 }, {  160, 0x0000 }, {  160, 0x0000 }, {  160, 0x0020 },
+  {  260, 0x0000 }, {  260, 0x4000 }, {  261, 0x0000 }, {  261, 0x0000 },
+  {  261, 0x0000 }, {  261, 0x0000 }, {  261, 0x0000 }, {  261, 0x0000 },
+  {  261, 0x0000 }, {  261, 0x0000 }, {  261, 0x0040 }, {  262, 0x0400 },
+  {  263, 0x0000 }, {  263, 0x0000 }, {  263, 0x0000 }, {  263, 0x0020 },
   /* 0x5d00 */
-  {  161, 0x0000 }, {  161, 0x0000 }, {  161, 0x0080 }, {  162, 0x0000 },
-  {  162, 0x0004 }, {  163, 0x0008 }, {  164, 0x2000 }, {  165, 0x0000 },
-  {  165, 0x0000 }, {  165, 0x0000 }, {  165, 0x0000 }, {  165, 0x0300 },
-  {  167, 0x0000 }, {  167, 0x0001 },
+  {  264, 0x0000 }, {  264, 0x0000 }, {  264, 0x0080 }, {  265, 0x0000 },
+  {  265, 0x0004 }, {  266, 0x0008 }, {  267, 0x2000 }, {  268, 0x0000 },
+  {  268, 0x0000 }, {  268, 0x0000 }, {  268, 0x0000 }, {  268, 0x0300 },
+  {  270, 0x0000 }, {  270, 0x0001 },
 };
 static const Summary16 cp932ext_uni2indx_page5f[458] = {
   /* 0x5f00 */
-  {  168, 0x0000 }, {  168, 0x0000 }, {  168, 0x0002 }, {  169, 0x0010 },
-  {  170, 0x0020 }, {  171, 0x0000 }, {  171, 0x0080 }, {  172, 0x0000 },
-  {  172, 0x0000 }, {  172, 0x0000 }, {  172, 0x0000 }, {  172, 0x0080 },
-  {  173, 0x0000 }, {  173, 0x4000 }, {  174, 0x0000 }, {  174, 0x0000 },
+  {  271, 0x0000 }, {  271, 0x0000 }, {  271, 0x0002 }, {  272, 0x0010 },
+  {  273, 0x0020 }, {  274, 0x0000 }, {  274, 0x0080 }, {  275, 0x0000 },
+  {  275, 0x0000 }, {  275, 0x0000 }, {  275, 0x0000 }, {  275, 0x0080 },
+  {  276, 0x0000 }, {  276, 0x4000 }, {  277, 0x0000 }, {  277, 0x0000 },
   /* 0x6000 */
-  {  174, 0x0000 }, {  174, 0x0000 }, {  174, 0x0000 }, {  174, 0x0000 },
-  {  174, 0x0000 }, {  174, 0x2000 }, {  175, 0x0000 }, {  175, 0x0000 },
-  {  175, 0x0420 }, {  177, 0x0000 }, {  177, 0x0000 }, {  177, 0x0000 },
-  {  177, 0x0000 }, {  177, 0x4020 }, {  179, 0x0000 }, {  179, 0x0004 },
+  {  277, 0x0000 }, {  277, 0x0000 }, {  277, 0x0000 }, {  277, 0x0000 },
+  {  277, 0x0000 }, {  277, 0x2000 }, {  278, 0x0000 }, {  278, 0x0000 },
+  {  278, 0x0420 }, {  280, 0x0000 }, {  280, 0x0000 }, {  280, 0x0000 },
+  {  280, 0x0000 }, {  280, 0x4020 }, {  282, 0x0000 }, {  282, 0x0004 },
   /* 0x6100 */
-  {  180, 0x0000 }, {  180, 0x0002 }, {  181, 0x0001 }, {  182, 0x0081 },
-  {  184, 0x0000 }, {  184, 0x0000 }, {  184, 0x0000 }, {  184, 0x0000 },
-  {  184, 0x0000 }, {  184, 0x0100 }, {  185, 0x0000 }, {  185, 0x0000 },
-  {  185, 0x0000 }, {  185, 0x0000 }, {  185, 0x0000 }, {  185, 0x0000 },
+  {  283, 0x0000 }, {  283, 0x0002 }, {  284, 0x0001 }, {  285, 0x0081 },
+  {  287, 0x0000 }, {  287, 0x0000 }, {  287, 0x0000 }, {  287, 0x0000 },
+  {  287, 0x0000 }, {  287, 0x0100 }, {  288, 0x0000 }, {  288, 0x0000 },
+  {  288, 0x0000 }, {  288, 0x0000 }, {  288, 0x0000 }, {  288, 0x0000 },
   /* 0x6200 */
-  {  185, 0x0000 }, {  185, 0x0008 }, {  186, 0x0000 }, {  186, 0x0000 },
-  {  186, 0x0000 }, {  186, 0x0000 }, {  186, 0x0000 }, {  186, 0x0000 },
-  {  186, 0x0000 }, {  186, 0x0000 }, {  186, 0x0040 }, {  187, 0x0000 },
-  {  187, 0x0000 }, {  187, 0x0000 }, {  187, 0x0000 }, {  187, 0x0000 },
+  {  288, 0x0000 }, {  288, 0x0008 }, {  289, 0x0000 }, {  289, 0x0000 },
+  {  289, 0x0000 }, {  289, 0x0000 }, {  289, 0x0000 }, {  289, 0x0000 },
+  {  289, 0x0000 }, {  289, 0x0000 }, {  289, 0x0040 }, {  290, 0x0000 },
+  {  290, 0x0000 }, {  290, 0x0000 }, {  290, 0x0000 }, {  290, 0x0000 },
   /* 0x6300 */
-  {  187, 0x0000 }, {  187, 0x0000 }, {  187, 0x0000 }, {  187, 0x0000 },
-  {  187, 0x0000 }, {  187, 0x0000 }, {  187, 0x0000 }, {  187, 0x0000 },
-  {  187, 0x0000 }, {  187, 0x0000 }, {  187, 0x0000 }, {  187, 0x0000 },
-  {  187, 0x0000 }, {  187, 0x0000 }, {  187, 0x0000 }, {  187, 0x0020 },
+  {  290, 0x0000 }, {  290, 0x0000 }, {  290, 0x0000 }, {  290, 0x0000 },
+  {  290, 0x0000 }, {  290, 0x0000 }, {  290, 0x0000 }, {  290, 0x0000 },
+  {  290, 0x0000 }, {  290, 0x0000 }, {  290, 0x0000 }, {  290, 0x0000 },
+  {  290, 0x0000 }, {  290, 0x0000 }, {  290, 0x0000 }, {  290, 0x0020 },
   /* 0x6400 */
-  {  188, 0x0000 }, {  188, 0x0000 }, {  188, 0x0000 }, {  188, 0x0000 },
-  {  188, 0x0000 }, {  188, 0x0000 }, {  188, 0x0001 }, {  189, 0x0000 },
-  {  189, 0x0000 }, {  189, 0x2000 }, {  190, 0x0000 }, {  190, 0x0000 },
-  {  190, 0x4000 }, {  191, 0x0000 }, {  191, 0x0000 }, {  191, 0x0000 },
+  {  291, 0x0000 }, {  291, 0x0000 }, {  291, 0x0000 }, {  291, 0x0000 },
+  {  291, 0x0000 }, {  291, 0x0000 }, {  291, 0x0001 }, {  292, 0x0000 },
+  {  292, 0x0000 }, {  292, 0x2000 }, {  293, 0x0000 }, {  293, 0x0000 },
+  {  293, 0x4000 }, {  294, 0x0000 }, {  294, 0x0000 }, {  294, 0x0000 },
   /* 0x6500 */
-  {  191, 0x0000 }, {  191, 0x0000 }, {  191, 0x0000 }, {  191, 0x0000 },
-  {  191, 0x4000 }, {  192, 0x0000 }, {  192, 0x0000 }, {  192, 0x0000 },
-  {  192, 0x0000 }, {  192, 0x0000 }, {  192, 0x0000 }, {  192, 0x0000 },
-  {  192, 0x0000 }, {  192, 0x0000 }, {  192, 0x0000 }, {  192, 0x0000 },
+  {  294, 0x0000 }, {  294, 0x0000 }, {  294, 0x0000 }, {  294, 0x0000 },
+  {  294, 0x4000 }, {  295, 0x0000 }, {  295, 0x0000 }, {  295, 0x0000 },
+  {  295, 0x0000 }, {  295, 0x0000 }, {  295, 0x0000 }, {  295, 0x0000 },
+  {  295, 0x0000 }, {  295, 0x0000 }, {  295, 0x0000 }, {  295, 0x0000 },
   /* 0x6600 */
-  {  192, 0x0201 }, {  194, 0x4020 }, {  196, 0x4010 }, {  198, 0x0802 },
-  {  200, 0x0000 }, {  200, 0x0280 }, {  202, 0x0020 }, {  203, 0x0008 },
-  {  204, 0x0000 }, {  204, 0x0200 }, {  205, 0x0001 }, {  206, 0x8004 },
-  {  208, 0x0000 }, {  208, 0x0000 }, {  208, 0x0000 }, {  208, 0x0c00 },
+  {  295, 0x0201 }, {  297, 0x4020 }, {  299, 0x4010 }, {  301, 0x0802 },
+  {  303, 0x0000 }, {  303, 0x0280 }, {  305, 0x0020 }, {  306, 0x0008 },
+  {  307, 0x0000 }, {  307, 0x0200 }, {  308, 0x0001 }, {  309, 0x8004 },
+  {  311, 0x0000 }, {  311, 0x0000 }, {  311, 0x0000 }, {  311, 0x0c00 },
   /* 0x6700 */
-  {  210, 0x4000 }, {  211, 0x0000 }, {  211, 0x0000 }, {  211, 0x0000 },
-  {  211, 0x0000 }, {  211, 0x0000 }, {  211, 0x0040 }, {  212, 0x0000 },
-  {  212, 0x0000 }, {  212, 0x0000 }, {  212, 0x0000 }, {  212, 0x0800 },
-  {  213, 0x0001 }, {  214, 0x0000 }, {  214, 0x0000 }, {  214, 0x0000 },
+  {  313, 0x4000 }, {  314, 0x0000 }, {  314, 0x0000 }, {  314, 0x0000 },
+  {  314, 0x0000 }, {  314, 0x0000 }, {  314, 0x0040 }, {  315, 0x0000 },
+  {  315, 0x0000 }, {  315, 0x0000 }, {  315, 0x0000 }, {  315, 0x0800 },
+  {  316, 0x0001 }, {  317, 0x0000 }, {  317, 0x0000 }, {  317, 0x0000 },
   /* 0x6800 */
-  {  214, 0x0002 }, {  215, 0x0000 }, {  215, 0x0000 }, {  215, 0x0000 },
-  {  215, 0x0010 }, {  216, 0x0004 }, {  217, 0x0000 }, {  217, 0x0000 },
-  {  217, 0x0000 }, {  217, 0x0000 }, {  217, 0x0000 }, {  217, 0x0000 },
-  {  217, 0x8100 }, {  219, 0x0000 }, {  219, 0x0000 }, {  219, 0x0000 },
+  {  317, 0x0002 }, {  318, 0x0000 }, {  318, 0x0000 }, {  318, 0x0000 },
+  {  318, 0x0010 }, {  319, 0x0004 }, {  320, 0x0000 }, {  320, 0x0000 },
+  {  320, 0x0000 }, {  320, 0x0000 }, {  320, 0x0000 }, {  320, 0x0000 },
+  {  320, 0x8100 }, {  322, 0x0000 }, {  322, 0x0000 }, {  322, 0x0000 },
   /* 0x6900 */
-  {  219, 0x0000 }, {  219, 0x0000 }, {  219, 0x0000 }, {  219, 0x0000 },
-  {  219, 0x0000 }, {  219, 0x0000 }, {  219, 0x0100 }, {  220, 0x0000 },
-  {  220, 0x0000 }, {  220, 0x0100 }, {  221, 0x0000 }, {  221, 0x0000 },
-  {  221, 0x0000 }, {  221, 0x0000 }, {  221, 0x0004 }, {  222, 0x0000 },
+  {  322, 0x0000 }, {  322, 0x0000 }, {  322, 0x0000 }, {  322, 0x0000 },
+  {  322, 0x0000 }, {  322, 0x0000 }, {  322, 0x0100 }, {  323, 0x0000 },
+  {  323, 0x0000 }, {  323, 0x0100 }, {  324, 0x0000 }, {  324, 0x0000 },
+  {  324, 0x0000 }, {  324, 0x0000 }, {  324, 0x0004 }, {  325, 0x0000 },
   /* 0x6a00 */
-  {  222, 0x0000 }, {  222, 0x0000 }, {  222, 0x0000 }, {  222, 0x0001 },
-  {  223, 0x0040 }, {  224, 0x0000 }, {  224, 0x0800 }, {  225, 0x4008 },
-  {  227, 0x0000 }, {  227, 0x0000 }, {  227, 0x0000 }, {  227, 0x0000 },
-  {  227, 0x0000 }, {  227, 0x0000 }, {  227, 0x0014 }, {  229, 0x0000 },
+  {  325, 0x0000 }, {  325, 0x0000 }, {  325, 0x0000 }, {  325, 0x0001 },
+  {  326, 0x0040 }, {  327, 0x0000 }, {  327, 0x0800 }, {  328, 0x4008 },
+  {  330, 0x0000 }, {  330, 0x0000 }, {  330, 0x0000 }, {  330, 0x0000 },
+  {  330, 0x0000 }, {  330, 0x0000 }, {  330, 0x0014 }, {  332, 0x0000 },
   /* 0x6b00 */
-  {  229, 0x0000 }, {  229, 0x0000 }, {  229, 0x0000 }, {  229, 0x0000 },
-  {  229, 0x0000 }, {  229, 0x0000 }, {  229, 0x0000 }, {  229, 0x0000 },
-  {  229, 0x0000 }, {  229, 0x0000 }, {  229, 0x0000 }, {  229, 0x0000 },
-  {  229, 0x0000 }, {  229, 0x0040 }, {  230, 0x0000 }, {  230, 0x0000 },
+  {  332, 0x0000 }, {  332, 0x0000 }, {  332, 0x0000 }, {  332, 0x0000 },
+  {  332, 0x0000 }, {  332, 0x0000 }, {  332, 0x0000 }, {  332, 0x0000 },
+  {  332, 0x0000 }, {  332, 0x0000 }, {  332, 0x0000 }, {  332, 0x0000 },
+  {  332, 0x0000 }, {  332, 0x0040 }, {  333, 0x0000 }, {  333, 0x0000 },
   /* 0x6c00 */
-  {  230, 0x0000 }, {  230, 0x0000 }, {  230, 0x0000 }, {  230, 0x8000 },
-  {  231, 0x0000 }, {  231, 0x1000 }, {  232, 0x8000 }, {  233, 0x0000 },
-  {  233, 0x0040 }, {  234, 0x0000 }, {  234, 0x0000 }, {  234, 0x0000 },
-  {  234, 0x0000 }, {  234, 0x0400 }, {  235, 0x0000 }, {  235, 0x0000 },
+  {  333, 0x0000 }, {  333, 0x0000 }, {  333, 0x0000 }, {  333, 0x8000 },
+  {  334, 0x0000 }, {  334, 0x1000 }, {  335, 0x8000 }, {  336, 0x0000 },
+  {  336, 0x0040 }, {  337, 0x0000 }, {  337, 0x0000 }, {  337, 0x0000 },
+  {  337, 0x0000 }, {  337, 0x0400 }, {  338, 0x0000 }, {  338, 0x0000 },
   /* 0x6d00 */
-  {  235, 0x0010 }, {  236, 0x0000 }, {  236, 0x0000 }, {  236, 0x0000 },
-  {  236, 0x0000 }, {  236, 0x0000 }, {  236, 0x8000 }, {  237, 0x0000 },
-  {  237, 0x0080 }, {  238, 0x0040 }, {  239, 0x1000 }, {  240, 0x0000 },
-  {  240, 0x8000 }, {  241, 0x0000 }, {  241, 0x0000 }, {  241, 0x1104 },
+  {  338, 0x0010 }, {  339, 0x0000 }, {  339, 0x0000 }, {  339, 0x0000 },
+  {  339, 0x0000 }, {  339, 0x0000 }, {  339, 0x8000 }, {  340, 0x0000 },
+  {  340, 0x0080 }, {  341, 0x0040 }, {  342, 0x1000 }, {  343, 0x0000 },
+  {  343, 0x8000 }, {  344, 0x0000 }, {  344, 0x0000 }, {  344, 0x1104 },
   /* 0x6e00 */
-  {  244, 0x0000 }, {  244, 0x0000 }, {  244, 0x0080 }, {  245, 0x1200 },
-  {  247, 0x0000 }, {  247, 0x1000 }, {  248, 0x0000 }, {  248, 0x0000 },
-  {  248, 0x0000 }, {  248, 0x0000 }, {  248, 0x0000 }, {  248, 0x8000 },
-  {  249, 0x0000 }, {  249, 0x0000 }, {  249, 0x0000 }, {  249, 0x0000 },
+  {  347, 0x0000 }, {  347, 0x0000 }, {  347, 0x0080 }, {  348, 0x1200 },
+  {  350, 0x0000 }, {  350, 0x1000 }, {  351, 0x0000 }, {  351, 0x0000 },
+  {  351, 0x0000 }, {  351, 0x0000 }, {  351, 0x0000 }, {  351, 0x8000 },
+  {  352, 0x0000 }, {  352, 0x0000 }, {  352, 0x0000 }, {  352, 0x0000 },
   /* 0x6f00 */
-  {  249, 0x0000 }, {  249, 0x0000 }, {  249, 0x0000 }, {  249, 0x0000 },
-  {  249, 0x0000 }, {  249, 0x0000 }, {  249, 0x0000 }, {  249, 0x0000 },
-  {  249, 0x0100 }, {  250, 0x0000 }, {  250, 0x0000 }, {  250, 0x0020 },
-  {  251, 0x0000 }, {  251, 0x0000 }, {  251, 0x0000 }, {  251, 0x0020 },
+  {  352, 0x0000 }, {  352, 0x0000 }, {  352, 0x0000 }, {  352, 0x0000 },
+  {  352, 0x0000 }, {  352, 0x0000 }, {  352, 0x0000 }, {  352, 0x0000 },
+  {  352, 0x0100 }, {  353, 0x0000 }, {  353, 0x0000 }, {  353, 0x0020 },
+  {  354, 0x0000 }, {  354, 0x0000 }, {  354, 0x0000 }, {  354, 0x0020 },
   /* 0x7000 */
-  {  252, 0x00a0 }, {  254, 0x0000 }, {  254, 0x0100 }, {  255, 0x0000 },
-  {  255, 0x0000 }, {  255, 0x0000 }, {  255, 0x0000 }, {  255, 0x0000 },
-  {  255, 0x0020 }, {  256, 0x0000 }, {  256, 0x0800 }, {  257, 0x0800 },
-  {  258, 0x0000 }, {  258, 0x0000 }, {  258, 0x0000 }, {  258, 0x0000 },
+  {  355, 0x00a0 }, {  357, 0x0000 }, {  357, 0x0100 }, {  358, 0x0000 },
+  {  358, 0x0000 }, {  358, 0x0000 }, {  358, 0x0000 }, {  358, 0x0000 },
+  {  358, 0x0020 }, {  359, 0x0000 }, {  359, 0x0800 }, {  360, 0x0800 },
+  {  361, 0x0000 }, {  361, 0x0000 }, {  361, 0x0000 }, {  361, 0x0000 },
   /* 0x7100 */
-  {  258, 0x8010 }, {  260, 0x0000 }, {  260, 0x0000 }, {  260, 0x0000 },
-  {  260, 0x00c0 }, {  262, 0x1000 }, {  263, 0x0000 }, {  263, 0x0000 },
-  {  263, 0x0000 }, {  263, 0x0000 }, {  263, 0x0000 }, {  263, 0x0000 },
-  {  263, 0x0002 }, {  264, 0x0000 }, {  264, 0x0000 }, {  264, 0x4000 },
+  {  361, 0x8010 }, {  363, 0x0000 }, {  363, 0x0000 }, {  363, 0x0000 },
+  {  363, 0x00c0 }, {  365, 0x1000 }, {  366, 0x0000 }, {  366, 0x0000 },
+  {  366, 0x0000 }, {  366, 0x0000 }, {  366, 0x0000 }, {  366, 0x0000 },
+  {  366, 0x0002 }, {  367, 0x0000 }, {  367, 0x0000 }, {  367, 0x4000 },
   /* 0x7200 */
-  {  265, 0x0000 }, {  265, 0x0000 }, {  265, 0x0000 }, {  265, 0x0000 },
-  {  265, 0x0000 }, {  265, 0x0000 }, {  265, 0x0000 }, {  265, 0x0000 },
-  {  265, 0x0000 }, {  265, 0x0000 }, {  265, 0x0000 }, {  265, 0x4002 },
-  {  267, 0x0000 }, {  267, 0x0000 }, {  267, 0x0000 }, {  267, 0x0000 },
+  {  368, 0x0000 }, {  368, 0x0000 }, {  368, 0x0000 }, {  368, 0x0000 },
+  {  368, 0x0000 }, {  368, 0x0000 }, {  368, 0x0000 }, {  368, 0x0000 },
+  {  368, 0x0000 }, {  368, 0x0000 }, {  368, 0x0000 }, {  368, 0x4002 },
+  {  370, 0x0000 }, {  370, 0x0000 }, {  370, 0x0000 }, {  370, 0x0000 },
   /* 0x7300 */
-  {  267, 0x0000 }, {  267, 0x0000 }, {  267, 0x0010 }, {  268, 0x0000 },
-  {  268, 0x0000 }, {  268, 0x0000 }, {  268, 0x0000 }, {  268, 0x0080 },
-  {  269, 0x0000 }, {  269, 0x0000 }, {  269, 0x0000 }, {  269, 0x2000 },
-  {  270, 0x0200 }, {  271, 0x0044 }, {  273, 0x0008 }, {  274, 0x0020 },
+  {  370, 0x0000 }, {  370, 0x0000 }, {  370, 0x0010 }, {  371, 0x0000 },
+  {  371, 0x0000 }, {  371, 0x0000 }, {  371, 0x0000 }, {  371, 0x0080 },
+  {  372, 0x0000 }, {  372, 0x0000 }, {  372, 0x0000 }, {  372, 0x2000 },
+  {  373, 0x0200 }, {  374, 0x0044 }, {  376, 0x0008 }, {  377, 0x0020 },
   /* 0x7400 */
-  {  275, 0x0080 }, {  276, 0x0000 }, {  276, 0x4640 }, {  280, 0x0000 },
-  {  280, 0x0000 }, {  280, 0x0000 }, {  280, 0x0004 }, {  281, 0x0000 },
-  {  281, 0x0200 }, {  282, 0x8000 }, {  283, 0x0000 }, {  283, 0x0000 },
-  {  283, 0x0000 }, {  283, 0x0000 }, {  283, 0x0000 }, {  283, 0x0000 },
+  {  378, 0x0080 }, {  379, 0x0000 }, {  379, 0x4640 }, {  383, 0x0000 },
+  {  383, 0x0000 }, {  383, 0x0000 }, {  383, 0x0004 }, {  384, 0x0000 },
+  {  384, 0x0200 }, {  385, 0x8000 }, {  386, 0x0000 }, {  386, 0x0000 },
+  {  386, 0x0000 }, {  386, 0x0000 }, {  386, 0x0000 }, {  386, 0x0000 },
   /* 0x7500 */
-  {  283, 0x0002 }, {  284, 0x0000 }, {  284, 0x8000 }, {  285, 0x0000 },
-  {  285, 0x0000 }, {  285, 0x0000 }, {  285, 0x8000 }, {  286, 0x0000 },
-  {  286, 0x0000 }, {  286, 0x0000 }, {  286, 0x0000 }, {  286, 0x0000 },
-  {  286, 0x0000 }, {  286, 0x0000 }, {  286, 0x0000 }, {  286, 0x0000 },
+  {  386, 0x0002 }, {  387, 0x0000 }, {  387, 0x8000 }, {  388, 0x0000 },
+  {  388, 0x0000 }, {  388, 0x0000 }, {  388, 0x8000 }, {  389, 0x0000 },
+  {  389, 0x0000 }, {  389, 0x0000 }, {  389, 0x0000 }, {  389, 0x0000 },
+  {  389, 0x0000 }, {  389, 0x0000 }, {  389, 0x0000 }, {  389, 0x0000 },
   /* 0x7600 */
-  {  286, 0x0000 }, {  286, 0x0000 }, {  286, 0x0000 }, {  286, 0x0000 },
-  {  286, 0x0000 }, {  286, 0x0000 }, {  286, 0x0000 }, {  286, 0x0000 },
-  {  286, 0x0004 }, {  287, 0x5800 }, {  290, 0x0040 }, {  291, 0x0000 },
-  {  291, 0x0000 }, {  291, 0x0000 }, {  291, 0x0000 }, {  291, 0x0000 },
+  {  389, 0x0000 }, {  389, 0x0000 }, {  389, 0x0000 }, {  389, 0x0000 },
+  {  389, 0x0000 }, {  389, 0x0000 }, {  389, 0x0000 }, {  389, 0x0000 },
+  {  389, 0x0004 }, {  390, 0x5800 }, {  393, 0x0040 }, {  394, 0x0000 },
+  {  394, 0x0000 }, {  394, 0x0000 }, {  394, 0x0000 }, {  394, 0x0000 },
   /* 0x7700 */
-  {  291, 0x0000 }, {  291, 0x0000 }, {  291, 0x0000 }, {  291, 0x0000 },
-  {  291, 0x0040 }, {  292, 0x0000 }, {  292, 0x0000 }, {  292, 0x0000 },
-  {  292, 0x0000 }, {  292, 0x0000 }, {  292, 0x0000 }, {  292, 0x0000 },
-  {  292, 0x0000 }, {  292, 0x0000 }, {  292, 0x0000 }, {  292, 0x0000 },
+  {  394, 0x0000 }, {  394, 0x0000 }, {  394, 0x0000 }, {  394, 0x0000 },
+  {  394, 0x0040 }, {  395, 0x0000 }, {  395, 0x0000 }, {  395, 0x0000 },
+  {  395, 0x0000 }, {  395, 0x0000 }, {  395, 0x0000 }, {  395, 0x0000 },
+  {  395, 0x0000 }, {  395, 0x0000 }, {  395, 0x0000 }, {  395, 0x0000 },
   /* 0x7800 */
-  {  292, 0x0000 }, {  292, 0x0000 }, {  292, 0x0002 }, {  293, 0x0000 },
-  {  293, 0x4000 }, {  294, 0x0000 }, {  294, 0x0010 }, {  295, 0x0400 },
-  {  296, 0x0000 }, {  296, 0x0000 }, {  296, 0x0000 }, {  296, 0x0000 },
-  {  296, 0x0000 }, {  296, 0x0000 }, {  296, 0x0000 }, {  296, 0x0000 },
+  {  395, 0x0000 }, {  395, 0x0000 }, {  395, 0x0002 }, {  396, 0x0000 },
+  {  396, 0x4000 }, {  397, 0x0000 }, {  397, 0x0010 }, {  398, 0x0400 },
+  {  399, 0x0000 }, {  399, 0x0000 }, {  399, 0x0000 }, {  399, 0x0000 },
+  {  399, 0x0000 }, {  399, 0x0000 }, {  399, 0x0000 }, {  399, 0x0000 },
   /* 0x7900 */
-  {  296, 0x0000 }, {  296, 0x0000 }, {  296, 0x0000 }, {  296, 0x0001 },
-  {  297, 0x0000 }, {  297, 0x0000 }, {  297, 0x0000 }, {  297, 0x0000 },
-  {  297, 0x0000 }, {  297, 0x0810 }, {  299, 0x0000 }, {  299, 0x0000 },
-  {  299, 0x0000 }, {  299, 0x0000 }, {  299, 0x0000 }, {  299, 0x0000 },
+  {  399, 0x0000 }, {  399, 0x0000 }, {  399, 0x0000 }, {  399, 0x0001 },
+  {  400, 0x0000 }, {  400, 0x0000 }, {  400, 0x0000 }, {  400, 0x0000 },
+  {  400, 0x0000 }, {  400, 0x0810 }, {  402, 0x0000 }, {  402, 0x0000 },
+  {  402, 0x0000 }, {  402, 0x0000 }, {  402, 0x0000 }, {  402, 0x0000 },
   /* 0x7a00 */
-  {  299, 0x0000 }, {  299, 0x0000 }, {  299, 0x0000 }, {  299, 0x0000 },
-  {  299, 0x0000 }, {  299, 0x0000 }, {  299, 0x0000 }, {  299, 0x0000 },
-  {  299, 0x0000 }, {  299, 0x0000 }, {  299, 0x0000 }, {  299, 0x0000 },
-  {  299, 0x0000 }, {  299, 0x0002 }, {  300, 0x0880 }, {  302, 0x0000 },
+  {  402, 0x0000 }, {  402, 0x0000 }, {  402, 0x0000 }, {  402, 0x0000 },
+  {  402, 0x0000 }, {  402, 0x0000 }, {  402, 0x0000 }, {  402, 0x0000 },
+  {  402, 0x0000 }, {  402, 0x0000 }, {  402, 0x0000 }, {  402, 0x0000 },
+  {  402, 0x0000 }, {  402, 0x0002 }, {  403, 0x0880 }, {  405, 0x0000 },
   /* 0x7b00 */
-  {  302, 0x0000 }, {  302, 0x0000 }, {  302, 0x0000 }, {  302, 0x0000 },
-  {  302, 0x0000 }, {  302, 0x0000 }, {  302, 0x0000 }, {  302, 0x0000 },
-  {  302, 0x0000 }, {  302, 0x4000 },
+  {  405, 0x0000 }, {  405, 0x0000 }, {  405, 0x0000 }, {  405, 0x0000 },
+  {  405, 0x0000 }, {  405, 0x0000 }, {  405, 0x0000 }, {  405, 0x0000 },
+  {  405, 0x0000 }, {  405, 0x4000 },
 };
 static const Summary16 cp932ext_uni2indx_page7d[43] = {
   /* 0x7d00 */
-  {  303, 0x0000 }, {  303, 0x0000 }, {  303, 0x0000 }, {  303, 0x0000 },
-  {  303, 0x0100 }, {  304, 0x1000 }, {  305, 0x0000 }, {  305, 0x0000 },
-  {  305, 0x0000 }, {  305, 0x0000 }, {  305, 0x0001 }, {  306, 0x0080 },
-  {  307, 0x0000 }, {  307, 0x0040 }, {  308, 0x0000 }, {  308, 0x0000 },
+  {  406, 0x0000 }, {  406, 0x0000 }, {  406, 0x0000 }, {  406, 0x0000 },
+  {  406, 0x0100 }, {  407, 0x1000 }, {  408, 0x0000 }, {  408, 0x0000 },
+  {  408, 0x0000 }, {  408, 0x0000 }, {  408, 0x0001 }, {  409, 0x0080 },
+  {  410, 0x0000 }, {  410, 0x0040 }, {  411, 0x0000 }, {  411, 0x0000 },
   /* 0x7e00 */
-  {  308, 0x0000 }, {  308, 0x0000 }, {  308, 0x0000 }, {  308, 0x0000 },
-  {  308, 0x0000 }, {  308, 0x0004 }, {  309, 0x0000 }, {  309, 0x0000 },
-  {  309, 0x0400 }, {  310, 0x0000 }, {  310, 0x0000 }, {  310, 0x0000 },
-  {  310, 0x0000 }, {  310, 0x0000 }, {  310, 0x0000 }, {  310, 0x0000 },
+  {  411, 0x0000 }, {  411, 0x0000 }, {  411, 0x0000 }, {  411, 0x0000 },
+  {  411, 0x0000 }, {  411, 0x0004 }, {  412, 0x0000 }, {  412, 0x0000 },
+  {  412, 0x0400 }, {  413, 0x0000 }, {  413, 0x0000 }, {  413, 0x0000 },
+  {  413, 0x0000 }, {  413, 0x0000 }, {  413, 0x0000 }, {  413, 0x0000 },
   /* 0x7f00 */
-  {  310, 0x0000 }, {  310, 0x0000 }, {  310, 0x0000 }, {  310, 0x0000 },
-  {  310, 0x0080 }, {  311, 0x0000 }, {  311, 0x0000 }, {  311, 0x0000 },
-  {  311, 0x0000 }, {  311, 0x0000 }, {  311, 0x0002 },
+  {  413, 0x0000 }, {  413, 0x0000 }, {  413, 0x0000 }, {  413, 0x0000 },
+  {  413, 0x0080 }, {  414, 0x0000 }, {  414, 0x0000 }, {  414, 0x0000 },
+  {  414, 0x0000 }, {  414, 0x0000 }, {  414, 0x0002 },
 };
 static const Summary16 cp932ext_uni2indx_page83[44] = {
   /* 0x8300 */
-  {  312, 0x0002 }, {  313, 0x0000 }, {  313, 0x0000 }, {  313, 0x0000 },
-  {  313, 0x0000 }, {  313, 0x0000 }, {  313, 0x0004 }, {  314, 0x8000 },
-  {  315, 0x0000 }, {  315, 0x0000 }, {  315, 0x0000 }, {  315, 0x0000 },
-  {  315, 0x0080 }, {  316, 0x0000 }, {  316, 0x0000 }, {  316, 0x0040 },
+  {  415, 0x0002 }, {  416, 0x0000 }, {  416, 0x0000 }, {  416, 0x0000 },
+  {  416, 0x0000 }, {  416, 0x0000 }, {  416, 0x0004 }, {  417, 0x8000 },
+  {  418, 0x0000 }, {  418, 0x0000 }, {  418, 0x0000 }, {  418, 0x0000 },
+  {  418, 0x0080 }, {  419, 0x0000 }, {  419, 0x0000 }, {  419, 0x0040 },
   /* 0x8400 */
-  {  317, 0x0000 }, {  317, 0x0000 }, {  317, 0x0000 }, {  317, 0x0000 },
-  {  317, 0x0100 }, {  318, 0x0000 }, {  318, 0x0000 }, {  318, 0x0000 },
-  {  318, 0x0000 }, {  318, 0x0000 }, {  318, 0x0000 }, {  318, 0x0010 },
-  {  319, 0x0000 }, {  319, 0x1000 }, {  320, 0x0000 }, {  320, 0x0000 },
+  {  420, 0x0000 }, {  420, 0x0000 }, {  420, 0x0000 }, {  420, 0x0000 },
+  {  420, 0x0100 }, {  421, 0x0000 }, {  421, 0x0000 }, {  421, 0x0000 },
+  {  421, 0x0000 }, {  421, 0x0000 }, {  421, 0x0000 }, {  421, 0x0010 },
+  {  422, 0x0000 }, {  422, 0x1000 }, {  423, 0x0000 }, {  423, 0x0000 },
   /* 0x8500 */
-  {  320, 0x0000 }, {  320, 0x0000 }, {  320, 0x0000 }, {  320, 0x0000 },
-  {  320, 0x0000 }, {  320, 0x0208 }, {  322, 0x0800 }, {  323, 0x0000 },
-  {  323, 0x0000 }, {  323, 0x0000 }, {  323, 0x0000 }, {  323, 0x0001 },
+  {  423, 0x0000 }, {  423, 0x0000 }, {  423, 0x0000 }, {  423, 0x0000 },
+  {  423, 0x0000 }, {  423, 0x0208 }, {  425, 0x0800 }, {  426, 0x0000 },
+  {  426, 0x0000 }, {  426, 0x0000 }, {  426, 0x0000 }, {  426, 0x0001 },
 };
 static const Summary16 cp932ext_uni2indx_page88[109] = {
   /* 0x8800 */
-  {  324, 0x0080 }, {  325, 0x0000 }, {  325, 0x0000 }, {  325, 0x0000 },
-  {  325, 0x0000 }, {  325, 0x0000 }, {  325, 0x0000 }, {  325, 0x0000 },
-  {  325, 0x0000 }, {  325, 0x0000 }, {  325, 0x0000 }, {  325, 0x0000 },
-  {  325, 0x0000 }, {  325, 0x0000 }, {  325, 0x0000 }, {  325, 0x0020 },
+  {  427, 0x0080 }, {  428, 0x0000 }, {  428, 0x0000 }, {  428, 0x0000 },
+  {  428, 0x0000 }, {  428, 0x0000 }, {  428, 0x0000 }, {  428, 0x0000 },
+  {  428, 0x0000 }, {  428, 0x0000 }, {  428, 0x0000 }, {  428, 0x0000 },
+  {  428, 0x0000 }, {  428, 0x0000 }, {  428, 0x0000 }, {  428, 0x0020 },
   /* 0x8900 */
-  {  326, 0x0000 }, {  326, 0x1000 }, {  327, 0x0000 }, {  327, 0x0000 },
-  {  327, 0x0000 }, {  327, 0x0000 }, {  327, 0x0000 }, {  327, 0x0000 },
-  {  327, 0x0000 }, {  327, 0x0000 }, {  327, 0x0000 }, {  327, 0x0000 },
-  {  327, 0x0000 }, {  327, 0x0000 }, {  327, 0x0000 }, {  327, 0x0000 },
+  {  429, 0x0000 }, {  429, 0x1000 }, {  430, 0x0000 }, {  430, 0x0000 },
+  {  430, 0x0000 }, {  430, 0x0000 }, {  430, 0x0000 }, {  430, 0x0000 },
+  {  430, 0x0000 }, {  430, 0x0000 }, {  430, 0x0000 }, {  430, 0x0000 },
+  {  430, 0x0000 }, {  430, 0x0000 }, {  430, 0x0000 }, {  430, 0x0000 },
   /* 0x8a00 */
-  {  327, 0x0000 }, {  327, 0x0004 }, {  328, 0x0000 }, {  328, 0x0080 },
-  {  329, 0x0000 }, {  329, 0x0000 }, {  329, 0x0000 }, {  329, 0x0200 },
-  {  330, 0x0000 }, {  330, 0x0000 }, {  330, 0x0080 }, {  331, 0x4000 },
-  {  332, 0x0000 }, {  332, 0x8000 }, {  333, 0x0000 }, {  333, 0x0040 },
+  {  430, 0x0000 }, {  430, 0x0004 }, {  431, 0x0000 }, {  431, 0x0080 },
+  {  432, 0x0000 }, {  432, 0x0000 }, {  432, 0x0000 }, {  432, 0x0200 },
+  {  433, 0x0000 }, {  433, 0x0000 }, {  433, 0x0080 }, {  434, 0x4000 },
+  {  435, 0x0000 }, {  435, 0x8000 }, {  436, 0x0000 }, {  436, 0x0040 },
   /* 0x8b00 */
-  {  334, 0x0000 }, {  334, 0x0000 }, {  334, 0x0000 }, {  334, 0x0000 },
-  {  334, 0x0000 }, {  334, 0x0008 }, {  335, 0x0000 }, {  335, 0x8000 },
-  {  336, 0x0000 }, {  336, 0x0000 }, {  336, 0x0000 }, {  336, 0x0000 },
-  {  336, 0x0000 }, {  336, 0x0000 }, {  336, 0x0000 }, {  336, 0x0000 },
+  {  437, 0x0000 }, {  437, 0x0000 }, {  437, 0x0000 }, {  437, 0x0000 },
+  {  437, 0x0000 }, {  437, 0x0008 }, {  438, 0x0000 }, {  438, 0x8000 },
+  {  439, 0x0000 }, {  439, 0x0000 }, {  439, 0x0000 }, {  439, 0x0000 },
+  {  439, 0x0000 }, {  439, 0x0000 }, {  439, 0x0000 }, {  439, 0x0000 },
   /* 0x8c00 */
-  {  336, 0x0000 }, {  336, 0x0000 }, {  336, 0x0000 }, {  336, 0x0000 },
-  {  336, 0x0000 }, {  336, 0x0000 }, {  336, 0x0000 }, {  336, 0x0000 },
-  {  336, 0x0000 }, {  336, 0x0000 }, {  336, 0x0000 }, {  336, 0x0000 },
-  {  336, 0x0000 }, {  336, 0x0000 }, {  336, 0x0000 }, {  336, 0x0011 },
+  {  439, 0x0000 }, {  439, 0x0000 }, {  439, 0x0000 }, {  439, 0x0000 },
+  {  439, 0x0000 }, {  439, 0x0000 }, {  439, 0x0000 }, {  439, 0x0000 },
+  {  439, 0x0000 }, {  439, 0x0000 }, {  439, 0x0000 }, {  439, 0x0000 },
+  {  439, 0x0000 }, {  439, 0x0000 }, {  439, 0x0000 }, {  439, 0x0011 },
   /* 0x8d00 */
-  {  338, 0x0000 }, {  338, 0x0004 }, {  339, 0x0000 }, {  339, 0x0000 },
-  {  339, 0x0000 }, {  339, 0x0000 }, {  339, 0x0000 }, {  339, 0x0040 },
-  {  340, 0x0000 }, {  340, 0x0000 }, {  340, 0x0000 }, {  340, 0x0000 },
-  {  340, 0x0000 }, {  340, 0x0000 }, {  340, 0x0000 }, {  340, 0x0000 },
+  {  441, 0x0000 }, {  441, 0x0004 }, {  442, 0x0000 }, {  442, 0x0000 },
+  {  442, 0x0000 }, {  442, 0x0000 }, {  442, 0x0000 }, {  442, 0x0040 },
+  {  443, 0x0000 }, {  443, 0x0000 }, {  443, 0x0000 }, {  443, 0x0000 },
+  {  443, 0x0000 }, {  443, 0x0000 }, {  443, 0x0000 }, {  443, 0x0000 },
   /* 0x8e00 */
-  {  340, 0x0000 }, {  340, 0x0000 }, {  340, 0x0000 }, {  340, 0x0000 },
-  {  340, 0x0000 }, {  340, 0x0000 }, {  340, 0x0000 }, {  340, 0x0000 },
-  {  340, 0x0000 }, {  340, 0x0000 }, {  340, 0x0000 }, {  340, 0x0000 },
-  {  340, 0x8000 },
+  {  443, 0x0000 }, {  443, 0x0000 }, {  443, 0x0000 }, {  443, 0x0000 },
+  {  443, 0x0000 }, {  443, 0x0000 }, {  443, 0x0000 }, {  443, 0x0000 },
+  {  443, 0x0000 }, {  443, 0x0000 }, {  443, 0x0000 }, {  443, 0x0000 },
+  {  443, 0x8000 },
 };
 static const Summary16 cp932ext_uni2indx_page90[238] = {
   /* 0x9000 */
-  {  341, 0x0000 }, {  341, 0x0000 }, {  341, 0x0000 }, {  341, 0x0000 },
-  {  341, 0x0000 }, {  341, 0x0000 }, {  341, 0x0080 }, {  342, 0x0000 },
-  {  342, 0x0000 }, {  342, 0x0000 }, {  342, 0x0000 }, {  342, 0x0000 },
-  {  342, 0x0000 }, {  342, 0x4000 }, {  343, 0x0000 }, {  343, 0x0000 },
+  {  444, 0x0000 }, {  444, 0x0000 }, {  444, 0x0000 }, {  444, 0x0000 },
+  {  444, 0x0000 }, {  444, 0x0000 }, {  444, 0x0080 }, {  445, 0x0000 },
+  {  445, 0x0000 }, {  445, 0x0000 }, {  445, 0x0000 }, {  445, 0x0000 },
+  {  445, 0x0000 }, {  445, 0x4000 }, {  446, 0x0000 }, {  446, 0x0000 },
   /* 0x9100 */
-  {  343, 0x0000 }, {  343, 0x0020 }, {  344, 0x0080 }, {  345, 0x0000 },
-  {  345, 0x0000 }, {  345, 0x0000 }, {  345, 0x0000 }, {  345, 0x0000 },
-  {  345, 0x0000 }, {  345, 0x0000 }, {  345, 0x0000 }, {  345, 0x0000 },
-  {  345, 0x0000 }, {  345, 0x4480 }, {  348, 0x6030 }, {  352, 0x0000 },
+  {  446, 0x0000 }, {  446, 0x0020 }, {  447, 0x0080 }, {  448, 0x0000 },
+  {  448, 0x0000 }, {  448, 0x0000 }, {  448, 0x0000 }, {  448, 0x0000 },
+  {  448, 0x0000 }, {  448, 0x0000 }, {  448, 0x0000 }, {  448, 0x0000 },
+  {  448, 0x0000 }, {  448, 0x4480 }, {  451, 0x6030 }, {  455, 0x0000 },
   /* 0x9200 */
-  {  352, 0x0440 }, {  354, 0x0001 }, {  355, 0x0000 }, {  355, 0x1600 },
-  {  358, 0x4001 }, {  360, 0x0202 }, {  362, 0x0080 }, {  363, 0x0180 },
-  {  365, 0x0100 }, {  366, 0x0000 }, {  366, 0x0080 }, {  367, 0x0000 },
-  {  367, 0x0000 }, {  367, 0x02a9 }, {  372, 0x0081 }, {  374, 0x8a00 },
+  {  455, 0x0440 }, {  457, 0x0001 }, {  458, 0x0000 }, {  458, 0x1600 },
+  {  461, 0x4001 }, {  463, 0x0202 }, {  465, 0x0080 }, {  466, 0x0180 },
+  {  468, 0x0100 }, {  469, 0x0000 }, {  469, 0x0080 }, {  470, 0x0000 },
+  {  470, 0x0000 }, {  470, 0x02a9 }, {  475, 0x0081 }, {  477, 0x8a00 },
   /* 0x9300 */
-  {  377, 0x0004 }, {  378, 0x6000 }, {  380, 0x0022 }, {  382, 0x0000 },
-  {  382, 0x0100 }, {  383, 0x0080 }, {  384, 0x0000 }, {  384, 0x0001 },
-  {  385, 0x0000 }, {  385, 0x0000 }, {  385, 0x0010 }, {  386, 0x0000 },
-  {  386, 0x0040 }, {  387, 0x4000 }, {  388, 0x0000 }, {  388, 0x0100 },
+  {  480, 0x0004 }, {  481, 0x6000 }, {  483, 0x0022 }, {  485, 0x0000 },
+  {  485, 0x0100 }, {  486, 0x0080 }, {  487, 0x0000 }, {  487, 0x0001 },
+  {  488, 0x0000 }, {  488, 0x0000 }, {  488, 0x0010 }, {  489, 0x0000 },
+  {  489, 0x0040 }, {  490, 0x4000 }, {  491, 0x0000 }, {  491, 0x0100 },
   /* 0x9400 */
-  {  389, 0x0000 }, {  389, 0x0000 }, {  389, 0x0000 }, {  389, 0x0002 },
-  {  390, 0x0120 }, {  392, 0x0000 }, {  392, 0x0000 }, {  392, 0x0000 },
-  {  392, 0x0000 }, {  392, 0x0000 }, {  392, 0x0000 }, {  392, 0x0000 },
-  {  392, 0x0000 }, {  392, 0x0000 }, {  392, 0x0000 }, {  392, 0x0000 },
+  {  492, 0x0000 }, {  492, 0x0000 }, {  492, 0x0000 }, {  492, 0x0002 },
+  {  493, 0x0120 }, {  495, 0x0000 }, {  495, 0x0000 }, {  495, 0x0000 },
+  {  495, 0x0000 }, {  495, 0x0000 }, {  495, 0x0000 }, {  495, 0x0000 },
+  {  495, 0x0000 }, {  495, 0x0000 }, {  495, 0x0000 }, {  495, 0x0000 },
   /* 0x9500 */
-  {  392, 0x0000 }, {  392, 0x0000 }, {  392, 0x0000 }, {  392, 0x0000 },
-  {  392, 0x0000 }, {  392, 0x0000 }, {  392, 0x0000 }, {  392, 0x0000 },
-  {  392, 0x0000 }, {  392, 0x0004 }, {  393, 0x0000 }, {  393, 0x0000 },
-  {  393, 0x0000 }, {  393, 0x0000 }, {  393, 0x0000 }, {  393, 0x0000 },
+  {  495, 0x0000 }, {  495, 0x0000 }, {  495, 0x0000 }, {  495, 0x0000 },
+  {  495, 0x0000 }, {  495, 0x0000 }, {  495, 0x0000 }, {  495, 0x0000 },
+  {  495, 0x0000 }, {  495, 0x0004 }, {  496, 0x0000 }, {  496, 0x0000 },
+  {  496, 0x0000 }, {  496, 0x0000 }, {  496, 0x0000 }, {  496, 0x0000 },
   /* 0x9600 */
-  {  393, 0x0000 }, {  393, 0x0000 }, {  393, 0x0000 }, {  393, 0x0000 },
-  {  393, 0x0000 }, {  393, 0x0000 }, {  393, 0x0000 }, {  393, 0x0000 },
-  {  393, 0x0000 }, {  393, 0x2000 }, {  394, 0x8000 }, {  395, 0x0000 },
-  {  395, 0x0000 }, {  395, 0x0000 }, {  395, 0x0000 }, {  395, 0x0000 },
+  {  496, 0x0000 }, {  496, 0x0000 }, {  496, 0x0000 }, {  496, 0x0000 },
+  {  496, 0x0000 }, {  496, 0x0000 }, {  496, 0x0000 }, {  496, 0x0000 },
+  {  496, 0x0000 }, {  496, 0x2000 }, {  497, 0x8000 }, {  498, 0x0000 },
+  {  498, 0x0000 }, {  498, 0x0000 }, {  498, 0x0000 }, {  498, 0x0000 },
   /* 0x9700 */
-  {  395, 0x0000 }, {  395, 0x0000 }, {  395, 0x0000 }, {  395, 0x0808 },
-  {  397, 0xa008 }, {  400, 0x0022 }, {  402, 0x0000 }, {  402, 0x0000 },
-  {  402, 0x0000 }, {  402, 0x0000 }, {  402, 0x0000 }, {  402, 0x0000 },
-  {  402, 0x0000 }, {  402, 0x0000 }, {  402, 0x0000 }, {  402, 0x0000 },
+  {  498, 0x0000 }, {  498, 0x0000 }, {  498, 0x0000 }, {  498, 0x0808 },
+  {  500, 0xa008 }, {  503, 0x0022 }, {  505, 0x0000 }, {  505, 0x0000 },
+  {  505, 0x0000 }, {  505, 0x0000 }, {  505, 0x0000 }, {  505, 0x0000 },
+  {  505, 0x0000 }, {  505, 0x0000 }, {  505, 0x0000 }, {  505, 0x0000 },
   /* 0x9800 */
-  {  402, 0x0000 }, {  402, 0x0000 }, {  402, 0x0000 }, {  402, 0x0000 },
-  {  402, 0x0000 }, {  402, 0x0080 }, {  403, 0x0020 }, {  404, 0x0000 },
-  {  404, 0x0000 }, {  404, 0x0000 }, {  404, 0x0000 }, {  404, 0x0000 },
-  {  404, 0x0000 }, {  404, 0x0000 }, {  404, 0x0000 }, {  404, 0x0000 },
+  {  505, 0x0000 }, {  505, 0x0000 }, {  505, 0x0000 }, {  505, 0x0000 },
+  {  505, 0x0000 }, {  505, 0x0080 }, {  506, 0x0020 }, {  507, 0x0000 },
+  {  507, 0x0000 }, {  507, 0x0000 }, {  507, 0x0000 }, {  507, 0x0000 },
+  {  507, 0x0000 }, {  507, 0x0000 }, {  507, 0x0000 }, {  507, 0x0000 },
   /* 0x9900 */
-  {  404, 0x0000 }, {  404, 0x0000 }, {  404, 0x0080 }, {  405, 0x0000 },
-  {  405, 0x0000 }, {  405, 0x0000 }, {  405, 0x0000 }, {  405, 0x0000 },
-  {  405, 0x0000 }, {  405, 0x4000 }, {  406, 0x0000 }, {  406, 0x0000 },
-  {  406, 0x0000 }, {  406, 0x0000 }, {  406, 0x0000 }, {  406, 0x0000 },
+  {  507, 0x0000 }, {  507, 0x0000 }, {  507, 0x0080 }, {  508, 0x0000 },
+  {  508, 0x0000 }, {  508, 0x0000 }, {  508, 0x0000 }, {  508, 0x0000 },
+  {  508, 0x0000 }, {  508, 0x4000 }, {  509, 0x0000 }, {  509, 0x0000 },
+  {  509, 0x0000 }, {  509, 0x0000 }, {  509, 0x0000 }, {  509, 0x0000 },
   /* 0x9a00 */
-  {  406, 0x0000 }, {  406, 0x0000 }, {  406, 0x0000 }, {  406, 0x0000 },
-  {  406, 0x4000 }, {  407, 0x0000 }, {  407, 0x0000 }, {  407, 0x0000 },
-  {  407, 0x0000 }, {  407, 0x0000 }, {  407, 0x0000 }, {  407, 0x0000 },
-  {  407, 0x0000 }, {  407, 0x1200 }, {  409, 0x0000 }, {  409, 0x0000 },
+  {  509, 0x0000 }, {  509, 0x0000 }, {  509, 0x0000 }, {  509, 0x0000 },
+  {  509, 0x4000 }, {  510, 0x0000 }, {  510, 0x0000 }, {  510, 0x0000 },
+  {  510, 0x0000 }, {  510, 0x0000 }, {  510, 0x0000 }, {  510, 0x0000 },
+  {  510, 0x0000 }, {  510, 0x1200 }, {  512, 0x0000 }, {  512, 0x0000 },
   /* 0x9b00 */
-  {  409, 0x0000 }, {  409, 0x0000 }, {  409, 0x0000 }, {  409, 0x0000 },
-  {  409, 0x0000 }, {  409, 0x0000 }, {  409, 0x0000 }, {  409, 0x0024 },
-  {  411, 0x8000 }, {  412, 0x0000 }, {  412, 0x0000 }, {  412, 0x0802 },
-  {  414, 0x0000 }, {  414, 0x0000 }, {  414, 0x0000 }, {  414, 0x0000 },
+  {  512, 0x0000 }, {  512, 0x0000 }, {  512, 0x0000 }, {  512, 0x0000 },
+  {  512, 0x0000 }, {  512, 0x0000 }, {  512, 0x0000 }, {  512, 0x0024 },
+  {  514, 0x8000 }, {  515, 0x0000 }, {  515, 0x0000 }, {  515, 0x0802 },
+  {  517, 0x0000 }, {  517, 0x0000 }, {  517, 0x0000 }, {  517, 0x0000 },
   /* 0x9c00 */
-  {  414, 0x0001 }, {  415, 0x0000 }, {  415, 0x0000 }, {  415, 0x0000 },
-  {  415, 0x0000 }, {  415, 0x0000 }, {  415, 0x0000 }, {  415, 0x0000 },
-  {  415, 0x0000 }, {  415, 0x0000 }, {  415, 0x0000 }, {  415, 0x0000 },
-  {  415, 0x0000 }, {  415, 0x0000 }, {  415, 0x0000 }, {  415, 0x0000 },
+  {  517, 0x0001 }, {  518, 0x0000 }, {  518, 0x0000 }, {  518, 0x0000 },
+  {  518, 0x0000 }, {  518, 0x0000 }, {  518, 0x0000 }, {  518, 0x0000 },
+  {  518, 0x0000 }, {  518, 0x0000 }, {  518, 0x0000 }, {  518, 0x0000 },
+  {  518, 0x0000 }, {  518, 0x0000 }, {  518, 0x0000 }, {  518, 0x0000 },
   /* 0x9d00 */
-  {  415, 0x0000 }, {  415, 0x0000 }, {  415, 0x0000 }, {  415, 0x0000 },
-  {  415, 0x0000 }, {  415, 0x0000 }, {  415, 0x0800 }, {  416, 0x0001 },
-  {  417, 0x0000 }, {  417, 0x0000 }, {  417, 0x0000 }, {  417, 0x0000 },
-  {  417, 0x0000 }, {  417, 0x0000 }, {  417, 0x0000 }, {  417, 0x0000 },
+  {  518, 0x0000 }, {  518, 0x0000 }, {  518, 0x0000 }, {  518, 0x0000 },
+  {  518, 0x0000 }, {  518, 0x0000 }, {  518, 0x0800 }, {  519, 0x0001 },
+  {  520, 0x0000 }, {  520, 0x0000 }, {  520, 0x0000 }, {  520, 0x0000 },
+  {  520, 0x0000 }, {  520, 0x0000 }, {  520, 0x0000 }, {  520, 0x0000 },
   /* 0x9e00 */
-  {  417, 0x0000 }, {  417, 0x0200 }, {  418, 0x0000 }, {  418, 0x0000 },
-  {  418, 0x0000 }, {  418, 0x0000 }, {  418, 0x0000 }, {  418, 0x0000 },
-  {  418, 0x0000 }, {  418, 0x0000 }, {  418, 0x0000 }, {  418, 0x0000 },
-  {  418, 0x0000 }, {  418, 0x0002 },
+  {  520, 0x0000 }, {  520, 0x0200 }, {  521, 0x0000 }, {  521, 0x0000 },
+  {  521, 0x0000 }, {  521, 0x0000 }, {  521, 0x0000 }, {  521, 0x0000 },
+  {  521, 0x0000 }, {  521, 0x0000 }, {  521, 0x0000 }, {  521, 0x0000 },
+  {  521, 0x0000 }, {  521, 0x0002 },
 };
 static const Summary16 cp932ext_uni2indx_pagef9[19] = {
   /* 0xf900 */
-  {  419, 0x0000 }, {  419, 0x0000 }, {  419, 0x0200 }, {  420, 0x0000 },
-  {  420, 0x0000 }, {  420, 0x0000 }, {  420, 0x0000 }, {  420, 0x0000 },
-  {  420, 0x0000 }, {  420, 0x0000 }, {  420, 0x0000 }, {  420, 0x0000 },
-  {  420, 0x0000 }, {  420, 0x1000 }, {  421, 0x0000 }, {  421, 0x0000 },
+  {  522, 0x0000 }, {  522, 0x0000 }, {  522, 0x0200 }, {  523, 0x0000 },
+  {  523, 0x0000 }, {  523, 0x0000 }, {  523, 0x0000 }, {  523, 0x0000 },
+  {  523, 0x0000 }, {  523, 0x0000 }, {  523, 0x0000 }, {  523, 0x0000 },
+  {  523, 0x0000 }, {  523, 0x1000 }, {  524, 0x0000 }, {  524, 0x0000 },
   /* 0xfa00 */
-  {  421, 0xc000 }, {  423, 0xffff }, {  439, 0x3fff },
+  {  524, 0xc000 }, {  526, 0xffff }, {  542, 0x3fff },
 };
 static const Summary16 cp932ext_uni2indx_pageff[15] = {
   /* 0xff00 */
-  {  453, 0x0084 }, {  455, 0x0000 }, {  455, 0x0000 }, {  455, 0x0000 },
-  {  455, 0x0000 }, {  455, 0x0000 }, {  455, 0x0000 }, {  455, 0x0000 },
-  {  455, 0x0000 }, {  455, 0x0000 }, {  455, 0x0000 }, {  455, 0x0000 },
-  {  455, 0x0000 }, {  455, 0x0000 }, {  455, 0x0014 },
+  {  556, 0xfffe }, {  571, 0xfc00 }, {  577, 0x0001 }, {  578, 0xf800 },
+  {  583, 0x0001 }, {  584, 0x7800 }, {  588, 0x0000 }, {  588, 0x0000 },
+  {  588, 0x0000 }, {  588, 0x0000 }, {  588, 0x0000 }, {  588, 0x0000 },
+  {  588, 0x0000 }, {  588, 0x0000 }, {  588, 0x003f },
 };
 
 static int
-cp932ext_wctomb (conv_t conv, unsigned char *r, ucs4_t wc, size_t n)
+cp932ext_wctomb (conv_t conv, unsigned char *r, ucs4_t wc, int n)
 {
   if (n >= 2) {
     const Summary16 *summary = NULL;
-    if (wc >= 0x2100 && wc < 0x22c0)
-      summary = &cp932ext_uni2indx_page21[(wc>>4)-0x210];
-    else if (wc >= 0x2400 && wc < 0x2480)
-      summary = &cp932ext_uni2indx_page24[(wc>>4)-0x240];
-    else if (wc >= 0x3000 && wc < 0x3020)
+    if (wc >= 0x0000 && wc < 0x0100)
+      summary = &cp932ext_uni2indx_page00[(wc>>4)];
+    else if (wc >= 0x2000 && wc < 0x2670)
+      summary = &cp932ext_uni2indx_page20[(wc>>4)-0x200];
+    else if (wc >= 0x3000 && wc < 0x3100)
       summary = &cp932ext_uni2indx_page30[(wc>>4)-0x300];
     else if (wc >= 0x3200 && wc < 0x33d0)
       summary = &cp932ext_uni2indx_page32[(wc>>4)-0x320];
@@ -690,9 +767,9 @@ cp932ext_wctomb (conv_t conv, unsigned c
       unsigned int i = wc & 0x0f;
       if (used & ((unsigned short) 1 << i)) {
         unsigned short c;
-        /* Keep in 'used' only the bits 0..i-1. */
+        /* Keep in `used' only the bits 0..i-1. */
         used &= ((unsigned short) 1 << i) - 1;
-        /* Add 'summary->indx' and the number of bits set in 'used'. */
+        /* Add `summary->indx' and the number of bits set in `used'. */
         used = (used & 0x5555) + ((used & 0xaaaa) >> 1);
         used = (used & 0x3333) + ((used & 0xcccc) >> 2);
         used = (used & 0x0f0f) + ((used & 0xf0f0) >> 4);
diff -uprN libiconv-1.15-old/lib/encodings.def libiconv-1.15/lib/encodings.def
--- libiconv-1.15-old/lib/encodings.def	2014-01-03 07:23:02.000000000 +0900
+++ libiconv-1.15/lib/encodings.def	2017-09-17 06:32:15.929437000 +0900
@@ -148,6 +148,12 @@ DEFENCODING(( "UTF-7",
             utf7,
             { utf7_mbtowc, NULL },        { utf7_wctomb, utf7_reset })
 
+DEFENCODING(( "UTF-7-IMAP",             /* RFC 2060, sec. 5.1.3 */
+              "UTF7IMAP",
+            ),
+            utf7imap,
+            { utf7imap_mbtowc, NULL },    { utf7imap_wctomb, utf7imap_reset })
+
 DEFENCODING(( "UCS-2-INTERNAL",         /* libiconv */
             ),
             ucs2internal,
@@ -815,7 +821,6 @@ DEFENCODING(( "EUC-JP",
               "Extended_UNIX_Code_Packed_Format_for_Japanese", /* IANA */
               "csEUCPkdFmtJapanese",    /* IANA */
             /*"EUC_JP",                    JDK 1.1 */
-            /*"CP51932",                   Windows */
             ),
             euc_jp,
             { euc_jp_mbtowc, NULL },      { euc_jp_wctomb, NULL })
@@ -828,6 +833,22 @@ DEFALIAS(     "SDECKANJI",
             euc_jp)
 #endif
 
+DEFENCODING(( "EUCJP-MS",               /* TOG/JVC */
+              "EUCJP-OPEN",             /* TOG/JVC */
+              "EUC-JP-MS",              /* glibc */
+              "EUCJP-WIN",              /* PHP */
+              "EUCJPMS",                /* MySQL */
+            ),
+            eucjp_ms,
+            { eucjp_ms_mbtowc, NULL },      { eucjp_ms_wctomb, NULL })
+
+DEFENCODING(( "CP51932",                /* Windows */
+              "WINDOWS-51932",          /* Windows */
+              "MS51932",
+            ),
+            cp51932,
+            { cp51932_mbtowc, NULL },       { cp51932_wctomb, NULL })
+
 DEFENCODING(( "SHIFT_JIS",              /* IANA */
               "SHIFT-JIS",              /* glibc */
               "SJIS",                   /* JDK 1.1, HP-UX, OSF/1 */
@@ -842,6 +863,14 @@ DEFALIAS(     "PCK",
 #endif
 
 DEFENCODING(( "CP932",                  /* glibc */
+              "WINDOWS-31J",            /* IANA */
+              "csWindows31J",           /* IANA */
+              "SJIS-OPEN",              /* TOG/VJC */
+              "SJIS-WIN",               /* PHP */
+              "WINDOWS-932",            /* Windows */
+              "MS932",                  /* Java */
+              "Shift_JIS-MS",
+              "SJIS-MS",
             ),
             cp932,
             { cp932_mbtowc, NULL },       { cp932_wctomb, NULL })
diff -uprN libiconv-1.15-old/lib/euc_jp.h libiconv-1.15/lib/euc_jp.h
--- libiconv-1.15-old/lib/euc_jp.h	2016-10-14 08:10:00.000000000 +0900
+++ libiconv-1.15/lib/euc_jp.h	2017-09-17 05:38:53.938763000 +0900
@@ -40,16 +40,8 @@ euc_jp_mbtowc (conv_t conv, ucs4_t *pwc,
         return jisx0208_mbtowc(conv,pwc,buf,2);
       } else
         return RET_ILSEQ;
-    } else {
-      /* User-defined range. See
-       * Ken Lunde's "CJKV Information Processing", table 4-66, p. 206. */
-      unsigned char c2 = s[1];
-      if (c2 >= 0xa1 && c2 < 0xff) {
-        *pwc = 0xe000 + 94*(c-0xf5) + (c2-0xa1);
-        return 2;
-      } else
-        return RET_ILSEQ;
-    }
+    } else
+      return RET_ILSEQ;
   }
   /* Code set 2 (half-width katakana) */
   if (c == 0x8e) {
@@ -89,16 +81,8 @@ euc_jp_mbtowc (conv_t conv, ucs4_t *pwc,
             return 3;
           } else
             return RET_ILSEQ;
-        } else {
-          /* User-defined range. See
-           * Ken Lunde's "CJKV Information Processing", table 4-66, p. 206. */
-          unsigned char c3 = s[2];
-          if (c3 >= 0xa1 && c3 < 0xff) {
-            *pwc = 0xe3ac + 94*(c2-0xf5) + (c3-0xa1);
-            return 3;
-          } else
-            return RET_ILSEQ;
-        }
+        } else
+          return RET_ILSEQ;
       } else
         return RET_ILSEQ;
     }
@@ -161,30 +145,5 @@ euc_jp_wctomb (conv_t conv, unsigned cha
     return 1;
   }
 
-  /* User-defined range. See
-   * Ken Lunde's "CJKV Information Processing", table 4-66, p. 206. */
-  if (wc >= 0xe000 && wc < 0xe758) {
-    if (wc < 0xe3ac) {
-      unsigned char c1, c2;
-      if (n < 2)
-        return RET_TOOSMALL;
-      c1 = (unsigned int) (wc - 0xe000) / 94;
-      c2 = (unsigned int) (wc - 0xe000) % 94;
-      r[0] = c1+0xf5;
-      r[1] = c2+0xa1;
-      return 2;
-    } else {
-      unsigned char c1, c2;
-      if (n < 3)
-        return RET_TOOSMALL;
-      c1 = (unsigned int) (wc - 0xe3ac) / 94;
-      c2 = (unsigned int) (wc - 0xe3ac) % 94;
-      r[0] = 0x8f;
-      r[1] = c1+0xf5;
-      r[2] = c2+0xa1;
-      return 3;
-    }
-  }
-
   return RET_ILUNI;
 }
diff -uprN libiconv-1.15-old/lib/eucjp_ms.h libiconv-1.15/lib/eucjp_ms.h
--- libiconv-1.15-old/lib/eucjp_ms.h	1970-01-01 09:00:00.000000000 +0900
+++ libiconv-1.15/lib/eucjp_ms.h	2017-09-17 06:17:40.004650000 +0900
@@ -0,0 +1,273 @@
+/*
+ * Copyright (C) 1999-2003 Free Software Foundation, Inc.
+ * This file is part of the GNU LIBICONV Library.
+ *
+ * The GNU LIBICONV Library is free software; you can redistribute it
+ * and/or modify it under the terms of the GNU Library General Public
+ * License as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * The GNU LIBICONV Library is distributed in the hope that it will be
+ * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Library General Public License for more details.
+ *
+ * You should have received a copy of the GNU Library General Public
+ * License along with the GNU LIBICONV Library; see the file COPYING.LIB.
+ * If not, write to the Free Software Foundation, Inc., 59 Temple Place -
+ * Suite 330, Boston, MA 02111-1307, USA.
+ */
+
+/*
+ * eucJP-ms
+ */
+
+#include "eucjp_msext.h"
+
+static int
+eucjp_ms_mbtowc (conv_t conv, ucs4_t *pwc, const unsigned char *s, size_t n)
+{
+  unsigned char c = *s;
+  /* Code set 0 (ASCII or JIS X 0201-1976 Roman) */
+  if (c < 0x80)
+    return ascii_mbtowc(conv,pwc,s,n);
+
+  /* Code set 1 (JIS X 0208) */
+  if (c >= 0xa1 && c < 0xff) {
+    if (n < 2)
+      return RET_TOOFEW(0);
+    if (c == 0xa1 || c == 0xa2 || c == 0xad) {
+      /* Code set 1 (eucJP-ms Rows 1,2 and 13) */
+      unsigned char c1 = c;
+      unsigned char c2 = s[1];
+      if (c2 >= 0xa1 && c2 < 0xff) {
+        unsigned char t1 = (c1 - 0xa1) >> 1;
+        unsigned char t2 = (((c1 - 0xa1) & 1) ? 0x5e : 0) + (c2 - 0xa1);
+        unsigned char buf[2];
+        buf[0] = (t1 < 0x1f ? t1+0x81 : t1+0xc1);
+        buf[1] = (t2 < 0x3f ? t2+0x40 : t2+0x41);
+        return cp932ext_mbtowc(conv,pwc,buf,2);
+      } else
+        return RET_ILSEQ;
+    }
+    else if (c < 0xf5) {
+      unsigned char c2 = s[1];
+      if (c2 >= 0xa1 && c2 < 0xff) {
+        unsigned char buf[2];
+        buf[0] = c-0x80; buf[1] = c2-0x80;
+        return jisx0208_mbtowc(conv,pwc,buf,2);
+      } else
+        return RET_ILSEQ;
+    } else {
+      /* User-defined range. See
+       * Ken Lunde's "CJKV Information Processing", table 4-66, p. 206. */
+      unsigned char c2 = s[1];
+      if (c2 >= 0xa1 && c2 < 0xff) {
+        *pwc = 0xe000 + 94*(c-0xf5) + (c2-0xa1);
+        return 2;
+      } else
+        return RET_ILSEQ;
+    }
+  }
+  /* Code set 2 (half-width katakana) */
+  if (c == 0x8e) {
+    if (n < 2)
+      return RET_TOOFEW(0);
+    {
+      unsigned char c2 = s[1];
+      if (c2 >= 0xa1 && c2 < 0xe0) {
+        int ret = jisx0201_mbtowc(conv,pwc,s+1,n-1);
+        if (ret == RET_ILSEQ)
+          return RET_ILSEQ;
+        if (ret != 1) abort();
+        return 2;
+      } else
+        return RET_ILSEQ;
+    }
+  }
+  /* Code set 3 (JIS X 0212-1990) */
+  if (c == 0x8f) {
+    if (n < 2)
+      return RET_TOOFEW(0);
+    {
+      unsigned char c2 = s[1];
+      if (c2 == 0xa2) {
+        if (n < 3)
+          return RET_TOOFEW(0);
+        else {
+          unsigned char c3 = s[2];
+          if (c3 == 0xc3) {
+            *pwc = 0xffe4;
+            return 3;
+          }
+        }
+      }
+      if (c2 >= 0xa1 && c2 < 0xff) {
+        if (n < 3)
+          return RET_TOOFEW(0);
+        if (c2 < 0xf3) {
+          unsigned char c3 = s[2];
+          if (c3 >= 0xa1 && c3 < 0xff) {
+            unsigned char buf[2];
+            int ret;
+            buf[0] = c2-0x80; buf[1] = c3-0x80;
+            ret = jisx0212_mbtowc(conv,pwc,buf,2);
+            if (ret == RET_ILSEQ)
+              return RET_ILSEQ;
+            if (ret != 2) abort();
+            return 3;
+          } else
+            return RET_ILSEQ;
+        }
+        else if (c2 >= 0xf3 && c2 < 0xf5) {
+          /* Code set 3 (eucJP-ms Rows 83 and 84) */
+          unsigned char c3 = s[2];
+          if (c3 >= 0xa1 && c3 < 0xff) {
+            unsigned char buf[2];
+            int ret;
+            buf[0] = c2; buf[1] = c3;
+            ret = eucjp_msext_mbtowc(conv,pwc,buf,2);
+            if (ret == RET_ILSEQ)
+              return RET_ILSEQ;
+            if (ret != 2) abort();
+            return 3;
+          } else
+            return RET_ILSEQ;
+        } else {
+          /* User-defined range. See
+           * Ken Lunde's "CJKV Information Processing", table 4-66, p. 206. */
+          unsigned char c3 = s[2];
+          if (c3 >= 0xa1 && c3 < 0xff) {
+            *pwc = 0xe3ac + 94*(c2-0xf5) + (c3-0xa1);
+            return 3;
+          } else
+            return RET_ILSEQ;
+        }
+      } else
+        return RET_ILSEQ;
+    }
+  }
+  return RET_ILSEQ;
+}
+
+static int
+eucjp_ms_wctomb (conv_t conv, unsigned char *r, ucs4_t wc, size_t n)
+{
+  unsigned char buf[2];
+  int ret;
+
+  switch (wc) {
+    case 0x2014: wc = 0x2015; break;
+  }
+
+  /* Code set 0 (ASCII or JIS X 0201-1976 Roman) */
+  ret = ascii_wctomb(conv,r,wc,n);
+  if (ret != RET_ILUNI)
+    return ret;
+
+  /* Code set 1 (JIS X 0208) */
+  ret = jisx0208_wctomb(conv,buf,wc,2);
+  if (ret != RET_ILUNI) {
+    if (ret != 2) abort();
+    if (n < 2)
+      return RET_TOOSMALL;
+    r[0] = buf[0]+0x80;
+    r[1] = buf[1]+0x80;
+    return 2;
+  }
+
+  /* Code set 1 (eucJP-ms Rows 1,2 and 13) */
+  ret = cp932ext_wctomb(conv,buf,wc,2);
+  if (ret != RET_ILUNI) {
+    unsigned char s1, s2;
+    if (ret != 2) abort();
+    if (n < 2)
+      return RET_TOOSMALL;
+    s1 = buf[0];
+    s2 = buf[1];
+    if (s1 < 0xf0) {
+      unsigned char t1 = (s1 < 0xe0 ? s1-0x81 : s1-0xc1);
+      unsigned char t2 = (s2 < 0x80 ? s2-0x40 : s2-0x41);
+      r[0] = 2*t1 + (t2 < 0x5e ? 0 : 1) + 0xa1;
+      r[1] = (t2 < 0x5e ? t2 : t2-0x5e) + 0xa1;
+      return 2;
+    }
+  }
+
+  /* Code set 2 (half-width katakana) */
+  ret = jisx0201_wctomb(conv,buf,wc,1);
+  if (ret != RET_ILUNI && buf[0] >= 0x80) {
+    if (ret != 1) abort();
+    if (n < 2)
+      return RET_TOOSMALL;
+    r[0] = 0x8e;
+    r[1] = buf[0];
+    return 2;
+  }
+
+  /* Code set 3 (JIS X 0212-1990) */
+  ret = jisx0212_wctomb(conv,buf,wc,2);
+  if (ret != RET_ILUNI) {
+    if (ret != 2) abort();
+    if (n < 3)
+      return RET_TOOSMALL;
+    r[0] = 0x8f;
+    r[1] = buf[0]+0x80;
+    r[2] = buf[1]+0x80;
+    return 3;
+  }
+
+  /* Code set 3 (eucJP-ms Rows 83 and 84) */
+  ret = eucjp_msext_wctomb(conv,buf,wc,2);
+  if (ret != RET_ILUNI) {
+    if (ret != 2) abort();
+    if (n < 3)
+      return RET_TOOSMALL;
+    r[0] = 0x8f;
+    r[1] = buf[0];
+    r[2] = buf[1];
+    return 3;
+  }
+
+  /* Extra compatibility with Shift_JIS.  */
+  if (wc == 0x00a5) {
+    r[0] = 0x5c;
+    return 1;
+  }
+  if (wc == 0x203e) {
+    r[0] = 0x7e;
+    return 1;
+  }
+
+  if (wc == 0xffe4) {
+    r[0] = 0x8f; r[1] = 0xa2; r[2] = 0xc3;
+    return 3;
+  }
+
+  /* User-defined range. See
+   * Ken Lunde's "CJKV Information Processing", table 4-66, p. 206. */
+  if (wc >= 0xe000 && wc < 0xe758) {
+    if (wc < 0xe3ac) {
+      unsigned char c1, c2;
+      if (n < 2)
+        return RET_TOOSMALL;
+      c1 = (unsigned int) (wc - 0xe000) / 94;
+      c2 = (unsigned int) (wc - 0xe000) % 94;
+      r[0] = c1+0xf5;
+      r[1] = c2+0xa1;
+      return 2;
+    } else {
+      unsigned char c1, c2;
+      if (n < 2)
+        return RET_TOOSMALL;
+      c1 = (unsigned int) (wc - 0xe3ac) / 94;
+      c2 = (unsigned int) (wc - 0xe3ac) % 94;
+      r[0] = 0x8f;
+      r[1] = c1+0xf5;
+      r[2] = c2+0xa1;
+      return 3;
+    }
+  }
+
+  return RET_ILUNI;
+}
diff -uprN libiconv-1.15-old/lib/eucjp_msext.h libiconv-1.15/lib/eucjp_msext.h
--- libiconv-1.15-old/lib/eucjp_msext.h	1970-01-01 09:00:00.000000000 +0900
+++ libiconv-1.15/lib/eucjp_msext.h	2017-09-17 05:38:53.946790000 +0900
@@ -0,0 +1,405 @@
+/*
+ * Copyright (C) 1999-2003 Free Software Foundation, Inc.
+ * This file is part of the GNU LIBICONV Library.
+ *
+ * The GNU LIBICONV Library is free software; you can redistribute it
+ * and/or modify it under the terms of the GNU Library General Public
+ * License as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * The GNU LIBICONV Library is distributed in the hope that it will be
+ * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Library General Public License for more details.
+ *
+ * You should have received a copy of the GNU Library General Public
+ * License along with the GNU LIBICONV Library; see the file COPYING.LIB.
+ * If not, write to the Free Software Foundation, Inc., 59 Temple Place -
+ * Suite 330, Boston, MA 02111-1307, USA.
+ */
+
+/*
+ * eucJP-ms extensions
+ */
+
+static const unsigned short eucjp_msext_2uni_pagef3[188] = {
+  /* 0xf3 */
+  0xfffd, 0xfffd, 0xfffd, 0xfffd, 0xfffd, 0xfffd, 0xfffd, 0xfffd,
+  0xfffd, 0xfffd, 0xfffd, 0xfffd, 0xfffd, 0xfffd, 0xfffd, 0xfffd,
+  0xfffd, 0xfffd, 0xfffd, 0xfffd, 0xfffd, 0xfffd, 0xfffd, 0xfffd,
+  0xfffd, 0xfffd, 0xfffd, 0xfffd, 0xfffd, 0xfffd, 0xfffd, 0xfffd,
+  0xfffd, 0xfffd, 0xfffd, 0xfffd, 0xfffd, 0xfffd, 0xfffd, 0xfffd,
+  0xfffd, 0xfffd, 0xfffd, 0xfffd, 0xfffd, 0xfffd, 0xfffd, 0xfffd,
+  0xfffd, 0xfffd, 0xfffd, 0xfffd, 0xfffd, 0xfffd, 0xfffd, 0xfffd,
+  0xfffd, 0xfffd, 0xfffd, 0xfffd, 0xfffd, 0xfffd, 0xfffd, 0xfffd,
+  0xfffd, 0xfffd, 0xfffd, 0xfffd, 0xfffd, 0xfffd, 0xfffd, 0xfffd,
+  0xfffd, 0xfffd, 0xfffd, 0xfffd, 0xfffd, 0xfffd, 0xfffd, 0xfffd,
+  0xfffd, 0xfffd, 0x2170, 0x2171, 0x2172, 0x2173, 0x2174, 0x2175,
+  0x2176, 0x2177, 0x2178, 0x2179, 0x2160, 0x2161,
+  /* 0xf4 */
+  0x2162, 0x2163, 0x2164, 0x2165, 0x2166, 0x2167, 0x2168, 0x2169,
+  0xff07, 0xff02, 0x3231, 0x2116, 0x2121, 0x70bb, 0x4efc, 0x50f4,
+  0x51ec, 0x5307, 0x5324, 0xfa0e, 0x548a, 0x5759, 0xfa0f, 0xfa10,
+  0x589e, 0x5bec, 0x5cf5, 0x5d53, 0xfa11, 0x5fb7, 0x6085, 0x6120,
+  0x654e, 0x663b, 0x6665, 0xfa12, 0xf929, 0x6801, 0xfa13, 0xfa14,
+  0x6a6b, 0x6ae2, 0x6df8, 0x6df2, 0x7028, 0xfa15, 0xfa16, 0x7501,
+  0x7682, 0x769e, 0xfa17, 0x7930, 0xfa18, 0xfa19, 0xfa1a, 0xfa1b,
+  0x7ae7, 0xfa1c, 0xfa1d, 0x7da0, 0x7dd6, 0xfa1e, 0x8362, 0xfa1f,
+  0x85b0, 0xfa20, 0xfa21, 0x8807, 0xfa22, 0x8b7f, 0x8cf4, 0x8d76,
+  0xfa23, 0xfa24, 0xfa25, 0x90de, 0xfa26, 0x9115, 0xfa27, 0xfa28,
+  0x9592, 0xf9dc, 0xfa29, 0x973b, 0x974d, 0x9751, 0xfa2a, 0xfa2b,
+  0xfa2c, 0x999e, 0x9ad9, 0x9b72, 0xfa2d, 0x9ed1,
+};
+
+static int
+eucjp_msext_mbtowc (conv_t conv, ucs4_t *pwc, const unsigned char *s, int n)
+{
+  unsigned char c1 = s[0];
+  if ((c1 >= 0xf3 && c1 <= 0xf4)) {
+    if (n >= 2) {
+      unsigned char c2 = s[1];
+      if (c2 >= 0xa1 && c2 < 0xff) {
+        unsigned int i = 94 * (c1 - 0xa1) + (c2 - 0xa1);
+        unsigned short wc = 0xfffd;
+        {
+          if (i < 7896)
+            wc = eucjp_msext_2uni_pagef3[i-7708];
+        }
+        if (wc != 0xfffd) {
+          *pwc = (ucs4_t) wc;
+          return 2;
+        }
+      }
+      return RET_ILSEQ;
+    }
+    return RET_TOOFEW(0);
+  }
+  return RET_ILSEQ;
+}
+
+static const unsigned short eucjp_msext_2charset[106] = {
+  0xf4ac, 0xf4ad, 0xf3fd, 0xf3fe, 0xf4a1, 0xf4a2, 0xf4a3, 0xf4a4,
+  0xf4a5, 0xf4a6, 0xf4a7, 0xf4a8, 0xf3f3, 0xf3f4, 0xf3f5, 0xf3f6,
+  0xf3f7, 0xf3f8, 0xf3f9, 0xf3fa, 0xf3fb, 0xf3fc, 0xf4ab, 0xf4af,
+  0xf4b0, 0xf4b1, 0xf4b2, 0xf4b3, 0xf4b5, 0xf4b6, 0xf4b9, 0xf4ba,
+  0xf4bb, 0xf4bc, 0xf4be, 0xf4bf, 0xf4c0, 0xf4c1, 0xf4c2, 0xf4c3,
+  0xf4c6, 0xf4c9, 0xf4ca, 0xf4cc, 0xf4cb, 0xf4cd, 0xf4ae, 0xf4d0,
+  0xf4d1, 0xf4d2, 0xf4d4, 0xf4d9, 0xf4dc, 0xf4dd, 0xf4df, 0xf4e1,
+  0xf4e4, 0xf4e6, 0xf4e7, 0xf4e8, 0xf4ec, 0xf4ee, 0xf4f1, 0xf4f4,
+  0xf4f5, 0xf4f6, 0xf4fa, 0xf4fb, 0xf4fc, 0xf4fe, 0xf4c5, 0xf4f2,
+  0xf4b4, 0xf4b7, 0xf4b8, 0xf4bd, 0xf4c4, 0xf4c7, 0xf4c8, 0xf4ce,
+  0xf4cf, 0xf4d3, 0xf4d5, 0xf4d6, 0xf4d7, 0xf4d8, 0xf4da, 0xf4db,
+  0xf4de, 0xf4e0, 0xf4e2, 0xf4e3, 0xf4e5, 0xf4e9, 0xf4ea, 0xf4eb,
+  0xf4ed, 0xf4ef, 0xf4f0, 0xf4f3, 0xf4f7, 0xf4f8, 0xf4f9, 0xf4fd,
+  0xf4aa, 0xf4a9,
+};
+
+static const Summary16 eucjp_msext_uni2indx_page21[8] = {
+  /* 0x2100 */
+  {    0, 0x0000 }, {    0, 0x0040 }, {    1, 0x0002 }, {    2, 0x0000 },
+  {    2, 0x0000 }, {    2, 0x0000 }, {    2, 0x03ff }, {   12, 0x03ff },
+};
+static const Summary16 eucjp_msext_uni2indx_page32[4] = {
+  /* 0x3200 */
+  {   22, 0x0000 }, {   22, 0x0000 }, {   22, 0x0000 }, {   22, 0x0002 },
+};
+static const Summary16 eucjp_msext_uni2indx_page4e[16] = {
+  /* 0x4e00 */
+  {   23, 0x0000 }, {   23, 0x0000 }, {   23, 0x0000 }, {   23, 0x0000 },
+  {   23, 0x0000 }, {   23, 0x0000 }, {   23, 0x0000 }, {   23, 0x0000 },
+  {   23, 0x0000 }, {   23, 0x0000 }, {   23, 0x0000 }, {   23, 0x0000 },
+  {   23, 0x0000 }, {   23, 0x0000 }, {   23, 0x0000 }, {   23, 0x1000 },
+};
+static const Summary16 eucjp_msext_uni2indx_page50[31] = {
+  /* 0x5000 */
+  {   24, 0x0000 }, {   24, 0x0000 }, {   24, 0x0000 }, {   24, 0x0000 },
+  {   24, 0x0000 }, {   24, 0x0000 }, {   24, 0x0000 }, {   24, 0x0000 },
+  {   24, 0x0000 }, {   24, 0x0000 }, {   24, 0x0000 }, {   24, 0x0000 },
+  {   24, 0x0000 }, {   24, 0x0000 }, {   24, 0x0000 }, {   24, 0x0010 },
+  /* 0x5100 */
+  {   25, 0x0000 }, {   25, 0x0000 }, {   25, 0x0000 }, {   25, 0x0000 },
+  {   25, 0x0000 }, {   25, 0x0000 }, {   25, 0x0000 }, {   25, 0x0000 },
+  {   25, 0x0000 }, {   25, 0x0000 }, {   25, 0x0000 }, {   25, 0x0000 },
+  {   25, 0x0000 }, {   25, 0x0000 }, {   25, 0x1000 },
+};
+static const Summary16 eucjp_msext_uni2indx_page53[25] = {
+  /* 0x5300 */
+  {   26, 0x0080 }, {   27, 0x0000 }, {   27, 0x0010 }, {   28, 0x0000 },
+  {   28, 0x0000 }, {   28, 0x0000 }, {   28, 0x0000 }, {   28, 0x0000 },
+  {   28, 0x0000 }, {   28, 0x0000 }, {   28, 0x0000 }, {   28, 0x0000 },
+  {   28, 0x0000 }, {   28, 0x0000 }, {   28, 0x0000 }, {   28, 0x0000 },
+  /* 0x5400 */
+  {   28, 0x0000 }, {   28, 0x0000 }, {   28, 0x0000 }, {   28, 0x0000 },
+  {   28, 0x0000 }, {   28, 0x0000 }, {   28, 0x0000 }, {   28, 0x0000 },
+  {   28, 0x0400 },
+};
+static const Summary16 eucjp_msext_uni2indx_page57[26] = {
+  /* 0x5700 */
+  {   29, 0x0000 }, {   29, 0x0000 }, {   29, 0x0000 }, {   29, 0x0000 },
+  {   29, 0x0000 }, {   29, 0x0200 }, {   30, 0x0000 }, {   30, 0x0000 },
+  {   30, 0x0000 }, {   30, 0x0000 }, {   30, 0x0000 }, {   30, 0x0000 },
+  {   30, 0x0000 }, {   30, 0x0000 }, {   30, 0x0000 }, {   30, 0x0000 },
+  /* 0x5800 */
+  {   30, 0x0000 }, {   30, 0x0000 }, {   30, 0x0000 }, {   30, 0x0000 },
+  {   30, 0x0000 }, {   30, 0x0000 }, {   30, 0x0000 }, {   30, 0x0000 },
+  {   30, 0x0000 }, {   30, 0x4000 },
+};
+static const Summary16 eucjp_msext_uni2indx_page5b[38] = {
+  /* 0x5b00 */
+  {   31, 0x0000 }, {   31, 0x0000 }, {   31, 0x0000 }, {   31, 0x0000 },
+  {   31, 0x0000 }, {   31, 0x0000 }, {   31, 0x0000 }, {   31, 0x0000 },
+  {   31, 0x0000 }, {   31, 0x0000 }, {   31, 0x0000 }, {   31, 0x0000 },
+  {   31, 0x0000 }, {   31, 0x0000 }, {   31, 0x1000 }, {   32, 0x0000 },
+  /* 0x5c00 */
+  {   32, 0x0000 }, {   32, 0x0000 }, {   32, 0x0000 }, {   32, 0x0000 },
+  {   32, 0x0000 }, {   32, 0x0000 }, {   32, 0x0000 }, {   32, 0x0000 },
+  {   32, 0x0000 }, {   32, 0x0000 }, {   32, 0x0000 }, {   32, 0x0000 },
+  {   32, 0x0000 }, {   32, 0x0000 }, {   32, 0x0000 }, {   32, 0x0020 },
+  /* 0x5d00 */
+  {   33, 0x0000 }, {   33, 0x0000 }, {   33, 0x0000 }, {   33, 0x0000 },
+  {   33, 0x0000 }, {   33, 0x0008 },
+};
+static const Summary16 eucjp_msext_uni2indx_page5f[35] = {
+  /* 0x5f00 */
+  {   34, 0x0000 }, {   34, 0x0000 }, {   34, 0x0000 }, {   34, 0x0000 },
+  {   34, 0x0000 }, {   34, 0x0000 }, {   34, 0x0000 }, {   34, 0x0000 },
+  {   34, 0x0000 }, {   34, 0x0000 }, {   34, 0x0000 }, {   34, 0x0080 },
+  {   35, 0x0000 }, {   35, 0x0000 }, {   35, 0x0000 }, {   35, 0x0000 },
+  /* 0x6000 */
+  {   35, 0x0000 }, {   35, 0x0000 }, {   35, 0x0000 }, {   35, 0x0000 },
+  {   35, 0x0000 }, {   35, 0x0000 }, {   35, 0x0000 }, {   35, 0x0000 },
+  {   35, 0x0020 }, {   36, 0x0000 }, {   36, 0x0000 }, {   36, 0x0000 },
+  {   36, 0x0000 }, {   36, 0x0000 }, {   36, 0x0000 }, {   36, 0x0000 },
+  /* 0x6100 */
+  {   36, 0x0000 }, {   36, 0x0000 }, {   36, 0x0001 },
+};
+static const Summary16 eucjp_msext_uni2indx_page65[23] = {
+  /* 0x6500 */
+  {   37, 0x0000 }, {   37, 0x0000 }, {   37, 0x0000 }, {   37, 0x0000 },
+  {   37, 0x4000 }, {   38, 0x0000 }, {   38, 0x0000 }, {   38, 0x0000 },
+  {   38, 0x0000 }, {   38, 0x0000 }, {   38, 0x0000 }, {   38, 0x0000 },
+  {   38, 0x0000 }, {   38, 0x0000 }, {   38, 0x0000 }, {   38, 0x0000 },
+  /* 0x6600 */
+  {   38, 0x0000 }, {   38, 0x0000 }, {   38, 0x0000 }, {   38, 0x0800 },
+  {   39, 0x0000 }, {   39, 0x0000 }, {   39, 0x0020 },
+};
+static const Summary16 eucjp_msext_uni2indx_page68[1] = {
+  /* 0x6800 */
+  {   40, 0x0002 },
+};
+static const Summary16 eucjp_msext_uni2indx_page6a[15] = {
+  /* 0x6a00 */
+  {   41, 0x0000 }, {   41, 0x0000 }, {   41, 0x0000 }, {   41, 0x0000 },
+  {   41, 0x0000 }, {   41, 0x0000 }, {   41, 0x0800 }, {   42, 0x0000 },
+  {   42, 0x0000 }, {   42, 0x0000 }, {   42, 0x0000 }, {   42, 0x0000 },
+  {   42, 0x0000 }, {   42, 0x0000 }, {   42, 0x0004 },
+};
+static const Summary16 eucjp_msext_uni2indx_page6d[16] = {
+  /* 0x6d00 */
+  {   43, 0x0000 }, {   43, 0x0000 }, {   43, 0x0000 }, {   43, 0x0000 },
+  {   43, 0x0000 }, {   43, 0x0000 }, {   43, 0x0000 }, {   43, 0x0000 },
+  {   43, 0x0000 }, {   43, 0x0000 }, {   43, 0x0000 }, {   43, 0x0000 },
+  {   43, 0x0000 }, {   43, 0x0000 }, {   43, 0x0000 }, {   43, 0x0104 },
+};
+static const Summary16 eucjp_msext_uni2indx_page70[12] = {
+  /* 0x7000 */
+  {   45, 0x0000 }, {   45, 0x0000 }, {   45, 0x0100 }, {   46, 0x0000 },
+  {   46, 0x0000 }, {   46, 0x0000 }, {   46, 0x0000 }, {   46, 0x0000 },
+  {   46, 0x0000 }, {   46, 0x0000 }, {   46, 0x0000 }, {   46, 0x0800 },
+};
+static const Summary16 eucjp_msext_uni2indx_page75[26] = {
+  /* 0x7500 */
+  {   47, 0x0002 }, {   48, 0x0000 }, {   48, 0x0000 }, {   48, 0x0000 },
+  {   48, 0x0000 }, {   48, 0x0000 }, {   48, 0x0000 }, {   48, 0x0000 },
+  {   48, 0x0000 }, {   48, 0x0000 }, {   48, 0x0000 }, {   48, 0x0000 },
+  {   48, 0x0000 }, {   48, 0x0000 }, {   48, 0x0000 }, {   48, 0x0000 },
+  /* 0x7600 */
+  {   48, 0x0000 }, {   48, 0x0000 }, {   48, 0x0000 }, {   48, 0x0000 },
+  {   48, 0x0000 }, {   48, 0x0000 }, {   48, 0x0000 }, {   48, 0x0000 },
+  {   48, 0x0004 }, {   49, 0x4000 },
+};
+static const Summary16 eucjp_msext_uni2indx_page79[31] = {
+  /* 0x7900 */
+  {   50, 0x0000 }, {   50, 0x0000 }, {   50, 0x0000 }, {   50, 0x0001 },
+  {   51, 0x0000 }, {   51, 0x0000 }, {   51, 0x0000 }, {   51, 0x0000 },
+  {   51, 0x0000 }, {   51, 0x0000 }, {   51, 0x0000 }, {   51, 0x0000 },
+  {   51, 0x0000 }, {   51, 0x0000 }, {   51, 0x0000 }, {   51, 0x0000 },
+  /* 0x7a00 */
+  {   51, 0x0000 }, {   51, 0x0000 }, {   51, 0x0000 }, {   51, 0x0000 },
+  {   51, 0x0000 }, {   51, 0x0000 }, {   51, 0x0000 }, {   51, 0x0000 },
+  {   51, 0x0000 }, {   51, 0x0000 }, {   51, 0x0000 }, {   51, 0x0000 },
+  {   51, 0x0000 }, {   51, 0x0000 }, {   51, 0x0080 },
+};
+static const Summary16 eucjp_msext_uni2indx_page7d[14] = {
+  /* 0x7d00 */
+  {   52, 0x0000 }, {   52, 0x0000 }, {   52, 0x0000 }, {   52, 0x0000 },
+  {   52, 0x0000 }, {   52, 0x0000 }, {   52, 0x0000 }, {   52, 0x0000 },
+  {   52, 0x0000 }, {   52, 0x0000 }, {   52, 0x0001 }, {   53, 0x0000 },
+  {   53, 0x0000 }, {   53, 0x0040 },
+};
+static const Summary16 eucjp_msext_uni2indx_page83[7] = {
+  /* 0x8300 */
+  {   54, 0x0000 }, {   54, 0x0000 }, {   54, 0x0000 }, {   54, 0x0000 },
+  {   54, 0x0000 }, {   54, 0x0000 }, {   54, 0x0004 },
+};
+static const Summary16 eucjp_msext_uni2indx_page85[12] = {
+  /* 0x8500 */
+  {   55, 0x0000 }, {   55, 0x0000 }, {   55, 0x0000 }, {   55, 0x0000 },
+  {   55, 0x0000 }, {   55, 0x0000 }, {   55, 0x0000 }, {   55, 0x0000 },
+  {   55, 0x0000 }, {   55, 0x0000 }, {   55, 0x0000 }, {   55, 0x0001 },
+};
+static const Summary16 eucjp_msext_uni2indx_page88[1] = {
+  /* 0x8800 */
+  {   56, 0x0080 },
+};
+static const Summary16 eucjp_msext_uni2indx_page8b[40] = {
+  /* 0x8b00 */
+  {   57, 0x0000 }, {   57, 0x0000 }, {   57, 0x0000 }, {   57, 0x0000 },
+  {   57, 0x0000 }, {   57, 0x0000 }, {   57, 0x0000 }, {   57, 0x8000 },
+  {   58, 0x0000 }, {   58, 0x0000 }, {   58, 0x0000 }, {   58, 0x0000 },
+  {   58, 0x0000 }, {   58, 0x0000 }, {   58, 0x0000 }, {   58, 0x0000 },
+  /* 0x8c00 */
+  {   58, 0x0000 }, {   58, 0x0000 }, {   58, 0x0000 }, {   58, 0x0000 },
+  {   58, 0x0000 }, {   58, 0x0000 }, {   58, 0x0000 }, {   58, 0x0000 },
+  {   58, 0x0000 }, {   58, 0x0000 }, {   58, 0x0000 }, {   58, 0x0000 },
+  {   58, 0x0000 }, {   58, 0x0000 }, {   58, 0x0000 }, {   58, 0x0010 },
+  /* 0x8d00 */
+  {   59, 0x0000 }, {   59, 0x0000 }, {   59, 0x0000 }, {   59, 0x0000 },
+  {   59, 0x0000 }, {   59, 0x0000 }, {   59, 0x0000 }, {   59, 0x0040 },
+};
+static const Summary16 eucjp_msext_uni2indx_page90[18] = {
+  /* 0x9000 */
+  {   60, 0x0000 }, {   60, 0x0000 }, {   60, 0x0000 }, {   60, 0x0000 },
+  {   60, 0x0000 }, {   60, 0x0000 }, {   60, 0x0000 }, {   60, 0x0000 },
+  {   60, 0x0000 }, {   60, 0x0000 }, {   60, 0x0000 }, {   60, 0x0000 },
+  {   60, 0x0000 }, {   60, 0x4000 }, {   61, 0x0000 }, {   61, 0x0000 },
+  /* 0x9100 */
+  {   61, 0x0000 }, {   61, 0x0020 },
+};
+static const Summary16 eucjp_msext_uni2indx_page95[10] = {
+  /* 0x9500 */
+  {   62, 0x0000 }, {   62, 0x0000 }, {   62, 0x0000 }, {   62, 0x0000 },
+  {   62, 0x0000 }, {   62, 0x0000 }, {   62, 0x0000 }, {   62, 0x0000 },
+  {   62, 0x0000 }, {   62, 0x0004 },
+};
+static const Summary16 eucjp_msext_uni2indx_page97[6] = {
+  /* 0x9700 */
+  {   63, 0x0000 }, {   63, 0x0000 }, {   63, 0x0000 }, {   63, 0x0800 },
+  {   64, 0x2000 }, {   65, 0x0002 },
+};
+static const Summary16 eucjp_msext_uni2indx_page99[40] = {
+  /* 0x9900 */
+  {   66, 0x0000 }, {   66, 0x0000 }, {   66, 0x0000 }, {   66, 0x0000 },
+  {   66, 0x0000 }, {   66, 0x0000 }, {   66, 0x0000 }, {   66, 0x0000 },
+  {   66, 0x0000 }, {   66, 0x4000 }, {   67, 0x0000 }, {   67, 0x0000 },
+  {   67, 0x0000 }, {   67, 0x0000 }, {   67, 0x0000 }, {   67, 0x0000 },
+  /* 0x9a00 */
+  {   67, 0x0000 }, {   67, 0x0000 }, {   67, 0x0000 }, {   67, 0x0000 },
+  {   67, 0x0000 }, {   67, 0x0000 }, {   67, 0x0000 }, {   67, 0x0000 },
+  {   67, 0x0000 }, {   67, 0x0000 }, {   67, 0x0000 }, {   67, 0x0000 },
+  {   67, 0x0000 }, {   67, 0x0200 }, {   68, 0x0000 }, {   68, 0x0000 },
+  /* 0x9b00 */
+  {   68, 0x0000 }, {   68, 0x0000 }, {   68, 0x0000 }, {   68, 0x0000 },
+  {   68, 0x0000 }, {   68, 0x0000 }, {   68, 0x0000 }, {   68, 0x0004 },
+};
+static const Summary16 eucjp_msext_uni2indx_page9e[14] = {
+  /* 0x9e00 */
+  {   69, 0x0000 }, {   69, 0x0000 }, {   69, 0x0000 }, {   69, 0x0000 },
+  {   69, 0x0000 }, {   69, 0x0000 }, {   69, 0x0000 }, {   69, 0x0000 },
+  {   69, 0x0000 }, {   69, 0x0000 }, {   69, 0x0000 }, {   69, 0x0000 },
+  {   69, 0x0000 }, {   69, 0x0002 },
+};
+static const Summary16 eucjp_msext_uni2indx_pagef9[19] = {
+  /* 0xf900 */
+  {   70, 0x0000 }, {   70, 0x0000 }, {   70, 0x0200 }, {   71, 0x0000 },
+  {   71, 0x0000 }, {   71, 0x0000 }, {   71, 0x0000 }, {   71, 0x0000 },
+  {   71, 0x0000 }, {   71, 0x0000 }, {   71, 0x0000 }, {   71, 0x0000 },
+  {   71, 0x0000 }, {   71, 0x1000 }, {   72, 0x0000 }, {   72, 0x0000 },
+  /* 0xfa00 */
+  {   72, 0xc000 }, {   74, 0xffff }, {   90, 0x3fff },
+};
+static const Summary16 eucjp_msext_uni2indx_pageff[1] = {
+  /* 0xff00 */
+  {  104, 0x0084 },
+};
+
+static int
+eucjp_msext_wctomb (conv_t conv, unsigned char *r, ucs4_t wc, int n)
+{
+  if (n >= 2) {
+    const Summary16 *summary = NULL;
+    if (wc >= 0x2100 && wc < 0x2180)
+      summary = &eucjp_msext_uni2indx_page21[(wc>>4)-0x210];
+    else if (wc >= 0x3200 && wc < 0x3240)
+      summary = &eucjp_msext_uni2indx_page32[(wc>>4)-0x320];
+    else if (wc >= 0x4e00 && wc < 0x4f00)
+      summary = &eucjp_msext_uni2indx_page4e[(wc>>4)-0x4e0];
+    else if (wc >= 0x5000 && wc < 0x51f0)
+      summary = &eucjp_msext_uni2indx_page50[(wc>>4)-0x500];
+    else if (wc >= 0x5300 && wc < 0x5490)
+      summary = &eucjp_msext_uni2indx_page53[(wc>>4)-0x530];
+    else if (wc >= 0x5700 && wc < 0x58a0)
+      summary = &eucjp_msext_uni2indx_page57[(wc>>4)-0x570];
+    else if (wc >= 0x5b00 && wc < 0x5d60)
+      summary = &eucjp_msext_uni2indx_page5b[(wc>>4)-0x5b0];
+    else if (wc >= 0x5f00 && wc < 0x6130)
+      summary = &eucjp_msext_uni2indx_page5f[(wc>>4)-0x5f0];
+    else if (wc >= 0x6500 && wc < 0x6670)
+      summary = &eucjp_msext_uni2indx_page65[(wc>>4)-0x650];
+    else if (wc >= 0x6800 && wc < 0x6810)
+      summary = &eucjp_msext_uni2indx_page68[(wc>>4)-0x680];
+    else if (wc >= 0x6a00 && wc < 0x6af0)
+      summary = &eucjp_msext_uni2indx_page6a[(wc>>4)-0x6a0];
+    else if (wc >= 0x6d00 && wc < 0x6e00)
+      summary = &eucjp_msext_uni2indx_page6d[(wc>>4)-0x6d0];
+    else if (wc >= 0x7000 && wc < 0x70c0)
+      summary = &eucjp_msext_uni2indx_page70[(wc>>4)-0x700];
+    else if (wc >= 0x7500 && wc < 0x76a0)
+      summary = &eucjp_msext_uni2indx_page75[(wc>>4)-0x750];
+    else if (wc >= 0x7900 && wc < 0x7af0)
+      summary = &eucjp_msext_uni2indx_page79[(wc>>4)-0x790];
+    else if (wc >= 0x7d00 && wc < 0x7de0)
+      summary = &eucjp_msext_uni2indx_page7d[(wc>>4)-0x7d0];
+    else if (wc >= 0x8300 && wc < 0x8370)
+      summary = &eucjp_msext_uni2indx_page83[(wc>>4)-0x830];
+    else if (wc >= 0x8500 && wc < 0x85c0)
+      summary = &eucjp_msext_uni2indx_page85[(wc>>4)-0x850];
+    else if (wc >= 0x8800 && wc < 0x8810)
+      summary = &eucjp_msext_uni2indx_page88[(wc>>4)-0x880];
+    else if (wc >= 0x8b00 && wc < 0x8d80)
+      summary = &eucjp_msext_uni2indx_page8b[(wc>>4)-0x8b0];
+    else if (wc >= 0x9000 && wc < 0x9120)
+      summary = &eucjp_msext_uni2indx_page90[(wc>>4)-0x900];
+    else if (wc >= 0x9500 && wc < 0x95a0)
+      summary = &eucjp_msext_uni2indx_page95[(wc>>4)-0x950];
+    else if (wc >= 0x9700 && wc < 0x9760)
+      summary = &eucjp_msext_uni2indx_page97[(wc>>4)-0x970];
+    else if (wc >= 0x9900 && wc < 0x9b80)
+      summary = &eucjp_msext_uni2indx_page99[(wc>>4)-0x990];
+    else if (wc >= 0x9e00 && wc < 0x9ee0)
+      summary = &eucjp_msext_uni2indx_page9e[(wc>>4)-0x9e0];
+    else if (wc >= 0xf900 && wc < 0xfa30)
+      summary = &eucjp_msext_uni2indx_pagef9[(wc>>4)-0xf90];
+    else if (wc >= 0xff00 && wc < 0xff10)
+      summary = &eucjp_msext_uni2indx_pageff[(wc>>4)-0xff0];
+    if (summary) {
+      unsigned short used = summary->used;
+      unsigned int i = wc & 0x0f;
+      if (used & ((unsigned short) 1 << i)) {
+        unsigned short c;
+        /* Keep in `used' only the bits 0..i-1. */
+        used &= ((unsigned short) 1 << i) - 1;
+        /* Add `summary->indx' and the number of bits set in `used'. */
+        used = (used & 0x5555) + ((used & 0xaaaa) >> 1);
+        used = (used & 0x3333) + ((used & 0xcccc) >> 2);
+        used = (used & 0x0f0f) + ((used & 0xf0f0) >> 4);
+        used = (used & 0x00ff) + (used >> 8);
+        c = eucjp_msext_2charset[summary->indx + used];
+        r[0] = (c >> 8); r[1] = (c & 0xff);
+        return 2;
+      }
+    }
+    return RET_ILUNI;
+  }
+  return RET_TOOSMALL;
+}
diff -uprN libiconv-1.15-old/lib/flags.h libiconv-1.15/lib/flags.h
--- libiconv-1.15-old/lib/flags.h	2017-01-02 08:03:24.000000000 +0900
+++ libiconv-1.15/lib/flags.h	2017-09-17 06:32:24.489662000 +0900
@@ -27,6 +27,7 @@
 #define ei_utf32be_oflags (HAVE_ACCENTS | HAVE_QUOTATION_MARKS | HAVE_HANGUL_JAMO)
 #define ei_utf32le_oflags (HAVE_ACCENTS | HAVE_QUOTATION_MARKS | HAVE_HANGUL_JAMO)
 #define ei_utf7_oflags (HAVE_ACCENTS | HAVE_QUOTATION_MARKS | HAVE_HANGUL_JAMO)
+#define ei_utf7imap_oflags (HAVE_ACCENTS | HAVE_QUOTATION_MARKS | HAVE_HANGUL_JAMO)
 #define ei_ucs2internal_oflags (HAVE_ACCENTS | HAVE_QUOTATION_MARKS | HAVE_HANGUL_JAMO)
 #define ei_ucs2swapped_oflags (HAVE_ACCENTS | HAVE_QUOTATION_MARKS | HAVE_HANGUL_JAMO)
 #define ei_ucs4internal_oflags (HAVE_ACCENTS | HAVE_QUOTATION_MARKS | HAVE_HANGUL_JAMO)
@@ -99,6 +100,8 @@
 #define ei_isoir165_oflags (HAVE_QUOTATION_MARKS)
 #define ei_ksc5601_oflags (HAVE_QUOTATION_MARKS | HAVE_HANGUL_JAMO)
 #define ei_euc_jp_oflags (HAVE_ACCENTS | HAVE_QUOTATION_MARKS)
+#define ei_eucjp_ms_oflags (HAVE_ACCENTS | HAVE_QUOTATION_MARKS)
+#define ei_cp51932_oflags (HAVE_ACCENTS | HAVE_QUOTATION_MARKS)
 #define ei_sjis_oflags (HAVE_ACCENTS | HAVE_QUOTATION_MARKS)
 #define ei_cp932_oflags (HAVE_ACCENTS | HAVE_QUOTATION_MARKS)
 #define ei_iso2022_jp_oflags (HAVE_ACCENTS | HAVE_QUOTATION_MARKS)
diff -uprN libiconv-1.15-old/lib/iso2022_jpms.h libiconv-1.15/lib/iso2022_jpms.h
--- libiconv-1.15-old/lib/iso2022_jpms.h	2016-10-14 07:49:26.000000000 +0900
+++ libiconv-1.15/lib/iso2022_jpms.h	2017-09-17 06:25:56.209584000 +0900
@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2001, 2008, 2011-2012, 2016 Free Software Foundation, Inc.
+ * Copyright (C) 1999-2004 Free Software Foundation, Inc.
  * This file is part of the GNU LIBICONV Library.
  *
  * The GNU LIBICONV Library is free software; you can redistribute it
@@ -14,71 +14,23 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with the GNU LIBICONV Library; see the file COPYING.LIB.
- * If not, see <http://www.gnu.org/licenses/>.
+ * If not, write to the Free Software Foundation, Inc., 59 Temple Place -
+ * Suite 330, Boston, MA 02111-1307, USA.
  */
 
 /*
- * ISO-2022-JP-MS
- * alias CP50221
- *
- * This is an extension of ISO-2022-JP-1 with larger character sets.
- * It uses ESC $ B and ESC $ ( D to denote *extensions* of JIS X 0208 and
- * JIS X 0212, respectively.  This violates the principles of ISO 2022,
- * where
- *   1. character sets to be used by ISO 2022 have to be registered at the
- *      ISO IR registry <http://www.itscj.ipsj.or.jp/ISO-IR/>,
- *   2. different character sets are designated by different escape
- *      sequences.
- * It's a typical instance of the "embrace and extend" strategy by Microsoft
- * <http://en.wikipedia.org/wiki/Embrace,_extend_and_extinguish>.
- */
-
-/*
- * Windows has three encodings CP50220, CP50221, CP50222.
- * The common parts are:
- *   - US-ASCII (0x00..0x7F)
- *   - JIS X 0208 extended by
- *       - one row (0x2D),
- *       - a private use area (rows 0x75..0x7E = U+E000..U+E3AB),
- *     enabled with ESC $ B, disabled with ESC ( B.
- *   - JIS X 0212 extended by
- *       - two rows (0x73..0x74),
- *       - a private use area (rows 0x75..0x7E = U+E3AC..U+E757),
- *     enabled with ESC $ ( D, disabled with ESC ( B.
- * They differ in the handling of JIS X 0201 characters (halfwidth Katakana)
- * in the conversion direction Unicode -> CP5022x:
- *   * CP50220 maps the halfwidth Katakana to fullwidth Katakana characters.
- *   * CP50221 contains the JIS X 0201 halfwidth Katakana characters,
- *     enabled with ESC ( I, disabled with ESC ( B.
- *   * CP50222 contains the JIS X 0201 halfwidth Katakana characters,
- *     enabled with ESC ( J 0x0E, disabled with ESC ( B.
- * In the conversion direction CP5022x -> Unicode, all three operate the same:
- *   - ESC ( I is supported and understood.
- *   - ESC ( J 0x0E is not accepted.  (Tested on Windows XP SP3.)
- * Conclusion:
- *   - CP50222 should not be used, because the multibyte sequence that it
- *     produces cannot be parsed by either of the three encodings.
- *   - CP50221 is preferrable to CP50220, because it can faithfully represent
- *     the halfwidth Katakana characters.
- * We therefore implement CP50221.  As an extension, in the mbtowc conversion
- * direction, we support also ESC ( J 0x0E, just in case.
+ * iso2022_jpms
  */
 
-#include "cp50221_0208_ext.h"
-#include "cp50221_0212_ext.h"
-
 #define ESC 0x1b
-#define SO  0x0e
-#define SI  0x0f
 
 /*
  * The state can be one of the following values.
  */
-#define STATE_ASCII             0  /* Esc ( B */
-#define STATE_JISX0201ROMAN     1  /* Esc ( J */ /* only in mbtowc direction */
-#define STATE_JISX0201KATAKANA  2  /* Esc ( I */
-#define STATE_JISX0208MS        3  /* Esc $ @ or Esc $ B */
-#define STATE_JISX0212MS        4  /* Esc $ ( D */
+#define STATE_ASCII         0
+#define STATE_JISX0201KANA  1
+#define STATE_JISX0208      2
+#define STATE_UDC           3
 
 static int
 iso2022_jpms_mbtowc (conv_t conv, ucs4_t *pwc, const unsigned char *s, size_t n)
@@ -92,7 +44,7 @@ iso2022_jpms_mbtowc (conv_t conv, ucs4_t
       if (n < count+3)
         goto none;
       if (s[1] == '(') {
-        if (s[2] == 'B') {
+        if (s[2] == 'B' || s[2] == 'J') {
           state = STATE_ASCII;
           s += 3; count += 3;
           if (n < count+1)
@@ -100,181 +52,118 @@ iso2022_jpms_mbtowc (conv_t conv, ucs4_t
           continue;
         }
         if (s[2] == 'I') {
-          state = STATE_JISX0201KATAKANA;
+          state = STATE_JISX0201KANA;
           s += 3; count += 3;
           if (n < count+1)
             goto none;
           continue;
         }
-        if (s[2] == 'J') {
-          state = STATE_JISX0201ROMAN;
-          s += 3; count += 3;
-          if (n < count+1)
-            goto none;
-          continue;
-        }
-        goto ilseq;
+        return RET_ILSEQ;
       }
       if (s[1] == '$') {
         if (s[2] == '@' || s[2] == 'B') {
           /* We don't distinguish JIS X 0208-1978 and JIS X 0208-1983. */
-          state = STATE_JISX0208MS;
+          state = STATE_JISX0208;
           s += 3; count += 3;
           if (n < count+1)
             goto none;
           continue;
         }
-        if (s[2] == '(') {
-          if (n < count+4)
+        else if (s[2] == '(') {
+          if (n <count+4)
             goto none;
-          if (s[3] == 'D') {
-            state = STATE_JISX0212MS;
+          if (s[3] == '?') {
+            state = STATE_UDC;
             s += 4; count += 4;
             if (n < count+1)
               goto none;
             continue;
           }
         }
-        goto ilseq;
+        return RET_ILSEQ;
       }
-      goto ilseq;
-    }
-    if (c == SO) {
-      if (state == STATE_JISX0201ROMAN)
-        state = STATE_JISX0201KATAKANA;
-      s += 1; count += 1;
-      if (n < count+1)
-        goto none;
-      continue;
-    }
-    if (c == SI) {
-      if (state == STATE_JISX0201KATAKANA)
-        state = STATE_JISX0201ROMAN;
-      s += 1; count += 1;
-      if (n < count+1)
-        goto none;
-      continue;
+      return RET_ILSEQ;
     }
     break;
   }
+
   switch (state) {
+    int ret;
+    unsigned char c1, c2;
     case STATE_ASCII:
       if (c < 0x80) {
-        int ret = ascii_mbtowc(conv,pwc,s,1);
+        ret = ascii_mbtowc(conv,pwc,s,1);
         if (ret == RET_ILSEQ)
-          goto ilseq;
+          return RET_ILSEQ;
         if (ret != 1) abort();
         conv->istate = state;
         return count+1;
-      } else
-        goto ilseq;
-    case STATE_JISX0201ROMAN:
-      if (c < 0x80) {
-        int ret = jisx0201_mbtowc(conv,pwc,s,1);
-        if (ret == RET_ILSEQ)
-          goto ilseq;
-        if (ret != 1) abort();
-        conv->istate = state;
-        return count+1;
-      } else
-        goto ilseq;
-    case STATE_JISX0201KATAKANA:
-      if (c < 0x80) {
-        unsigned char buf = c+0x80;
-        int ret = jisx0201_mbtowc(conv,pwc,&buf,1);
-        if (ret == RET_ILSEQ)
-          goto ilseq;
-        if (ret != 1) abort();
-        conv->istate = state;
-        return count+1;
-      } else
-        goto ilseq;
-    case STATE_JISX0208MS:
+      } /*else
+         *return RET_ILSEQ;*/
+    case STATE_JISX0201KANA:
+      if (c > 0x20)
+        c |= 0x80;
+      ret = jisx0201_mbtowc(conv,pwc,&c,1);
+      if (ret == RET_ILSEQ)
+        return RET_ILSEQ;
+      if (ret != 1) abort();
+      conv->istate = state;
+      return count+1;
+    case STATE_JISX0208:
       if (n < count+2)
         goto none;
-      if (s[0] < 0x80 && s[1] < 0x80) {
-        int ret;
-        if (s[0] < 0x75) {
-          if (s[0] == 0x2d) {
-            /* Extension of JIS X 0208.  */
-            if (s[1] >= 0x21 && s[1] <= 0x79) {
-              unsigned char i = (s[1] - 0x21) + 1;
-              ret = cp50221_0208_ext_mbtowc(conv,pwc,&i,1);
-              if (ret == 1)
-                ret = 2;
-            } else
-              ret = RET_ILSEQ;
-          } else {
-            /* JIS X 0208.  */
-            ret = jisx0208_mbtowc(conv,pwc,s,2);
-          }
-        } else {
-          /* Extension of JIS X 0208.
-             0x{75..7E}{21..8E} maps to U+E000..U+E3AB.
-             But some rows maps to characters present in CP932.  */
-          if (s[0] <= 0x7e && (s[1] >= 0x21 && s[1] <= 0x7e)) {
-            unsigned short wc = 0xfffd;
-            if (s[0] >= 0x79 && s[0] <= 0x7c)
-              wc = cp932ext_2uni_pageed[(s[0] - 0x79) * 94 + (s[1] - 0x21)];
-            if (wc == 0xfffd)
-              wc = (s[0] - 0x75) * 94 + (s[1] - 0x21) + 0xe000;
-            *pwc = wc;
-            ret = 2;
-          } else
-            ret = RET_ILSEQ;
-        }
-        if (ret == RET_ILSEQ)
-          goto ilseq;
-        if (ret != 2) abort();
-        conv->istate = state;
-        return count+2;
+      if (s[0] == 0x21 || s[0] == 0x22 || s[0] == 0x2d
+               || (0x79 <= s[0] && s[0] <= 0x7c))
+      {
+        /* iso2022_jpms Rows 1,2,13,89-92 */
+        c1 = s[0];
+        c2 = s[1];
+        if (0x21 <= c2 && c2 <= 0x7e) {
+          unsigned char t1 = (c1 - 0x21) >> 1;
+          unsigned char t2 = (((c1 - 0x21) & 1) ? 0x5e : 0) + (c2 - 0x21);
+          unsigned char buf[2];
+          buf[0] = (t1 < 0x1f ? t1+0x81 : t1+0xc1);
+          buf[1] = (t2 < 0x3f ? t2+0x40 : t2+0x41);
+          ret = cp932ext_mbtowc(conv,pwc,buf,2);
+          if (ret == RET_ILSEQ)
+            return RET_ILSEQ;
+          if (ret != 2) abort();
+          conv->istate = state;
+          return count+2;
+        } else
+          return RET_ILSEQ;
+      }
+      else if (0x21 <= s[0] && s[0] <= 0x7e) {
+        /* JIS X 0208 Rows 3-12,14-94 */
+        if (0x21 <= s[1] && s[1] <= 0x7e) {
+          ret = jisx0208_mbtowc(conv,pwc,s,2);
+          if (ret == RET_ILSEQ)
+            return RET_ILSEQ;
+          if (ret != 2) abort();
+          conv->istate = state;
+          return count+2;
+        } else
+          return RET_ILSEQ;
       } else
-        goto ilseq;
-    case STATE_JISX0212MS:
+        return RET_ILSEQ;
+    case STATE_UDC:
       if (n < count+2)
         goto none;
-      if (s[0] < 0x80 && s[1] < 0x80) {
-        int ret;
-        if (s[0] < 0x73) {
-          /* JIS X 0212.  */
-          ret = jisx0212_mbtowc(conv,pwc,s,2);
-        } else {
-          if (s[0] < 0x75) {
-            /* Extension of JIS X 0212.  */
-            if (s[1] >= 0x21 && s[1] <= 0x7e) {
-              unsigned char i = (s[0] - 0x73) * 94 + (s[1] - 0x21) + 1;
-              ret = cp50221_0212_ext_mbtowc(conv,pwc,&i,1);
-              if (ret == 1)
-                ret = 2;
-            } else
-              ret = RET_ILSEQ;
-          } else {
-            /* Extension of JIS X 0208.
-               0x{75..7E}{21..8E} maps to U+E3AC..U+E757.  */
-            if (s[0] <= 0x7e && (s[1] >= 0x21 && s[1] <= 0x7e)) {
-              *pwc = (s[0] - 0x75) * 94 + (s[1] - 0x21) + 0xe3ac;
-              ret = 2;
-            } else
-              ret = RET_ILSEQ;
-          }
-        }
-        if (ret == RET_ILSEQ)
-          goto ilseq;
-        if (ret != 2) abort();
-        conv->istate = state;
-        return count+2;
+      if (0x21 <= s[0] && s[0] <= 0x34) {
+        if (0x21 <= s[1] && s[1] <= 0x7e) {
+          *pwc = (s[0] - 0x21) * 94 + (s[1] - 0x21) + 0xe000;
+          conv->istate = state;
+          return count+2;
+        } else
+          return RET_ILSEQ;
       } else
-        goto ilseq;
+        return RET_ILSEQ;
     default: abort();
   }
 
 none:
   conv->istate = state;
   return RET_TOOFEW(count);
-
-ilseq:
-  conv->istate = state;
-  return RET_SHIFT_ILSEQ(count);
 }
 
 static int
@@ -284,6 +173,18 @@ iso2022_jpms_wctomb (conv_t conv, unsign
   unsigned char buf[2];
   int ret;
 
+  switch (wc) {
+    case 0x2014: wc = 0x2015; break;
+  }
+
+  switch (wc) {
+    /* JIS X 0201 Roman to ASCII */
+    case 0x00a5: wc = 0x005c; break;
+    case 0x203e: wc = 0x007e; break;
+    /* JIS to Microsoft */
+    case 0x2014: wc = 0x2015; break;
+  }
+
   /* Try ASCII. */
   ret = ascii_wctomb(conv,buf,wc,1);
   if (ret != RET_ILUNI) {
@@ -305,120 +206,119 @@ iso2022_jpms_wctomb (conv_t conv, unsign
     }
   }
 
-  /* Try JIS X 0201-1976 Katakana. */
-  ret = jisx0201_wctomb(conv,buf,wc,1);
+  /* Try JIS X 0208-1990 in place of JIS X 0208-1978 and JIS X 0208-1983. */
+  ret = jisx0208_wctomb(conv,buf,wc,2);
   if (ret != RET_ILUNI) {
-    if (ret != 1) abort();
-    if (buf[0] >= 0x80) {
-      int count = (state == STATE_JISX0201KATAKANA ? 1 : 4);
+    if (ret != 2) abort();
+    if (buf[0] < 0x80 && buf[1] < 0x80) {
+      int count = 2;
       if (n < count)
         return RET_TOOSMALL;
-      if (state != STATE_JISX0201KATAKANA) {
+      if (state != STATE_JISX0208) {
+        count = 5;
+        if (n < count)
+          return RET_TOOSMALL;
         r[0] = ESC;
-        r[1] = '(';
-        r[2] = 'I';
+        r[1] = '$';
+        r[2] = 'B';
         r += 3;
-        state = STATE_JISX0201KATAKANA;
+        state = STATE_JISX0208;
       }
-      r[0] = buf[0]-0x80;
+      r[0] = buf[0];
+      r[1] = buf[1];
       conv->ostate = state;
       return count;
     }
   }
 
-  /* Try JIS X 0208-1990, in place of JIS X 0208-1978 and JIS X 0208-1983,
-     and the extensions mentioned above.  */
-  if (wc >= 0xe000 && wc < 0xe3ac) {
-    unsigned short i = wc - 0xe000;
-    buf[0] = (i / 94) + 0x75;
-    buf[1] = (i % 94) + 0x21;
-    ret = 2;
-  } else {
-    ret = jisx0208_wctomb(conv,buf,wc,2);
-    if (ret == RET_ILUNI) {
-      /* Extension of JIS X 0208.  */
-      unsigned char i;
-      ret = cp50221_0208_ext_wctomb(conv,&i,wc,1);
-      if (ret == 1) {
-        buf[0] = 0x2d;
-        buf[1] = i-1 + 0x21;
-        ret = 2;
-      } else if (wc == 0x663B) {
-        buf[0] = 0x7a;
-        buf[1] = 0x36;
-        ret = 2;
-      } else if (wc == 0xffe2) {
-        buf[0] = 0x7c;
-        buf[1] = 0x7b;
-        ret = 2;
-      } else if (wc == 0xffe4) {
-        buf[0] = 0x7c;
-        buf[1] = 0x7c;
-        ret = 2;
-      }
-    }
-  }
+  /* Try cp932ext */
+  ret = cp932ext_wctomb(conv,buf,wc,2);
   if (ret != RET_ILUNI) {
+    unsigned char s1, s2;
+    int count = 2;
     if (ret != 2) abort();
-    if (buf[0] < 0x80 && buf[1] < 0x80) {
-      int count = (state == STATE_JISX0208MS ? 2 : 5);
+    if (n < count)
+      return RET_TOOSMALL;
+    if (state != STATE_JISX0208) {
+      count = 5;
       if (n < count)
         return RET_TOOSMALL;
-      if (state != STATE_JISX0208MS) {
-        r[0] = ESC;
-        r[1] = '$';
-        r[2] = 'B';
-        r += 3;
-        state = STATE_JISX0208MS;
-      }
-      r[0] = buf[0];
-      r[1] = buf[1];
+      r[0] = ESC;
+      r[1] = '$';
+      r[2] = 'B';
+      r += 3;
+      state = STATE_JISX0208;
+    }
+    s1 = buf[0];
+    s2 = buf[1];
+    if (s1 < 0xf0) {
+      unsigned char t1 = (s1 < 0xe0 ? s1-0x81 : s1-0xc1);
+      unsigned char t2 = (s2 < 0x80 ? s2-0x40 : s2-0x41);
+      r[0] = 2*t1 + (t2 < 0x5e ? 0 : 1) + 0x21;
+      r[1] = (t2 < 0x5e ? t2 : t2-0x5e) + 0x21;
       conv->ostate = state;
       return count;
     }
-  }
-
-  /* Try JIS X 0212-1990 and the extensions mentioned above. */
-  if (wc >= 0xe3ac && wc < 0xe758) {
-    unsigned short i = wc - 0xe3ac;
-    buf[0] = (i / 94) + 0x75;
-    buf[1] = (i % 94) + 0x21;
-    ret = 2;
-  } else {
-    ret = jisx0212_wctomb(conv,buf,wc,2);
-    if (ret == RET_ILUNI) {
-      /* Extension of JIS X 0212.  */
-      unsigned char i;
-      ret = cp50221_0212_ext_wctomb(conv,&i,wc,1);
-      if (ret == 1) {
-        i -= 1;
-        buf[0] = (i / 94) + 0x73;
-        buf[1] = (i % 94) + 0x21;
-        ret = 2;
-      }
+    else if (s1 >= 0xfa) {
+      unsigned short linear = 188 * s1 + (s2 < 0x7f ? s2-0x40 : s2-0x41);
+      if (0xb7b4 <= linear)
+        linear -= 0xb7b4 - 0xae0c;
+      else if (0xb7ad <= linear)
+        linear -= 0xb7ad - 0xaf81;
+      else
+        linear -= 0xb798 - 0xaf76;
+      r[0] = (linear - 0x819e) / 94;
+      r[1] = linear % 94 + 0x21;
+      conv->ostate = state;
+      return count;
     }
+    else
+      return RET_ILUNI;
   }
+
+  /* Try JIS X 0201-1976 Kana. */
+  ret = jisx0201_wctomb(conv,buf,wc,1);
   if (ret != RET_ILUNI) {
-    if (ret != 2) abort();
-    if (buf[0] < 0x80 && buf[1] < 0x80) {
-      int count = (state == STATE_JISX0212MS ? 2 : 6);
+    if (ret != 1) abort();
+    if (buf[0] > 0x80) {
+      int count = (state == STATE_JISX0201KANA ? 1 : 4);
       if (n < count)
         return RET_TOOSMALL;
-      if (state != STATE_JISX0212MS) {
+      if (state != STATE_JISX0201KANA) {
         r[0] = ESC;
-        r[1] = '$';
-        r[2] = '(';
-        r[3] = 'D';
-        r += 4;
-        state = STATE_JISX0212MS;
+        r[1] = '(';
+        r[2] = 'I';
+        r += 3;
+        state = STATE_JISX0201KANA;
       }
-      r[0] = buf[0];
-      r[1] = buf[1];
+      r[0] = buf[0] & 0x7f;
       conv->ostate = state;
       return count;
     }
   }
 
+  /* User-defined range */
+  if (wc >= 0xe000 && wc < 0xe758) {
+    unsigned char c1, c2;
+    int count = (state == STATE_UDC  ? 2 : 6);
+    c1 = (unsigned char)((wc - 0xe000) / 94 + 0x21);
+    c2 = (unsigned char)((wc - 0xe000) % 94 + 0x21);
+    if (n < count)
+      return RET_TOOSMALL;
+    if (state != STATE_UDC) {
+      r[0] = ESC;
+      r[1] = '$';
+      r[2] = '(';
+      r[3] = '?';
+      r += 4;
+      state = STATE_UDC;
+    }
+    r[0] = c1;
+    r[1] = c2;
+    conv->ostate = state;
+    return count;
+  }
+
   return RET_ILUNI;
 }
 
@@ -438,8 +338,7 @@ iso2022_jpms_reset (conv_t conv, unsigne
     return 0;
 }
 
-#undef STATE_JISX0212MS
-#undef STATE_JISX0208MS
-#undef STATE_JISX0201KATAKANA
-#undef STATE_JISX0201ROMAN
+#undef STATE_UDC
+#undef STATE_JISX0208
+#undef STATE_JISX0201KANA
 #undef STATE_ASCII
diff -uprN libiconv-1.15-old/lib/jisx0201.h libiconv-1.15/lib/jisx0201.h
--- libiconv-1.15-old/lib/jisx0201.h	2016-10-14 08:20:28.000000000 +0900
+++ libiconv-1.15/lib/jisx0201.h	2017-09-17 05:38:53.952620000 +0900
@@ -26,12 +26,7 @@ jisx0201_mbtowc (conv_t conv, ucs4_t *pw
 {
   unsigned char c = *s;
   if (c < 0x80) {
-    if (c == 0x5c)
-      *pwc = (ucs4_t) 0x00a5;
-    else if (c == 0x7e)
-      *pwc = (ucs4_t) 0x203e;
-    else
-      *pwc = (ucs4_t) c;
+    *pwc = (ucs4_t) c;
     return 1;
   } else {
     if (c >= 0xa1 && c < 0xe0) {
@@ -45,18 +40,10 @@ jisx0201_mbtowc (conv_t conv, ucs4_t *pw
 static int
 jisx0201_wctomb (conv_t conv, unsigned char *r, ucs4_t wc, size_t n)
 {
-  if (wc < 0x0080 && !(wc == 0x005c || wc == 0x007e)) {
+  if (wc < 0x0080) {
     *r = wc;
     return 1;
   }
-  if (wc == 0x00a5) {
-    *r = 0x5c;
-    return 1;
-  }
-  if (wc == 0x203e) {
-    *r = 0x7e;
-    return 1;
-  }
   if (wc >= 0xff61 && wc < 0xffa0) {
     *r = wc - 0xfec0;
     return 1;
diff -uprN libiconv-1.15-old/lib/jisx0208.h libiconv-1.15/lib/jisx0208.h
--- libiconv-1.15-old/lib/jisx0208.h	2016-10-14 08:20:46.000000000 +0900
+++ libiconv-1.15/lib/jisx0208.h	2017-09-17 05:38:53.956176000 +0900
@@ -26,7 +26,7 @@ static const unsigned short jisx0208_2un
   0x3000, 0x3001, 0x3002, 0xff0c, 0xff0e, 0x30fb, 0xff1a, 0xff1b,
   0xff1f, 0xff01, 0x309b, 0x309c, 0x00b4, 0xff40, 0x00a8, 0xff3e,
   0xffe3, 0xff3f, 0x30fd, 0x30fe, 0x309d, 0x309e, 0x3003, 0x4edd,
-  0x3005, 0x3006, 0x3007, 0x30fc, 0x2015, 0x2010, 0xff0f, 0xff3c,
+  0x3005, 0x3006, 0x3007, 0x30fc, 0x2014, 0x2010, 0xff0f, 0xff3c,
   0x301c, 0x2016, 0xff5c, 0x2026, 0x2025, 0x2018, 0x2019, 0x201c,
   0x201d, 0xff08, 0xff09, 0x3014, 0x3015, 0xff3b, 0xff3d, 0xff5b,
   0xff5d, 0x3008, 0x3009, 0x300a, 0x300b, 0x300c, 0x300d, 0x300e,
@@ -1919,7 +1919,7 @@ static const Summary16 jisx0208_uni2indx
 };
 static const Summary16 jisx0208_uni2indx_page20[50] = {
   /* 0x2000 */
-  {  125, 0x0000 }, {  125, 0x3361 }, {  132, 0x0063 }, {  136, 0x080d },
+  {  125, 0x0000 }, {  125, 0x3351 }, {  132, 0x0063 }, {  136, 0x080d },
   {  140, 0x0000 }, {  140, 0x0000 }, {  140, 0x0000 }, {  140, 0x0000 },
   {  140, 0x0000 }, {  140, 0x0000 }, {  140, 0x0000 }, {  140, 0x0000 },
   {  140, 0x0000 }, {  140, 0x0000 }, {  140, 0x0000 }, {  140, 0x0000 },
diff -uprN libiconv-1.15-old/lib/shift_jisx0213.h libiconv-1.15/lib/shift_jisx0213.h
--- libiconv-1.15-old/lib/shift_jisx0213.h	2016-10-14 07:46:02.000000000 +0900
+++ libiconv-1.15/lib/shift_jisx0213.h	2017-09-17 05:38:53.957139000 +0900
@@ -49,14 +49,9 @@ shift_jisx0213_mbtowc (conv_t conv, ucs4
     return 0; /* Don't advance the input pointer. */
   } else {
     unsigned char c = *s;
+    /* Plain ISO646-JP character. */
     if (c < 0x80) {
-      /* Plain ISO646-JP character. */
-      if (c == 0x5c)
-        *pwc = (ucs4_t) 0x00a5;
-      else if (c == 0x7e)
-        *pwc = (ucs4_t) 0x203e;
-      else
-        *pwc = (ucs4_t) c;
+      *pwc = (ucs4_t) c;
       return 1;
     } else if (c >= 0xa1 && c <= 0xdf) {
       *pwc = c + 0xfec0;
@@ -212,27 +207,13 @@ shift_jisx0213_wctomb (conv_t conv, unsi
     count = 2;
   }
 
-  if (wc < 0x80 && wc != 0x5c && wc != 0x7e) {
+  if (wc < 0x80) {
     /* Plain ISO646-JP character. */
     if (n > count) {
       r[0] = (unsigned char) wc;
       conv->ostate = 0;
       return count+1;
     } else
-      return RET_TOOSMALL;
-  } else if (wc == 0x00a5) {
-    if (n > count) {
-      r[0] = 0x5c;
-      conv->ostate = 0;
-      return count+1;
-    } else
-      return RET_TOOSMALL;
-  } else if (wc == 0x203e) {
-    if (n > count) {
-      r[0] = 0x7e;
-      conv->ostate = 0;
-      return count+1;
-    } else
       return RET_TOOSMALL;
   } else if (wc >= 0xff61 && wc <= 0xff9f) {
     /* Half-width katakana. */
diff -uprN libiconv-1.15-old/lib/sjis.h libiconv-1.15/lib/sjis.h
--- libiconv-1.15-old/lib/sjis.h	2016-10-14 08:26:47.000000000 +0900
+++ libiconv-1.15/lib/sjis.h	2017-09-17 05:38:53.957947000 +0900
@@ -63,16 +63,6 @@ sjis_mbtowc (conv_t conv, ucs4_t *pwc, c
         buf[1] = (t2 < 0x5e ? t2 : t2-0x5e) + 0x21;
         return jisx0208_mbtowc(conv,pwc,buf,2);
       }
-    } else if (s1 >= 0xf0 && s1 <= 0xf9) {
-      /* User-defined range. See
-       * Ken Lunde's "CJKV Information Processing", table 4-66, p. 206. */
-      if (n < 2)
-        return RET_TOOFEW(0);
-      s2 = s[1];
-      if ((s2 >= 0x40 && s2 <= 0x7e) || (s2 >= 0x80 && s2 <= 0xfc)) {
-        *pwc = 0xe000 + 188*(s1 - 0xf0) + (s2 < 0x80 ? s2-0x40 : s2-0x41);
-        return 2;
-      }
     }
     return RET_ILSEQ;
   }
@@ -114,18 +104,5 @@ sjis_wctomb (conv_t conv, unsigned char
     }
   }
 
-  /* User-defined range. See
-   * Ken Lunde's "CJKV Information Processing", table 4-66, p. 206. */
-  if (wc >= 0xe000 && wc < 0xe758) {
-    unsigned char c1, c2;
-    if (n < 2)
-      return RET_TOOSMALL;
-    c1 = (unsigned int) (wc - 0xe000) / 188;
-    c2 = (unsigned int) (wc - 0xe000) % 188;
-    r[0] = c1+0xf0;
-    r[1] = (c2 < 0x3f ? c2+0x40 : c2+0x41);
-    return 2;
-  }
-
   return RET_ILUNI;
 }
diff -uprN libiconv-1.15-old/lib/utf7imap.h libiconv-1.15/lib/utf7imap.h
--- libiconv-1.15-old/lib/utf7imap.h	1970-01-01 09:00:00.000000000 +0900
+++ libiconv-1.15/lib/utf7imap.h	2017-09-17 06:16:13.919741000 +0900
@@ -0,0 +1,352 @@
+/*
+
+ * Parts of this file are copyright (C) 2002-2004 Weldon Whipple and
+ * his employers. Significant portions of the code are based on
+ * similar code from the GNU LIBICONV Library, which is
+ * Copyright (C) 1999-2001 Free Software Foundation, Inc.
+ *
+ * Conditions for use and distribution are the same as for the GNU
+ * LIBICONV Library.
+ *
+ * The GNU LIBICONV Library is free software; you can redistribute it
+ * and/or modify it under the terms of the GNU Library General Public
+ * License as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * The GNU LIBICONV Library is distributed in the hope that it will be
+ * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Library General Public License for more details.
+ *
+ * You should have received a copy of the GNU Library General Public
+ * License along with the GNU LIBICONV Library; see the file COPYING.LIB.
+ * If not, write to the Free Software Foundation, Inc., 59 Temple Place -
+ * Suite 330, Boston, MA 02111-1307, USA.  */
+
+/*
+ * UTF-7 IMAP variant described in RFC 2060 (section 5.1.3)
+ */
+
+/* Specification: RFC 2152 (and old RFC 1641, RFC 1642) */
+/* The original Base64 encoding is defined in RFC 2045. */
+
+/* Set of direct characters:
+ *   A-Z a-z 0-9 ' ( ) , - . / : ? space 
+ *   ! " # $ % + * ; < = > @ [ ] ^ _ ` { | } \ ~
+ */
+static const unsigned char directimap_tab[128/8] = {
+  0x00, 0x00, 0x00, 0x00, 0xbf, 0xff, 0xff, 0xff,
+  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f,
+};
+
+#define isdirectimap(ch) ((ch) < 128 && ((directimap_tab[(ch)>>3] >> (ch & 7)) & 1))
+
+/* WWhipple: BUG01053: Use + instead of & to represent 62!! */
+/* Set of base64 characters, extended:
+ *   A-Z a-z 0-9 + , -
+ */
+static const unsigned char xbase64imap_tab[128/8] = {
+  0x00, 0x00, 0x00, 0x00, 0x00, 0x38, 0xff, 0x03,
+  0xfe, 0xff, 0xff, 0x07, 0xfe, 0xff, 0xff, 0x07,
+};
+
+#define isxbase64imap(ch) ((ch) < 128 && ((xbase64imap_tab[(ch)>>3] >> (ch & 7)) & 1))
+
+/*
+ * The state is structured as follows:
+ * bit 1..0: shift
+ * bit 7..2: data
+ * Precise meaning:
+ *   shift      data
+ *     0         0           not inside base64 encoding
+ *     1         0           inside base64, no pending bits
+ *     2      XXXX00         inside base64, 4 bits remain from 2nd byte
+ *     3      XX0000         inside base64, 2 bits remain from 3rd byte
+ */
+
+static int
+utf7imap_mbtowc (conv_t conv, ucs4_t *pwc, const unsigned char *s, int n)
+{
+  state_t state = conv->istate;
+  int count = 0; /* number of input bytes already read */
+  if (state & 3)
+    goto active;
+  else
+    goto inactive;
+
+inactive:
+  {
+    /* Here (state & 3) == 0 */
+    if (n < count+1)
+      goto none;
+    {
+      unsigned char c = *s;
+      if (isdirectimap(c)) {
+        *pwc = (ucs4_t) c;
+        conv->istate = state;
+        return count+1;
+      }
+      if (c == '&') {
+        if (n < count+2)
+          goto none;
+        if (s[1] == '-') {
+          *pwc = (ucs4_t) '&';
+          conv->istate = state;
+          return count+2;
+        }
+        s++; count++;
+        state = 1;
+        goto active;
+      }
+      return RET_ILSEQ;
+    }
+  }
+
+active:
+  {
+    /* base64 encoding active */
+    unsigned int wc = 0;
+    state_t base64state = state;
+    unsigned int kmax = 2; /* number of payload bytes to read */
+    unsigned int k = 0; /* number of payload bytes already read */
+    unsigned int base64count = 0; /* number of base64 bytes already read */
+    for (;;) {
+      unsigned char c = *s;
+      unsigned int i;
+      if (c >= 'A' && c <= 'Z')
+        i = c-'A';
+      else if (c >= 'a' && c <= 'z')
+        i = c-'a'+26;
+      else if (c >= '0' && c <= '9')
+        i = c-'0'+52;
+      else if (c == '+')
+        i = 62;
+      else if (c == ',')
+        i = 63;
+      else {
+        /* c terminates base64 encoding */
+        if (base64state & -4)
+          return RET_ILSEQ; /* data must be 0, otherwise illegal */
+        if (base64count)
+          return RET_ILSEQ; /* partial UTF-16 characters are invalid */
+        if (c == '-') {
+          s++; count++;
+        }
+        state = 0;
+        goto inactive;
+      }
+      s++; base64count++;
+      /* read 6 bits: 0 <= i < 64 */
+      switch (base64state & 3) {
+        case 1: /* inside base64, no pending bits */
+          base64state = (i << 2) | 0; break;
+        case 0: /* inside base64, 6 bits remain from 1st byte */
+          wc = (wc << 8) | (base64state & -4) | (i >> 4); k++;
+          base64state = ((i & 15) << 4) | 2; break;
+        case 2: /* inside base64, 4 bits remain from 2nd byte */
+          wc = (wc << 8) | (base64state & -4) | (i >> 2); k++;
+          base64state = ((i & 3) << 6) | 3; break;
+        case 3: /* inside base64, 2 bits remain from 3rd byte */
+          wc = (wc << 8) | (base64state & -4) | i; k++;
+          base64state = 1; break;
+      }
+      if (k == kmax) {
+        /* UTF-16: When we see a High Surrogate, we must also decode
+           the following Low Surrogate. */
+        if (kmax == 2 && (wc >= 0xd800 && wc < 0xdc00))
+          kmax = 4;
+        else
+          break;
+      }
+      if (n < count+base64count+1)
+        goto none;
+    }
+    /* Here k = kmax > 0, hence base64count > 0. */
+    if ((base64state & 3) == 0) abort();
+    if (kmax == 4) {
+      ucs4_t wc1 = wc >> 16;
+      ucs4_t wc2 = wc & 0xffff;
+      if (!(wc1 >= 0xd800 && wc1 < 0xdc00)) abort();
+      if (!(wc2 >= 0xdc00 && wc2 < 0xe000)) return RET_ILSEQ;
+      *pwc = 0x10000 + ((wc1 - 0xd800) << 10) + (wc2 - 0xdc00);
+    } else {
+      *pwc = wc;
+    }
+    conv->istate = base64state;
+    return count+base64count;
+  }
+
+none:
+  conv->istate = state;
+  return RET_TOOFEW(count);
+}
+
+/*
+ * The state is structured as follows:
+ * bit 1..0: shift
+ * bit 7..2: data
+ * Precise meaning:
+ *   shift      data
+ *     0         0           not inside base64 encoding
+ *     1         0           inside base64, no pending bits
+ *     2       XX00          inside base64, 2 bits known for 2nd byte
+ *     3       XXXX          inside base64, 4 bits known for 3rd byte
+ */
+static int
+utf7imap_wctomb (conv_t conv, unsigned char *r, ucs4_t iwc, size_t n)
+{
+  state_t state = conv->ostate;
+  unsigned int wc = iwc;
+  int count = 0;
+  if (state & 3)
+    goto active;
+
+/*inactive:*/
+  {
+    if (isdirectimap(wc)) {
+      r[0] = (unsigned char) wc;
+      /*conv->ostate = state;*/
+      return 1;
+    } else {
+      *r++ = '&';
+      if (wc == '&') {
+        if (n < 2)
+          return RET_TOOSMALL;
+        *r = '-';
+        /*conv->ostate = state;*/
+        return 2;
+      }
+      count = 1;
+      state = 1;
+      goto active;
+    }
+  }
+
+active:
+  {
+    /* base64 encoding active */
+       /* If the next character is one we can encode directly (and if
+	  the previous character--during the last call--was encoded in
+	  base64, then ... */
+    if (isdirectimap(wc)) {
+      /* deactivate base64 encoding */
+      count += ((state & 3) >= 2 ? 1 : 0) + (isxbase64imap(wc) ? 1 : 0) + 1;
+      if (n < count)
+        return RET_TOOSMALL;
+      if ((state & 3) >= 2) {
+        unsigned int i = state & -4;
+        unsigned char c;
+        if (i < 26)
+          c = i+'A';
+        else if (i < 52)
+          c = i-26+'a';
+        else if (i < 62)
+          c = i-52+'0';
+        else if (i == 62)
+          c = '+';
+        else if (i == 63)
+          c = ',';
+        else
+          abort();
+        *r++ = c;
+      }
+      if (isxbase64imap(wc))
+        *r++ = '-';
+      state = 0;
+      *r++ = (unsigned char) wc;
+      conv->ostate = state;
+      return count;
+    } else {
+      unsigned int k; /* number of payload bytes to write */
+      if (wc < 0x10000) {
+        k = 2;
+        count += ((state & 3) >= 2 ? 3 : 2);
+      } else if (wc < 0x110000) {
+        unsigned int wc1 = 0xd800 + ((wc - 0x10000) >> 10);
+        unsigned int wc2 = 0xdc00 + ((wc - 0x10000) & 0x3ff);
+        wc = (wc1 << 16) | wc2;
+        k = 4;
+        count += ((state & 3) >= 3 ? 6 : 5);
+      } else
+        return RET_ILUNI;
+      if (n < count)
+        return RET_TOOSMALL;
+      for (;;) {
+        unsigned int i;
+        unsigned char c;
+        switch (state & 3) {
+          case 0: /* inside base64, 6 bits known for 4th byte */
+            c = (state & -4) >> 2; state = 1; break;
+          case 1: /* inside base64, no pending bits */
+            i = (wc >> (8 * --k)) & 0xff;
+            c = i >> 2; state = ((i & 3) << 4) | 2; break;
+          case 2: /* inside base64, 2 bits known for 2nd byte */
+            i = (wc >> (8 * --k)) & 0xff;
+            c = (state & -4) | (i >> 4); state = ((i & 15) << 2) | 3; break;
+          case 3: /* inside base64, 4 bits known for 3rd byte */
+            i = (wc >> (8 * --k)) & 0xff;
+            c = (state & -4) | (i >> 6); state = ((i & 63) << 2) | 0; break;
+          default: abort(); /* stupid gcc */
+        }
+        if (c < 26)
+          c = c+'A';
+        else if (c < 52)
+          c = c-26+'a';
+        else if (c < 62)
+          c = c-52+'0';
+        else if (c == 62)
+          c = '+';
+        else if (c == 63)
+          c = ',';
+        else
+          abort();
+        *r++ = c;
+        if ((state & 3) && (k == 0))
+          break;
+      }
+      conv->ostate = state;
+      return count;
+    }
+  }
+}
+
+static int
+utf7imap_reset (conv_t conv, unsigned char *r, size_t n)
+{
+  state_t state = conv->ostate;
+  if (state & 3) {
+    /* deactivate base64 encoding */
+    /* We will output two bytes (the rest of a pending character
+       and '-') if in state 2 or 3. If in state 1, there are
+       no pending bits, so count is 1, and we will output just
+       the closing '-'. */
+    unsigned int count = ((state & 3) >= 2 ? 1 : 0) + 1;
+    if (n < count)
+      return RET_TOOSMALL;
+    if ((state & 3) >= 2) {
+      unsigned int i = state & -4; /* Get high-order 6 bits */
+      unsigned char c;
+      if (i < 26)
+        c = i+'A';
+      else if (i < 52)
+        c = i-26+'a';
+      else if (i < 62)
+        c = i-52+'0';
+      else if (i == 62)
+        c = '+';
+      else if (i == 63)
+        c = ',';
+      else
+        abort();
+      *r++ = c;
+    }
+    *r++ = '-';
+    /* conv->ostate = 0; will be done by the caller */
+    return count;
+  } 
+  else
+    return 0;
+}
+
+
+
diff -uprN libiconv-1.15-old/libcharset/include/libcharset.h libiconv-1.15/libcharset/include/libcharset.h
--- libiconv-1.15-old/libcharset/include/libcharset.h	1970-01-01 09:00:00.000000000 +0900
+++ libiconv-1.15/libcharset/include/libcharset.h	2017-08-02 10:28:46.000000000 +0900
@@ -0,0 +1,45 @@
+/* Copyright (C) 2003 Free Software Foundation, Inc.
+   This file is part of the GNU CHARSET Library.
+
+   The GNU CHARSET Library is free software; you can redistribute it and/or
+   modify it under the terms of the GNU Library General Public License as
+   published by the Free Software Foundation; either version 2 of the
+   License, or (at your option) any later version.
+
+   The GNU CHARSET Library is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+   Library General Public License for more details.
+
+   You should have received a copy of the GNU Library General Public License
+   along with the GNU CHARSET Library; see the file COPYING.LIB.  If not,
+   see <http://www.gnu.org/licenses/>.  */
+
+#ifndef _LIBCHARSET_H
+#define _LIBCHARSET_H
+
+#include <localcharset.h>
+
+
+#ifdef __cplusplus
+extern "C" {
+#endif
+
+
+/* Support for relocatable packages.  */
+
+/* Sets the original and the current installation prefix of the package.
+   Relocation simply replaces a pathname starting with the original prefix
+   by the corresponding pathname with the current prefix instead.  Both
+   prefixes should be directory names without trailing slash (i.e. use ""
+   instead of "/").  */
+extern void libcharset_set_relocation_prefix (const char *orig_prefix,
+                                              const char *curr_prefix);
+
+
+#ifdef __cplusplus
+}
+#endif
+
+
+#endif /* _LIBCHARSET_H */
diff -uprN libiconv-1.15-old/libcharset/include/localcharset.h libiconv-1.15/libcharset/include/localcharset.h
--- libiconv-1.15-old/libcharset/include/localcharset.h	1970-01-01 09:00:00.000000000 +0900
+++ libiconv-1.15/libcharset/include/localcharset.h	2017-08-02 10:12:54.000000000 +0900
@@ -0,0 +1,46 @@
+/* Determine a canonical name for the current locale's character encoding.
+   Copyright (C) 2000-2003 Free Software Foundation, Inc.
+   This file is part of the GNU CHARSET Library.
+
+   This program is free software; you can redistribute it and/or modify it
+   under the terms of the GNU Library General Public License as published
+   by the Free Software Foundation; either version 2, or (at your option)
+   any later version.
+
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+   Library General Public License for more details.
+
+   You should have received a copy of the GNU Library General Public License
+   along with this program; if not, see <http://www.gnu.org/licenses/>.  */
+
+#ifndef _LOCALCHARSET_H
+#define _LOCALCHARSET_H
+
+#if 1 && BUILDING_LIBCHARSET
+#define LIBCHARSET_DLL_EXPORTED __attribute__((__visibility__("default")))
+#else
+#define LIBCHARSET_DLL_EXPORTED
+#endif
+
+
+#ifdef __cplusplus
+extern "C" {
+#endif
+
+
+/* Determine the current locale's character encoding, and canonicalize it
+   into one of the canonical names listed in config.charset.
+   The result must not be freed; it is statically allocated.
+   If the canonical name cannot be determined, the result is a non-canonical
+   name.  */
+extern LIBCHARSET_DLL_EXPORTED const char * locale_charset (void);
+
+
+#ifdef __cplusplus
+}
+#endif
+
+
+#endif /* _LOCALCHARSET_H */
diff -uprN libiconv-1.15-old/libcharset/lib/localcharset.c libiconv-1.15/libcharset/lib/localcharset.c
--- libiconv-1.15-old/libcharset/lib/localcharset.c	2016-12-02 21:55:29.000000000 +0900
+++ libiconv-1.15/libcharset/lib/localcharset.c	2017-09-17 05:38:53.963259000 +0900
@@ -86,6 +86,9 @@
 #ifndef O_NOFOLLOW
 # define O_NOFOLLOW 0
 #endif
+#ifndef HAVE_WORKING_O_NOFOLLOW
+# define HAVE_WORKING_O_NOFOLLOW 0
+#endif
 
 #if defined _WIN32 || defined __WIN32__ || defined __CYGWIN__ || defined __EMX__ || defined __DJGPP__
   /* Native Windows, Cygwin, OS/2, DOS */
diff -uprN libiconv-1.15-old/man/iconv_open.3 libiconv-1.15/man/iconv_open.3
--- libiconv-1.15-old/man/iconv_open.3	2014-01-03 07:23:02.000000000 +0900
+++ libiconv-1.15/man/iconv_open.3	2017-09-17 06:01:48.224708000 +0900
@@ -45,7 +45,7 @@ ISO\-8859\-{6,8}, CP{1255,1256}, CP862,
 Japanese
 .nf
 .fi
-EUC\-JP, SHIFT_JIS, CP932, ISO\-2022\-JP, ISO\-2022\-JP\-2, ISO\-2022\-JP\-1,
+EUC\-JP, EUCJP\-MS, SHIFT_JIS, CP932, ISO\-2022\-JP, ISO\-2022\-JP\-2, ISO\-2022\-JP\-1,
 ISO-2022\-JP\-MS
 .TP
 Chinese
diff -uprN libiconv-1.15-old/man/iconv_open.3.html libiconv-1.15/man/iconv_open.3.html
--- libiconv-1.15-old/man/iconv_open.3.html	2017-01-02 08:03:27.000000000 +0900
+++ libiconv-1.15/man/iconv_open.3.html	2017-09-17 06:30:30.484617000 +0900
@@ -1,4 +1,4 @@
-<!-- Creator     : groff version 1.22.3 -->
+<!-- Creator     : groff version 1.19.2 -->
 <!DOCTYPE html PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN"
 "http://www.w3.org/TR/html4/loose.dtd">
 <html>
@@ -7,17 +7,16 @@
 <meta http-equiv="Content-Type" content="text/html; charset=US-ASCII">
 <meta name="Content-Style" content="text/css">
 <style type="text/css">
-       p       { margin-top: 0; margin-bottom: 0; vertical-align: top }
-       pre     { margin-top: 0; margin-bottom: 0; vertical-align: top }
-       table   { margin-top: 0; margin-bottom: 0; vertical-align: top }
-       h1      { text-align: center }
+       p     { margin-top: 0; margin-bottom: 0; }
+       pre   { margin-top: 0; margin-bottom: 0; }
+       table { margin-top: 0; margin-bottom: 0; }
 </style>
 <title>ICONV_OPEN</title>
 
 </head>
 <body>
 
-<h1 align="center">ICONV_OPEN</h1>
+<h1 align=center>ICONV_OPEN</h1>
 
 <a href="#NAME">NAME</a><br>
 <a href="#SYNOPSIS">SYNOPSIS</a><br>
@@ -30,17 +29,15 @@
 <hr>
 
 
-<h2>NAME
 <a name="NAME"></a>
-</h2>
+<h2>NAME</h2>
 
 
 <p style="margin-left:11%; margin-top: 1em">iconv_open
 &minus; allocate descriptor for character set conversion</p>
 
-<h2>SYNOPSIS
 <a name="SYNOPSIS"></a>
-</h2>
+<h2>SYNOPSIS</h2>
 
 
 <p style="margin-left:11%; margin-top: 1em"><b>#include
@@ -50,9 +47,8 @@
 iconv_open (const char*</b> <i>tocode</i><b>, const
 char*</b> <i>fromcode</i><b>);</b></p>
 
-<h2>DESCRIPTION
 <a name="DESCRIPTION"></a>
-</h2>
+<h2>DESCRIPTION</h2>
 
 
 <p style="margin-left:11%; margin-top: 1em">The
@@ -82,8 +78,9 @@ CP{1255,1256}, CP862, Mac{Hebrew,Arabic}
 
 <p style="margin-left:11%;">Japanese</p>
 
-<p style="margin-left:22%;">EUC&minus;JP, SHIFT_JIS, CP932,
-ISO&minus;2022&minus;JP, ISO&minus;2022&minus;JP&minus;2,
+<p style="margin-left:22%;">EUC&minus;JP, EUCJP&minus;MS,
+SHIFT_JIS, CP932, ISO&minus;2022&minus;JP,
+ISO&minus;2022&minus;JP&minus;2,
 ISO&minus;2022&minus;JP&minus;1,
 ISO-2022&minus;JP&minus;MS</p>
 
@@ -95,21 +92,22 @@ BIG5&minus;HKSCS:2004, BIG5&minus;HKSCS:
 BIG5&minus;HKSCS:1999, ISO&minus;2022&minus;CN,
 ISO&minus;2022&minus;CN&minus;EXT</p>
 
-<table width="100%" border="0" rules="none" frame="void"
+<table width="100%" border=0 rules="none" frame="void"
        cellspacing="0" cellpadding="0">
 <tr valign="top" align="left">
 <td width="11%"></td>
 <td width="9%">
 
 
-<p>Korean</p></td>
+<p style="margin-top: 1em" valign="top">Korean</p></td>
 <td width="2%"></td>
 <td width="50%">
 
 
-<p>EUC&minus;KR, CP949, ISO&minus;2022&minus;KR, JOHAB</p></td>
+<p style="margin-top: 1em" valign="top">EUC&minus;KR,
+CP949, ISO&minus;2022&minus;KR, JOHAB</p></td>
 <td width="28%">
-</td></tr>
+</td>
 </table>
 
 <p style="margin-left:11%;">Armenian</p>
@@ -121,47 +119,48 @@ ISO&minus;2022&minus;CN&minus;EXT</p>
 <p style="margin-left:22%;">Georgian&minus;Academy,
 Georgian&minus;PS</p>
 
-<table width="100%" border="0" rules="none" frame="void"
+<table width="100%" border=0 rules="none" frame="void"
        cellspacing="0" cellpadding="0">
 <tr valign="top" align="left">
 <td width="11%"></td>
 <td width="9%">
 
 
-<p>Tajik</p></td>
+<p style="margin-top: 1em" valign="top">Tajik</p></td>
 <td width="2%"></td>
 <td width="35%">
 
 
-<p>KOI8&minus;T</p></td>
+<p style="margin-top: 1em" valign="top">KOI8&minus;T</p></td>
 <td width="43%">
-</td></tr>
+</td>
 <tr valign="top" align="left">
 <td width="11%"></td>
 <td width="9%">
 
 
-<p>Kazakh</p></td>
+<p style="margin-top: 1em" valign="top">Kazakh</p></td>
 <td width="2%"></td>
 <td width="35%">
 
 
-<p>PT154, RK1048</p></td>
+<p style="margin-top: 1em" valign="top">PT154, RK1048</p></td>
 <td width="43%">
-</td></tr>
+</td>
 <tr valign="top" align="left">
 <td width="11%"></td>
 <td width="9%">
 
 
-<p>Thai</p></td>
+<p style="margin-top: 1em" valign="top">Thai</p></td>
 <td width="2%"></td>
 <td width="35%">
 
 
-<p>TIS&minus;620, CP874, MacThai</p></td>
+<p style="margin-top: 1em" valign="top">TIS&minus;620,
+CP874, MacThai</p></td>
 <td width="43%">
-</td></tr>
+</td>
 </table>
 
 <p style="margin-left:11%;">Laotian</p>
@@ -264,9 +263,8 @@ used in multiple threads simultaneously.
 back to the initial state, use <b>iconv</b> with NULL as
 <i>inbuf</i> argument.</p>
 
-<h2>RETURN VALUE
 <a name="RETURN VALUE"></a>
-</h2>
+<h2>RETURN VALUE</h2>
 
 
 <p style="margin-left:11%; margin-top: 1em">The
@@ -274,40 +272,38 @@ back to the initial state, use <b>iconv<
 conversion descriptor. In case of error, it sets
 <b>errno</b> and returns (iconv_t)(&minus;1).</p>
 
-<h2>ERRORS
 <a name="ERRORS"></a>
-</h2>
+<h2>ERRORS</h2>
 
 
 <p style="margin-left:11%; margin-top: 1em">The following
 error can occur, among others:</p>
 
-<table width="100%" border="0" rules="none" frame="void"
+<table width="100%" border=0 rules="none" frame="void"
        cellspacing="0" cellpadding="0">
 <tr valign="top" align="left">
 <td width="11%"></td>
 <td width="9%">
 
 
-<p><b>EINVAL</b></p></td>
+<p style="margin-top: 1em" valign="top"><b>EINVAL</b></p></td>
 <td width="2%"></td>
 <td width="78%">
 
 
-<p>The conversion from <i>fromcode</i> to <i>tocode</i> is
-not supported by the implementation.</p></td></tr>
+<p style="margin-top: 1em" valign="top">The conversion from
+<i>fromcode</i> to <i>tocode</i> is not supported by the
+implementation.</p> </td>
 </table>
 
-<h2>CONFORMING TO
 <a name="CONFORMING TO"></a>
-</h2>
+<h2>CONFORMING TO</h2>
 
 
 <p style="margin-left:11%; margin-top: 1em">POSIX:2001</p>
 
-<h2>SEE ALSO
 <a name="SEE ALSO"></a>
-</h2>
+<h2>SEE ALSO</h2>
 
 
 
diff -uprN libiconv-1.15-old/tests/CP51932.IRREVERSIBLE.TXT libiconv-1.15/tests/CP51932.IRREVERSIBLE.TXT
--- libiconv-1.15-old/tests/CP51932.IRREVERSIBLE.TXT	1970-01-01 09:00:00.000000000 +0900
+++ libiconv-1.15/tests/CP51932.IRREVERSIBLE.TXT	2017-09-17 05:38:53.967947000 +0900
@@ -0,0 +1,19 @@
+0x5C	0x00A5
+0x7E	0x203E
+0xA1BD	0x2014
+0xA1C1	0x301C
+0xA1C2	0x2016
+0xA1DD	0x2212
+0xA1F1	0x00A2
+0xA1F2	0x00A3
+0xA2CC	0x00AC
+0xADF0	0x2252
+0xADF1	0x2261
+0xADF2	0x222B
+0xADF5	0x221A
+0xADF6	0x22A5
+0xADF7	0x2220
+0xADFA	0x2235
+0xADFB	0x2229
+0xADFC	0x222A
+0xFCFB	0xFFE2
diff -uprN libiconv-1.15-old/tests/CP51932.TXT libiconv-1.15/tests/CP51932.TXT
--- libiconv-1.15-old/tests/CP51932.TXT	1970-01-01 09:00:00.000000000 +0900
+++ libiconv-1.15/tests/CP51932.TXT	2017-09-17 05:38:54.042286000 +0900
@@ -0,0 +1,7527 @@
+0x00	0x0000
+0x01	0x0001
+0x02	0x0002
+0x03	0x0003
+0x04	0x0004
+0x05	0x0005
+0x06	0x0006
+0x07	0x0007
+0x08	0x0008
+0x09	0x0009
+0x0A	0x000A
+0x0B	0x000B
+0x0C	0x000C
+0x0D	0x000D
+0x0E	0x000E
+0x0F	0x000F
+0x10	0x0010
+0x11	0x0011
+0x12	0x0012
+0x13	0x0013
+0x14	0x0014
+0x15	0x0015
+0x16	0x0016
+0x17	0x0017
+0x18	0x0018
+0x19	0x0019
+0x1A	0x001A
+0x1B	0x001B
+0x1C	0x001C
+0x1D	0x001D
+0x1E	0x001E
+0x1F	0x001F
+0x20	0x0020
+0x21	0x0021
+0x22	0x0022
+0x23	0x0023
+0x24	0x0024
+0x25	0x0025
+0x26	0x0026
+0x27	0x0027
+0x28	0x0028
+0x29	0x0029
+0x2A	0x002A
+0x2B	0x002B
+0x2C	0x002C
+0x2D	0x002D
+0x2E	0x002E
+0x2F	0x002F
+0x30	0x0030
+0x31	0x0031
+0x32	0x0032
+0x33	0x0033
+0x34	0x0034
+0x35	0x0035
+0x36	0x0036
+0x37	0x0037
+0x38	0x0038
+0x39	0x0039
+0x3A	0x003A
+0x3B	0x003B
+0x3C	0x003C
+0x3D	0x003D
+0x3E	0x003E
+0x3F	0x003F
+0x40	0x0040
+0x41	0x0041
+0x42	0x0042
+0x43	0x0043
+0x44	0x0044
+0x45	0x0045
+0x46	0x0046
+0x47	0x0047
+0x48	0x0048
+0x49	0x0049
+0x4A	0x004A
+0x4B	0x004B
+0x4C	0x004C
+0x4D	0x004D
+0x4E	0x004E
+0x4F	0x004F
+0x50	0x0050
+0x51	0x0051
+0x52	0x0052
+0x53	0x0053
+0x54	0x0054
+0x55	0x0055
+0x56	0x0056
+0x57	0x0057
+0x58	0x0058
+0x59	0x0059
+0x5A	0x005A
+0x5B	0x005B
+0x5C	0x005C
+0x5D	0x005D
+0x5E	0x005E
+0x5F	0x005F
+0x60	0x0060
+0x61	0x0061
+0x62	0x0062
+0x63	0x0063
+0x64	0x0064
+0x65	0x0065
+0x66	0x0066
+0x67	0x0067
+0x68	0x0068
+0x69	0x0069
+0x6A	0x006A
+0x6B	0x006B
+0x6C	0x006C
+0x6D	0x006D
+0x6E	0x006E
+0x6F	0x006F
+0x70	0x0070
+0x71	0x0071
+0x72	0x0072
+0x73	0x0073
+0x74	0x0074
+0x75	0x0075
+0x76	0x0076
+0x77	0x0077
+0x78	0x0078
+0x79	0x0079
+0x7A	0x007A
+0x7B	0x007B
+0x7C	0x007C
+0x7D	0x007D
+0x7E	0x007E
+0x7F	0x007F
+0x8EA1	0xFF61
+0x8EA2	0xFF62
+0x8EA3	0xFF63
+0x8EA4	0xFF64
+0x8EA5	0xFF65
+0x8EA6	0xFF66
+0x8EA7	0xFF67
+0x8EA8	0xFF68
+0x8EA9	0xFF69
+0x8EAA	0xFF6A
+0x8EAB	0xFF6B
+0x8EAC	0xFF6C
+0x8EAD	0xFF6D
+0x8EAE	0xFF6E
+0x8EAF	0xFF6F
+0x8EB0	0xFF70
+0x8EB1	0xFF71
+0x8EB2	0xFF72
+0x8EB3	0xFF73
+0x8EB4	0xFF74
+0x8EB5	0xFF75
+0x8EB6	0xFF76
+0x8EB7	0xFF77
+0x8EB8	0xFF78
+0x8EB9	0xFF79
+0x8EBA	0xFF7A
+0x8EBB	0xFF7B
+0x8EBC	0xFF7C
+0x8EBD	0xFF7D
+0x8EBE	0xFF7E
+0x8EBF	0xFF7F
+0x8EC0	0xFF80
+0x8EC1	0xFF81
+0x8EC2	0xFF82
+0x8EC3	0xFF83
+0x8EC4	0xFF84
+0x8EC5	0xFF85
+0x8EC6	0xFF86
+0x8EC7	0xFF87
+0x8EC8	0xFF88
+0x8EC9	0xFF89
+0x8ECA	0xFF8A
+0x8ECB	0xFF8B
+0x8ECC	0xFF8C
+0x8ECD	0xFF8D
+0x8ECE	0xFF8E
+0x8ECF	0xFF8F
+0x8ED0	0xFF90
+0x8ED1	0xFF91
+0x8ED2	0xFF92
+0x8ED3	0xFF93
+0x8ED4	0xFF94
+0x8ED5	0xFF95
+0x8ED6	0xFF96
+0x8ED7	0xFF97
+0x8ED8	0xFF98
+0x8ED9	0xFF99
+0x8EDA	0xFF9A
+0x8EDB	0xFF9B
+0x8EDC	0xFF9C
+0x8EDD	0xFF9D
+0x8EDE	0xFF9E
+0x8EDF	0xFF9F
+0xA1A1	0x3000
+0xA1A2	0x3001
+0xA1A3	0x3002
+0xA1A4	0xFF0C
+0xA1A5	0xFF0E
+0xA1A6	0x30FB
+0xA1A7	0xFF1A
+0xA1A8	0xFF1B
+0xA1A9	0xFF1F
+0xA1AA	0xFF01
+0xA1AB	0x309B
+0xA1AC	0x309C
+0xA1AD	0x00B4
+0xA1AE	0xFF40
+0xA1AF	0x00A8
+0xA1B0	0xFF3E
+0xA1B1	0xFFE3
+0xA1B2	0xFF3F
+0xA1B3	0x30FD
+0xA1B4	0x30FE
+0xA1B5	0x309D
+0xA1B6	0x309E
+0xA1B7	0x3003
+0xA1B8	0x4EDD
+0xA1B9	0x3005
+0xA1BA	0x3006
+0xA1BB	0x3007
+0xA1BC	0x30FC
+0xA1BD	0x2015
+0xA1BE	0x2010
+0xA1BF	0xFF0F
+0xA1C0	0xFF3C
+0xA1C1	0xFF5E
+0xA1C2	0x2225
+0xA1C3	0xFF5C
+0xA1C4	0x2026
+0xA1C5	0x2025
+0xA1C6	0x2018
+0xA1C7	0x2019
+0xA1C8	0x201C
+0xA1C9	0x201D
+0xA1CA	0xFF08
+0xA1CB	0xFF09
+0xA1CC	0x3014
+0xA1CD	0x3015
+0xA1CE	0xFF3B
+0xA1CF	0xFF3D
+0xA1D0	0xFF5B
+0xA1D1	0xFF5D
+0xA1D2	0x3008
+0xA1D3	0x3009
+0xA1D4	0x300A
+0xA1D5	0x300B
+0xA1D6	0x300C
+0xA1D7	0x300D
+0xA1D8	0x300E
+0xA1D9	0x300F
+0xA1DA	0x3010
+0xA1DB	0x3011
+0xA1DC	0xFF0B
+0xA1DD	0xFF0D
+0xA1DE	0x00B1
+0xA1DF	0x00D7
+0xA1E0	0x00F7
+0xA1E1	0xFF1D
+0xA1E2	0x2260
+0xA1E3	0xFF1C
+0xA1E4	0xFF1E
+0xA1E5	0x2266
+0xA1E6	0x2267
+0xA1E7	0x221E
+0xA1E8	0x2234
+0xA1E9	0x2642
+0xA1EA	0x2640
+0xA1EB	0x00B0
+0xA1EC	0x2032
+0xA1ED	0x2033
+0xA1EE	0x2103
+0xA1EF	0xFFE5
+0xA1F0	0xFF04
+0xA1F1	0xFFE0
+0xA1F2	0xFFE1
+0xA1F3	0xFF05
+0xA1F4	0xFF03
+0xA1F5	0xFF06
+0xA1F6	0xFF0A
+0xA1F7	0xFF20
+0xA1F8	0x00A7
+0xA1F9	0x2606
+0xA1FA	0x2605
+0xA1FB	0x25CB
+0xA1FC	0x25CF
+0xA1FD	0x25CE
+0xA1FE	0x25C7
+0xA2A1	0x25C6
+0xA2A2	0x25A1
+0xA2A3	0x25A0
+0xA2A4	0x25B3
+0xA2A5	0x25B2
+0xA2A6	0x25BD
+0xA2A7	0x25BC
+0xA2A8	0x203B
+0xA2A9	0x3012
+0xA2AA	0x2192
+0xA2AB	0x2190
+0xA2AC	0x2191
+0xA2AD	0x2193
+0xA2AE	0x3013
+0xA2BA	0x2208
+0xA2BB	0x220B
+0xA2BC	0x2286
+0xA2BD	0x2287
+0xA2BE	0x2282
+0xA2BF	0x2283
+0xA2C0	0x222A
+0xA2C1	0x2229
+0xA2CA	0x2227
+0xA2CB	0x2228
+0xA2CC	0xFFE2
+0xA2CD	0x21D2
+0xA2CE	0x21D4
+0xA2CF	0x2200
+0xA2D0	0x2203
+0xA2DC	0x2220
+0xA2DD	0x22A5
+0xA2DE	0x2312
+0xA2DF	0x2202
+0xA2E0	0x2207
+0xA2E1	0x2261
+0xA2E2	0x2252
+0xA2E3	0x226A
+0xA2E4	0x226B
+0xA2E5	0x221A
+0xA2E6	0x223D
+0xA2E7	0x221D
+0xA2E8	0x2235
+0xA2E9	0x222B
+0xA2EA	0x222C
+0xA2F2	0x212B
+0xA2F3	0x2030
+0xA2F4	0x266F
+0xA2F5	0x266D
+0xA2F6	0x266A
+0xA2F7	0x2020
+0xA2F8	0x2021
+0xA2F9	0x00B6
+0xA2FE	0x25EF
+0xA3B0	0xFF10
+0xA3B1	0xFF11
+0xA3B2	0xFF12
+0xA3B3	0xFF13
+0xA3B4	0xFF14
+0xA3B5	0xFF15
+0xA3B6	0xFF16
+0xA3B7	0xFF17
+0xA3B8	0xFF18
+0xA3B9	0xFF19
+0xA3C1	0xFF21
+0xA3C2	0xFF22
+0xA3C3	0xFF23
+0xA3C4	0xFF24
+0xA3C5	0xFF25
+0xA3C6	0xFF26
+0xA3C7	0xFF27
+0xA3C8	0xFF28
+0xA3C9	0xFF29
+0xA3CA	0xFF2A
+0xA3CB	0xFF2B
+0xA3CC	0xFF2C
+0xA3CD	0xFF2D
+0xA3CE	0xFF2E
+0xA3CF	0xFF2F
+0xA3D0	0xFF30
+0xA3D1	0xFF31
+0xA3D2	0xFF32
+0xA3D3	0xFF33
+0xA3D4	0xFF34
+0xA3D5	0xFF35
+0xA3D6	0xFF36
+0xA3D7	0xFF37
+0xA3D8	0xFF38
+0xA3D9	0xFF39
+0xA3DA	0xFF3A
+0xA3E1	0xFF41
+0xA3E2	0xFF42
+0xA3E3	0xFF43
+0xA3E4	0xFF44
+0xA3E5	0xFF45
+0xA3E6	0xFF46
+0xA3E7	0xFF47
+0xA3E8	0xFF48
+0xA3E9	0xFF49
+0xA3EA	0xFF4A
+0xA3EB	0xFF4B
+0xA3EC	0xFF4C
+0xA3ED	0xFF4D
+0xA3EE	0xFF4E
+0xA3EF	0xFF4F
+0xA3F0	0xFF50
+0xA3F1	0xFF51
+0xA3F2	0xFF52
+0xA3F3	0xFF53
+0xA3F4	0xFF54
+0xA3F5	0xFF55
+0xA3F6	0xFF56
+0xA3F7	0xFF57
+0xA3F8	0xFF58
+0xA3F9	0xFF59
+0xA3FA	0xFF5A
+0xA4A1	0x3041
+0xA4A2	0x3042
+0xA4A3	0x3043
+0xA4A4	0x3044
+0xA4A5	0x3045
+0xA4A6	0x3046
+0xA4A7	0x3047
+0xA4A8	0x3048
+0xA4A9	0x3049
+0xA4AA	0x304A
+0xA4AB	0x304B
+0xA4AC	0x304C
+0xA4AD	0x304D
+0xA4AE	0x304E
+0xA4AF	0x304F
+0xA4B0	0x3050
+0xA4B1	0x3051
+0xA4B2	0x3052
+0xA4B3	0x3053
+0xA4B4	0x3054
+0xA4B5	0x3055
+0xA4B6	0x3056
+0xA4B7	0x3057
+0xA4B8	0x3058
+0xA4B9	0x3059
+0xA4BA	0x305A
+0xA4BB	0x305B
+0xA4BC	0x305C
+0xA4BD	0x305D
+0xA4BE	0x305E
+0xA4BF	0x305F
+0xA4C0	0x3060
+0xA4C1	0x3061
+0xA4C2	0x3062
+0xA4C3	0x3063
+0xA4C4	0x3064
+0xA4C5	0x3065
+0xA4C6	0x3066
+0xA4C7	0x3067
+0xA4C8	0x3068
+0xA4C9	0x3069
+0xA4CA	0x306A
+0xA4CB	0x306B
+0xA4CC	0x306C
+0xA4CD	0x306D
+0xA4CE	0x306E
+0xA4CF	0x306F
+0xA4D0	0x3070
+0xA4D1	0x3071
+0xA4D2	0x3072
+0xA4D3	0x3073
+0xA4D4	0x3074
+0xA4D5	0x3075
+0xA4D6	0x3076
+0xA4D7	0x3077
+0xA4D8	0x3078
+0xA4D9	0x3079
+0xA4DA	0x307A
+0xA4DB	0x307B
+0xA4DC	0x307C
+0xA4DD	0x307D
+0xA4DE	0x307E
+0xA4DF	0x307F
+0xA4E0	0x3080
+0xA4E1	0x3081
+0xA4E2	0x3082
+0xA4E3	0x3083
+0xA4E4	0x3084
+0xA4E5	0x3085
+0xA4E6	0x3086
+0xA4E7	0x3087
+0xA4E8	0x3088
+0xA4E9	0x3089
+0xA4EA	0x308A
+0xA4EB	0x308B
+0xA4EC	0x308C
+0xA4ED	0x308D
+0xA4EE	0x308E
+0xA4EF	0x308F
+0xA4F0	0x3090
+0xA4F1	0x3091
+0xA4F2	0x3092
+0xA4F3	0x3093
+0xA5A1	0x30A1
+0xA5A2	0x30A2
+0xA5A3	0x30A3
+0xA5A4	0x30A4
+0xA5A5	0x30A5
+0xA5A6	0x30A6
+0xA5A7	0x30A7
+0xA5A8	0x30A8
+0xA5A9	0x30A9
+0xA5AA	0x30AA
+0xA5AB	0x30AB
+0xA5AC	0x30AC
+0xA5AD	0x30AD
+0xA5AE	0x30AE
+0xA5AF	0x30AF
+0xA5B0	0x30B0
+0xA5B1	0x30B1
+0xA5B2	0x30B2
+0xA5B3	0x30B3
+0xA5B4	0x30B4
+0xA5B5	0x30B5
+0xA5B6	0x30B6
+0xA5B7	0x30B7
+0xA5B8	0x30B8
+0xA5B9	0x30B9
+0xA5BA	0x30BA
+0xA5BB	0x30BB
+0xA5BC	0x30BC
+0xA5BD	0x30BD
+0xA5BE	0x30BE
+0xA5BF	0x30BF
+0xA5C0	0x30C0
+0xA5C1	0x30C1
+0xA5C2	0x30C2
+0xA5C3	0x30C3
+0xA5C4	0x30C4
+0xA5C5	0x30C5
+0xA5C6	0x30C6
+0xA5C7	0x30C7
+0xA5C8	0x30C8
+0xA5C9	0x30C9
+0xA5CA	0x30CA
+0xA5CB	0x30CB
+0xA5CC	0x30CC
+0xA5CD	0x30CD
+0xA5CE	0x30CE
+0xA5CF	0x30CF
+0xA5D0	0x30D0
+0xA5D1	0x30D1
+0xA5D2	0x30D2
+0xA5D3	0x30D3
+0xA5D4	0x30D4
+0xA5D5	0x30D5
+0xA5D6	0x30D6
+0xA5D7	0x30D7
+0xA5D8	0x30D8
+0xA5D9	0x30D9
+0xA5DA	0x30DA
+0xA5DB	0x30DB
+0xA5DC	0x30DC
+0xA5DD	0x30DD
+0xA5DE	0x30DE
+0xA5DF	0x30DF
+0xA5E0	0x30E0
+0xA5E1	0x30E1
+0xA5E2	0x30E2
+0xA5E3	0x30E3
+0xA5E4	0x30E4
+0xA5E5	0x30E5
+0xA5E6	0x30E6
+0xA5E7	0x30E7
+0xA5E8	0x30E8
+0xA5E9	0x30E9
+0xA5EA	0x30EA
+0xA5EB	0x30EB
+0xA5EC	0x30EC
+0xA5ED	0x30ED
+0xA5EE	0x30EE
+0xA5EF	0x30EF
+0xA5F0	0x30F0
+0xA5F1	0x30F1
+0xA5F2	0x30F2
+0xA5F3	0x30F3
+0xA5F4	0x30F4
+0xA5F5	0x30F5
+0xA5F6	0x30F6
+0xA6A1	0x0391
+0xA6A2	0x0392
+0xA6A3	0x0393
+0xA6A4	0x0394
+0xA6A5	0x0395
+0xA6A6	0x0396
+0xA6A7	0x0397
+0xA6A8	0x0398
+0xA6A9	0x0399
+0xA6AA	0x039A
+0xA6AB	0x039B
+0xA6AC	0x039C
+0xA6AD	0x039D
+0xA6AE	0x039E
+0xA6AF	0x039F
+0xA6B0	0x03A0
+0xA6B1	0x03A1
+0xA6B2	0x03A3
+0xA6B3	0x03A4
+0xA6B4	0x03A5
+0xA6B5	0x03A6
+0xA6B6	0x03A7
+0xA6B7	0x03A8
+0xA6B8	0x03A9
+0xA6C1	0x03B1
+0xA6C2	0x03B2
+0xA6C3	0x03B3
+0xA6C4	0x03B4
+0xA6C5	0x03B5
+0xA6C6	0x03B6
+0xA6C7	0x03B7
+0xA6C8	0x03B8
+0xA6C9	0x03B9
+0xA6CA	0x03BA
+0xA6CB	0x03BB
+0xA6CC	0x03BC
+0xA6CD	0x03BD
+0xA6CE	0x03BE
+0xA6CF	0x03BF
+0xA6D0	0x03C0
+0xA6D1	0x03C1
+0xA6D2	0x03C3
+0xA6D3	0x03C4
+0xA6D4	0x03C5
+0xA6D5	0x03C6
+0xA6D6	0x03C7
+0xA6D7	0x03C8
+0xA6D8	0x03C9
+0xA7A1	0x0410
+0xA7A2	0x0411
+0xA7A3	0x0412
+0xA7A4	0x0413
+0xA7A5	0x0414
+0xA7A6	0x0415
+0xA7A7	0x0401
+0xA7A8	0x0416
+0xA7A9	0x0417
+0xA7AA	0x0418
+0xA7AB	0x0419
+0xA7AC	0x041A
+0xA7AD	0x041B
+0xA7AE	0x041C
+0xA7AF	0x041D
+0xA7B0	0x041E
+0xA7B1	0x041F
+0xA7B2	0x0420
+0xA7B3	0x0421
+0xA7B4	0x0422
+0xA7B5	0x0423
+0xA7B6	0x0424
+0xA7B7	0x0425
+0xA7B8	0x0426
+0xA7B9	0x0427
+0xA7BA	0x0428
+0xA7BB	0x0429
+0xA7BC	0x042A
+0xA7BD	0x042B
+0xA7BE	0x042C
+0xA7BF	0x042D
+0xA7C0	0x042E
+0xA7C1	0x042F
+0xA7D1	0x0430
+0xA7D2	0x0431
+0xA7D3	0x0432
+0xA7D4	0x0433
+0xA7D5	0x0434
+0xA7D6	0x0435
+0xA7D7	0x0451
+0xA7D8	0x0436
+0xA7D9	0x0437
+0xA7DA	0x0438
+0xA7DB	0x0439
+0xA7DC	0x043A
+0xA7DD	0x043B
+0xA7DE	0x043C
+0xA7DF	0x043D
+0xA7E0	0x043E
+0xA7E1	0x043F
+0xA7E2	0x0440
+0xA7E3	0x0441
+0xA7E4	0x0442
+0xA7E5	0x0443
+0xA7E6	0x0444
+0xA7E7	0x0445
+0xA7E8	0x0446
+0xA7E9	0x0447
+0xA7EA	0x0448
+0xA7EB	0x0449
+0xA7EC	0x044A
+0xA7ED	0x044B
+0xA7EE	0x044C
+0xA7EF	0x044D
+0xA7F0	0x044E
+0xA7F1	0x044F
+0xA8A1	0x2500
+0xA8A2	0x2502
+0xA8A3	0x250C
+0xA8A4	0x2510
+0xA8A5	0x2518
+0xA8A6	0x2514
+0xA8A7	0x251C
+0xA8A8	0x252C
+0xA8A9	0x2524
+0xA8AA	0x2534
+0xA8AB	0x253C
+0xA8AC	0x2501
+0xA8AD	0x2503
+0xA8AE	0x250F
+0xA8AF	0x2513
+0xA8B0	0x251B
+0xA8B1	0x2517
+0xA8B2	0x2523
+0xA8B3	0x2533
+0xA8B4	0x252B
+0xA8B5	0x253B
+0xA8B6	0x254B
+0xA8B7	0x2520
+0xA8B8	0x252F
+0xA8B9	0x2528
+0xA8BA	0x2537
+0xA8BB	0x253F
+0xA8BC	0x251D
+0xA8BD	0x2530
+0xA8BE	0x2525
+0xA8BF	0x2538
+0xA8C0	0x2542
+0xADA1	0x2460
+0xADA2	0x2461
+0xADA3	0x2462
+0xADA4	0x2463
+0xADA5	0x2464
+0xADA6	0x2465
+0xADA7	0x2466
+0xADA8	0x2467
+0xADA9	0x2468
+0xADAA	0x2469
+0xADAB	0x246A
+0xADAC	0x246B
+0xADAD	0x246C
+0xADAE	0x246D
+0xADAF	0x246E
+0xADB0	0x246F
+0xADB1	0x2470
+0xADB2	0x2471
+0xADB3	0x2472
+0xADB4	0x2473
+0xADB5	0x2160
+0xADB6	0x2161
+0xADB7	0x2162
+0xADB8	0x2163
+0xADB9	0x2164
+0xADBA	0x2165
+0xADBB	0x2166
+0xADBC	0x2167
+0xADBD	0x2168
+0xADBE	0x2169
+0xADC0	0x3349
+0xADC1	0x3314
+0xADC2	0x3322
+0xADC3	0x334D
+0xADC4	0x3318
+0xADC5	0x3327
+0xADC6	0x3303
+0xADC7	0x3336
+0xADC8	0x3351
+0xADC9	0x3357
+0xADCA	0x330D
+0xADCB	0x3326
+0xADCC	0x3323
+0xADCD	0x332B
+0xADCE	0x334A
+0xADCF	0x333B
+0xADD0	0x339C
+0xADD1	0x339D
+0xADD2	0x339E
+0xADD3	0x338E
+0xADD4	0x338F
+0xADD5	0x33C4
+0xADD6	0x33A1
+0xADDF	0x337B
+0xADE0	0x301D
+0xADE1	0x301F
+0xADE2	0x2116
+0xADE3	0x33CD
+0xADE4	0x2121
+0xADE5	0x32A4
+0xADE6	0x32A5
+0xADE7	0x32A6
+0xADE8	0x32A7
+0xADE9	0x32A8
+0xADEA	0x3231
+0xADEB	0x3232
+0xADEC	0x3239
+0xADED	0x337E
+0xADEE	0x337D
+0xADEF	0x337C
+0xADF0	0x2252
+0xADF1	0x2261
+0xADF2	0x222B
+0xADF3	0x222E
+0xADF4	0x2211
+0xADF5	0x221A
+0xADF6	0x22A5
+0xADF7	0x2220
+0xADF8	0x221F
+0xADF9	0x22BF
+0xADFA	0x2235
+0xADFB	0x2229
+0xADFC	0x222A
+0xB0A1	0x4E9C
+0xB0A2	0x5516
+0xB0A3	0x5A03
+0xB0A4	0x963F
+0xB0A5	0x54C0
+0xB0A6	0x611B
+0xB0A7	0x6328
+0xB0A8	0x59F6
+0xB0A9	0x9022
+0xB0AA	0x8475
+0xB0AB	0x831C
+0xB0AC	0x7A50
+0xB0AD	0x60AA
+0xB0AE	0x63E1
+0xB0AF	0x6E25
+0xB0B0	0x65ED
+0xB0B1	0x8466
+0xB0B2	0x82A6
+0xB0B3	0x9BF5
+0xB0B4	0x6893
+0xB0B5	0x5727
+0xB0B6	0x65A1
+0xB0B7	0x6271
+0xB0B8	0x5B9B
+0xB0B9	0x59D0
+0xB0BA	0x867B
+0xB0BB	0x98F4
+0xB0BC	0x7D62
+0xB0BD	0x7DBE
+0xB0BE	0x9B8E
+0xB0BF	0x6216
+0xB0C0	0x7C9F
+0xB0C1	0x88B7
+0xB0C2	0x5B89
+0xB0C3	0x5EB5
+0xB0C4	0x6309
+0xB0C5	0x6697
+0xB0C6	0x6848
+0xB0C7	0x95C7
+0xB0C8	0x978D
+0xB0C9	0x674F
+0xB0CA	0x4EE5
+0xB0CB	0x4F0A
+0xB0CC	0x4F4D
+0xB0CD	0x4F9D
+0xB0CE	0x5049
+0xB0CF	0x56F2
+0xB0D0	0x5937
+0xB0D1	0x59D4
+0xB0D2	0x5A01
+0xB0D3	0x5C09
+0xB0D4	0x60DF
+0xB0D5	0x610F
+0xB0D6	0x6170
+0xB0D7	0x6613
+0xB0D8	0x6905
+0xB0D9	0x70BA
+0xB0DA	0x754F
+0xB0DB	0x7570
+0xB0DC	0x79FB
+0xB0DD	0x7DAD
+0xB0DE	0x7DEF
+0xB0DF	0x80C3
+0xB0E0	0x840E
+0xB0E1	0x8863
+0xB0E2	0x8B02
+0xB0E3	0x9055
+0xB0E4	0x907A
+0xB0E5	0x533B
+0xB0E6	0x4E95
+0xB0E7	0x4EA5
+0xB0E8	0x57DF
+0xB0E9	0x80B2
+0xB0EA	0x90C1
+0xB0EB	0x78EF
+0xB0EC	0x4E00
+0xB0ED	0x58F1
+0xB0EE	0x6EA2
+0xB0EF	0x9038
+0xB0F0	0x7A32
+0xB0F1	0x8328
+0xB0F2	0x828B
+0xB0F3	0x9C2F
+0xB0F4	0x5141
+0xB0F5	0x5370
+0xB0F6	0x54BD
+0xB0F7	0x54E1
+0xB0F8	0x56E0
+0xB0F9	0x59FB
+0xB0FA	0x5F15
+0xB0FB	0x98F2
+0xB0FC	0x6DEB
+0xB0FD	0x80E4
+0xB0FE	0x852D
+0xB1A1	0x9662
+0xB1A2	0x9670
+0xB1A3	0x96A0
+0xB1A4	0x97FB
+0xB1A5	0x540B
+0xB1A6	0x53F3
+0xB1A7	0x5B87
+0xB1A8	0x70CF
+0xB1A9	0x7FBD
+0xB1AA	0x8FC2
+0xB1AB	0x96E8
+0xB1AC	0x536F
+0xB1AD	0x9D5C
+0xB1AE	0x7ABA
+0xB1AF	0x4E11
+0xB1B0	0x7893
+0xB1B1	0x81FC
+0xB1B2	0x6E26
+0xB1B3	0x5618
+0xB1B4	0x5504
+0xB1B5	0x6B1D
+0xB1B6	0x851A
+0xB1B7	0x9C3B
+0xB1B8	0x59E5
+0xB1B9	0x53A9
+0xB1BA	0x6D66
+0xB1BB	0x74DC
+0xB1BC	0x958F
+0xB1BD	0x5642
+0xB1BE	0x4E91
+0xB1BF	0x904B
+0xB1C0	0x96F2
+0xB1C1	0x834F
+0xB1C2	0x990C
+0xB1C3	0x53E1
+0xB1C4	0x55B6
+0xB1C5	0x5B30
+0xB1C6	0x5F71
+0xB1C7	0x6620
+0xB1C8	0x66F3
+0xB1C9	0x6804
+0xB1CA	0x6C38
+0xB1CB	0x6CF3
+0xB1CC	0x6D29
+0xB1CD	0x745B
+0xB1CE	0x76C8
+0xB1CF	0x7A4E
+0xB1D0	0x9834
+0xB1D1	0x82F1
+0xB1D2	0x885B
+0xB1D3	0x8A60
+0xB1D4	0x92ED
+0xB1D5	0x6DB2
+0xB1D6	0x75AB
+0xB1D7	0x76CA
+0xB1D8	0x99C5
+0xB1D9	0x60A6
+0xB1DA	0x8B01
+0xB1DB	0x8D8A
+0xB1DC	0x95B2
+0xB1DD	0x698E
+0xB1DE	0x53AD
+0xB1DF	0x5186
+0xB1E0	0x5712
+0xB1E1	0x5830
+0xB1E2	0x5944
+0xB1E3	0x5BB4
+0xB1E4	0x5EF6
+0xB1E5	0x6028
+0xB1E6	0x63A9
+0xB1E7	0x63F4
+0xB1E8	0x6CBF
+0xB1E9	0x6F14
+0xB1EA	0x708E
+0xB1EB	0x7114
+0xB1EC	0x7159
+0xB1ED	0x71D5
+0xB1EE	0x733F
+0xB1EF	0x7E01
+0xB1F0	0x8276
+0xB1F1	0x82D1
+0xB1F2	0x8597
+0xB1F3	0x9060
+0xB1F4	0x925B
+0xB1F5	0x9D1B
+0xB1F6	0x5869
+0xB1F7	0x65BC
+0xB1F8	0x6C5A
+0xB1F9	0x7525
+0xB1FA	0x51F9
+0xB1FB	0x592E
+0xB1FC	0x5965
+0xB1FD	0x5F80
+0xB1FE	0x5FDC
+0xB2A1	0x62BC
+0xB2A2	0x65FA
+0xB2A3	0x6A2A
+0xB2A4	0x6B27
+0xB2A5	0x6BB4
+0xB2A6	0x738B
+0xB2A7	0x7FC1
+0xB2A8	0x8956
+0xB2A9	0x9D2C
+0xB2AA	0x9D0E
+0xB2AB	0x9EC4
+0xB2AC	0x5CA1
+0xB2AD	0x6C96
+0xB2AE	0x837B
+0xB2AF	0x5104
+0xB2B0	0x5C4B
+0xB2B1	0x61B6
+0xB2B2	0x81C6
+0xB2B3	0x6876
+0xB2B4	0x7261
+0xB2B5	0x4E59
+0xB2B6	0x4FFA
+0xB2B7	0x5378
+0xB2B8	0x6069
+0xB2B9	0x6E29
+0xB2BA	0x7A4F
+0xB2BB	0x97F3
+0xB2BC	0x4E0B
+0xB2BD	0x5316
+0xB2BE	0x4EEE
+0xB2BF	0x4F55
+0xB2C0	0x4F3D
+0xB2C1	0x4FA1
+0xB2C2	0x4F73
+0xB2C3	0x52A0
+0xB2C4	0x53EF
+0xB2C5	0x5609
+0xB2C6	0x590F
+0xB2C7	0x5AC1
+0xB2C8	0x5BB6
+0xB2C9	0x5BE1
+0xB2CA	0x79D1
+0xB2CB	0x6687
+0xB2CC	0x679C
+0xB2CD	0x67B6
+0xB2CE	0x6B4C
+0xB2CF	0x6CB3
+0xB2D0	0x706B
+0xB2D1	0x73C2
+0xB2D2	0x798D
+0xB2D3	0x79BE
+0xB2D4	0x7A3C
+0xB2D5	0x7B87
+0xB2D6	0x82B1
+0xB2D7	0x82DB
+0xB2D8	0x8304
+0xB2D9	0x8377
+0xB2DA	0x83EF
+0xB2DB	0x83D3
+0xB2DC	0x8766
+0xB2DD	0x8AB2
+0xB2DE	0x5629
+0xB2DF	0x8CA8
+0xB2E0	0x8FE6
+0xB2E1	0x904E
+0xB2E2	0x971E
+0xB2E3	0x868A
+0xB2E4	0x4FC4
+0xB2E5	0x5CE8
+0xB2E6	0x6211
+0xB2E7	0x7259
+0xB2E8	0x753B
+0xB2E9	0x81E5
+0xB2EA	0x82BD
+0xB2EB	0x86FE
+0xB2EC	0x8CC0
+0xB2ED	0x96C5
+0xB2EE	0x9913
+0xB2EF	0x99D5
+0xB2F0	0x4ECB
+0xB2F1	0x4F1A
+0xB2F2	0x89E3
+0xB2F3	0x56DE
+0xB2F4	0x584A
+0xB2F5	0x58CA
+0xB2F6	0x5EFB
+0xB2F7	0x5FEB
+0xB2F8	0x602A
+0xB2F9	0x6094
+0xB2FA	0x6062
+0xB2FB	0x61D0
+0xB2FC	0x6212
+0xB2FD	0x62D0
+0xB2FE	0x6539
+0xB3A1	0x9B41
+0xB3A2	0x6666
+0xB3A3	0x68B0
+0xB3A4	0x6D77
+0xB3A5	0x7070
+0xB3A6	0x754C
+0xB3A7	0x7686
+0xB3A8	0x7D75
+0xB3A9	0x82A5
+0xB3AA	0x87F9
+0xB3AB	0x958B
+0xB3AC	0x968E
+0xB3AD	0x8C9D
+0xB3AE	0x51F1
+0xB3AF	0x52BE
+0xB3B0	0x5916
+0xB3B1	0x54B3
+0xB3B2	0x5BB3
+0xB3B3	0x5D16
+0xB3B4	0x6168
+0xB3B5	0x6982
+0xB3B6	0x6DAF
+0xB3B7	0x788D
+0xB3B8	0x84CB
+0xB3B9	0x8857
+0xB3BA	0x8A72
+0xB3BB	0x93A7
+0xB3BC	0x9AB8
+0xB3BD	0x6D6C
+0xB3BE	0x99A8
+0xB3BF	0x86D9
+0xB3C0	0x57A3
+0xB3C1	0x67FF
+0xB3C2	0x86CE
+0xB3C3	0x920E
+0xB3C4	0x5283
+0xB3C5	0x5687
+0xB3C6	0x5404
+0xB3C7	0x5ED3
+0xB3C8	0x62E1
+0xB3C9	0x64B9
+0xB3CA	0x683C
+0xB3CB	0x6838
+0xB3CC	0x6BBB
+0xB3CD	0x7372
+0xB3CE	0x78BA
+0xB3CF	0x7A6B
+0xB3D0	0x899A
+0xB3D1	0x89D2
+0xB3D2	0x8D6B
+0xB3D3	0x8F03
+0xB3D4	0x90ED
+0xB3D5	0x95A3
+0xB3D6	0x9694
+0xB3D7	0x9769
+0xB3D8	0x5B66
+0xB3D9	0x5CB3
+0xB3DA	0x697D
+0xB3DB	0x984D
+0xB3DC	0x984E
+0xB3DD	0x639B
+0xB3DE	0x7B20
+0xB3DF	0x6A2B
+0xB3E0	0x6A7F
+0xB3E1	0x68B6
+0xB3E2	0x9C0D
+0xB3E3	0x6F5F
+0xB3E4	0x5272
+0xB3E5	0x559D
+0xB3E6	0x6070
+0xB3E7	0x62EC
+0xB3E8	0x6D3B
+0xB3E9	0x6E07
+0xB3EA	0x6ED1
+0xB3EB	0x845B
+0xB3EC	0x8910
+0xB3ED	0x8F44
+0xB3EE	0x4E14
+0xB3EF	0x9C39
+0xB3F0	0x53F6
+0xB3F1	0x691B
+0xB3F2	0x6A3A
+0xB3F3	0x9784
+0xB3F4	0x682A
+0xB3F5	0x515C
+0xB3F6	0x7AC3
+0xB3F7	0x84B2
+0xB3F8	0x91DC
+0xB3F9	0x938C
+0xB3FA	0x565B
+0xB3FB	0x9D28
+0xB3FC	0x6822
+0xB3FD	0x8305
+0xB3FE	0x8431
+0xB4A1	0x7CA5
+0xB4A2	0x5208
+0xB4A3	0x82C5
+0xB4A4	0x74E6
+0xB4A5	0x4E7E
+0xB4A6	0x4F83
+0xB4A7	0x51A0
+0xB4A8	0x5BD2
+0xB4A9	0x520A
+0xB4AA	0x52D8
+0xB4AB	0x52E7
+0xB4AC	0x5DFB
+0xB4AD	0x559A
+0xB4AE	0x582A
+0xB4AF	0x59E6
+0xB4B0	0x5B8C
+0xB4B1	0x5B98
+0xB4B2	0x5BDB
+0xB4B3	0x5E72
+0xB4B4	0x5E79
+0xB4B5	0x60A3
+0xB4B6	0x611F
+0xB4B7	0x6163
+0xB4B8	0x61BE
+0xB4B9	0x63DB
+0xB4BA	0x6562
+0xB4BB	0x67D1
+0xB4BC	0x6853
+0xB4BD	0x68FA
+0xB4BE	0x6B3E
+0xB4BF	0x6B53
+0xB4C0	0x6C57
+0xB4C1	0x6F22
+0xB4C2	0x6F97
+0xB4C3	0x6F45
+0xB4C4	0x74B0
+0xB4C5	0x7518
+0xB4C6	0x76E3
+0xB4C7	0x770B
+0xB4C8	0x7AFF
+0xB4C9	0x7BA1
+0xB4CA	0x7C21
+0xB4CB	0x7DE9
+0xB4CC	0x7F36
+0xB4CD	0x7FF0
+0xB4CE	0x809D
+0xB4CF	0x8266
+0xB4D0	0x839E
+0xB4D1	0x89B3
+0xB4D2	0x8ACC
+0xB4D3	0x8CAB
+0xB4D4	0x9084
+0xB4D5	0x9451
+0xB4D6	0x9593
+0xB4D7	0x9591
+0xB4D8	0x95A2
+0xB4D9	0x9665
+0xB4DA	0x97D3
+0xB4DB	0x9928
+0xB4DC	0x8218
+0xB4DD	0x4E38
+0xB4DE	0x542B
+0xB4DF	0x5CB8
+0xB4E0	0x5DCC
+0xB4E1	0x73A9
+0xB4E2	0x764C
+0xB4E3	0x773C
+0xB4E4	0x5CA9
+0xB4E5	0x7FEB
+0xB4E6	0x8D0B
+0xB4E7	0x96C1
+0xB4E8	0x9811
+0xB4E9	0x9854
+0xB4EA	0x9858
+0xB4EB	0x4F01
+0xB4EC	0x4F0E
+0xB4ED	0x5371
+0xB4EE	0x559C
+0xB4EF	0x5668
+0xB4F0	0x57FA
+0xB4F1	0x5947
+0xB4F2	0x5B09
+0xB4F3	0x5BC4
+0xB4F4	0x5C90
+0xB4F5	0x5E0C
+0xB4F6	0x5E7E
+0xB4F7	0x5FCC
+0xB4F8	0x63EE
+0xB4F9	0x673A
+0xB4FA	0x65D7
+0xB4FB	0x65E2
+0xB4FC	0x671F
+0xB4FD	0x68CB
+0xB4FE	0x68C4
+0xB5A1	0x6A5F
+0xB5A2	0x5E30
+0xB5A3	0x6BC5
+0xB5A4	0x6C17
+0xB5A5	0x6C7D
+0xB5A6	0x757F
+0xB5A7	0x7948
+0xB5A8	0x5B63
+0xB5A9	0x7A00
+0xB5AA	0x7D00
+0xB5AB	0x5FBD
+0xB5AC	0x898F
+0xB5AD	0x8A18
+0xB5AE	0x8CB4
+0xB5AF	0x8D77
+0xB5B0	0x8ECC
+0xB5B1	0x8F1D
+0xB5B2	0x98E2
+0xB5B3	0x9A0E
+0xB5B4	0x9B3C
+0xB5B5	0x4E80
+0xB5B6	0x507D
+0xB5B7	0x5100
+0xB5B8	0x5993
+0xB5B9	0x5B9C
+0xB5BA	0x622F
+0xB5BB	0x6280
+0xB5BC	0x64EC
+0xB5BD	0x6B3A
+0xB5BE	0x72A0
+0xB5BF	0x7591
+0xB5C0	0x7947
+0xB5C1	0x7FA9
+0xB5C2	0x87FB
+0xB5C3	0x8ABC
+0xB5C4	0x8B70
+0xB5C5	0x63AC
+0xB5C6	0x83CA
+0xB5C7	0x97A0
+0xB5C8	0x5409
+0xB5C9	0x5403
+0xB5CA	0x55AB
+0xB5CB	0x6854
+0xB5CC	0x6A58
+0xB5CD	0x8A70
+0xB5CE	0x7827
+0xB5CF	0x6775
+0xB5D0	0x9ECD
+0xB5D1	0x5374
+0xB5D2	0x5BA2
+0xB5D3	0x811A
+0xB5D4	0x8650
+0xB5D5	0x9006
+0xB5D6	0x4E18
+0xB5D7	0x4E45
+0xB5D8	0x4EC7
+0xB5D9	0x4F11
+0xB5DA	0x53CA
+0xB5DB	0x5438
+0xB5DC	0x5BAE
+0xB5DD	0x5F13
+0xB5DE	0x6025
+0xB5DF	0x6551
+0xB5E0	0x673D
+0xB5E1	0x6C42
+0xB5E2	0x6C72
+0xB5E3	0x6CE3
+0xB5E4	0x7078
+0xB5E5	0x7403
+0xB5E6	0x7A76
+0xB5E7	0x7AAE
+0xB5E8	0x7B08
+0xB5E9	0x7D1A
+0xB5EA	0x7CFE
+0xB5EB	0x7D66
+0xB5EC	0x65E7
+0xB5ED	0x725B
+0xB5EE	0x53BB
+0xB5EF	0x5C45
+0xB5F0	0x5DE8
+0xB5F1	0x62D2
+0xB5F2	0x62E0
+0xB5F3	0x6319
+0xB5F4	0x6E20
+0xB5F5	0x865A
+0xB5F6	0x8A31
+0xB5F7	0x8DDD
+0xB5F8	0x92F8
+0xB5F9	0x6F01
+0xB5FA	0x79A6
+0xB5FB	0x9B5A
+0xB5FC	0x4EA8
+0xB5FD	0x4EAB
+0xB5FE	0x4EAC
+0xB6A1	0x4F9B
+0xB6A2	0x4FA0
+0xB6A3	0x50D1
+0xB6A4	0x5147
+0xB6A5	0x7AF6
+0xB6A6	0x5171
+0xB6A7	0x51F6
+0xB6A8	0x5354
+0xB6A9	0x5321
+0xB6AA	0x537F
+0xB6AB	0x53EB
+0xB6AC	0x55AC
+0xB6AD	0x5883
+0xB6AE	0x5CE1
+0xB6AF	0x5F37
+0xB6B0	0x5F4A
+0xB6B1	0x602F
+0xB6B2	0x6050
+0xB6B3	0x606D
+0xB6B4	0x631F
+0xB6B5	0x6559
+0xB6B6	0x6A4B
+0xB6B7	0x6CC1
+0xB6B8	0x72C2
+0xB6B9	0x72ED
+0xB6BA	0x77EF
+0xB6BB	0x80F8
+0xB6BC	0x8105
+0xB6BD	0x8208
+0xB6BE	0x854E
+0xB6BF	0x90F7
+0xB6C0	0x93E1
+0xB6C1	0x97FF
+0xB6C2	0x9957
+0xB6C3	0x9A5A
+0xB6C4	0x4EF0
+0xB6C5	0x51DD
+0xB6C6	0x5C2D
+0xB6C7	0x6681
+0xB6C8	0x696D
+0xB6C9	0x5C40
+0xB6CA	0x66F2
+0xB6CB	0x6975
+0xB6CC	0x7389
+0xB6CD	0x6850
+0xB6CE	0x7C81
+0xB6CF	0x50C5
+0xB6D0	0x52E4
+0xB6D1	0x5747
+0xB6D2	0x5DFE
+0xB6D3	0x9326
+0xB6D4	0x65A4
+0xB6D5	0x6B23
+0xB6D6	0x6B3D
+0xB6D7	0x7434
+0xB6D8	0x7981
+0xB6D9	0x79BD
+0xB6DA	0x7B4B
+0xB6DB	0x7DCA
+0xB6DC	0x82B9
+0xB6DD	0x83CC
+0xB6DE	0x887F
+0xB6DF	0x895F
+0xB6E0	0x8B39
+0xB6E1	0x8FD1
+0xB6E2	0x91D1
+0xB6E3	0x541F
+0xB6E4	0x9280
+0xB6E5	0x4E5D
+0xB6E6	0x5036
+0xB6E7	0x53E5
+0xB6E8	0x533A
+0xB6E9	0x72D7
+0xB6EA	0x7396
+0xB6EB	0x77E9
+0xB6EC	0x82E6
+0xB6ED	0x8EAF
+0xB6EE	0x99C6
+0xB6EF	0x99C8
+0xB6F0	0x99D2
+0xB6F1	0x5177
+0xB6F2	0x611A
+0xB6F3	0x865E
+0xB6F4	0x55B0
+0xB6F5	0x7A7A
+0xB6F6	0x5076
+0xB6F7	0x5BD3
+0xB6F8	0x9047
+0xB6F9	0x9685
+0xB6FA	0x4E32
+0xB6FB	0x6ADB
+0xB6FC	0x91E7
+0xB6FD	0x5C51
+0xB6FE	0x5C48
+0xB7A1	0x6398
+0xB7A2	0x7A9F
+0xB7A3	0x6C93
+0xB7A4	0x9774
+0xB7A5	0x8F61
+0xB7A6	0x7AAA
+0xB7A7	0x718A
+0xB7A8	0x9688
+0xB7A9	0x7C82
+0xB7AA	0x6817
+0xB7AB	0x7E70
+0xB7AC	0x6851
+0xB7AD	0x936C
+0xB7AE	0x52F2
+0xB7AF	0x541B
+0xB7B0	0x85AB
+0xB7B1	0x8A13
+0xB7B2	0x7FA4
+0xB7B3	0x8ECD
+0xB7B4	0x90E1
+0xB7B5	0x5366
+0xB7B6	0x8888
+0xB7B7	0x7941
+0xB7B8	0x4FC2
+0xB7B9	0x50BE
+0xB7BA	0x5211
+0xB7BB	0x5144
+0xB7BC	0x5553
+0xB7BD	0x572D
+0xB7BE	0x73EA
+0xB7BF	0x578B
+0xB7C0	0x5951
+0xB7C1	0x5F62
+0xB7C2	0x5F84
+0xB7C3	0x6075
+0xB7C4	0x6176
+0xB7C5	0x6167
+0xB7C6	0x61A9
+0xB7C7	0x63B2
+0xB7C8	0x643A
+0xB7C9	0x656C
+0xB7CA	0x666F
+0xB7CB	0x6842
+0xB7CC	0x6E13
+0xB7CD	0x7566
+0xB7CE	0x7A3D
+0xB7CF	0x7CFB
+0xB7D0	0x7D4C
+0xB7D1	0x7D99
+0xB7D2	0x7E4B
+0xB7D3	0x7F6B
+0xB7D4	0x830E
+0xB7D5	0x834A
+0xB7D6	0x86CD
+0xB7D7	0x8A08
+0xB7D8	0x8A63
+0xB7D9	0x8B66
+0xB7DA	0x8EFD
+0xB7DB	0x981A
+0xB7DC	0x9D8F
+0xB7DD	0x82B8
+0xB7DE	0x8FCE
+0xB7DF	0x9BE8
+0xB7E0	0x5287
+0xB7E1	0x621F
+0xB7E2	0x6483
+0xB7E3	0x6FC0
+0xB7E4	0x9699
+0xB7E5	0x6841
+0xB7E6	0x5091
+0xB7E7	0x6B20
+0xB7E8	0x6C7A
+0xB7E9	0x6F54
+0xB7EA	0x7A74
+0xB7EB	0x7D50
+0xB7EC	0x8840
+0xB7ED	0x8A23
+0xB7EE	0x6708
+0xB7EF	0x4EF6
+0xB7F0	0x5039
+0xB7F1	0x5026
+0xB7F2	0x5065
+0xB7F3	0x517C
+0xB7F4	0x5238
+0xB7F5	0x5263
+0xB7F6	0x55A7
+0xB7F7	0x570F
+0xB7F8	0x5805
+0xB7F9	0x5ACC
+0xB7FA	0x5EFA
+0xB7FB	0x61B2
+0xB7FC	0x61F8
+0xB7FD	0x62F3
+0xB7FE	0x6372
+0xB8A1	0x691C
+0xB8A2	0x6A29
+0xB8A3	0x727D
+0xB8A4	0x72AC
+0xB8A5	0x732E
+0xB8A6	0x7814
+0xB8A7	0x786F
+0xB8A8	0x7D79
+0xB8A9	0x770C
+0xB8AA	0x80A9
+0xB8AB	0x898B
+0xB8AC	0x8B19
+0xB8AD	0x8CE2
+0xB8AE	0x8ED2
+0xB8AF	0x9063
+0xB8B0	0x9375
+0xB8B1	0x967A
+0xB8B2	0x9855
+0xB8B3	0x9A13
+0xB8B4	0x9E78
+0xB8B5	0x5143
+0xB8B6	0x539F
+0xB8B7	0x53B3
+0xB8B8	0x5E7B
+0xB8B9	0x5F26
+0xB8BA	0x6E1B
+0xB8BB	0x6E90
+0xB8BC	0x7384
+0xB8BD	0x73FE
+0xB8BE	0x7D43
+0xB8BF	0x8237
+0xB8C0	0x8A00
+0xB8C1	0x8AFA
+0xB8C2	0x9650
+0xB8C3	0x4E4E
+0xB8C4	0x500B
+0xB8C5	0x53E4
+0xB8C6	0x547C
+0xB8C7	0x56FA
+0xB8C8	0x59D1
+0xB8C9	0x5B64
+0xB8CA	0x5DF1
+0xB8CB	0x5EAB
+0xB8CC	0x5F27
+0xB8CD	0x6238
+0xB8CE	0x6545
+0xB8CF	0x67AF
+0xB8D0	0x6E56
+0xB8D1	0x72D0
+0xB8D2	0x7CCA
+0xB8D3	0x88B4
+0xB8D4	0x80A1
+0xB8D5	0x80E1
+0xB8D6	0x83F0
+0xB8D7	0x864E
+0xB8D8	0x8A87
+0xB8D9	0x8DE8
+0xB8DA	0x9237
+0xB8DB	0x96C7
+0xB8DC	0x9867
+0xB8DD	0x9F13
+0xB8DE	0x4E94
+0xB8DF	0x4E92
+0xB8E0	0x4F0D
+0xB8E1	0x5348
+0xB8E2	0x5449
+0xB8E3	0x543E
+0xB8E4	0x5A2F
+0xB8E5	0x5F8C
+0xB8E6	0x5FA1
+0xB8E7	0x609F
+0xB8E8	0x68A7
+0xB8E9	0x6A8E
+0xB8EA	0x745A
+0xB8EB	0x7881
+0xB8EC	0x8A9E
+0xB8ED	0x8AA4
+0xB8EE	0x8B77
+0xB8EF	0x9190
+0xB8F0	0x4E5E
+0xB8F1	0x9BC9
+0xB8F2	0x4EA4
+0xB8F3	0x4F7C
+0xB8F4	0x4FAF
+0xB8F5	0x5019
+0xB8F6	0x5016
+0xB8F7	0x5149
+0xB8F8	0x516C
+0xB8F9	0x529F
+0xB8FA	0x52B9
+0xB8FB	0x52FE
+0xB8FC	0x539A
+0xB8FD	0x53E3
+0xB8FE	0x5411
+0xB9A1	0x540E
+0xB9A2	0x5589
+0xB9A3	0x5751
+0xB9A4	0x57A2
+0xB9A5	0x597D
+0xB9A6	0x5B54
+0xB9A7	0x5B5D
+0xB9A8	0x5B8F
+0xB9A9	0x5DE5
+0xB9AA	0x5DE7
+0xB9AB	0x5DF7
+0xB9AC	0x5E78
+0xB9AD	0x5E83
+0xB9AE	0x5E9A
+0xB9AF	0x5EB7
+0xB9B0	0x5F18
+0xB9B1	0x6052
+0xB9B2	0x614C
+0xB9B3	0x6297
+0xB9B4	0x62D8
+0xB9B5	0x63A7
+0xB9B6	0x653B
+0xB9B7	0x6602
+0xB9B8	0x6643
+0xB9B9	0x66F4
+0xB9BA	0x676D
+0xB9BB	0x6821
+0xB9BC	0x6897
+0xB9BD	0x69CB
+0xB9BE	0x6C5F
+0xB9BF	0x6D2A
+0xB9C0	0x6D69
+0xB9C1	0x6E2F
+0xB9C2	0x6E9D
+0xB9C3	0x7532
+0xB9C4	0x7687
+0xB9C5	0x786C
+0xB9C6	0x7A3F
+0xB9C7	0x7CE0
+0xB9C8	0x7D05
+0xB9C9	0x7D18
+0xB9CA	0x7D5E
+0xB9CB	0x7DB1
+0xB9CC	0x8015
+0xB9CD	0x8003
+0xB9CE	0x80AF
+0xB9CF	0x80B1
+0xB9D0	0x8154
+0xB9D1	0x818F
+0xB9D2	0x822A
+0xB9D3	0x8352
+0xB9D4	0x884C
+0xB9D5	0x8861
+0xB9D6	0x8B1B
+0xB9D7	0x8CA2
+0xB9D8	0x8CFC
+0xB9D9	0x90CA
+0xB9DA	0x9175
+0xB9DB	0x9271
+0xB9DC	0x783F
+0xB9DD	0x92FC
+0xB9DE	0x95A4
+0xB9DF	0x964D
+0xB9E0	0x9805
+0xB9E1	0x9999
+0xB9E2	0x9AD8
+0xB9E3	0x9D3B
+0xB9E4	0x525B
+0xB9E5	0x52AB
+0xB9E6	0x53F7
+0xB9E7	0x5408
+0xB9E8	0x58D5
+0xB9E9	0x62F7
+0xB9EA	0x6FE0
+0xB9EB	0x8C6A
+0xB9EC	0x8F5F
+0xB9ED	0x9EB9
+0xB9EE	0x514B
+0xB9EF	0x523B
+0xB9F0	0x544A
+0xB9F1	0x56FD
+0xB9F2	0x7A40
+0xB9F3	0x9177
+0xB9F4	0x9D60
+0xB9F5	0x9ED2
+0xB9F6	0x7344
+0xB9F7	0x6F09
+0xB9F8	0x8170
+0xB9F9	0x7511
+0xB9FA	0x5FFD
+0xB9FB	0x60DA
+0xB9FC	0x9AA8
+0xB9FD	0x72DB
+0xB9FE	0x8FBC
+0xBAA1	0x6B64
+0xBAA2	0x9803
+0xBAA3	0x4ECA
+0xBAA4	0x56F0
+0xBAA5	0x5764
+0xBAA6	0x58BE
+0xBAA7	0x5A5A
+0xBAA8	0x6068
+0xBAA9	0x61C7
+0xBAAA	0x660F
+0xBAAB	0x6606
+0xBAAC	0x6839
+0xBAAD	0x68B1
+0xBAAE	0x6DF7
+0xBAAF	0x75D5
+0xBAB0	0x7D3A
+0xBAB1	0x826E
+0xBAB2	0x9B42
+0xBAB3	0x4E9B
+0xBAB4	0x4F50
+0xBAB5	0x53C9
+0xBAB6	0x5506
+0xBAB7	0x5D6F
+0xBAB8	0x5DE6
+0xBAB9	0x5DEE
+0xBABA	0x67FB
+0xBABB	0x6C99
+0xBABC	0x7473
+0xBABD	0x7802
+0xBABE	0x8A50
+0xBABF	0x9396
+0xBAC0	0x88DF
+0xBAC1	0x5750
+0xBAC2	0x5EA7
+0xBAC3	0x632B
+0xBAC4	0x50B5
+0xBAC5	0x50AC
+0xBAC6	0x518D
+0xBAC7	0x6700
+0xBAC8	0x54C9
+0xBAC9	0x585E
+0xBACA	0x59BB
+0xBACB	0x5BB0
+0xBACC	0x5F69
+0xBACD	0x624D
+0xBACE	0x63A1
+0xBACF	0x683D
+0xBAD0	0x6B73
+0xBAD1	0x6E08
+0xBAD2	0x707D
+0xBAD3	0x91C7
+0xBAD4	0x7280
+0xBAD5	0x7815
+0xBAD6	0x7826
+0xBAD7	0x796D
+0xBAD8	0x658E
+0xBAD9	0x7D30
+0xBADA	0x83DC
+0xBADB	0x88C1
+0xBADC	0x8F09
+0xBADD	0x969B
+0xBADE	0x5264
+0xBADF	0x5728
+0xBAE0	0x6750
+0xBAE1	0x7F6A
+0xBAE2	0x8CA1
+0xBAE3	0x51B4
+0xBAE4	0x5742
+0xBAE5	0x962A
+0xBAE6	0x583A
+0xBAE7	0x698A
+0xBAE8	0x80B4
+0xBAE9	0x54B2
+0xBAEA	0x5D0E
+0xBAEB	0x57FC
+0xBAEC	0x7895
+0xBAED	0x9DFA
+0xBAEE	0x4F5C
+0xBAEF	0x524A
+0xBAF0	0x548B
+0xBAF1	0x643E
+0xBAF2	0x6628
+0xBAF3	0x6714
+0xBAF4	0x67F5
+0xBAF5	0x7A84
+0xBAF6	0x7B56
+0xBAF7	0x7D22
+0xBAF8	0x932F
+0xBAF9	0x685C
+0xBAFA	0x9BAD
+0xBAFB	0x7B39
+0xBAFC	0x5319
+0xBAFD	0x518A
+0xBAFE	0x5237
+0xBBA1	0x5BDF
+0xBBA2	0x62F6
+0xBBA3	0x64AE
+0xBBA4	0x64E6
+0xBBA5	0x672D
+0xBBA6	0x6BBA
+0xBBA7	0x85A9
+0xBBA8	0x96D1
+0xBBA9	0x7690
+0xBBAA	0x9BD6
+0xBBAB	0x634C
+0xBBAC	0x9306
+0xBBAD	0x9BAB
+0xBBAE	0x76BF
+0xBBAF	0x6652
+0xBBB0	0x4E09
+0xBBB1	0x5098
+0xBBB2	0x53C2
+0xBBB3	0x5C71
+0xBBB4	0x60E8
+0xBBB5	0x6492
+0xBBB6	0x6563
+0xBBB7	0x685F
+0xBBB8	0x71E6
+0xBBB9	0x73CA
+0xBBBA	0x7523
+0xBBBB	0x7B97
+0xBBBC	0x7E82
+0xBBBD	0x8695
+0xBBBE	0x8B83
+0xBBBF	0x8CDB
+0xBBC0	0x9178
+0xBBC1	0x9910
+0xBBC2	0x65AC
+0xBBC3	0x66AB
+0xBBC4	0x6B8B
+0xBBC5	0x4ED5
+0xBBC6	0x4ED4
+0xBBC7	0x4F3A
+0xBBC8	0x4F7F
+0xBBC9	0x523A
+0xBBCA	0x53F8
+0xBBCB	0x53F2
+0xBBCC	0x55E3
+0xBBCD	0x56DB
+0xBBCE	0x58EB
+0xBBCF	0x59CB
+0xBBD0	0x59C9
+0xBBD1	0x59FF
+0xBBD2	0x5B50
+0xBBD3	0x5C4D
+0xBBD4	0x5E02
+0xBBD5	0x5E2B
+0xBBD6	0x5FD7
+0xBBD7	0x601D
+0xBBD8	0x6307
+0xBBD9	0x652F
+0xBBDA	0x5B5C
+0xBBDB	0x65AF
+0xBBDC	0x65BD
+0xBBDD	0x65E8
+0xBBDE	0x679D
+0xBBDF	0x6B62
+0xBBE0	0x6B7B
+0xBBE1	0x6C0F
+0xBBE2	0x7345
+0xBBE3	0x7949
+0xBBE4	0x79C1
+0xBBE5	0x7CF8
+0xBBE6	0x7D19
+0xBBE7	0x7D2B
+0xBBE8	0x80A2
+0xBBE9	0x8102
+0xBBEA	0x81F3
+0xBBEB	0x8996
+0xBBEC	0x8A5E
+0xBBED	0x8A69
+0xBBEE	0x8A66
+0xBBEF	0x8A8C
+0xBBF0	0x8AEE
+0xBBF1	0x8CC7
+0xBBF2	0x8CDC
+0xBBF3	0x96CC
+0xBBF4	0x98FC
+0xBBF5	0x6B6F
+0xBBF6	0x4E8B
+0xBBF7	0x4F3C
+0xBBF8	0x4F8D
+0xBBF9	0x5150
+0xBBFA	0x5B57
+0xBBFB	0x5BFA
+0xBBFC	0x6148
+0xBBFD	0x6301
+0xBBFE	0x6642
+0xBCA1	0x6B21
+0xBCA2	0x6ECB
+0xBCA3	0x6CBB
+0xBCA4	0x723E
+0xBCA5	0x74BD
+0xBCA6	0x75D4
+0xBCA7	0x78C1
+0xBCA8	0x793A
+0xBCA9	0x800C
+0xBCAA	0x8033
+0xBCAB	0x81EA
+0xBCAC	0x8494
+0xBCAD	0x8F9E
+0xBCAE	0x6C50
+0xBCAF	0x9E7F
+0xBCB0	0x5F0F
+0xBCB1	0x8B58
+0xBCB2	0x9D2B
+0xBCB3	0x7AFA
+0xBCB4	0x8EF8
+0xBCB5	0x5B8D
+0xBCB6	0x96EB
+0xBCB7	0x4E03
+0xBCB8	0x53F1
+0xBCB9	0x57F7
+0xBCBA	0x5931
+0xBCBB	0x5AC9
+0xBCBC	0x5BA4
+0xBCBD	0x6089
+0xBCBE	0x6E7F
+0xBCBF	0x6F06
+0xBCC0	0x75BE
+0xBCC1	0x8CEA
+0xBCC2	0x5B9F
+0xBCC3	0x8500
+0xBCC4	0x7BE0
+0xBCC5	0x5072
+0xBCC6	0x67F4
+0xBCC7	0x829D
+0xBCC8	0x5C61
+0xBCC9	0x854A
+0xBCCA	0x7E1E
+0xBCCB	0x820E
+0xBCCC	0x5199
+0xBCCD	0x5C04
+0xBCCE	0x6368
+0xBCCF	0x8D66
+0xBCD0	0x659C
+0xBCD1	0x716E
+0xBCD2	0x793E
+0xBCD3	0x7D17
+0xBCD4	0x8005
+0xBCD5	0x8B1D
+0xBCD6	0x8ECA
+0xBCD7	0x906E
+0xBCD8	0x86C7
+0xBCD9	0x90AA
+0xBCDA	0x501F
+0xBCDB	0x52FA
+0xBCDC	0x5C3A
+0xBCDD	0x6753
+0xBCDE	0x707C
+0xBCDF	0x7235
+0xBCE0	0x914C
+0xBCE1	0x91C8
+0xBCE2	0x932B
+0xBCE3	0x82E5
+0xBCE4	0x5BC2
+0xBCE5	0x5F31
+0xBCE6	0x60F9
+0xBCE7	0x4E3B
+0xBCE8	0x53D6
+0xBCE9	0x5B88
+0xBCEA	0x624B
+0xBCEB	0x6731
+0xBCEC	0x6B8A
+0xBCED	0x72E9
+0xBCEE	0x73E0
+0xBCEF	0x7A2E
+0xBCF0	0x816B
+0xBCF1	0x8DA3
+0xBCF2	0x9152
+0xBCF3	0x9996
+0xBCF4	0x5112
+0xBCF5	0x53D7
+0xBCF6	0x546A
+0xBCF7	0x5BFF
+0xBCF8	0x6388
+0xBCF9	0x6A39
+0xBCFA	0x7DAC
+0xBCFB	0x9700
+0xBCFC	0x56DA
+0xBCFD	0x53CE
+0xBCFE	0x5468
+0xBDA1	0x5B97
+0xBDA2	0x5C31
+0xBDA3	0x5DDE
+0xBDA4	0x4FEE
+0xBDA5	0x6101
+0xBDA6	0x62FE
+0xBDA7	0x6D32
+0xBDA8	0x79C0
+0xBDA9	0x79CB
+0xBDAA	0x7D42
+0xBDAB	0x7E4D
+0xBDAC	0x7FD2
+0xBDAD	0x81ED
+0xBDAE	0x821F
+0xBDAF	0x8490
+0xBDB0	0x8846
+0xBDB1	0x8972
+0xBDB2	0x8B90
+0xBDB3	0x8E74
+0xBDB4	0x8F2F
+0xBDB5	0x9031
+0xBDB6	0x914B
+0xBDB7	0x916C
+0xBDB8	0x96C6
+0xBDB9	0x919C
+0xBDBA	0x4EC0
+0xBDBB	0x4F4F
+0xBDBC	0x5145
+0xBDBD	0x5341
+0xBDBE	0x5F93
+0xBDBF	0x620E
+0xBDC0	0x67D4
+0xBDC1	0x6C41
+0xBDC2	0x6E0B
+0xBDC3	0x7363
+0xBDC4	0x7E26
+0xBDC5	0x91CD
+0xBDC6	0x9283
+0xBDC7	0x53D4
+0xBDC8	0x5919
+0xBDC9	0x5BBF
+0xBDCA	0x6DD1
+0xBDCB	0x795D
+0xBDCC	0x7E2E
+0xBDCD	0x7C9B
+0xBDCE	0x587E
+0xBDCF	0x719F
+0xBDD0	0x51FA
+0xBDD1	0x8853
+0xBDD2	0x8FF0
+0xBDD3	0x4FCA
+0xBDD4	0x5CFB
+0xBDD5	0x6625
+0xBDD6	0x77AC
+0xBDD7	0x7AE3
+0xBDD8	0x821C
+0xBDD9	0x99FF
+0xBDDA	0x51C6
+0xBDDB	0x5FAA
+0xBDDC	0x65EC
+0xBDDD	0x696F
+0xBDDE	0x6B89
+0xBDDF	0x6DF3
+0xBDE0	0x6E96
+0xBDE1	0x6F64
+0xBDE2	0x76FE
+0xBDE3	0x7D14
+0xBDE4	0x5DE1
+0xBDE5	0x9075
+0xBDE6	0x9187
+0xBDE7	0x9806
+0xBDE8	0x51E6
+0xBDE9	0x521D
+0xBDEA	0x6240
+0xBDEB	0x6691
+0xBDEC	0x66D9
+0xBDED	0x6E1A
+0xBDEE	0x5EB6
+0xBDEF	0x7DD2
+0xBDF0	0x7F72
+0xBDF1	0x66F8
+0xBDF2	0x85AF
+0xBDF3	0x85F7
+0xBDF4	0x8AF8
+0xBDF5	0x52A9
+0xBDF6	0x53D9
+0xBDF7	0x5973
+0xBDF8	0x5E8F
+0xBDF9	0x5F90
+0xBDFA	0x6055
+0xBDFB	0x92E4
+0xBDFC	0x9664
+0xBDFD	0x50B7
+0xBDFE	0x511F
+0xBEA1	0x52DD
+0xBEA2	0x5320
+0xBEA3	0x5347
+0xBEA4	0x53EC
+0xBEA5	0x54E8
+0xBEA6	0x5546
+0xBEA7	0x5531
+0xBEA8	0x5617
+0xBEA9	0x5968
+0xBEAA	0x59BE
+0xBEAB	0x5A3C
+0xBEAC	0x5BB5
+0xBEAD	0x5C06
+0xBEAE	0x5C0F
+0xBEAF	0x5C11
+0xBEB0	0x5C1A
+0xBEB1	0x5E84
+0xBEB2	0x5E8A
+0xBEB3	0x5EE0
+0xBEB4	0x5F70
+0xBEB5	0x627F
+0xBEB6	0x6284
+0xBEB7	0x62DB
+0xBEB8	0x638C
+0xBEB9	0x6377
+0xBEBA	0x6607
+0xBEBB	0x660C
+0xBEBC	0x662D
+0xBEBD	0x6676
+0xBEBE	0x677E
+0xBEBF	0x68A2
+0xBEC0	0x6A1F
+0xBEC1	0x6A35
+0xBEC2	0x6CBC
+0xBEC3	0x6D88
+0xBEC4	0x6E09
+0xBEC5	0x6E58
+0xBEC6	0x713C
+0xBEC7	0x7126
+0xBEC8	0x7167
+0xBEC9	0x75C7
+0xBECA	0x7701
+0xBECB	0x785D
+0xBECC	0x7901
+0xBECD	0x7965
+0xBECE	0x79F0
+0xBECF	0x7AE0
+0xBED0	0x7B11
+0xBED1	0x7CA7
+0xBED2	0x7D39
+0xBED3	0x8096
+0xBED4	0x83D6
+0xBED5	0x848B
+0xBED6	0x8549
+0xBED7	0x885D
+0xBED8	0x88F3
+0xBED9	0x8A1F
+0xBEDA	0x8A3C
+0xBEDB	0x8A54
+0xBEDC	0x8A73
+0xBEDD	0x8C61
+0xBEDE	0x8CDE
+0xBEDF	0x91A4
+0xBEE0	0x9266
+0xBEE1	0x937E
+0xBEE2	0x9418
+0xBEE3	0x969C
+0xBEE4	0x9798
+0xBEE5	0x4E0A
+0xBEE6	0x4E08
+0xBEE7	0x4E1E
+0xBEE8	0x4E57
+0xBEE9	0x5197
+0xBEEA	0x5270
+0xBEEB	0x57CE
+0xBEEC	0x5834
+0xBEED	0x58CC
+0xBEEE	0x5B22
+0xBEEF	0x5E38
+0xBEF0	0x60C5
+0xBEF1	0x64FE
+0xBEF2	0x6761
+0xBEF3	0x6756
+0xBEF4	0x6D44
+0xBEF5	0x72B6
+0xBEF6	0x7573
+0xBEF7	0x7A63
+0xBEF8	0x84B8
+0xBEF9	0x8B72
+0xBEFA	0x91B8
+0xBEFB	0x9320
+0xBEFC	0x5631
+0xBEFD	0x57F4
+0xBEFE	0x98FE
+0xBFA1	0x62ED
+0xBFA2	0x690D
+0xBFA3	0x6B96
+0xBFA4	0x71ED
+0xBFA5	0x7E54
+0xBFA6	0x8077
+0xBFA7	0x8272
+0xBFA8	0x89E6
+0xBFA9	0x98DF
+0xBFAA	0x8755
+0xBFAB	0x8FB1
+0xBFAC	0x5C3B
+0xBFAD	0x4F38
+0xBFAE	0x4FE1
+0xBFAF	0x4FB5
+0xBFB0	0x5507
+0xBFB1	0x5A20
+0xBFB2	0x5BDD
+0xBFB3	0x5BE9
+0xBFB4	0x5FC3
+0xBFB5	0x614E
+0xBFB6	0x632F
+0xBFB7	0x65B0
+0xBFB8	0x664B
+0xBFB9	0x68EE
+0xBFBA	0x699B
+0xBFBB	0x6D78
+0xBFBC	0x6DF1
+0xBFBD	0x7533
+0xBFBE	0x75B9
+0xBFBF	0x771F
+0xBFC0	0x795E
+0xBFC1	0x79E6
+0xBFC2	0x7D33
+0xBFC3	0x81E3
+0xBFC4	0x82AF
+0xBFC5	0x85AA
+0xBFC6	0x89AA
+0xBFC7	0x8A3A
+0xBFC8	0x8EAB
+0xBFC9	0x8F9B
+0xBFCA	0x9032
+0xBFCB	0x91DD
+0xBFCC	0x9707
+0xBFCD	0x4EBA
+0xBFCE	0x4EC1
+0xBFCF	0x5203
+0xBFD0	0x5875
+0xBFD1	0x58EC
+0xBFD2	0x5C0B
+0xBFD3	0x751A
+0xBFD4	0x5C3D
+0xBFD5	0x814E
+0xBFD6	0x8A0A
+0xBFD7	0x8FC5
+0xBFD8	0x9663
+0xBFD9	0x976D
+0xBFDA	0x7B25
+0xBFDB	0x8ACF
+0xBFDC	0x9808
+0xBFDD	0x9162
+0xBFDE	0x56F3
+0xBFDF	0x53A8
+0xBFE0	0x9017
+0xBFE1	0x5439
+0xBFE2	0x5782
+0xBFE3	0x5E25
+0xBFE4	0x63A8
+0xBFE5	0x6C34
+0xBFE6	0x708A
+0xBFE7	0x7761
+0xBFE8	0x7C8B
+0xBFE9	0x7FE0
+0xBFEA	0x8870
+0xBFEB	0x9042
+0xBFEC	0x9154
+0xBFED	0x9310
+0xBFEE	0x9318
+0xBFEF	0x968F
+0xBFF0	0x745E
+0xBFF1	0x9AC4
+0xBFF2	0x5D07
+0xBFF3	0x5D69
+0xBFF4	0x6570
+0xBFF5	0x67A2
+0xBFF6	0x8DA8
+0xBFF7	0x96DB
+0xBFF8	0x636E
+0xBFF9	0x6749
+0xBFFA	0x6919
+0xBFFB	0x83C5
+0xBFFC	0x9817
+0xBFFD	0x96C0
+0xBFFE	0x88FE
+0xC0A1	0x6F84
+0xC0A2	0x647A
+0xC0A3	0x5BF8
+0xC0A4	0x4E16
+0xC0A5	0x702C
+0xC0A6	0x755D
+0xC0A7	0x662F
+0xC0A8	0x51C4
+0xC0A9	0x5236
+0xC0AA	0x52E2
+0xC0AB	0x59D3
+0xC0AC	0x5F81
+0xC0AD	0x6027
+0xC0AE	0x6210
+0xC0AF	0x653F
+0xC0B0	0x6574
+0xC0B1	0x661F
+0xC0B2	0x6674
+0xC0B3	0x68F2
+0xC0B4	0x6816
+0xC0B5	0x6B63
+0xC0B6	0x6E05
+0xC0B7	0x7272
+0xC0B8	0x751F
+0xC0B9	0x76DB
+0xC0BA	0x7CBE
+0xC0BB	0x8056
+0xC0BC	0x58F0
+0xC0BD	0x88FD
+0xC0BE	0x897F
+0xC0BF	0x8AA0
+0xC0C0	0x8A93
+0xC0C1	0x8ACB
+0xC0C2	0x901D
+0xC0C3	0x9192
+0xC0C4	0x9752
+0xC0C5	0x9759
+0xC0C6	0x6589
+0xC0C7	0x7A0E
+0xC0C8	0x8106
+0xC0C9	0x96BB
+0xC0CA	0x5E2D
+0xC0CB	0x60DC
+0xC0CC	0x621A
+0xC0CD	0x65A5
+0xC0CE	0x6614
+0xC0CF	0x6790
+0xC0D0	0x77F3
+0xC0D1	0x7A4D
+0xC0D2	0x7C4D
+0xC0D3	0x7E3E
+0xC0D4	0x810A
+0xC0D5	0x8CAC
+0xC0D6	0x8D64
+0xC0D7	0x8DE1
+0xC0D8	0x8E5F
+0xC0D9	0x78A9
+0xC0DA	0x5207
+0xC0DB	0x62D9
+0xC0DC	0x63A5
+0xC0DD	0x6442
+0xC0DE	0x6298
+0xC0DF	0x8A2D
+0xC0E0	0x7A83
+0xC0E1	0x7BC0
+0xC0E2	0x8AAC
+0xC0E3	0x96EA
+0xC0E4	0x7D76
+0xC0E5	0x820C
+0xC0E6	0x8749
+0xC0E7	0x4ED9
+0xC0E8	0x5148
+0xC0E9	0x5343
+0xC0EA	0x5360
+0xC0EB	0x5BA3
+0xC0EC	0x5C02
+0xC0ED	0x5C16
+0xC0EE	0x5DDD
+0xC0EF	0x6226
+0xC0F0	0x6247
+0xC0F1	0x64B0
+0xC0F2	0x6813
+0xC0F3	0x6834
+0xC0F4	0x6CC9
+0xC0F5	0x6D45
+0xC0F6	0x6D17
+0xC0F7	0x67D3
+0xC0F8	0x6F5C
+0xC0F9	0x714E
+0xC0FA	0x717D
+0xC0FB	0x65CB
+0xC0FC	0x7A7F
+0xC0FD	0x7BAD
+0xC0FE	0x7DDA
+0xC1A1	0x7E4A
+0xC1A2	0x7FA8
+0xC1A3	0x817A
+0xC1A4	0x821B
+0xC1A5	0x8239
+0xC1A6	0x85A6
+0xC1A7	0x8A6E
+0xC1A8	0x8CCE
+0xC1A9	0x8DF5
+0xC1AA	0x9078
+0xC1AB	0x9077
+0xC1AC	0x92AD
+0xC1AD	0x9291
+0xC1AE	0x9583
+0xC1AF	0x9BAE
+0xC1B0	0x524D
+0xC1B1	0x5584
+0xC1B2	0x6F38
+0xC1B3	0x7136
+0xC1B4	0x5168
+0xC1B5	0x7985
+0xC1B6	0x7E55
+0xC1B7	0x81B3
+0xC1B8	0x7CCE
+0xC1B9	0x564C
+0xC1BA	0x5851
+0xC1BB	0x5CA8
+0xC1BC	0x63AA
+0xC1BD	0x66FE
+0xC1BE	0x66FD
+0xC1BF	0x695A
+0xC1C0	0x72D9
+0xC1C1	0x758F
+0xC1C2	0x758E
+0xC1C3	0x790E
+0xC1C4	0x7956
+0xC1C5	0x79DF
+0xC1C6	0x7C97
+0xC1C7	0x7D20
+0xC1C8	0x7D44
+0xC1C9	0x8607
+0xC1CA	0x8A34
+0xC1CB	0x963B
+0xC1CC	0x9061
+0xC1CD	0x9F20
+0xC1CE	0x50E7
+0xC1CF	0x5275
+0xC1D0	0x53CC
+0xC1D1	0x53E2
+0xC1D2	0x5009
+0xC1D3	0x55AA
+0xC1D4	0x58EE
+0xC1D5	0x594F
+0xC1D6	0x723D
+0xC1D7	0x5B8B
+0xC1D8	0x5C64
+0xC1D9	0x531D
+0xC1DA	0x60E3
+0xC1DB	0x60F3
+0xC1DC	0x635C
+0xC1DD	0x6383
+0xC1DE	0x633F
+0xC1DF	0x63BB
+0xC1E0	0x64CD
+0xC1E1	0x65E9
+0xC1E2	0x66F9
+0xC1E3	0x5DE3
+0xC1E4	0x69CD
+0xC1E5	0x69FD
+0xC1E6	0x6F15
+0xC1E7	0x71E5
+0xC1E8	0x4E89
+0xC1E9	0x75E9
+0xC1EA	0x76F8
+0xC1EB	0x7A93
+0xC1EC	0x7CDF
+0xC1ED	0x7DCF
+0xC1EE	0x7D9C
+0xC1EF	0x8061
+0xC1F0	0x8349
+0xC1F1	0x8358
+0xC1F2	0x846C
+0xC1F3	0x84BC
+0xC1F4	0x85FB
+0xC1F5	0x88C5
+0xC1F6	0x8D70
+0xC1F7	0x9001
+0xC1F8	0x906D
+0xC1F9	0x9397
+0xC1FA	0x971C
+0xC1FB	0x9A12
+0xC1FC	0x50CF
+0xC1FD	0x5897
+0xC1FE	0x618E
+0xC2A1	0x81D3
+0xC2A2	0x8535
+0xC2A3	0x8D08
+0xC2A4	0x9020
+0xC2A5	0x4FC3
+0xC2A6	0x5074
+0xC2A7	0x5247
+0xC2A8	0x5373
+0xC2A9	0x606F
+0xC2AA	0x6349
+0xC2AB	0x675F
+0xC2AC	0x6E2C
+0xC2AD	0x8DB3
+0xC2AE	0x901F
+0xC2AF	0x4FD7
+0xC2B0	0x5C5E
+0xC2B1	0x8CCA
+0xC2B2	0x65CF
+0xC2B3	0x7D9A
+0xC2B4	0x5352
+0xC2B5	0x8896
+0xC2B6	0x5176
+0xC2B7	0x63C3
+0xC2B8	0x5B58
+0xC2B9	0x5B6B
+0xC2BA	0x5C0A
+0xC2BB	0x640D
+0xC2BC	0x6751
+0xC2BD	0x905C
+0xC2BE	0x4ED6
+0xC2BF	0x591A
+0xC2C0	0x592A
+0xC2C1	0x6C70
+0xC2C2	0x8A51
+0xC2C3	0x553E
+0xC2C4	0x5815
+0xC2C5	0x59A5
+0xC2C6	0x60F0
+0xC2C7	0x6253
+0xC2C8	0x67C1
+0xC2C9	0x8235
+0xC2CA	0x6955
+0xC2CB	0x9640
+0xC2CC	0x99C4
+0xC2CD	0x9A28
+0xC2CE	0x4F53
+0xC2CF	0x5806
+0xC2D0	0x5BFE
+0xC2D1	0x8010
+0xC2D2	0x5CB1
+0xC2D3	0x5E2F
+0xC2D4	0x5F85
+0xC2D5	0x6020
+0xC2D6	0x614B
+0xC2D7	0x6234
+0xC2D8	0x66FF
+0xC2D9	0x6CF0
+0xC2DA	0x6EDE
+0xC2DB	0x80CE
+0xC2DC	0x817F
+0xC2DD	0x82D4
+0xC2DE	0x888B
+0xC2DF	0x8CB8
+0xC2E0	0x9000
+0xC2E1	0x902E
+0xC2E2	0x968A
+0xC2E3	0x9EDB
+0xC2E4	0x9BDB
+0xC2E5	0x4EE3
+0xC2E6	0x53F0
+0xC2E7	0x5927
+0xC2E8	0x7B2C
+0xC2E9	0x918D
+0xC2EA	0x984C
+0xC2EB	0x9DF9
+0xC2EC	0x6EDD
+0xC2ED	0x7027
+0xC2EE	0x5353
+0xC2EF	0x5544
+0xC2F0	0x5B85
+0xC2F1	0x6258
+0xC2F2	0x629E
+0xC2F3	0x62D3
+0xC2F4	0x6CA2
+0xC2F5	0x6FEF
+0xC2F6	0x7422
+0xC2F7	0x8A17
+0xC2F8	0x9438
+0xC2F9	0x6FC1
+0xC2FA	0x8AFE
+0xC2FB	0x8338
+0xC2FC	0x51E7
+0xC2FD	0x86F8
+0xC2FE	0x53EA
+0xC3A1	0x53E9
+0xC3A2	0x4F46
+0xC3A3	0x9054
+0xC3A4	0x8FB0
+0xC3A5	0x596A
+0xC3A6	0x8131
+0xC3A7	0x5DFD
+0xC3A8	0x7AEA
+0xC3A9	0x8FBF
+0xC3AA	0x68DA
+0xC3AB	0x8C37
+0xC3AC	0x72F8
+0xC3AD	0x9C48
+0xC3AE	0x6A3D
+0xC3AF	0x8AB0
+0xC3B0	0x4E39
+0xC3B1	0x5358
+0xC3B2	0x5606
+0xC3B3	0x5766
+0xC3B4	0x62C5
+0xC3B5	0x63A2
+0xC3B6	0x65E6
+0xC3B7	0x6B4E
+0xC3B8	0x6DE1
+0xC3B9	0x6E5B
+0xC3BA	0x70AD
+0xC3BB	0x77ED
+0xC3BC	0x7AEF
+0xC3BD	0x7BAA
+0xC3BE	0x7DBB
+0xC3BF	0x803D
+0xC3C0	0x80C6
+0xC3C1	0x86CB
+0xC3C2	0x8A95
+0xC3C3	0x935B
+0xC3C4	0x56E3
+0xC3C5	0x58C7
+0xC3C6	0x5F3E
+0xC3C7	0x65AD
+0xC3C8	0x6696
+0xC3C9	0x6A80
+0xC3CA	0x6BB5
+0xC3CB	0x7537
+0xC3CC	0x8AC7
+0xC3CD	0x5024
+0xC3CE	0x77E5
+0xC3CF	0x5730
+0xC3D0	0x5F1B
+0xC3D1	0x6065
+0xC3D2	0x667A
+0xC3D3	0x6C60
+0xC3D4	0x75F4
+0xC3D5	0x7A1A
+0xC3D6	0x7F6E
+0xC3D7	0x81F4
+0xC3D8	0x8718
+0xC3D9	0x9045
+0xC3DA	0x99B3
+0xC3DB	0x7BC9
+0xC3DC	0x755C
+0xC3DD	0x7AF9
+0xC3DE	0x7B51
+0xC3DF	0x84C4
+0xC3E0	0x9010
+0xC3E1	0x79E9
+0xC3E2	0x7A92
+0xC3E3	0x8336
+0xC3E4	0x5AE1
+0xC3E5	0x7740
+0xC3E6	0x4E2D
+0xC3E7	0x4EF2
+0xC3E8	0x5B99
+0xC3E9	0x5FE0
+0xC3EA	0x62BD
+0xC3EB	0x663C
+0xC3EC	0x67F1
+0xC3ED	0x6CE8
+0xC3EE	0x866B
+0xC3EF	0x8877
+0xC3F0	0x8A3B
+0xC3F1	0x914E
+0xC3F2	0x92F3
+0xC3F3	0x99D0
+0xC3F4	0x6A17
+0xC3F5	0x7026
+0xC3F6	0x732A
+0xC3F7	0x82E7
+0xC3F8	0x8457
+0xC3F9	0x8CAF
+0xC3FA	0x4E01
+0xC3FB	0x5146
+0xC3FC	0x51CB
+0xC3FD	0x558B
+0xC3FE	0x5BF5
+0xC4A1	0x5E16
+0xC4A2	0x5E33
+0xC4A3	0x5E81
+0xC4A4	0x5F14
+0xC4A5	0x5F35
+0xC4A6	0x5F6B
+0xC4A7	0x5FB4
+0xC4A8	0x61F2
+0xC4A9	0x6311
+0xC4AA	0x66A2
+0xC4AB	0x671D
+0xC4AC	0x6F6E
+0xC4AD	0x7252
+0xC4AE	0x753A
+0xC4AF	0x773A
+0xC4B0	0x8074
+0xC4B1	0x8139
+0xC4B2	0x8178
+0xC4B3	0x8776
+0xC4B4	0x8ABF
+0xC4B5	0x8ADC
+0xC4B6	0x8D85
+0xC4B7	0x8DF3
+0xC4B8	0x929A
+0xC4B9	0x9577
+0xC4BA	0x9802
+0xC4BB	0x9CE5
+0xC4BC	0x52C5
+0xC4BD	0x6357
+0xC4BE	0x76F4
+0xC4BF	0x6715
+0xC4C0	0x6C88
+0xC4C1	0x73CD
+0xC4C2	0x8CC3
+0xC4C3	0x93AE
+0xC4C4	0x9673
+0xC4C5	0x6D25
+0xC4C6	0x589C
+0xC4C7	0x690E
+0xC4C8	0x69CC
+0xC4C9	0x8FFD
+0xC4CA	0x939A
+0xC4CB	0x75DB
+0xC4CC	0x901A
+0xC4CD	0x585A
+0xC4CE	0x6802
+0xC4CF	0x63B4
+0xC4D0	0x69FB
+0xC4D1	0x4F43
+0xC4D2	0x6F2C
+0xC4D3	0x67D8
+0xC4D4	0x8FBB
+0xC4D5	0x8526
+0xC4D6	0x7DB4
+0xC4D7	0x9354
+0xC4D8	0x693F
+0xC4D9	0x6F70
+0xC4DA	0x576A
+0xC4DB	0x58F7
+0xC4DC	0x5B2C
+0xC4DD	0x7D2C
+0xC4DE	0x722A
+0xC4DF	0x540A
+0xC4E0	0x91E3
+0xC4E1	0x9DB4
+0xC4E2	0x4EAD
+0xC4E3	0x4F4E
+0xC4E4	0x505C
+0xC4E5	0x5075
+0xC4E6	0x5243
+0xC4E7	0x8C9E
+0xC4E8	0x5448
+0xC4E9	0x5824
+0xC4EA	0x5B9A
+0xC4EB	0x5E1D
+0xC4EC	0x5E95
+0xC4ED	0x5EAD
+0xC4EE	0x5EF7
+0xC4EF	0x5F1F
+0xC4F0	0x608C
+0xC4F1	0x62B5
+0xC4F2	0x633A
+0xC4F3	0x63D0
+0xC4F4	0x68AF
+0xC4F5	0x6C40
+0xC4F6	0x7887
+0xC4F7	0x798E
+0xC4F8	0x7A0B
+0xC4F9	0x7DE0
+0xC4FA	0x8247
+0xC4FB	0x8A02
+0xC4FC	0x8AE6
+0xC4FD	0x8E44
+0xC4FE	0x9013
+0xC5A1	0x90B8
+0xC5A2	0x912D
+0xC5A3	0x91D8
+0xC5A4	0x9F0E
+0xC5A5	0x6CE5
+0xC5A6	0x6458
+0xC5A7	0x64E2
+0xC5A8	0x6575
+0xC5A9	0x6EF4
+0xC5AA	0x7684
+0xC5AB	0x7B1B
+0xC5AC	0x9069
+0xC5AD	0x93D1
+0xC5AE	0x6EBA
+0xC5AF	0x54F2
+0xC5B0	0x5FB9
+0xC5B1	0x64A4
+0xC5B2	0x8F4D
+0xC5B3	0x8FED
+0xC5B4	0x9244
+0xC5B5	0x5178
+0xC5B6	0x586B
+0xC5B7	0x5929
+0xC5B8	0x5C55
+0xC5B9	0x5E97
+0xC5BA	0x6DFB
+0xC5BB	0x7E8F
+0xC5BC	0x751C
+0xC5BD	0x8CBC
+0xC5BE	0x8EE2
+0xC5BF	0x985B
+0xC5C0	0x70B9
+0xC5C1	0x4F1D
+0xC5C2	0x6BBF
+0xC5C3	0x6FB1
+0xC5C4	0x7530
+0xC5C5	0x96FB
+0xC5C6	0x514E
+0xC5C7	0x5410
+0xC5C8	0x5835
+0xC5C9	0x5857
+0xC5CA	0x59AC
+0xC5CB	0x5C60
+0xC5CC	0x5F92
+0xC5CD	0x6597
+0xC5CE	0x675C
+0xC5CF	0x6E21
+0xC5D0	0x767B
+0xC5D1	0x83DF
+0xC5D2	0x8CED
+0xC5D3	0x9014
+0xC5D4	0x90FD
+0xC5D5	0x934D
+0xC5D6	0x7825
+0xC5D7	0x783A
+0xC5D8	0x52AA
+0xC5D9	0x5EA6
+0xC5DA	0x571F
+0xC5DB	0x5974
+0xC5DC	0x6012
+0xC5DD	0x5012
+0xC5DE	0x515A
+0xC5DF	0x51AC
+0xC5E0	0x51CD
+0xC5E1	0x5200
+0xC5E2	0x5510
+0xC5E3	0x5854
+0xC5E4	0x5858
+0xC5E5	0x5957
+0xC5E6	0x5B95
+0xC5E7	0x5CF6
+0xC5E8	0x5D8B
+0xC5E9	0x60BC
+0xC5EA	0x6295
+0xC5EB	0x642D
+0xC5EC	0x6771
+0xC5ED	0x6843
+0xC5EE	0x68BC
+0xC5EF	0x68DF
+0xC5F0	0x76D7
+0xC5F1	0x6DD8
+0xC5F2	0x6E6F
+0xC5F3	0x6D9B
+0xC5F4	0x706F
+0xC5F5	0x71C8
+0xC5F6	0x5F53
+0xC5F7	0x75D8
+0xC5F8	0x7977
+0xC5F9	0x7B49
+0xC5FA	0x7B54
+0xC5FB	0x7B52
+0xC5FC	0x7CD6
+0xC5FD	0x7D71
+0xC5FE	0x5230
+0xC6A1	0x8463
+0xC6A2	0x8569
+0xC6A3	0x85E4
+0xC6A4	0x8A0E
+0xC6A5	0x8B04
+0xC6A6	0x8C46
+0xC6A7	0x8E0F
+0xC6A8	0x9003
+0xC6A9	0x900F
+0xC6AA	0x9419
+0xC6AB	0x9676
+0xC6AC	0x982D
+0xC6AD	0x9A30
+0xC6AE	0x95D8
+0xC6AF	0x50CD
+0xC6B0	0x52D5
+0xC6B1	0x540C
+0xC6B2	0x5802
+0xC6B3	0x5C0E
+0xC6B4	0x61A7
+0xC6B5	0x649E
+0xC6B6	0x6D1E
+0xC6B7	0x77B3
+0xC6B8	0x7AE5
+0xC6B9	0x80F4
+0xC6BA	0x8404
+0xC6BB	0x9053
+0xC6BC	0x9285
+0xC6BD	0x5CE0
+0xC6BE	0x9D07
+0xC6BF	0x533F
+0xC6C0	0x5F97
+0xC6C1	0x5FB3
+0xC6C2	0x6D9C
+0xC6C3	0x7279
+0xC6C4	0x7763
+0xC6C5	0x79BF
+0xC6C6	0x7BE4
+0xC6C7	0x6BD2
+0xC6C8	0x72EC
+0xC6C9	0x8AAD
+0xC6CA	0x6803
+0xC6CB	0x6A61
+0xC6CC	0x51F8
+0xC6CD	0x7A81
+0xC6CE	0x6934
+0xC6CF	0x5C4A
+0xC6D0	0x9CF6
+0xC6D1	0x82EB
+0xC6D2	0x5BC5
+0xC6D3	0x9149
+0xC6D4	0x701E
+0xC6D5	0x5678
+0xC6D6	0x5C6F
+0xC6D7	0x60C7
+0xC6D8	0x6566
+0xC6D9	0x6C8C
+0xC6DA	0x8C5A
+0xC6DB	0x9041
+0xC6DC	0x9813
+0xC6DD	0x5451
+0xC6DE	0x66C7
+0xC6DF	0x920D
+0xC6E0	0x5948
+0xC6E1	0x90A3
+0xC6E2	0x5185
+0xC6E3	0x4E4D
+0xC6E4	0x51EA
+0xC6E5	0x8599
+0xC6E6	0x8B0E
+0xC6E7	0x7058
+0xC6E8	0x637A
+0xC6E9	0x934B
+0xC6EA	0x6962
+0xC6EB	0x99B4
+0xC6EC	0x7E04
+0xC6ED	0x7577
+0xC6EE	0x5357
+0xC6EF	0x6960
+0xC6F0	0x8EDF
+0xC6F1	0x96E3
+0xC6F2	0x6C5D
+0xC6F3	0x4E8C
+0xC6F4	0x5C3C
+0xC6F5	0x5F10
+0xC6F6	0x8FE9
+0xC6F7	0x5302
+0xC6F8	0x8CD1
+0xC6F9	0x8089
+0xC6FA	0x8679
+0xC6FB	0x5EFF
+0xC6FC	0x65E5
+0xC6FD	0x4E73
+0xC6FE	0x5165
+0xC7A1	0x5982
+0xC7A2	0x5C3F
+0xC7A3	0x97EE
+0xC7A4	0x4EFB
+0xC7A5	0x598A
+0xC7A6	0x5FCD
+0xC7A7	0x8A8D
+0xC7A8	0x6FE1
+0xC7A9	0x79B0
+0xC7AA	0x7962
+0xC7AB	0x5BE7
+0xC7AC	0x8471
+0xC7AD	0x732B
+0xC7AE	0x71B1
+0xC7AF	0x5E74
+0xC7B0	0x5FF5
+0xC7B1	0x637B
+0xC7B2	0x649A
+0xC7B3	0x71C3
+0xC7B4	0x7C98
+0xC7B5	0x4E43
+0xC7B6	0x5EFC
+0xC7B7	0x4E4B
+0xC7B8	0x57DC
+0xC7B9	0x56A2
+0xC7BA	0x60A9
+0xC7BB	0x6FC3
+0xC7BC	0x7D0D
+0xC7BD	0x80FD
+0xC7BE	0x8133
+0xC7BF	0x81BF
+0xC7C0	0x8FB2
+0xC7C1	0x8997
+0xC7C2	0x86A4
+0xC7C3	0x5DF4
+0xC7C4	0x628A
+0xC7C5	0x64AD
+0xC7C6	0x8987
+0xC7C7	0x6777
+0xC7C8	0x6CE2
+0xC7C9	0x6D3E
+0xC7CA	0x7436
+0xC7CB	0x7834
+0xC7CC	0x5A46
+0xC7CD	0x7F75
+0xC7CE	0x82AD
+0xC7CF	0x99AC
+0xC7D0	0x4FF3
+0xC7D1	0x5EC3
+0xC7D2	0x62DD
+0xC7D3	0x6392
+0xC7D4	0x6557
+0xC7D5	0x676F
+0xC7D6	0x76C3
+0xC7D7	0x724C
+0xC7D8	0x80CC
+0xC7D9	0x80BA
+0xC7DA	0x8F29
+0xC7DB	0x914D
+0xC7DC	0x500D
+0xC7DD	0x57F9
+0xC7DE	0x5A92
+0xC7DF	0x6885
+0xC7E0	0x6973
+0xC7E1	0x7164
+0xC7E2	0x72FD
+0xC7E3	0x8CB7
+0xC7E4	0x58F2
+0xC7E5	0x8CE0
+0xC7E6	0x966A
+0xC7E7	0x9019
+0xC7E8	0x877F
+0xC7E9	0x79E4
+0xC7EA	0x77E7
+0xC7EB	0x8429
+0xC7EC	0x4F2F
+0xC7ED	0x5265
+0xC7EE	0x535A
+0xC7EF	0x62CD
+0xC7F0	0x67CF
+0xC7F1	0x6CCA
+0xC7F2	0x767D
+0xC7F3	0x7B94
+0xC7F4	0x7C95
+0xC7F5	0x8236
+0xC7F6	0x8584
+0xC7F7	0x8FEB
+0xC7F8	0x66DD
+0xC7F9	0x6F20
+0xC7FA	0x7206
+0xC7FB	0x7E1B
+0xC7FC	0x83AB
+0xC7FD	0x99C1
+0xC7FE	0x9EA6
+0xC8A1	0x51FD
+0xC8A2	0x7BB1
+0xC8A3	0x7872
+0xC8A4	0x7BB8
+0xC8A5	0x8087
+0xC8A6	0x7B48
+0xC8A7	0x6AE8
+0xC8A8	0x5E61
+0xC8A9	0x808C
+0xC8AA	0x7551
+0xC8AB	0x7560
+0xC8AC	0x516B
+0xC8AD	0x9262
+0xC8AE	0x6E8C
+0xC8AF	0x767A
+0xC8B0	0x9197
+0xC8B1	0x9AEA
+0xC8B2	0x4F10
+0xC8B3	0x7F70
+0xC8B4	0x629C
+0xC8B5	0x7B4F
+0xC8B6	0x95A5
+0xC8B7	0x9CE9
+0xC8B8	0x567A
+0xC8B9	0x5859
+0xC8BA	0x86E4
+0xC8BB	0x96BC
+0xC8BC	0x4F34
+0xC8BD	0x5224
+0xC8BE	0x534A
+0xC8BF	0x53CD
+0xC8C0	0x53DB
+0xC8C1	0x5E06
+0xC8C2	0x642C
+0xC8C3	0x6591
+0xC8C4	0x677F
+0xC8C5	0x6C3E
+0xC8C6	0x6C4E
+0xC8C7	0x7248
+0xC8C8	0x72AF
+0xC8C9	0x73ED
+0xC8CA	0x7554
+0xC8CB	0x7E41
+0xC8CC	0x822C
+0xC8CD	0x85E9
+0xC8CE	0x8CA9
+0xC8CF	0x7BC4
+0xC8D0	0x91C6
+0xC8D1	0x7169
+0xC8D2	0x9812
+0xC8D3	0x98EF
+0xC8D4	0x633D
+0xC8D5	0x6669
+0xC8D6	0x756A
+0xC8D7	0x76E4
+0xC8D8	0x78D0
+0xC8D9	0x8543
+0xC8DA	0x86EE
+0xC8DB	0x532A
+0xC8DC	0x5351
+0xC8DD	0x5426
+0xC8DE	0x5983
+0xC8DF	0x5E87
+0xC8E0	0x5F7C
+0xC8E1	0x60B2
+0xC8E2	0x6249
+0xC8E3	0x6279
+0xC8E4	0x62AB
+0xC8E5	0x6590
+0xC8E6	0x6BD4
+0xC8E7	0x6CCC
+0xC8E8	0x75B2
+0xC8E9	0x76AE
+0xC8EA	0x7891
+0xC8EB	0x79D8
+0xC8EC	0x7DCB
+0xC8ED	0x7F77
+0xC8EE	0x80A5
+0xC8EF	0x88AB
+0xC8F0	0x8AB9
+0xC8F1	0x8CBB
+0xC8F2	0x907F
+0xC8F3	0x975E
+0xC8F4	0x98DB
+0xC8F5	0x6A0B
+0xC8F6	0x7C38
+0xC8F7	0x5099
+0xC8F8	0x5C3E
+0xC8F9	0x5FAE
+0xC8FA	0x6787
+0xC8FB	0x6BD8
+0xC8FC	0x7435
+0xC8FD	0x7709
+0xC8FE	0x7F8E
+0xC9A1	0x9F3B
+0xC9A2	0x67CA
+0xC9A3	0x7A17
+0xC9A4	0x5339
+0xC9A5	0x758B
+0xC9A6	0x9AED
+0xC9A7	0x5F66
+0xC9A8	0x819D
+0xC9A9	0x83F1
+0xC9AA	0x8098
+0xC9AB	0x5F3C
+0xC9AC	0x5FC5
+0xC9AD	0x7562
+0xC9AE	0x7B46
+0xC9AF	0x903C
+0xC9B0	0x6867
+0xC9B1	0x59EB
+0xC9B2	0x5A9B
+0xC9B3	0x7D10
+0xC9B4	0x767E
+0xC9B5	0x8B2C
+0xC9B6	0x4FF5
+0xC9B7	0x5F6A
+0xC9B8	0x6A19
+0xC9B9	0x6C37
+0xC9BA	0x6F02
+0xC9BB	0x74E2
+0xC9BC	0x7968
+0xC9BD	0x8868
+0xC9BE	0x8A55
+0xC9BF	0x8C79
+0xC9C0	0x5EDF
+0xC9C1	0x63CF
+0xC9C2	0x75C5
+0xC9C3	0x79D2
+0xC9C4	0x82D7
+0xC9C5	0x9328
+0xC9C6	0x92F2
+0xC9C7	0x849C
+0xC9C8	0x86ED
+0xC9C9	0x9C2D
+0xC9CA	0x54C1
+0xC9CB	0x5F6C
+0xC9CC	0x658C
+0xC9CD	0x6D5C
+0xC9CE	0x7015
+0xC9CF	0x8CA7
+0xC9D0	0x8CD3
+0xC9D1	0x983B
+0xC9D2	0x654F
+0xC9D3	0x74F6
+0xC9D4	0x4E0D
+0xC9D5	0x4ED8
+0xC9D6	0x57E0
+0xC9D7	0x592B
+0xC9D8	0x5A66
+0xC9D9	0x5BCC
+0xC9DA	0x51A8
+0xC9DB	0x5E03
+0xC9DC	0x5E9C
+0xC9DD	0x6016
+0xC9DE	0x6276
+0xC9DF	0x6577
+0xC9E0	0x65A7
+0xC9E1	0x666E
+0xC9E2	0x6D6E
+0xC9E3	0x7236
+0xC9E4	0x7B26
+0xC9E5	0x8150
+0xC9E6	0x819A
+0xC9E7	0x8299
+0xC9E8	0x8B5C
+0xC9E9	0x8CA0
+0xC9EA	0x8CE6
+0xC9EB	0x8D74
+0xC9EC	0x961C
+0xC9ED	0x9644
+0xC9EE	0x4FAE
+0xC9EF	0x64AB
+0xC9F0	0x6B66
+0xC9F1	0x821E
+0xC9F2	0x8461
+0xC9F3	0x856A
+0xC9F4	0x90E8
+0xC9F5	0x5C01
+0xC9F6	0x6953
+0xC9F7	0x98A8
+0xC9F8	0x847A
+0xC9F9	0x8557
+0xC9FA	0x4F0F
+0xC9FB	0x526F
+0xC9FC	0x5FA9
+0xC9FD	0x5E45
+0xC9FE	0x670D
+0xCAA1	0x798F
+0xCAA2	0x8179
+0xCAA3	0x8907
+0xCAA4	0x8986
+0xCAA5	0x6DF5
+0xCAA6	0x5F17
+0xCAA7	0x6255
+0xCAA8	0x6CB8
+0xCAA9	0x4ECF
+0xCAAA	0x7269
+0xCAAB	0x9B92
+0xCAAC	0x5206
+0xCAAD	0x543B
+0xCAAE	0x5674
+0xCAAF	0x58B3
+0xCAB0	0x61A4
+0xCAB1	0x626E
+0xCAB2	0x711A
+0xCAB3	0x596E
+0xCAB4	0x7C89
+0xCAB5	0x7CDE
+0xCAB6	0x7D1B
+0xCAB7	0x96F0
+0xCAB8	0x6587
+0xCAB9	0x805E
+0xCABA	0x4E19
+0xCABB	0x4F75
+0xCABC	0x5175
+0xCABD	0x5840
+0xCABE	0x5E63
+0xCABF	0x5E73
+0xCAC0	0x5F0A
+0xCAC1	0x67C4
+0xCAC2	0x4E26
+0xCAC3	0x853D
+0xCAC4	0x9589
+0xCAC5	0x965B
+0xCAC6	0x7C73
+0xCAC7	0x9801
+0xCAC8	0x50FB
+0xCAC9	0x58C1
+0xCACA	0x7656
+0xCACB	0x78A7
+0xCACC	0x5225
+0xCACD	0x77A5
+0xCACE	0x8511
+0xCACF	0x7B86
+0xCAD0	0x504F
+0xCAD1	0x5909
+0xCAD2	0x7247
+0xCAD3	0x7BC7
+0xCAD4	0x7DE8
+0xCAD5	0x8FBA
+0xCAD6	0x8FD4
+0xCAD7	0x904D
+0xCAD8	0x4FBF
+0xCAD9	0x52C9
+0xCADA	0x5A29
+0xCADB	0x5F01
+0xCADC	0x97AD
+0xCADD	0x4FDD
+0xCADE	0x8217
+0xCADF	0x92EA
+0xCAE0	0x5703
+0xCAE1	0x6355
+0xCAE2	0x6B69
+0xCAE3	0x752B
+0xCAE4	0x88DC
+0xCAE5	0x8F14
+0xCAE6	0x7A42
+0xCAE7	0x52DF
+0xCAE8	0x5893
+0xCAE9	0x6155
+0xCAEA	0x620A
+0xCAEB	0x66AE
+0xCAEC	0x6BCD
+0xCAED	0x7C3F
+0xCAEE	0x83E9
+0xCAEF	0x5023
+0xCAF0	0x4FF8
+0xCAF1	0x5305
+0xCAF2	0x5446
+0xCAF3	0x5831
+0xCAF4	0x5949
+0xCAF5	0x5B9D
+0xCAF6	0x5CF0
+0xCAF7	0x5CEF
+0xCAF8	0x5D29
+0xCAF9	0x5E96
+0xCAFA	0x62B1
+0xCAFB	0x6367
+0xCAFC	0x653E
+0xCAFD	0x65B9
+0xCAFE	0x670B
+0xCBA1	0x6CD5
+0xCBA2	0x6CE1
+0xCBA3	0x70F9
+0xCBA4	0x7832
+0xCBA5	0x7E2B
+0xCBA6	0x80DE
+0xCBA7	0x82B3
+0xCBA8	0x840C
+0xCBA9	0x84EC
+0xCBAA	0x8702
+0xCBAB	0x8912
+0xCBAC	0x8A2A
+0xCBAD	0x8C4A
+0xCBAE	0x90A6
+0xCBAF	0x92D2
+0xCBB0	0x98FD
+0xCBB1	0x9CF3
+0xCBB2	0x9D6C
+0xCBB3	0x4E4F
+0xCBB4	0x4EA1
+0xCBB5	0x508D
+0xCBB6	0x5256
+0xCBB7	0x574A
+0xCBB8	0x59A8
+0xCBB9	0x5E3D
+0xCBBA	0x5FD8
+0xCBBB	0x5FD9
+0xCBBC	0x623F
+0xCBBD	0x66B4
+0xCBBE	0x671B
+0xCBBF	0x67D0
+0xCBC0	0x68D2
+0xCBC1	0x5192
+0xCBC2	0x7D21
+0xCBC3	0x80AA
+0xCBC4	0x81A8
+0xCBC5	0x8B00
+0xCBC6	0x8C8C
+0xCBC7	0x8CBF
+0xCBC8	0x927E
+0xCBC9	0x9632
+0xCBCA	0x5420
+0xCBCB	0x982C
+0xCBCC	0x5317
+0xCBCD	0x50D5
+0xCBCE	0x535C
+0xCBCF	0x58A8
+0xCBD0	0x64B2
+0xCBD1	0x6734
+0xCBD2	0x7267
+0xCBD3	0x7766
+0xCBD4	0x7A46
+0xCBD5	0x91E6
+0xCBD6	0x52C3
+0xCBD7	0x6CA1
+0xCBD8	0x6B86
+0xCBD9	0x5800
+0xCBDA	0x5E4C
+0xCBDB	0x5954
+0xCBDC	0x672C
+0xCBDD	0x7FFB
+0xCBDE	0x51E1
+0xCBDF	0x76C6
+0xCBE0	0x6469
+0xCBE1	0x78E8
+0xCBE2	0x9B54
+0xCBE3	0x9EBB
+0xCBE4	0x57CB
+0xCBE5	0x59B9
+0xCBE6	0x6627
+0xCBE7	0x679A
+0xCBE8	0x6BCE
+0xCBE9	0x54E9
+0xCBEA	0x69D9
+0xCBEB	0x5E55
+0xCBEC	0x819C
+0xCBED	0x6795
+0xCBEE	0x9BAA
+0xCBEF	0x67FE
+0xCBF0	0x9C52
+0xCBF1	0x685D
+0xCBF2	0x4EA6
+0xCBF3	0x4FE3
+0xCBF4	0x53C8
+0xCBF5	0x62B9
+0xCBF6	0x672B
+0xCBF7	0x6CAB
+0xCBF8	0x8FC4
+0xCBF9	0x4FAD
+0xCBFA	0x7E6D
+0xCBFB	0x9EBF
+0xCBFC	0x4E07
+0xCBFD	0x6162
+0xCBFE	0x6E80
+0xCCA1	0x6F2B
+0xCCA2	0x8513
+0xCCA3	0x5473
+0xCCA4	0x672A
+0xCCA5	0x9B45
+0xCCA6	0x5DF3
+0xCCA7	0x7B95
+0xCCA8	0x5CAC
+0xCCA9	0x5BC6
+0xCCAA	0x871C
+0xCCAB	0x6E4A
+0xCCAC	0x84D1
+0xCCAD	0x7A14
+0xCCAE	0x8108
+0xCCAF	0x5999
+0xCCB0	0x7C8D
+0xCCB1	0x6C11
+0xCCB2	0x7720
+0xCCB3	0x52D9
+0xCCB4	0x5922
+0xCCB5	0x7121
+0xCCB6	0x725F
+0xCCB7	0x77DB
+0xCCB8	0x9727
+0xCCB9	0x9D61
+0xCCBA	0x690B
+0xCCBB	0x5A7F
+0xCCBC	0x5A18
+0xCCBD	0x51A5
+0xCCBE	0x540D
+0xCCBF	0x547D
+0xCCC0	0x660E
+0xCCC1	0x76DF
+0xCCC2	0x8FF7
+0xCCC3	0x9298
+0xCCC4	0x9CF4
+0xCCC5	0x59EA
+0xCCC6	0x725D
+0xCCC7	0x6EC5
+0xCCC8	0x514D
+0xCCC9	0x68C9
+0xCCCA	0x7DBF
+0xCCCB	0x7DEC
+0xCCCC	0x9762
+0xCCCD	0x9EBA
+0xCCCE	0x6478
+0xCCCF	0x6A21
+0xCCD0	0x8302
+0xCCD1	0x5984
+0xCCD2	0x5B5F
+0xCCD3	0x6BDB
+0xCCD4	0x731B
+0xCCD5	0x76F2
+0xCCD6	0x7DB2
+0xCCD7	0x8017
+0xCCD8	0x8499
+0xCCD9	0x5132
+0xCCDA	0x6728
+0xCCDB	0x9ED9
+0xCCDC	0x76EE
+0xCCDD	0x6762
+0xCCDE	0x52FF
+0xCCDF	0x9905
+0xCCE0	0x5C24
+0xCCE1	0x623B
+0xCCE2	0x7C7E
+0xCCE3	0x8CB0
+0xCCE4	0x554F
+0xCCE5	0x60B6
+0xCCE6	0x7D0B
+0xCCE7	0x9580
+0xCCE8	0x5301
+0xCCE9	0x4E5F
+0xCCEA	0x51B6
+0xCCEB	0x591C
+0xCCEC	0x723A
+0xCCED	0x8036
+0xCCEE	0x91CE
+0xCCEF	0x5F25
+0xCCF0	0x77E2
+0xCCF1	0x5384
+0xCCF2	0x5F79
+0xCCF3	0x7D04
+0xCCF4	0x85AC
+0xCCF5	0x8A33
+0xCCF6	0x8E8D
+0xCCF7	0x9756
+0xCCF8	0x67F3
+0xCCF9	0x85AE
+0xCCFA	0x9453
+0xCCFB	0x6109
+0xCCFC	0x6108
+0xCCFD	0x6CB9
+0xCCFE	0x7652
+0xCDA1	0x8AED
+0xCDA2	0x8F38
+0xCDA3	0x552F
+0xCDA4	0x4F51
+0xCDA5	0x512A
+0xCDA6	0x52C7
+0xCDA7	0x53CB
+0xCDA8	0x5BA5
+0xCDA9	0x5E7D
+0xCDAA	0x60A0
+0xCDAB	0x6182
+0xCDAC	0x63D6
+0xCDAD	0x6709
+0xCDAE	0x67DA
+0xCDAF	0x6E67
+0xCDB0	0x6D8C
+0xCDB1	0x7336
+0xCDB2	0x7337
+0xCDB3	0x7531
+0xCDB4	0x7950
+0xCDB5	0x88D5
+0xCDB6	0x8A98
+0xCDB7	0x904A
+0xCDB8	0x9091
+0xCDB9	0x90F5
+0xCDBA	0x96C4
+0xCDBB	0x878D
+0xCDBC	0x5915
+0xCDBD	0x4E88
+0xCDBE	0x4F59
+0xCDBF	0x4E0E
+0xCDC0	0x8A89
+0xCDC1	0x8F3F
+0xCDC2	0x9810
+0xCDC3	0x50AD
+0xCDC4	0x5E7C
+0xCDC5	0x5996
+0xCDC6	0x5BB9
+0xCDC7	0x5EB8
+0xCDC8	0x63DA
+0xCDC9	0x63FA
+0xCDCA	0x64C1
+0xCDCB	0x66DC
+0xCDCC	0x694A
+0xCDCD	0x69D8
+0xCDCE	0x6D0B
+0xCDCF	0x6EB6
+0xCDD0	0x7194
+0xCDD1	0x7528
+0xCDD2	0x7AAF
+0xCDD3	0x7F8A
+0xCDD4	0x8000
+0xCDD5	0x8449
+0xCDD6	0x84C9
+0xCDD7	0x8981
+0xCDD8	0x8B21
+0xCDD9	0x8E0A
+0xCDDA	0x9065
+0xCDDB	0x967D
+0xCDDC	0x990A
+0xCDDD	0x617E
+0xCDDE	0x6291
+0xCDDF	0x6B32
+0xCDE0	0x6C83
+0xCDE1	0x6D74
+0xCDE2	0x7FCC
+0xCDE3	0x7FFC
+0xCDE4	0x6DC0
+0xCDE5	0x7F85
+0xCDE6	0x87BA
+0xCDE7	0x88F8
+0xCDE8	0x6765
+0xCDE9	0x83B1
+0xCDEA	0x983C
+0xCDEB	0x96F7
+0xCDEC	0x6D1B
+0xCDED	0x7D61
+0xCDEE	0x843D
+0xCDEF	0x916A
+0xCDF0	0x4E71
+0xCDF1	0x5375
+0xCDF2	0x5D50
+0xCDF3	0x6B04
+0xCDF4	0x6FEB
+0xCDF5	0x85CD
+0xCDF6	0x862D
+0xCDF7	0x89A7
+0xCDF8	0x5229
+0xCDF9	0x540F
+0xCDFA	0x5C65
+0xCDFB	0x674E
+0xCDFC	0x68A8
+0xCDFD	0x7406
+0xCDFE	0x7483
+0xCEA1	0x75E2
+0xCEA2	0x88CF
+0xCEA3	0x88E1
+0xCEA4	0x91CC
+0xCEA5	0x96E2
+0xCEA6	0x9678
+0xCEA7	0x5F8B
+0xCEA8	0x7387
+0xCEA9	0x7ACB
+0xCEAA	0x844E
+0xCEAB	0x63A0
+0xCEAC	0x7565
+0xCEAD	0x5289
+0xCEAE	0x6D41
+0xCEAF	0x6E9C
+0xCEB0	0x7409
+0xCEB1	0x7559
+0xCEB2	0x786B
+0xCEB3	0x7C92
+0xCEB4	0x9686
+0xCEB5	0x7ADC
+0xCEB6	0x9F8D
+0xCEB7	0x4FB6
+0xCEB8	0x616E
+0xCEB9	0x65C5
+0xCEBA	0x865C
+0xCEBB	0x4E86
+0xCEBC	0x4EAE
+0xCEBD	0x50DA
+0xCEBE	0x4E21
+0xCEBF	0x51CC
+0xCEC0	0x5BEE
+0xCEC1	0x6599
+0xCEC2	0x6881
+0xCEC3	0x6DBC
+0xCEC4	0x731F
+0xCEC5	0x7642
+0xCEC6	0x77AD
+0xCEC7	0x7A1C
+0xCEC8	0x7CE7
+0xCEC9	0x826F
+0xCECA	0x8AD2
+0xCECB	0x907C
+0xCECC	0x91CF
+0xCECD	0x9675
+0xCECE	0x9818
+0xCECF	0x529B
+0xCED0	0x7DD1
+0xCED1	0x502B
+0xCED2	0x5398
+0xCED3	0x6797
+0xCED4	0x6DCB
+0xCED5	0x71D0
+0xCED6	0x7433
+0xCED7	0x81E8
+0xCED8	0x8F2A
+0xCED9	0x96A3
+0xCEDA	0x9C57
+0xCEDB	0x9E9F
+0xCEDC	0x7460
+0xCEDD	0x5841
+0xCEDE	0x6D99
+0xCEDF	0x7D2F
+0xCEE0	0x985E
+0xCEE1	0x4EE4
+0xCEE2	0x4F36
+0xCEE3	0x4F8B
+0xCEE4	0x51B7
+0xCEE5	0x52B1
+0xCEE6	0x5DBA
+0xCEE7	0x601C
+0xCEE8	0x73B2
+0xCEE9	0x793C
+0xCEEA	0x82D3
+0xCEEB	0x9234
+0xCEEC	0x96B7
+0xCEED	0x96F6
+0xCEEE	0x970A
+0xCEEF	0x9E97
+0xCEF0	0x9F62
+0xCEF1	0x66A6
+0xCEF2	0x6B74
+0xCEF3	0x5217
+0xCEF4	0x52A3
+0xCEF5	0x70C8
+0xCEF6	0x88C2
+0xCEF7	0x5EC9
+0xCEF8	0x604B
+0xCEF9	0x6190
+0xCEFA	0x6F23
+0xCEFB	0x7149
+0xCEFC	0x7C3E
+0xCEFD	0x7DF4
+0xCEFE	0x806F
+0xCFA1	0x84EE
+0xCFA2	0x9023
+0xCFA3	0x932C
+0xCFA4	0x5442
+0xCFA5	0x9B6F
+0xCFA6	0x6AD3
+0xCFA7	0x7089
+0xCFA8	0x8CC2
+0xCFA9	0x8DEF
+0xCFAA	0x9732
+0xCFAB	0x52B4
+0xCFAC	0x5A41
+0xCFAD	0x5ECA
+0xCFAE	0x5F04
+0xCFAF	0x6717
+0xCFB0	0x697C
+0xCFB1	0x6994
+0xCFB2	0x6D6A
+0xCFB3	0x6F0F
+0xCFB4	0x7262
+0xCFB5	0x72FC
+0xCFB6	0x7BED
+0xCFB7	0x8001
+0xCFB8	0x807E
+0xCFB9	0x874B
+0xCFBA	0x90CE
+0xCFBB	0x516D
+0xCFBC	0x9E93
+0xCFBD	0x7984
+0xCFBE	0x808B
+0xCFBF	0x9332
+0xCFC0	0x8AD6
+0xCFC1	0x502D
+0xCFC2	0x548C
+0xCFC3	0x8A71
+0xCFC4	0x6B6A
+0xCFC5	0x8CC4
+0xCFC6	0x8107
+0xCFC7	0x60D1
+0xCFC8	0x67A0
+0xCFC9	0x9DF2
+0xCFCA	0x4E99
+0xCFCB	0x4E98
+0xCFCC	0x9C10
+0xCFCD	0x8A6B
+0xCFCE	0x85C1
+0xCFCF	0x8568
+0xCFD0	0x6900
+0xCFD1	0x6E7E
+0xCFD2	0x7897
+0xCFD3	0x8155
+0xD0A1	0x5F0C
+0xD0A2	0x4E10
+0xD0A3	0x4E15
+0xD0A4	0x4E2A
+0xD0A5	0x4E31
+0xD0A6	0x4E36
+0xD0A7	0x4E3C
+0xD0A8	0x4E3F
+0xD0A9	0x4E42
+0xD0AA	0x4E56
+0xD0AB	0x4E58
+0xD0AC	0x4E82
+0xD0AD	0x4E85
+0xD0AE	0x8C6B
+0xD0AF	0x4E8A
+0xD0B0	0x8212
+0xD0B1	0x5F0D
+0xD0B2	0x4E8E
+0xD0B3	0x4E9E
+0xD0B4	0x4E9F
+0xD0B5	0x4EA0
+0xD0B6	0x4EA2
+0xD0B7	0x4EB0
+0xD0B8	0x4EB3
+0xD0B9	0x4EB6
+0xD0BA	0x4ECE
+0xD0BB	0x4ECD
+0xD0BC	0x4EC4
+0xD0BD	0x4EC6
+0xD0BE	0x4EC2
+0xD0BF	0x4ED7
+0xD0C0	0x4EDE
+0xD0C1	0x4EED
+0xD0C2	0x4EDF
+0xD0C3	0x4EF7
+0xD0C4	0x4F09
+0xD0C5	0x4F5A
+0xD0C6	0x4F30
+0xD0C7	0x4F5B
+0xD0C8	0x4F5D
+0xD0C9	0x4F57
+0xD0CA	0x4F47
+0xD0CB	0x4F76
+0xD0CC	0x4F88
+0xD0CD	0x4F8F
+0xD0CE	0x4F98
+0xD0CF	0x4F7B
+0xD0D0	0x4F69
+0xD0D1	0x4F70
+0xD0D2	0x4F91
+0xD0D3	0x4F6F
+0xD0D4	0x4F86
+0xD0D5	0x4F96
+0xD0D6	0x5118
+0xD0D7	0x4FD4
+0xD0D8	0x4FDF
+0xD0D9	0x4FCE
+0xD0DA	0x4FD8
+0xD0DB	0x4FDB
+0xD0DC	0x4FD1
+0xD0DD	0x4FDA
+0xD0DE	0x4FD0
+0xD0DF	0x4FE4
+0xD0E0	0x4FE5
+0xD0E1	0x501A
+0xD0E2	0x5028
+0xD0E3	0x5014
+0xD0E4	0x502A
+0xD0E5	0x5025
+0xD0E6	0x5005
+0xD0E7	0x4F1C
+0xD0E8	0x4FF6
+0xD0E9	0x5021
+0xD0EA	0x5029
+0xD0EB	0x502C
+0xD0EC	0x4FFE
+0xD0ED	0x4FEF
+0xD0EE	0x5011
+0xD0EF	0x5006
+0xD0F0	0x5043
+0xD0F1	0x5047
+0xD0F2	0x6703
+0xD0F3	0x5055
+0xD0F4	0x5050
+0xD0F5	0x5048
+0xD0F6	0x505A
+0xD0F7	0x5056
+0xD0F8	0x506C
+0xD0F9	0x5078
+0xD0FA	0x5080
+0xD0FB	0x509A
+0xD0FC	0x5085
+0xD0FD	0x50B4
+0xD0FE	0x50B2
+0xD1A1	0x50C9
+0xD1A2	0x50CA
+0xD1A3	0x50B3
+0xD1A4	0x50C2
+0xD1A5	0x50D6
+0xD1A6	0x50DE
+0xD1A7	0x50E5
+0xD1A8	0x50ED
+0xD1A9	0x50E3
+0xD1AA	0x50EE
+0xD1AB	0x50F9
+0xD1AC	0x50F5
+0xD1AD	0x5109
+0xD1AE	0x5101
+0xD1AF	0x5102
+0xD1B0	0x5116
+0xD1B1	0x5115
+0xD1B2	0x5114
+0xD1B3	0x511A
+0xD1B4	0x5121
+0xD1B5	0x513A
+0xD1B6	0x5137
+0xD1B7	0x513C
+0xD1B8	0x513B
+0xD1B9	0x513F
+0xD1BA	0x5140
+0xD1BB	0x5152
+0xD1BC	0x514C
+0xD1BD	0x5154
+0xD1BE	0x5162
+0xD1BF	0x7AF8
+0xD1C0	0x5169
+0xD1C1	0x516A
+0xD1C2	0x516E
+0xD1C3	0x5180
+0xD1C4	0x5182
+0xD1C5	0x56D8
+0xD1C6	0x518C
+0xD1C7	0x5189
+0xD1C8	0x518F
+0xD1C9	0x5191
+0xD1CA	0x5193
+0xD1CB	0x5195
+0xD1CC	0x5196
+0xD1CD	0x51A4
+0xD1CE	0x51A6
+0xD1CF	0x51A2
+0xD1D0	0x51A9
+0xD1D1	0x51AA
+0xD1D2	0x51AB
+0xD1D3	0x51B3
+0xD1D4	0x51B1
+0xD1D5	0x51B2
+0xD1D6	0x51B0
+0xD1D7	0x51B5
+0xD1D8	0x51BD
+0xD1D9	0x51C5
+0xD1DA	0x51C9
+0xD1DB	0x51DB
+0xD1DC	0x51E0
+0xD1DD	0x8655
+0xD1DE	0x51E9
+0xD1DF	0x51ED
+0xD1E0	0x51F0
+0xD1E1	0x51F5
+0xD1E2	0x51FE
+0xD1E3	0x5204
+0xD1E4	0x520B
+0xD1E5	0x5214
+0xD1E6	0x520E
+0xD1E7	0x5227
+0xD1E8	0x522A
+0xD1E9	0x522E
+0xD1EA	0x5233
+0xD1EB	0x5239
+0xD1EC	0x524F
+0xD1ED	0x5244
+0xD1EE	0x524B
+0xD1EF	0x524C
+0xD1F0	0x525E
+0xD1F1	0x5254
+0xD1F2	0x526A
+0xD1F3	0x5274
+0xD1F4	0x5269
+0xD1F5	0x5273
+0xD1F6	0x527F
+0xD1F7	0x527D
+0xD1F8	0x528D
+0xD1F9	0x5294
+0xD1FA	0x5292
+0xD1FB	0x5271
+0xD1FC	0x5288
+0xD1FD	0x5291
+0xD1FE	0x8FA8
+0xD2A1	0x8FA7
+0xD2A2	0x52AC
+0xD2A3	0x52AD
+0xD2A4	0x52BC
+0xD2A5	0x52B5
+0xD2A6	0x52C1
+0xD2A7	0x52CD
+0xD2A8	0x52D7
+0xD2A9	0x52DE
+0xD2AA	0x52E3
+0xD2AB	0x52E6
+0xD2AC	0x98ED
+0xD2AD	0x52E0
+0xD2AE	0x52F3
+0xD2AF	0x52F5
+0xD2B0	0x52F8
+0xD2B1	0x52F9
+0xD2B2	0x5306
+0xD2B3	0x5308
+0xD2B4	0x7538
+0xD2B5	0x530D
+0xD2B6	0x5310
+0xD2B7	0x530F
+0xD2B8	0x5315
+0xD2B9	0x531A
+0xD2BA	0x5323
+0xD2BB	0x532F
+0xD2BC	0x5331
+0xD2BD	0x5333
+0xD2BE	0x5338
+0xD2BF	0x5340
+0xD2C0	0x5346
+0xD2C1	0x5345
+0xD2C2	0x4E17
+0xD2C3	0x5349
+0xD2C4	0x534D
+0xD2C5	0x51D6
+0xD2C6	0x535E
+0xD2C7	0x5369
+0xD2C8	0x536E
+0xD2C9	0x5918
+0xD2CA	0x537B
+0xD2CB	0x5377
+0xD2CC	0x5382
+0xD2CD	0x5396
+0xD2CE	0x53A0
+0xD2CF	0x53A6
+0xD2D0	0x53A5
+0xD2D1	0x53AE
+0xD2D2	0x53B0
+0xD2D3	0x53B6
+0xD2D4	0x53C3
+0xD2D5	0x7C12
+0xD2D6	0x96D9
+0xD2D7	0x53DF
+0xD2D8	0x66FC
+0xD2D9	0x71EE
+0xD2DA	0x53EE
+0xD2DB	0x53E8
+0xD2DC	0x53ED
+0xD2DD	0x53FA
+0xD2DE	0x5401
+0xD2DF	0x543D
+0xD2E0	0x5440
+0xD2E1	0x542C
+0xD2E2	0x542D
+0xD2E3	0x543C
+0xD2E4	0x542E
+0xD2E5	0x5436
+0xD2E6	0x5429
+0xD2E7	0x541D
+0xD2E8	0x544E
+0xD2E9	0x548F
+0xD2EA	0x5475
+0xD2EB	0x548E
+0xD2EC	0x545F
+0xD2ED	0x5471
+0xD2EE	0x5477
+0xD2EF	0x5470
+0xD2F0	0x5492
+0xD2F1	0x547B
+0xD2F2	0x5480
+0xD2F3	0x5476
+0xD2F4	0x5484
+0xD2F5	0x5490
+0xD2F6	0x5486
+0xD2F7	0x54C7
+0xD2F8	0x54A2
+0xD2F9	0x54B8
+0xD2FA	0x54A5
+0xD2FB	0x54AC
+0xD2FC	0x54C4
+0xD2FD	0x54C8
+0xD2FE	0x54A8
+0xD3A1	0x54AB
+0xD3A2	0x54C2
+0xD3A3	0x54A4
+0xD3A4	0x54BE
+0xD3A5	0x54BC
+0xD3A6	0x54D8
+0xD3A7	0x54E5
+0xD3A8	0x54E6
+0xD3A9	0x550F
+0xD3AA	0x5514
+0xD3AB	0x54FD
+0xD3AC	0x54EE
+0xD3AD	0x54ED
+0xD3AE	0x54FA
+0xD3AF	0x54E2
+0xD3B0	0x5539
+0xD3B1	0x5540
+0xD3B2	0x5563
+0xD3B3	0x554C
+0xD3B4	0x552E
+0xD3B5	0x555C
+0xD3B6	0x5545
+0xD3B7	0x5556
+0xD3B8	0x5557
+0xD3B9	0x5538
+0xD3BA	0x5533
+0xD3BB	0x555D
+0xD3BC	0x5599
+0xD3BD	0x5580
+0xD3BE	0x54AF
+0xD3BF	0x558A
+0xD3C0	0x559F
+0xD3C1	0x557B
+0xD3C2	0x557E
+0xD3C3	0x5598
+0xD3C4	0x559E
+0xD3C5	0x55AE
+0xD3C6	0x557C
+0xD3C7	0x5583
+0xD3C8	0x55A9
+0xD3C9	0x5587
+0xD3CA	0x55A8
+0xD3CB	0x55DA
+0xD3CC	0x55C5
+0xD3CD	0x55DF
+0xD3CE	0x55C4
+0xD3CF	0x55DC
+0xD3D0	0x55E4
+0xD3D1	0x55D4
+0xD3D2	0x5614
+0xD3D3	0x55F7
+0xD3D4	0x5616
+0xD3D5	0x55FE
+0xD3D6	0x55FD
+0xD3D7	0x561B
+0xD3D8	0x55F9
+0xD3D9	0x564E
+0xD3DA	0x5650
+0xD3DB	0x71DF
+0xD3DC	0x5634
+0xD3DD	0x5636
+0xD3DE	0x5632
+0xD3DF	0x5638
+0xD3E0	0x566B
+0xD3E1	0x5664
+0xD3E2	0x562F
+0xD3E3	0x566C
+0xD3E4	0x566A
+0xD3E5	0x5686
+0xD3E6	0x5680
+0xD3E7	0x568A
+0xD3E8	0x56A0
+0xD3E9	0x5694
+0xD3EA	0x568F
+0xD3EB	0x56A5
+0xD3EC	0x56AE
+0xD3ED	0x56B6
+0xD3EE	0x56B4
+0xD3EF	0x56C2
+0xD3F0	0x56BC
+0xD3F1	0x56C1
+0xD3F2	0x56C3
+0xD3F3	0x56C0
+0xD3F4	0x56C8
+0xD3F5	0x56CE
+0xD3F6	0x56D1
+0xD3F7	0x56D3
+0xD3F8	0x56D7
+0xD3F9	0x56EE
+0xD3FA	0x56F9
+0xD3FB	0x5700
+0xD3FC	0x56FF
+0xD3FD	0x5704
+0xD3FE	0x5709
+0xD4A1	0x5708
+0xD4A2	0x570B
+0xD4A3	0x570D
+0xD4A4	0x5713
+0xD4A5	0x5718
+0xD4A6	0x5716
+0xD4A7	0x55C7
+0xD4A8	0x571C
+0xD4A9	0x5726
+0xD4AA	0x5737
+0xD4AB	0x5738
+0xD4AC	0x574E
+0xD4AD	0x573B
+0xD4AE	0x5740
+0xD4AF	0x574F
+0xD4B0	0x5769
+0xD4B1	0x57C0
+0xD4B2	0x5788
+0xD4B3	0x5761
+0xD4B4	0x577F
+0xD4B5	0x5789
+0xD4B6	0x5793
+0xD4B7	0x57A0
+0xD4B8	0x57B3
+0xD4B9	0x57A4
+0xD4BA	0x57AA
+0xD4BB	0x57B0
+0xD4BC	0x57C3
+0xD4BD	0x57C6
+0xD4BE	0x57D4
+0xD4BF	0x57D2
+0xD4C0	0x57D3
+0xD4C1	0x580A
+0xD4C2	0x57D6
+0xD4C3	0x57E3
+0xD4C4	0x580B
+0xD4C5	0x5819
+0xD4C6	0x581D
+0xD4C7	0x5872
+0xD4C8	0x5821
+0xD4C9	0x5862
+0xD4CA	0x584B
+0xD4CB	0x5870
+0xD4CC	0x6BC0
+0xD4CD	0x5852
+0xD4CE	0x583D
+0xD4CF	0x5879
+0xD4D0	0x5885
+0xD4D1	0x58B9
+0xD4D2	0x589F
+0xD4D3	0x58AB
+0xD4D4	0x58BA
+0xD4D5	0x58DE
+0xD4D6	0x58BB
+0xD4D7	0x58B8
+0xD4D8	0x58AE
+0xD4D9	0x58C5
+0xD4DA	0x58D3
+0xD4DB	0x58D1
+0xD4DC	0x58D7
+0xD4DD	0x58D9
+0xD4DE	0x58D8
+0xD4DF	0x58E5
+0xD4E0	0x58DC
+0xD4E1	0x58E4
+0xD4E2	0x58DF
+0xD4E3	0x58EF
+0xD4E4	0x58FA
+0xD4E5	0x58F9
+0xD4E6	0x58FB
+0xD4E7	0x58FC
+0xD4E8	0x58FD
+0xD4E9	0x5902
+0xD4EA	0x590A
+0xD4EB	0x5910
+0xD4EC	0x591B
+0xD4ED	0x68A6
+0xD4EE	0x5925
+0xD4EF	0x592C
+0xD4F0	0x592D
+0xD4F1	0x5932
+0xD4F2	0x5938
+0xD4F3	0x593E
+0xD4F4	0x7AD2
+0xD4F5	0x5955
+0xD4F6	0x5950
+0xD4F7	0x594E
+0xD4F8	0x595A
+0xD4F9	0x5958
+0xD4FA	0x5962
+0xD4FB	0x5960
+0xD4FC	0x5967
+0xD4FD	0x596C
+0xD4FE	0x5969
+0xD5A1	0x5978
+0xD5A2	0x5981
+0xD5A3	0x599D
+0xD5A4	0x4F5E
+0xD5A5	0x4FAB
+0xD5A6	0x59A3
+0xD5A7	0x59B2
+0xD5A8	0x59C6
+0xD5A9	0x59E8
+0xD5AA	0x59DC
+0xD5AB	0x598D
+0xD5AC	0x59D9
+0xD5AD	0x59DA
+0xD5AE	0x5A25
+0xD5AF	0x5A1F
+0xD5B0	0x5A11
+0xD5B1	0x5A1C
+0xD5B2	0x5A09
+0xD5B3	0x5A1A
+0xD5B4	0x5A40
+0xD5B5	0x5A6C
+0xD5B6	0x5A49
+0xD5B7	0x5A35
+0xD5B8	0x5A36
+0xD5B9	0x5A62
+0xD5BA	0x5A6A
+0xD5BB	0x5A9A
+0xD5BC	0x5ABC
+0xD5BD	0x5ABE
+0xD5BE	0x5ACB
+0xD5BF	0x5AC2
+0xD5C0	0x5ABD
+0xD5C1	0x5AE3
+0xD5C2	0x5AD7
+0xD5C3	0x5AE6
+0xD5C4	0x5AE9
+0xD5C5	0x5AD6
+0xD5C6	0x5AFA
+0xD5C7	0x5AFB
+0xD5C8	0x5B0C
+0xD5C9	0x5B0B
+0xD5CA	0x5B16
+0xD5CB	0x5B32
+0xD5CC	0x5AD0
+0xD5CD	0x5B2A
+0xD5CE	0x5B36
+0xD5CF	0x5B3E
+0xD5D0	0x5B43
+0xD5D1	0x5B45
+0xD5D2	0x5B40
+0xD5D3	0x5B51
+0xD5D4	0x5B55
+0xD5D5	0x5B5A
+0xD5D6	0x5B5B
+0xD5D7	0x5B65
+0xD5D8	0x5B69
+0xD5D9	0x5B70
+0xD5DA	0x5B73
+0xD5DB	0x5B75
+0xD5DC	0x5B78
+0xD5DD	0x6588
+0xD5DE	0x5B7A
+0xD5DF	0x5B80
+0xD5E0	0x5B83
+0xD5E1	0x5BA6
+0xD5E2	0x5BB8
+0xD5E3	0x5BC3
+0xD5E4	0x5BC7
+0xD5E5	0x5BC9
+0xD5E6	0x5BD4
+0xD5E7	0x5BD0
+0xD5E8	0x5BE4
+0xD5E9	0x5BE6
+0xD5EA	0x5BE2
+0xD5EB	0x5BDE
+0xD5EC	0x5BE5
+0xD5ED	0x5BEB
+0xD5EE	0x5BF0
+0xD5EF	0x5BF6
+0xD5F0	0x5BF3
+0xD5F1	0x5C05
+0xD5F2	0x5C07
+0xD5F3	0x5C08
+0xD5F4	0x5C0D
+0xD5F5	0x5C13
+0xD5F6	0x5C20
+0xD5F7	0x5C22
+0xD5F8	0x5C28
+0xD5F9	0x5C38
+0xD5FA	0x5C39
+0xD5FB	0x5C41
+0xD5FC	0x5C46
+0xD5FD	0x5C4E
+0xD5FE	0x5C53
+0xD6A1	0x5C50
+0xD6A2	0x5C4F
+0xD6A3	0x5B71
+0xD6A4	0x5C6C
+0xD6A5	0x5C6E
+0xD6A6	0x4E62
+0xD6A7	0x5C76
+0xD6A8	0x5C79
+0xD6A9	0x5C8C
+0xD6AA	0x5C91
+0xD6AB	0x5C94
+0xD6AC	0x599B
+0xD6AD	0x5CAB
+0xD6AE	0x5CBB
+0xD6AF	0x5CB6
+0xD6B0	0x5CBC
+0xD6B1	0x5CB7
+0xD6B2	0x5CC5
+0xD6B3	0x5CBE
+0xD6B4	0x5CC7
+0xD6B5	0x5CD9
+0xD6B6	0x5CE9
+0xD6B7	0x5CFD
+0xD6B8	0x5CFA
+0xD6B9	0x5CED
+0xD6BA	0x5D8C
+0xD6BB	0x5CEA
+0xD6BC	0x5D0B
+0xD6BD	0x5D15
+0xD6BE	0x5D17
+0xD6BF	0x5D5C
+0xD6C0	0x5D1F
+0xD6C1	0x5D1B
+0xD6C2	0x5D11
+0xD6C3	0x5D14
+0xD6C4	0x5D22
+0xD6C5	0x5D1A
+0xD6C6	0x5D19
+0xD6C7	0x5D18
+0xD6C8	0x5D4C
+0xD6C9	0x5D52
+0xD6CA	0x5D4E
+0xD6CB	0x5D4B
+0xD6CC	0x5D6C
+0xD6CD	0x5D73
+0xD6CE	0x5D76
+0xD6CF	0x5D87
+0xD6D0	0x5D84
+0xD6D1	0x5D82
+0xD6D2	0x5DA2
+0xD6D3	0x5D9D
+0xD6D4	0x5DAC
+0xD6D5	0x5DAE
+0xD6D6	0x5DBD
+0xD6D7	0x5D90
+0xD6D8	0x5DB7
+0xD6D9	0x5DBC
+0xD6DA	0x5DC9
+0xD6DB	0x5DCD
+0xD6DC	0x5DD3
+0xD6DD	0x5DD2
+0xD6DE	0x5DD6
+0xD6DF	0x5DDB
+0xD6E0	0x5DEB
+0xD6E1	0x5DF2
+0xD6E2	0x5DF5
+0xD6E3	0x5E0B
+0xD6E4	0x5E1A
+0xD6E5	0x5E19
+0xD6E6	0x5E11
+0xD6E7	0x5E1B
+0xD6E8	0x5E36
+0xD6E9	0x5E37
+0xD6EA	0x5E44
+0xD6EB	0x5E43
+0xD6EC	0x5E40
+0xD6ED	0x5E4E
+0xD6EE	0x5E57
+0xD6EF	0x5E54
+0xD6F0	0x5E5F
+0xD6F1	0x5E62
+0xD6F2	0x5E64
+0xD6F3	0x5E47
+0xD6F4	0x5E75
+0xD6F5	0x5E76
+0xD6F6	0x5E7A
+0xD6F7	0x9EBC
+0xD6F8	0x5E7F
+0xD6F9	0x5EA0
+0xD6FA	0x5EC1
+0xD6FB	0x5EC2
+0xD6FC	0x5EC8
+0xD6FD	0x5ED0
+0xD6FE	0x5ECF
+0xD7A1	0x5ED6
+0xD7A2	0x5EE3
+0xD7A3	0x5EDD
+0xD7A4	0x5EDA
+0xD7A5	0x5EDB
+0xD7A6	0x5EE2
+0xD7A7	0x5EE1
+0xD7A8	0x5EE8
+0xD7A9	0x5EE9
+0xD7AA	0x5EEC
+0xD7AB	0x5EF1
+0xD7AC	0x5EF3
+0xD7AD	0x5EF0
+0xD7AE	0x5EF4
+0xD7AF	0x5EF8
+0xD7B0	0x5EFE
+0xD7B1	0x5F03
+0xD7B2	0x5F09
+0xD7B3	0x5F5D
+0xD7B4	0x5F5C
+0xD7B5	0x5F0B
+0xD7B6	0x5F11
+0xD7B7	0x5F16
+0xD7B8	0x5F29
+0xD7B9	0x5F2D
+0xD7BA	0x5F38
+0xD7BB	0x5F41
+0xD7BC	0x5F48
+0xD7BD	0x5F4C
+0xD7BE	0x5F4E
+0xD7BF	0x5F2F
+0xD7C0	0x5F51
+0xD7C1	0x5F56
+0xD7C2	0x5F57
+0xD7C3	0x5F59
+0xD7C4	0x5F61
+0xD7C5	0x5F6D
+0xD7C6	0x5F73
+0xD7C7	0x5F77
+0xD7C8	0x5F83
+0xD7C9	0x5F82
+0xD7CA	0x5F7F
+0xD7CB	0x5F8A
+0xD7CC	0x5F88
+0xD7CD	0x5F91
+0xD7CE	0x5F87
+0xD7CF	0x5F9E
+0xD7D0	0x5F99
+0xD7D1	0x5F98
+0xD7D2	0x5FA0
+0xD7D3	0x5FA8
+0xD7D4	0x5FAD
+0xD7D5	0x5FBC
+0xD7D6	0x5FD6
+0xD7D7	0x5FFB
+0xD7D8	0x5FE4
+0xD7D9	0x5FF8
+0xD7DA	0x5FF1
+0xD7DB	0x5FDD
+0xD7DC	0x60B3
+0xD7DD	0x5FFF
+0xD7DE	0x6021
+0xD7DF	0x6060
+0xD7E0	0x6019
+0xD7E1	0x6010
+0xD7E2	0x6029
+0xD7E3	0x600E
+0xD7E4	0x6031
+0xD7E5	0x601B
+0xD7E6	0x6015
+0xD7E7	0x602B
+0xD7E8	0x6026
+0xD7E9	0x600F
+0xD7EA	0x603A
+0xD7EB	0x605A
+0xD7EC	0x6041
+0xD7ED	0x606A
+0xD7EE	0x6077
+0xD7EF	0x605F
+0xD7F0	0x604A
+0xD7F1	0x6046
+0xD7F2	0x604D
+0xD7F3	0x6063
+0xD7F4	0x6043
+0xD7F5	0x6064
+0xD7F6	0x6042
+0xD7F7	0x606C
+0xD7F8	0x606B
+0xD7F9	0x6059
+0xD7FA	0x6081
+0xD7FB	0x608D
+0xD7FC	0x60E7
+0xD7FD	0x6083
+0xD7FE	0x609A
+0xD8A1	0x6084
+0xD8A2	0x609B
+0xD8A3	0x6096
+0xD8A4	0x6097
+0xD8A5	0x6092
+0xD8A6	0x60A7
+0xD8A7	0x608B
+0xD8A8	0x60E1
+0xD8A9	0x60B8
+0xD8AA	0x60E0
+0xD8AB	0x60D3
+0xD8AC	0x60B4
+0xD8AD	0x5FF0
+0xD8AE	0x60BD
+0xD8AF	0x60C6
+0xD8B0	0x60B5
+0xD8B1	0x60D8
+0xD8B2	0x614D
+0xD8B3	0x6115
+0xD8B4	0x6106
+0xD8B5	0x60F6
+0xD8B6	0x60F7
+0xD8B7	0x6100
+0xD8B8	0x60F4
+0xD8B9	0x60FA
+0xD8BA	0x6103
+0xD8BB	0x6121
+0xD8BC	0x60FB
+0xD8BD	0x60F1
+0xD8BE	0x610D
+0xD8BF	0x610E
+0xD8C0	0x6147
+0xD8C1	0x613E
+0xD8C2	0x6128
+0xD8C3	0x6127
+0xD8C4	0x614A
+0xD8C5	0x613F
+0xD8C6	0x613C
+0xD8C7	0x612C
+0xD8C8	0x6134
+0xD8C9	0x613D
+0xD8CA	0x6142
+0xD8CB	0x6144
+0xD8CC	0x6173
+0xD8CD	0x6177
+0xD8CE	0x6158
+0xD8CF	0x6159
+0xD8D0	0x615A
+0xD8D1	0x616B
+0xD8D2	0x6174
+0xD8D3	0x616F
+0xD8D4	0x6165
+0xD8D5	0x6171
+0xD8D6	0x615F
+0xD8D7	0x615D
+0xD8D8	0x6153
+0xD8D9	0x6175
+0xD8DA	0x6199
+0xD8DB	0x6196
+0xD8DC	0x6187
+0xD8DD	0x61AC
+0xD8DE	0x6194
+0xD8DF	0x619A
+0xD8E0	0x618A
+0xD8E1	0x6191
+0xD8E2	0x61AB
+0xD8E3	0x61AE
+0xD8E4	0x61CC
+0xD8E5	0x61CA
+0xD8E6	0x61C9
+0xD8E7	0x61F7
+0xD8E8	0x61C8
+0xD8E9	0x61C3
+0xD8EA	0x61C6
+0xD8EB	0x61BA
+0xD8EC	0x61CB
+0xD8ED	0x7F79
+0xD8EE	0x61CD
+0xD8EF	0x61E6
+0xD8F0	0x61E3
+0xD8F1	0x61F6
+0xD8F2	0x61FA
+0xD8F3	0x61F4
+0xD8F4	0x61FF
+0xD8F5	0x61FD
+0xD8F6	0x61FC
+0xD8F7	0x61FE
+0xD8F8	0x6200
+0xD8F9	0x6208
+0xD8FA	0x6209
+0xD8FB	0x620D
+0xD8FC	0x620C
+0xD8FD	0x6214
+0xD8FE	0x621B
+0xD9A1	0x621E
+0xD9A2	0x6221
+0xD9A3	0x622A
+0xD9A4	0x622E
+0xD9A5	0x6230
+0xD9A6	0x6232
+0xD9A7	0x6233
+0xD9A8	0x6241
+0xD9A9	0x624E
+0xD9AA	0x625E
+0xD9AB	0x6263
+0xD9AC	0x625B
+0xD9AD	0x6260
+0xD9AE	0x6268
+0xD9AF	0x627C
+0xD9B0	0x6282
+0xD9B1	0x6289
+0xD9B2	0x627E
+0xD9B3	0x6292
+0xD9B4	0x6293
+0xD9B5	0x6296
+0xD9B6	0x62D4
+0xD9B7	0x6283
+0xD9B8	0x6294
+0xD9B9	0x62D7
+0xD9BA	0x62D1
+0xD9BB	0x62BB
+0xD9BC	0x62CF
+0xD9BD	0x62FF
+0xD9BE	0x62C6
+0xD9BF	0x64D4
+0xD9C0	0x62C8
+0xD9C1	0x62DC
+0xD9C2	0x62CC
+0xD9C3	0x62CA
+0xD9C4	0x62C2
+0xD9C5	0x62C7
+0xD9C6	0x629B
+0xD9C7	0x62C9
+0xD9C8	0x630C
+0xD9C9	0x62EE
+0xD9CA	0x62F1
+0xD9CB	0x6327
+0xD9CC	0x6302
+0xD9CD	0x6308
+0xD9CE	0x62EF
+0xD9CF	0x62F5
+0xD9D0	0x6350
+0xD9D1	0x633E
+0xD9D2	0x634D
+0xD9D3	0x641C
+0xD9D4	0x634F
+0xD9D5	0x6396
+0xD9D6	0x638E
+0xD9D7	0x6380
+0xD9D8	0x63AB
+0xD9D9	0x6376
+0xD9DA	0x63A3
+0xD9DB	0x638F
+0xD9DC	0x6389
+0xD9DD	0x639F
+0xD9DE	0x63B5
+0xD9DF	0x636B
+0xD9E0	0x6369
+0xD9E1	0x63BE
+0xD9E2	0x63E9
+0xD9E3	0x63C0
+0xD9E4	0x63C6
+0xD9E5	0x63E3
+0xD9E6	0x63C9
+0xD9E7	0x63D2
+0xD9E8	0x63F6
+0xD9E9	0x63C4
+0xD9EA	0x6416
+0xD9EB	0x6434
+0xD9EC	0x6406
+0xD9ED	0x6413
+0xD9EE	0x6426
+0xD9EF	0x6436
+0xD9F0	0x651D
+0xD9F1	0x6417
+0xD9F2	0x6428
+0xD9F3	0x640F
+0xD9F4	0x6467
+0xD9F5	0x646F
+0xD9F6	0x6476
+0xD9F7	0x644E
+0xD9F8	0x652A
+0xD9F9	0x6495
+0xD9FA	0x6493
+0xD9FB	0x64A5
+0xD9FC	0x64A9
+0xD9FD	0x6488
+0xD9FE	0x64BC
+0xDAA1	0x64DA
+0xDAA2	0x64D2
+0xDAA3	0x64C5
+0xDAA4	0x64C7
+0xDAA5	0x64BB
+0xDAA6	0x64D8
+0xDAA7	0x64C2
+0xDAA8	0x64F1
+0xDAA9	0x64E7
+0xDAAA	0x8209
+0xDAAB	0x64E0
+0xDAAC	0x64E1
+0xDAAD	0x62AC
+0xDAAE	0x64E3
+0xDAAF	0x64EF
+0xDAB0	0x652C
+0xDAB1	0x64F6
+0xDAB2	0x64F4
+0xDAB3	0x64F2
+0xDAB4	0x64FA
+0xDAB5	0x6500
+0xDAB6	0x64FD
+0xDAB7	0x6518
+0xDAB8	0x651C
+0xDAB9	0x6505
+0xDABA	0x6524
+0xDABB	0x6523
+0xDABC	0x652B
+0xDABD	0x6534
+0xDABE	0x6535
+0xDABF	0x6537
+0xDAC0	0x6536
+0xDAC1	0x6538
+0xDAC2	0x754B
+0xDAC3	0x6548
+0xDAC4	0x6556
+0xDAC5	0x6555
+0xDAC6	0x654D
+0xDAC7	0x6558
+0xDAC8	0x655E
+0xDAC9	0x655D
+0xDACA	0x6572
+0xDACB	0x6578
+0xDACC	0x6582
+0xDACD	0x6583
+0xDACE	0x8B8A
+0xDACF	0x659B
+0xDAD0	0x659F
+0xDAD1	0x65AB
+0xDAD2	0x65B7
+0xDAD3	0x65C3
+0xDAD4	0x65C6
+0xDAD5	0x65C1
+0xDAD6	0x65C4
+0xDAD7	0x65CC
+0xDAD8	0x65D2
+0xDAD9	0x65DB
+0xDADA	0x65D9
+0xDADB	0x65E0
+0xDADC	0x65E1
+0xDADD	0x65F1
+0xDADE	0x6772
+0xDADF	0x660A
+0xDAE0	0x6603
+0xDAE1	0x65FB
+0xDAE2	0x6773
+0xDAE3	0x6635
+0xDAE4	0x6636
+0xDAE5	0x6634
+0xDAE6	0x661C
+0xDAE7	0x664F
+0xDAE8	0x6644
+0xDAE9	0x6649
+0xDAEA	0x6641
+0xDAEB	0x665E
+0xDAEC	0x665D
+0xDAED	0x6664
+0xDAEE	0x6667
+0xDAEF	0x6668
+0xDAF0	0x665F
+0xDAF1	0x6662
+0xDAF2	0x6670
+0xDAF3	0x6683
+0xDAF4	0x6688
+0xDAF5	0x668E
+0xDAF6	0x6689
+0xDAF7	0x6684
+0xDAF8	0x6698
+0xDAF9	0x669D
+0xDAFA	0x66C1
+0xDAFB	0x66B9
+0xDAFC	0x66C9
+0xDAFD	0x66BE
+0xDAFE	0x66BC
+0xDBA1	0x66C4
+0xDBA2	0x66B8
+0xDBA3	0x66D6
+0xDBA4	0x66DA
+0xDBA5	0x66E0
+0xDBA6	0x663F
+0xDBA7	0x66E6
+0xDBA8	0x66E9
+0xDBA9	0x66F0
+0xDBAA	0x66F5
+0xDBAB	0x66F7
+0xDBAC	0x670F
+0xDBAD	0x6716
+0xDBAE	0x671E
+0xDBAF	0x6726
+0xDBB0	0x6727
+0xDBB1	0x9738
+0xDBB2	0x672E
+0xDBB3	0x673F
+0xDBB4	0x6736
+0xDBB5	0x6741
+0xDBB6	0x6738
+0xDBB7	0x6737
+0xDBB8	0x6746
+0xDBB9	0x675E
+0xDBBA	0x6760
+0xDBBB	0x6759
+0xDBBC	0x6763
+0xDBBD	0x6764
+0xDBBE	0x6789
+0xDBBF	0x6770
+0xDBC0	0x67A9
+0xDBC1	0x677C
+0xDBC2	0x676A
+0xDBC3	0x678C
+0xDBC4	0x678B
+0xDBC5	0x67A6
+0xDBC6	0x67A1
+0xDBC7	0x6785
+0xDBC8	0x67B7
+0xDBC9	0x67EF
+0xDBCA	0x67B4
+0xDBCB	0x67EC
+0xDBCC	0x67B3
+0xDBCD	0x67E9
+0xDBCE	0x67B8
+0xDBCF	0x67E4
+0xDBD0	0x67DE
+0xDBD1	0x67DD
+0xDBD2	0x67E2
+0xDBD3	0x67EE
+0xDBD4	0x67B9
+0xDBD5	0x67CE
+0xDBD6	0x67C6
+0xDBD7	0x67E7
+0xDBD8	0x6A9C
+0xDBD9	0x681E
+0xDBDA	0x6846
+0xDBDB	0x6829
+0xDBDC	0x6840
+0xDBDD	0x684D
+0xDBDE	0x6832
+0xDBDF	0x684E
+0xDBE0	0x68B3
+0xDBE1	0x682B
+0xDBE2	0x6859
+0xDBE3	0x6863
+0xDBE4	0x6877
+0xDBE5	0x687F
+0xDBE6	0x689F
+0xDBE7	0x688F
+0xDBE8	0x68AD
+0xDBE9	0x6894
+0xDBEA	0x689D
+0xDBEB	0x689B
+0xDBEC	0x6883
+0xDBED	0x6AAE
+0xDBEE	0x68B9
+0xDBEF	0x6874
+0xDBF0	0x68B5
+0xDBF1	0x68A0
+0xDBF2	0x68BA
+0xDBF3	0x690F
+0xDBF4	0x688D
+0xDBF5	0x687E
+0xDBF6	0x6901
+0xDBF7	0x68CA
+0xDBF8	0x6908
+0xDBF9	0x68D8
+0xDBFA	0x6922
+0xDBFB	0x6926
+0xDBFC	0x68E1
+0xDBFD	0x690C
+0xDBFE	0x68CD
+0xDCA1	0x68D4
+0xDCA2	0x68E7
+0xDCA3	0x68D5
+0xDCA4	0x6936
+0xDCA5	0x6912
+0xDCA6	0x6904
+0xDCA7	0x68D7
+0xDCA8	0x68E3
+0xDCA9	0x6925
+0xDCAA	0x68F9
+0xDCAB	0x68E0
+0xDCAC	0x68EF
+0xDCAD	0x6928
+0xDCAE	0x692A
+0xDCAF	0x691A
+0xDCB0	0x6923
+0xDCB1	0x6921
+0xDCB2	0x68C6
+0xDCB3	0x6979
+0xDCB4	0x6977
+0xDCB5	0x695C
+0xDCB6	0x6978
+0xDCB7	0x696B
+0xDCB8	0x6954
+0xDCB9	0x697E
+0xDCBA	0x696E
+0xDCBB	0x6939
+0xDCBC	0x6974
+0xDCBD	0x693D
+0xDCBE	0x6959
+0xDCBF	0x6930
+0xDCC0	0x6961
+0xDCC1	0x695E
+0xDCC2	0x695D
+0xDCC3	0x6981
+0xDCC4	0x696A
+0xDCC5	0x69B2
+0xDCC6	0x69AE
+0xDCC7	0x69D0
+0xDCC8	0x69BF
+0xDCC9	0x69C1
+0xDCCA	0x69D3
+0xDCCB	0x69BE
+0xDCCC	0x69CE
+0xDCCD	0x5BE8
+0xDCCE	0x69CA
+0xDCCF	0x69DD
+0xDCD0	0x69BB
+0xDCD1	0x69C3
+0xDCD2	0x69A7
+0xDCD3	0x6A2E
+0xDCD4	0x6991
+0xDCD5	0x69A0
+0xDCD6	0x699C
+0xDCD7	0x6995
+0xDCD8	0x69B4
+0xDCD9	0x69DE
+0xDCDA	0x69E8
+0xDCDB	0x6A02
+0xDCDC	0x6A1B
+0xDCDD	0x69FF
+0xDCDE	0x6B0A
+0xDCDF	0x69F9
+0xDCE0	0x69F2
+0xDCE1	0x69E7
+0xDCE2	0x6A05
+0xDCE3	0x69B1
+0xDCE4	0x6A1E
+0xDCE5	0x69ED
+0xDCE6	0x6A14
+0xDCE7	0x69EB
+0xDCE8	0x6A0A
+0xDCE9	0x6A12
+0xDCEA	0x6AC1
+0xDCEB	0x6A23
+0xDCEC	0x6A13
+0xDCED	0x6A44
+0xDCEE	0x6A0C
+0xDCEF	0x6A72
+0xDCF0	0x6A36
+0xDCF1	0x6A78
+0xDCF2	0x6A47
+0xDCF3	0x6A62
+0xDCF4	0x6A59
+0xDCF5	0x6A66
+0xDCF6	0x6A48
+0xDCF7	0x6A38
+0xDCF8	0x6A22
+0xDCF9	0x6A90
+0xDCFA	0x6A8D
+0xDCFB	0x6AA0
+0xDCFC	0x6A84
+0xDCFD	0x6AA2
+0xDCFE	0x6AA3
+0xDDA1	0x6A97
+0xDDA2	0x8617
+0xDDA3	0x6ABB
+0xDDA4	0x6AC3
+0xDDA5	0x6AC2
+0xDDA6	0x6AB8
+0xDDA7	0x6AB3
+0xDDA8	0x6AAC
+0xDDA9	0x6ADE
+0xDDAA	0x6AD1
+0xDDAB	0x6ADF
+0xDDAC	0x6AAA
+0xDDAD	0x6ADA
+0xDDAE	0x6AEA
+0xDDAF	0x6AFB
+0xDDB0	0x6B05
+0xDDB1	0x8616
+0xDDB2	0x6AFA
+0xDDB3	0x6B12
+0xDDB4	0x6B16
+0xDDB5	0x9B31
+0xDDB6	0x6B1F
+0xDDB7	0x6B38
+0xDDB8	0x6B37
+0xDDB9	0x76DC
+0xDDBA	0x6B39
+0xDDBB	0x98EE
+0xDDBC	0x6B47
+0xDDBD	0x6B43
+0xDDBE	0x6B49
+0xDDBF	0x6B50
+0xDDC0	0x6B59
+0xDDC1	0x6B54
+0xDDC2	0x6B5B
+0xDDC3	0x6B5F
+0xDDC4	0x6B61
+0xDDC5	0x6B78
+0xDDC6	0x6B79
+0xDDC7	0x6B7F
+0xDDC8	0x6B80
+0xDDC9	0x6B84
+0xDDCA	0x6B83
+0xDDCB	0x6B8D
+0xDDCC	0x6B98
+0xDDCD	0x6B95
+0xDDCE	0x6B9E
+0xDDCF	0x6BA4
+0xDDD0	0x6BAA
+0xDDD1	0x6BAB
+0xDDD2	0x6BAF
+0xDDD3	0x6BB2
+0xDDD4	0x6BB1
+0xDDD5	0x6BB3
+0xDDD6	0x6BB7
+0xDDD7	0x6BBC
+0xDDD8	0x6BC6
+0xDDD9	0x6BCB
+0xDDDA	0x6BD3
+0xDDDB	0x6BDF
+0xDDDC	0x6BEC
+0xDDDD	0x6BEB
+0xDDDE	0x6BF3
+0xDDDF	0x6BEF
+0xDDE0	0x9EBE
+0xDDE1	0x6C08
+0xDDE2	0x6C13
+0xDDE3	0x6C14
+0xDDE4	0x6C1B
+0xDDE5	0x6C24
+0xDDE6	0x6C23
+0xDDE7	0x6C5E
+0xDDE8	0x6C55
+0xDDE9	0x6C62
+0xDDEA	0x6C6A
+0xDDEB	0x6C82
+0xDDEC	0x6C8D
+0xDDED	0x6C9A
+0xDDEE	0x6C81
+0xDDEF	0x6C9B
+0xDDF0	0x6C7E
+0xDDF1	0x6C68
+0xDDF2	0x6C73
+0xDDF3	0x6C92
+0xDDF4	0x6C90
+0xDDF5	0x6CC4
+0xDDF6	0x6CF1
+0xDDF7	0x6CD3
+0xDDF8	0x6CBD
+0xDDF9	0x6CD7
+0xDDFA	0x6CC5
+0xDDFB	0x6CDD
+0xDDFC	0x6CAE
+0xDDFD	0x6CB1
+0xDDFE	0x6CBE
+0xDEA1	0x6CBA
+0xDEA2	0x6CDB
+0xDEA3	0x6CEF
+0xDEA4	0x6CD9
+0xDEA5	0x6CEA
+0xDEA6	0x6D1F
+0xDEA7	0x884D
+0xDEA8	0x6D36
+0xDEA9	0x6D2B
+0xDEAA	0x6D3D
+0xDEAB	0x6D38
+0xDEAC	0x6D19
+0xDEAD	0x6D35
+0xDEAE	0x6D33
+0xDEAF	0x6D12
+0xDEB0	0x6D0C
+0xDEB1	0x6D63
+0xDEB2	0x6D93
+0xDEB3	0x6D64
+0xDEB4	0x6D5A
+0xDEB5	0x6D79
+0xDEB6	0x6D59
+0xDEB7	0x6D8E
+0xDEB8	0x6D95
+0xDEB9	0x6FE4
+0xDEBA	0x6D85
+0xDEBB	0x6DF9
+0xDEBC	0x6E15
+0xDEBD	0x6E0A
+0xDEBE	0x6DB5
+0xDEBF	0x6DC7
+0xDEC0	0x6DE6
+0xDEC1	0x6DB8
+0xDEC2	0x6DC6
+0xDEC3	0x6DEC
+0xDEC4	0x6DDE
+0xDEC5	0x6DCC
+0xDEC6	0x6DE8
+0xDEC7	0x6DD2
+0xDEC8	0x6DC5
+0xDEC9	0x6DFA
+0xDECA	0x6DD9
+0xDECB	0x6DE4
+0xDECC	0x6DD5
+0xDECD	0x6DEA
+0xDECE	0x6DEE
+0xDECF	0x6E2D
+0xDED0	0x6E6E
+0xDED1	0x6E2E
+0xDED2	0x6E19
+0xDED3	0x6E72
+0xDED4	0x6E5F
+0xDED5	0x6E3E
+0xDED6	0x6E23
+0xDED7	0x6E6B
+0xDED8	0x6E2B
+0xDED9	0x6E76
+0xDEDA	0x6E4D
+0xDEDB	0x6E1F
+0xDEDC	0x6E43
+0xDEDD	0x6E3A
+0xDEDE	0x6E4E
+0xDEDF	0x6E24
+0xDEE0	0x6EFF
+0xDEE1	0x6E1D
+0xDEE2	0x6E38
+0xDEE3	0x6E82
+0xDEE4	0x6EAA
+0xDEE5	0x6E98
+0xDEE6	0x6EC9
+0xDEE7	0x6EB7
+0xDEE8	0x6ED3
+0xDEE9	0x6EBD
+0xDEEA	0x6EAF
+0xDEEB	0x6EC4
+0xDEEC	0x6EB2
+0xDEED	0x6ED4
+0xDEEE	0x6ED5
+0xDEEF	0x6E8F
+0xDEF0	0x6EA5
+0xDEF1	0x6EC2
+0xDEF2	0x6E9F
+0xDEF3	0x6F41
+0xDEF4	0x6F11
+0xDEF5	0x704C
+0xDEF6	0x6EEC
+0xDEF7	0x6EF8
+0xDEF8	0x6EFE
+0xDEF9	0x6F3F
+0xDEFA	0x6EF2
+0xDEFB	0x6F31
+0xDEFC	0x6EEF
+0xDEFD	0x6F32
+0xDEFE	0x6ECC
+0xDFA1	0x6F3E
+0xDFA2	0x6F13
+0xDFA3	0x6EF7
+0xDFA4	0x6F86
+0xDFA5	0x6F7A
+0xDFA6	0x6F78
+0xDFA7	0x6F81
+0xDFA8	0x6F80
+0xDFA9	0x6F6F
+0xDFAA	0x6F5B
+0xDFAB	0x6FF3
+0xDFAC	0x6F6D
+0xDFAD	0x6F82
+0xDFAE	0x6F7C
+0xDFAF	0x6F58
+0xDFB0	0x6F8E
+0xDFB1	0x6F91
+0xDFB2	0x6FC2
+0xDFB3	0x6F66
+0xDFB4	0x6FB3
+0xDFB5	0x6FA3
+0xDFB6	0x6FA1
+0xDFB7	0x6FA4
+0xDFB8	0x6FB9
+0xDFB9	0x6FC6
+0xDFBA	0x6FAA
+0xDFBB	0x6FDF
+0xDFBC	0x6FD5
+0xDFBD	0x6FEC
+0xDFBE	0x6FD4
+0xDFBF	0x6FD8
+0xDFC0	0x6FF1
+0xDFC1	0x6FEE
+0xDFC2	0x6FDB
+0xDFC3	0x7009
+0xDFC4	0x700B
+0xDFC5	0x6FFA
+0xDFC6	0x7011
+0xDFC7	0x7001
+0xDFC8	0x700F
+0xDFC9	0x6FFE
+0xDFCA	0x701B
+0xDFCB	0x701A
+0xDFCC	0x6F74
+0xDFCD	0x701D
+0xDFCE	0x7018
+0xDFCF	0x701F
+0xDFD0	0x7030
+0xDFD1	0x703E
+0xDFD2	0x7032
+0xDFD3	0x7051
+0xDFD4	0x7063
+0xDFD5	0x7099
+0xDFD6	0x7092
+0xDFD7	0x70AF
+0xDFD8	0x70F1
+0xDFD9	0x70AC
+0xDFDA	0x70B8
+0xDFDB	0x70B3
+0xDFDC	0x70AE
+0xDFDD	0x70DF
+0xDFDE	0x70CB
+0xDFDF	0x70DD
+0xDFE0	0x70D9
+0xDFE1	0x7109
+0xDFE2	0x70FD
+0xDFE3	0x711C
+0xDFE4	0x7119
+0xDFE5	0x7165
+0xDFE6	0x7155
+0xDFE7	0x7188
+0xDFE8	0x7166
+0xDFE9	0x7162
+0xDFEA	0x714C
+0xDFEB	0x7156
+0xDFEC	0x716C
+0xDFED	0x718F
+0xDFEE	0x71FB
+0xDFEF	0x7184
+0xDFF0	0x7195
+0xDFF1	0x71A8
+0xDFF2	0x71AC
+0xDFF3	0x71D7
+0xDFF4	0x71B9
+0xDFF5	0x71BE
+0xDFF6	0x71D2
+0xDFF7	0x71C9
+0xDFF8	0x71D4
+0xDFF9	0x71CE
+0xDFFA	0x71E0
+0xDFFB	0x71EC
+0xDFFC	0x71E7
+0xDFFD	0x71F5
+0xDFFE	0x71FC
+0xE0A1	0x71F9
+0xE0A2	0x71FF
+0xE0A3	0x720D
+0xE0A4	0x7210
+0xE0A5	0x721B
+0xE0A6	0x7228
+0xE0A7	0x722D
+0xE0A8	0x722C
+0xE0A9	0x7230
+0xE0AA	0x7232
+0xE0AB	0x723B
+0xE0AC	0x723C
+0xE0AD	0x723F
+0xE0AE	0x7240
+0xE0AF	0x7246
+0xE0B0	0x724B
+0xE0B1	0x7258
+0xE0B2	0x7274
+0xE0B3	0x727E
+0xE0B4	0x7282
+0xE0B5	0x7281
+0xE0B6	0x7287
+0xE0B7	0x7292
+0xE0B8	0x7296
+0xE0B9	0x72A2
+0xE0BA	0x72A7
+0xE0BB	0x72B9
+0xE0BC	0x72B2
+0xE0BD	0x72C3
+0xE0BE	0x72C6
+0xE0BF	0x72C4
+0xE0C0	0x72CE
+0xE0C1	0x72D2
+0xE0C2	0x72E2
+0xE0C3	0x72E0
+0xE0C4	0x72E1
+0xE0C5	0x72F9
+0xE0C6	0x72F7
+0xE0C7	0x500F
+0xE0C8	0x7317
+0xE0C9	0x730A
+0xE0CA	0x731C
+0xE0CB	0x7316
+0xE0CC	0x731D
+0xE0CD	0x7334
+0xE0CE	0x732F
+0xE0CF	0x7329
+0xE0D0	0x7325
+0xE0D1	0x733E
+0xE0D2	0x734E
+0xE0D3	0x734F
+0xE0D4	0x9ED8
+0xE0D5	0x7357
+0xE0D6	0x736A
+0xE0D7	0x7368
+0xE0D8	0x7370
+0xE0D9	0x7378
+0xE0DA	0x7375
+0xE0DB	0x737B
+0xE0DC	0x737A
+0xE0DD	0x73C8
+0xE0DE	0x73B3
+0xE0DF	0x73CE
+0xE0E0	0x73BB
+0xE0E1	0x73C0
+0xE0E2	0x73E5
+0xE0E3	0x73EE
+0xE0E4	0x73DE
+0xE0E5	0x74A2
+0xE0E6	0x7405
+0xE0E7	0x746F
+0xE0E8	0x7425
+0xE0E9	0x73F8
+0xE0EA	0x7432
+0xE0EB	0x743A
+0xE0EC	0x7455
+0xE0ED	0x743F
+0xE0EE	0x745F
+0xE0EF	0x7459
+0xE0F0	0x7441
+0xE0F1	0x745C
+0xE0F2	0x7469
+0xE0F3	0x7470
+0xE0F4	0x7463
+0xE0F5	0x746A
+0xE0F6	0x7476
+0xE0F7	0x747E
+0xE0F8	0x748B
+0xE0F9	0x749E
+0xE0FA	0x74A7
+0xE0FB	0x74CA
+0xE0FC	0x74CF
+0xE0FD	0x74D4
+0xE0FE	0x73F1
+0xE1A1	0x74E0
+0xE1A2	0x74E3
+0xE1A3	0x74E7
+0xE1A4	0x74E9
+0xE1A5	0x74EE
+0xE1A6	0x74F2
+0xE1A7	0x74F0
+0xE1A8	0x74F1
+0xE1A9	0x74F8
+0xE1AA	0x74F7
+0xE1AB	0x7504
+0xE1AC	0x7503
+0xE1AD	0x7505
+0xE1AE	0x750C
+0xE1AF	0x750E
+0xE1B0	0x750D
+0xE1B1	0x7515
+0xE1B2	0x7513
+0xE1B3	0x751E
+0xE1B4	0x7526
+0xE1B5	0x752C
+0xE1B6	0x753C
+0xE1B7	0x7544
+0xE1B8	0x754D
+0xE1B9	0x754A
+0xE1BA	0x7549
+0xE1BB	0x755B
+0xE1BC	0x7546
+0xE1BD	0x755A
+0xE1BE	0x7569
+0xE1BF	0x7564
+0xE1C0	0x7567
+0xE1C1	0x756B
+0xE1C2	0x756D
+0xE1C3	0x7578
+0xE1C4	0x7576
+0xE1C5	0x7586
+0xE1C6	0x7587
+0xE1C7	0x7574
+0xE1C8	0x758A
+0xE1C9	0x7589
+0xE1CA	0x7582
+0xE1CB	0x7594
+0xE1CC	0x759A
+0xE1CD	0x759D
+0xE1CE	0x75A5
+0xE1CF	0x75A3
+0xE1D0	0x75C2
+0xE1D1	0x75B3
+0xE1D2	0x75C3
+0xE1D3	0x75B5
+0xE1D4	0x75BD
+0xE1D5	0x75B8
+0xE1D6	0x75BC
+0xE1D7	0x75B1
+0xE1D8	0x75CD
+0xE1D9	0x75CA
+0xE1DA	0x75D2
+0xE1DB	0x75D9
+0xE1DC	0x75E3
+0xE1DD	0x75DE
+0xE1DE	0x75FE
+0xE1DF	0x75FF
+0xE1E0	0x75FC
+0xE1E1	0x7601
+0xE1E2	0x75F0
+0xE1E3	0x75FA
+0xE1E4	0x75F2
+0xE1E5	0x75F3
+0xE1E6	0x760B
+0xE1E7	0x760D
+0xE1E8	0x7609
+0xE1E9	0x761F
+0xE1EA	0x7627
+0xE1EB	0x7620
+0xE1EC	0x7621
+0xE1ED	0x7622
+0xE1EE	0x7624
+0xE1EF	0x7634
+0xE1F0	0x7630
+0xE1F1	0x763B
+0xE1F2	0x7647
+0xE1F3	0x7648
+0xE1F4	0x7646
+0xE1F5	0x765C
+0xE1F6	0x7658
+0xE1F7	0x7661
+0xE1F8	0x7662
+0xE1F9	0x7668
+0xE1FA	0x7669
+0xE1FB	0x766A
+0xE1FC	0x7667
+0xE1FD	0x766C
+0xE1FE	0x7670
+0xE2A1	0x7672
+0xE2A2	0x7676
+0xE2A3	0x7678
+0xE2A4	0x767C
+0xE2A5	0x7680
+0xE2A6	0x7683
+0xE2A7	0x7688
+0xE2A8	0x768B
+0xE2A9	0x768E
+0xE2AA	0x7696
+0xE2AB	0x7693
+0xE2AC	0x7699
+0xE2AD	0x769A
+0xE2AE	0x76B0
+0xE2AF	0x76B4
+0xE2B0	0x76B8
+0xE2B1	0x76B9
+0xE2B2	0x76BA
+0xE2B3	0x76C2
+0xE2B4	0x76CD
+0xE2B5	0x76D6
+0xE2B6	0x76D2
+0xE2B7	0x76DE
+0xE2B8	0x76E1
+0xE2B9	0x76E5
+0xE2BA	0x76E7
+0xE2BB	0x76EA
+0xE2BC	0x862F
+0xE2BD	0x76FB
+0xE2BE	0x7708
+0xE2BF	0x7707
+0xE2C0	0x7704
+0xE2C1	0x7729
+0xE2C2	0x7724
+0xE2C3	0x771E
+0xE2C4	0x7725
+0xE2C5	0x7726
+0xE2C6	0x771B
+0xE2C7	0x7737
+0xE2C8	0x7738
+0xE2C9	0x7747
+0xE2CA	0x775A
+0xE2CB	0x7768
+0xE2CC	0x776B
+0xE2CD	0x775B
+0xE2CE	0x7765
+0xE2CF	0x777F
+0xE2D0	0x777E
+0xE2D1	0x7779
+0xE2D2	0x778E
+0xE2D3	0x778B
+0xE2D4	0x7791
+0xE2D5	0x77A0
+0xE2D6	0x779E
+0xE2D7	0x77B0
+0xE2D8	0x77B6
+0xE2D9	0x77B9
+0xE2DA	0x77BF
+0xE2DB	0x77BC
+0xE2DC	0x77BD
+0xE2DD	0x77BB
+0xE2DE	0x77C7
+0xE2DF	0x77CD
+0xE2E0	0x77D7
+0xE2E1	0x77DA
+0xE2E2	0x77DC
+0xE2E3	0x77E3
+0xE2E4	0x77EE
+0xE2E5	0x77FC
+0xE2E6	0x780C
+0xE2E7	0x7812
+0xE2E8	0x7926
+0xE2E9	0x7820
+0xE2EA	0x792A
+0xE2EB	0x7845
+0xE2EC	0x788E
+0xE2ED	0x7874
+0xE2EE	0x7886
+0xE2EF	0x787C
+0xE2F0	0x789A
+0xE2F1	0x788C
+0xE2F2	0x78A3
+0xE2F3	0x78B5
+0xE2F4	0x78AA
+0xE2F5	0x78AF
+0xE2F6	0x78D1
+0xE2F7	0x78C6
+0xE2F8	0x78CB
+0xE2F9	0x78D4
+0xE2FA	0x78BE
+0xE2FB	0x78BC
+0xE2FC	0x78C5
+0xE2FD	0x78CA
+0xE2FE	0x78EC
+0xE3A1	0x78E7
+0xE3A2	0x78DA
+0xE3A3	0x78FD
+0xE3A4	0x78F4
+0xE3A5	0x7907
+0xE3A6	0x7912
+0xE3A7	0x7911
+0xE3A8	0x7919
+0xE3A9	0x792C
+0xE3AA	0x792B
+0xE3AB	0x7940
+0xE3AC	0x7960
+0xE3AD	0x7957
+0xE3AE	0x795F
+0xE3AF	0x795A
+0xE3B0	0x7955
+0xE3B1	0x7953
+0xE3B2	0x797A
+0xE3B3	0x797F
+0xE3B4	0x798A
+0xE3B5	0x799D
+0xE3B6	0x79A7
+0xE3B7	0x9F4B
+0xE3B8	0x79AA
+0xE3B9	0x79AE
+0xE3BA	0x79B3
+0xE3BB	0x79B9
+0xE3BC	0x79BA
+0xE3BD	0x79C9
+0xE3BE	0x79D5
+0xE3BF	0x79E7
+0xE3C0	0x79EC
+0xE3C1	0x79E1
+0xE3C2	0x79E3
+0xE3C3	0x7A08
+0xE3C4	0x7A0D
+0xE3C5	0x7A18
+0xE3C6	0x7A19
+0xE3C7	0x7A20
+0xE3C8	0x7A1F
+0xE3C9	0x7980
+0xE3CA	0x7A31
+0xE3CB	0x7A3B
+0xE3CC	0x7A3E
+0xE3CD	0x7A37
+0xE3CE	0x7A43
+0xE3CF	0x7A57
+0xE3D0	0x7A49
+0xE3D1	0x7A61
+0xE3D2	0x7A62
+0xE3D3	0x7A69
+0xE3D4	0x9F9D
+0xE3D5	0x7A70
+0xE3D6	0x7A79
+0xE3D7	0x7A7D
+0xE3D8	0x7A88
+0xE3D9	0x7A97
+0xE3DA	0x7A95
+0xE3DB	0x7A98
+0xE3DC	0x7A96
+0xE3DD	0x7AA9
+0xE3DE	0x7AC8
+0xE3DF	0x7AB0
+0xE3E0	0x7AB6
+0xE3E1	0x7AC5
+0xE3E2	0x7AC4
+0xE3E3	0x7ABF
+0xE3E4	0x9083
+0xE3E5	0x7AC7
+0xE3E6	0x7ACA
+0xE3E7	0x7ACD
+0xE3E8	0x7ACF
+0xE3E9	0x7AD5
+0xE3EA	0x7AD3
+0xE3EB	0x7AD9
+0xE3EC	0x7ADA
+0xE3ED	0x7ADD
+0xE3EE	0x7AE1
+0xE3EF	0x7AE2
+0xE3F0	0x7AE6
+0xE3F1	0x7AED
+0xE3F2	0x7AF0
+0xE3F3	0x7B02
+0xE3F4	0x7B0F
+0xE3F5	0x7B0A
+0xE3F6	0x7B06
+0xE3F7	0x7B33
+0xE3F8	0x7B18
+0xE3F9	0x7B19
+0xE3FA	0x7B1E
+0xE3FB	0x7B35
+0xE3FC	0x7B28
+0xE3FD	0x7B36
+0xE3FE	0x7B50
+0xE4A1	0x7B7A
+0xE4A2	0x7B04
+0xE4A3	0x7B4D
+0xE4A4	0x7B0B
+0xE4A5	0x7B4C
+0xE4A6	0x7B45
+0xE4A7	0x7B75
+0xE4A8	0x7B65
+0xE4A9	0x7B74
+0xE4AA	0x7B67
+0xE4AB	0x7B70
+0xE4AC	0x7B71
+0xE4AD	0x7B6C
+0xE4AE	0x7B6E
+0xE4AF	0x7B9D
+0xE4B0	0x7B98
+0xE4B1	0x7B9F
+0xE4B2	0x7B8D
+0xE4B3	0x7B9C
+0xE4B4	0x7B9A
+0xE4B5	0x7B8B
+0xE4B6	0x7B92
+0xE4B7	0x7B8F
+0xE4B8	0x7B5D
+0xE4B9	0x7B99
+0xE4BA	0x7BCB
+0xE4BB	0x7BC1
+0xE4BC	0x7BCC
+0xE4BD	0x7BCF
+0xE4BE	0x7BB4
+0xE4BF	0x7BC6
+0xE4C0	0x7BDD
+0xE4C1	0x7BE9
+0xE4C2	0x7C11
+0xE4C3	0x7C14
+0xE4C4	0x7BE6
+0xE4C5	0x7BE5
+0xE4C6	0x7C60
+0xE4C7	0x7C00
+0xE4C8	0x7C07
+0xE4C9	0x7C13
+0xE4CA	0x7BF3
+0xE4CB	0x7BF7
+0xE4CC	0x7C17
+0xE4CD	0x7C0D
+0xE4CE	0x7BF6
+0xE4CF	0x7C23
+0xE4D0	0x7C27
+0xE4D1	0x7C2A
+0xE4D2	0x7C1F
+0xE4D3	0x7C37
+0xE4D4	0x7C2B
+0xE4D5	0x7C3D
+0xE4D6	0x7C4C
+0xE4D7	0x7C43
+0xE4D8	0x7C54
+0xE4D9	0x7C4F
+0xE4DA	0x7C40
+0xE4DB	0x7C50
+0xE4DC	0x7C58
+0xE4DD	0x7C5F
+0xE4DE	0x7C64
+0xE4DF	0x7C56
+0xE4E0	0x7C65
+0xE4E1	0x7C6C
+0xE4E2	0x7C75
+0xE4E3	0x7C83
+0xE4E4	0x7C90
+0xE4E5	0x7CA4
+0xE4E6	0x7CAD
+0xE4E7	0x7CA2
+0xE4E8	0x7CAB
+0xE4E9	0x7CA1
+0xE4EA	0x7CA8
+0xE4EB	0x7CB3
+0xE4EC	0x7CB2
+0xE4ED	0x7CB1
+0xE4EE	0x7CAE
+0xE4EF	0x7CB9
+0xE4F0	0x7CBD
+0xE4F1	0x7CC0
+0xE4F2	0x7CC5
+0xE4F3	0x7CC2
+0xE4F4	0x7CD8
+0xE4F5	0x7CD2
+0xE4F6	0x7CDC
+0xE4F7	0x7CE2
+0xE4F8	0x9B3B
+0xE4F9	0x7CEF
+0xE4FA	0x7CF2
+0xE4FB	0x7CF4
+0xE4FC	0x7CF6
+0xE4FD	0x7CFA
+0xE4FE	0x7D06
+0xE5A1	0x7D02
+0xE5A2	0x7D1C
+0xE5A3	0x7D15
+0xE5A4	0x7D0A
+0xE5A5	0x7D45
+0xE5A6	0x7D4B
+0xE5A7	0x7D2E
+0xE5A8	0x7D32
+0xE5A9	0x7D3F
+0xE5AA	0x7D35
+0xE5AB	0x7D46
+0xE5AC	0x7D73
+0xE5AD	0x7D56
+0xE5AE	0x7D4E
+0xE5AF	0x7D72
+0xE5B0	0x7D68
+0xE5B1	0x7D6E
+0xE5B2	0x7D4F
+0xE5B3	0x7D63
+0xE5B4	0x7D93
+0xE5B5	0x7D89
+0xE5B6	0x7D5B
+0xE5B7	0x7D8F
+0xE5B8	0x7D7D
+0xE5B9	0x7D9B
+0xE5BA	0x7DBA
+0xE5BB	0x7DAE
+0xE5BC	0x7DA3
+0xE5BD	0x7DB5
+0xE5BE	0x7DC7
+0xE5BF	0x7DBD
+0xE5C0	0x7DAB
+0xE5C1	0x7E3D
+0xE5C2	0x7DA2
+0xE5C3	0x7DAF
+0xE5C4	0x7DDC
+0xE5C5	0x7DB8
+0xE5C6	0x7D9F
+0xE5C7	0x7DB0
+0xE5C8	0x7DD8
+0xE5C9	0x7DDD
+0xE5CA	0x7DE4
+0xE5CB	0x7DDE
+0xE5CC	0x7DFB
+0xE5CD	0x7DF2
+0xE5CE	0x7DE1
+0xE5CF	0x7E05
+0xE5D0	0x7E0A
+0xE5D1	0x7E23
+0xE5D2	0x7E21
+0xE5D3	0x7E12
+0xE5D4	0x7E31
+0xE5D5	0x7E1F
+0xE5D6	0x7E09
+0xE5D7	0x7E0B
+0xE5D8	0x7E22
+0xE5D9	0x7E46
+0xE5DA	0x7E66
+0xE5DB	0x7E3B
+0xE5DC	0x7E35
+0xE5DD	0x7E39
+0xE5DE	0x7E43
+0xE5DF	0x7E37
+0xE5E0	0x7E32
+0xE5E1	0x7E3A
+0xE5E2	0x7E67
+0xE5E3	0x7E5D
+0xE5E4	0x7E56
+0xE5E5	0x7E5E
+0xE5E6	0x7E59
+0xE5E7	0x7E5A
+0xE5E8	0x7E79
+0xE5E9	0x7E6A
+0xE5EA	0x7E69
+0xE5EB	0x7E7C
+0xE5EC	0x7E7B
+0xE5ED	0x7E83
+0xE5EE	0x7DD5
+0xE5EF	0x7E7D
+0xE5F0	0x8FAE
+0xE5F1	0x7E7F
+0xE5F2	0x7E88
+0xE5F3	0x7E89
+0xE5F4	0x7E8C
+0xE5F5	0x7E92
+0xE5F6	0x7E90
+0xE5F7	0x7E93
+0xE5F8	0x7E94
+0xE5F9	0x7E96
+0xE5FA	0x7E8E
+0xE5FB	0x7E9B
+0xE5FC	0x7E9C
+0xE5FD	0x7F38
+0xE5FE	0x7F3A
+0xE6A1	0x7F45
+0xE6A2	0x7F4C
+0xE6A3	0x7F4D
+0xE6A4	0x7F4E
+0xE6A5	0x7F50
+0xE6A6	0x7F51
+0xE6A7	0x7F55
+0xE6A8	0x7F54
+0xE6A9	0x7F58
+0xE6AA	0x7F5F
+0xE6AB	0x7F60
+0xE6AC	0x7F68
+0xE6AD	0x7F69
+0xE6AE	0x7F67
+0xE6AF	0x7F78
+0xE6B0	0x7F82
+0xE6B1	0x7F86
+0xE6B2	0x7F83
+0xE6B3	0x7F88
+0xE6B4	0x7F87
+0xE6B5	0x7F8C
+0xE6B6	0x7F94
+0xE6B7	0x7F9E
+0xE6B8	0x7F9D
+0xE6B9	0x7F9A
+0xE6BA	0x7FA3
+0xE6BB	0x7FAF
+0xE6BC	0x7FB2
+0xE6BD	0x7FB9
+0xE6BE	0x7FAE
+0xE6BF	0x7FB6
+0xE6C0	0x7FB8
+0xE6C1	0x8B71
+0xE6C2	0x7FC5
+0xE6C3	0x7FC6
+0xE6C4	0x7FCA
+0xE6C5	0x7FD5
+0xE6C6	0x7FD4
+0xE6C7	0x7FE1
+0xE6C8	0x7FE6
+0xE6C9	0x7FE9
+0xE6CA	0x7FF3
+0xE6CB	0x7FF9
+0xE6CC	0x98DC
+0xE6CD	0x8006
+0xE6CE	0x8004
+0xE6CF	0x800B
+0xE6D0	0x8012
+0xE6D1	0x8018
+0xE6D2	0x8019
+0xE6D3	0x801C
+0xE6D4	0x8021
+0xE6D5	0x8028
+0xE6D6	0x803F
+0xE6D7	0x803B
+0xE6D8	0x804A
+0xE6D9	0x8046
+0xE6DA	0x8052
+0xE6DB	0x8058
+0xE6DC	0x805A
+0xE6DD	0x805F
+0xE6DE	0x8062
+0xE6DF	0x8068
+0xE6E0	0x8073
+0xE6E1	0x8072
+0xE6E2	0x8070
+0xE6E3	0x8076
+0xE6E4	0x8079
+0xE6E5	0x807D
+0xE6E6	0x807F
+0xE6E7	0x8084
+0xE6E8	0x8086
+0xE6E9	0x8085
+0xE6EA	0x809B
+0xE6EB	0x8093
+0xE6EC	0x809A
+0xE6ED	0x80AD
+0xE6EE	0x5190
+0xE6EF	0x80AC
+0xE6F0	0x80DB
+0xE6F1	0x80E5
+0xE6F2	0x80D9
+0xE6F3	0x80DD
+0xE6F4	0x80C4
+0xE6F5	0x80DA
+0xE6F6	0x80D6
+0xE6F7	0x8109
+0xE6F8	0x80EF
+0xE6F9	0x80F1
+0xE6FA	0x811B
+0xE6FB	0x8129
+0xE6FC	0x8123
+0xE6FD	0x812F
+0xE6FE	0x814B
+0xE7A1	0x968B
+0xE7A2	0x8146
+0xE7A3	0x813E
+0xE7A4	0x8153
+0xE7A5	0x8151
+0xE7A6	0x80FC
+0xE7A7	0x8171
+0xE7A8	0x816E
+0xE7A9	0x8165
+0xE7AA	0x8166
+0xE7AB	0x8174
+0xE7AC	0x8183
+0xE7AD	0x8188
+0xE7AE	0x818A
+0xE7AF	0x8180
+0xE7B0	0x8182
+0xE7B1	0x81A0
+0xE7B2	0x8195
+0xE7B3	0x81A4
+0xE7B4	0x81A3
+0xE7B5	0x815F
+0xE7B6	0x8193
+0xE7B7	0x81A9
+0xE7B8	0x81B0
+0xE7B9	0x81B5
+0xE7BA	0x81BE
+0xE7BB	0x81B8
+0xE7BC	0x81BD
+0xE7BD	0x81C0
+0xE7BE	0x81C2
+0xE7BF	0x81BA
+0xE7C0	0x81C9
+0xE7C1	0x81CD
+0xE7C2	0x81D1
+0xE7C3	0x81D9
+0xE7C4	0x81D8
+0xE7C5	0x81C8
+0xE7C6	0x81DA
+0xE7C7	0x81DF
+0xE7C8	0x81E0
+0xE7C9	0x81E7
+0xE7CA	0x81FA
+0xE7CB	0x81FB
+0xE7CC	0x81FE
+0xE7CD	0x8201
+0xE7CE	0x8202
+0xE7CF	0x8205
+0xE7D0	0x8207
+0xE7D1	0x820A
+0xE7D2	0x820D
+0xE7D3	0x8210
+0xE7D4	0x8216
+0xE7D5	0x8229
+0xE7D6	0x822B
+0xE7D7	0x8238
+0xE7D8	0x8233
+0xE7D9	0x8240
+0xE7DA	0x8259
+0xE7DB	0x8258
+0xE7DC	0x825D
+0xE7DD	0x825A
+0xE7DE	0x825F
+0xE7DF	0x8264
+0xE7E0	0x8262
+0xE7E1	0x8268
+0xE7E2	0x826A
+0xE7E3	0x826B
+0xE7E4	0x822E
+0xE7E5	0x8271
+0xE7E6	0x8277
+0xE7E7	0x8278
+0xE7E8	0x827E
+0xE7E9	0x828D
+0xE7EA	0x8292
+0xE7EB	0x82AB
+0xE7EC	0x829F
+0xE7ED	0x82BB
+0xE7EE	0x82AC
+0xE7EF	0x82E1
+0xE7F0	0x82E3
+0xE7F1	0x82DF
+0xE7F2	0x82D2
+0xE7F3	0x82F4
+0xE7F4	0x82F3
+0xE7F5	0x82FA
+0xE7F6	0x8393
+0xE7F7	0x8303
+0xE7F8	0x82FB
+0xE7F9	0x82F9
+0xE7FA	0x82DE
+0xE7FB	0x8306
+0xE7FC	0x82DC
+0xE7FD	0x8309
+0xE7FE	0x82D9
+0xE8A1	0x8335
+0xE8A2	0x8334
+0xE8A3	0x8316
+0xE8A4	0x8332
+0xE8A5	0x8331
+0xE8A6	0x8340
+0xE8A7	0x8339
+0xE8A8	0x8350
+0xE8A9	0x8345
+0xE8AA	0x832F
+0xE8AB	0x832B
+0xE8AC	0x8317
+0xE8AD	0x8318
+0xE8AE	0x8385
+0xE8AF	0x839A
+0xE8B0	0x83AA
+0xE8B1	0x839F
+0xE8B2	0x83A2
+0xE8B3	0x8396
+0xE8B4	0x8323
+0xE8B5	0x838E
+0xE8B6	0x8387
+0xE8B7	0x838A
+0xE8B8	0x837C
+0xE8B9	0x83B5
+0xE8BA	0x8373
+0xE8BB	0x8375
+0xE8BC	0x83A0
+0xE8BD	0x8389
+0xE8BE	0x83A8
+0xE8BF	0x83F4
+0xE8C0	0x8413
+0xE8C1	0x83EB
+0xE8C2	0x83CE
+0xE8C3	0x83FD
+0xE8C4	0x8403
+0xE8C5	0x83D8
+0xE8C6	0x840B
+0xE8C7	0x83C1
+0xE8C8	0x83F7
+0xE8C9	0x8407
+0xE8CA	0x83E0
+0xE8CB	0x83F2
+0xE8CC	0x840D
+0xE8CD	0x8422
+0xE8CE	0x8420
+0xE8CF	0x83BD
+0xE8D0	0x8438
+0xE8D1	0x8506
+0xE8D2	0x83FB
+0xE8D3	0x846D
+0xE8D4	0x842A
+0xE8D5	0x843C
+0xE8D6	0x855A
+0xE8D7	0x8484
+0xE8D8	0x8477
+0xE8D9	0x846B
+0xE8DA	0x84AD
+0xE8DB	0x846E
+0xE8DC	0x8482
+0xE8DD	0x8469
+0xE8DE	0x8446
+0xE8DF	0x842C
+0xE8E0	0x846F
+0xE8E1	0x8479
+0xE8E2	0x8435
+0xE8E3	0x84CA
+0xE8E4	0x8462
+0xE8E5	0x84B9
+0xE8E6	0x84BF
+0xE8E7	0x849F
+0xE8E8	0x84D9
+0xE8E9	0x84CD
+0xE8EA	0x84BB
+0xE8EB	0x84DA
+0xE8EC	0x84D0
+0xE8ED	0x84C1
+0xE8EE	0x84C6
+0xE8EF	0x84D6
+0xE8F0	0x84A1
+0xE8F1	0x8521
+0xE8F2	0x84FF
+0xE8F3	0x84F4
+0xE8F4	0x8517
+0xE8F5	0x8518
+0xE8F6	0x852C
+0xE8F7	0x851F
+0xE8F8	0x8515
+0xE8F9	0x8514
+0xE8FA	0x84FC
+0xE8FB	0x8540
+0xE8FC	0x8563
+0xE8FD	0x8558
+0xE8FE	0x8548
+0xE9A1	0x8541
+0xE9A2	0x8602
+0xE9A3	0x854B
+0xE9A4	0x8555
+0xE9A5	0x8580
+0xE9A6	0x85A4
+0xE9A7	0x8588
+0xE9A8	0x8591
+0xE9A9	0x858A
+0xE9AA	0x85A8
+0xE9AB	0x856D
+0xE9AC	0x8594
+0xE9AD	0x859B
+0xE9AE	0x85EA
+0xE9AF	0x8587
+0xE9B0	0x859C
+0xE9B1	0x8577
+0xE9B2	0x857E
+0xE9B3	0x8590
+0xE9B4	0x85C9
+0xE9B5	0x85BA
+0xE9B6	0x85CF
+0xE9B7	0x85B9
+0xE9B8	0x85D0
+0xE9B9	0x85D5
+0xE9BA	0x85DD
+0xE9BB	0x85E5
+0xE9BC	0x85DC
+0xE9BD	0x85F9
+0xE9BE	0x860A
+0xE9BF	0x8613
+0xE9C0	0x860B
+0xE9C1	0x85FE
+0xE9C2	0x85FA
+0xE9C3	0x8606
+0xE9C4	0x8622
+0xE9C5	0x861A
+0xE9C6	0x8630
+0xE9C7	0x863F
+0xE9C8	0x864D
+0xE9C9	0x4E55
+0xE9CA	0x8654
+0xE9CB	0x865F
+0xE9CC	0x8667
+0xE9CD	0x8671
+0xE9CE	0x8693
+0xE9CF	0x86A3
+0xE9D0	0x86A9
+0xE9D1	0x86AA
+0xE9D2	0x868B
+0xE9D3	0x868C
+0xE9D4	0x86B6
+0xE9D5	0x86AF
+0xE9D6	0x86C4
+0xE9D7	0x86C6
+0xE9D8	0x86B0
+0xE9D9	0x86C9
+0xE9DA	0x8823
+0xE9DB	0x86AB
+0xE9DC	0x86D4
+0xE9DD	0x86DE
+0xE9DE	0x86E9
+0xE9DF	0x86EC
+0xE9E0	0x86DF
+0xE9E1	0x86DB
+0xE9E2	0x86EF
+0xE9E3	0x8712
+0xE9E4	0x8706
+0xE9E5	0x8708
+0xE9E6	0x8700
+0xE9E7	0x8703
+0xE9E8	0x86FB
+0xE9E9	0x8711
+0xE9EA	0x8709
+0xE9EB	0x870D
+0xE9EC	0x86F9
+0xE9ED	0x870A
+0xE9EE	0x8734
+0xE9EF	0x873F
+0xE9F0	0x8737
+0xE9F1	0x873B
+0xE9F2	0x8725
+0xE9F3	0x8729
+0xE9F4	0x871A
+0xE9F5	0x8760
+0xE9F6	0x875F
+0xE9F7	0x8778
+0xE9F8	0x874C
+0xE9F9	0x874E
+0xE9FA	0x8774
+0xE9FB	0x8757
+0xE9FC	0x8768
+0xE9FD	0x876E
+0xE9FE	0x8759
+0xEAA1	0x8753
+0xEAA2	0x8763
+0xEAA3	0x876A
+0xEAA4	0x8805
+0xEAA5	0x87A2
+0xEAA6	0x879F
+0xEAA7	0x8782
+0xEAA8	0x87AF
+0xEAA9	0x87CB
+0xEAAA	0x87BD
+0xEAAB	0x87C0
+0xEAAC	0x87D0
+0xEAAD	0x96D6
+0xEAAE	0x87AB
+0xEAAF	0x87C4
+0xEAB0	0x87B3
+0xEAB1	0x87C7
+0xEAB2	0x87C6
+0xEAB3	0x87BB
+0xEAB4	0x87EF
+0xEAB5	0x87F2
+0xEAB6	0x87E0
+0xEAB7	0x880F
+0xEAB8	0x880D
+0xEAB9	0x87FE
+0xEABA	0x87F6
+0xEABB	0x87F7
+0xEABC	0x880E
+0xEABD	0x87D2
+0xEABE	0x8811
+0xEABF	0x8816
+0xEAC0	0x8815
+0xEAC1	0x8822
+0xEAC2	0x8821
+0xEAC3	0x8831
+0xEAC4	0x8836
+0xEAC5	0x8839
+0xEAC6	0x8827
+0xEAC7	0x883B
+0xEAC8	0x8844
+0xEAC9	0x8842
+0xEACA	0x8852
+0xEACB	0x8859
+0xEACC	0x885E
+0xEACD	0x8862
+0xEACE	0x886B
+0xEACF	0x8881
+0xEAD0	0x887E
+0xEAD1	0x889E
+0xEAD2	0x8875
+0xEAD3	0x887D
+0xEAD4	0x88B5
+0xEAD5	0x8872
+0xEAD6	0x8882
+0xEAD7	0x8897
+0xEAD8	0x8892
+0xEAD9	0x88AE
+0xEADA	0x8899
+0xEADB	0x88A2
+0xEADC	0x888D
+0xEADD	0x88A4
+0xEADE	0x88B0
+0xEADF	0x88BF
+0xEAE0	0x88B1
+0xEAE1	0x88C3
+0xEAE2	0x88C4
+0xEAE3	0x88D4
+0xEAE4	0x88D8
+0xEAE5	0x88D9
+0xEAE6	0x88DD
+0xEAE7	0x88F9
+0xEAE8	0x8902
+0xEAE9	0x88FC
+0xEAEA	0x88F4
+0xEAEB	0x88E8
+0xEAEC	0x88F2
+0xEAED	0x8904
+0xEAEE	0x890C
+0xEAEF	0x890A
+0xEAF0	0x8913
+0xEAF1	0x8943
+0xEAF2	0x891E
+0xEAF3	0x8925
+0xEAF4	0x892A
+0xEAF5	0x892B
+0xEAF6	0x8941
+0xEAF7	0x8944
+0xEAF8	0x893B
+0xEAF9	0x8936
+0xEAFA	0x8938
+0xEAFB	0x894C
+0xEAFC	0x891D
+0xEAFD	0x8960
+0xEAFE	0x895E
+0xEBA1	0x8966
+0xEBA2	0x8964
+0xEBA3	0x896D
+0xEBA4	0x896A
+0xEBA5	0x896F
+0xEBA6	0x8974
+0xEBA7	0x8977
+0xEBA8	0x897E
+0xEBA9	0x8983
+0xEBAA	0x8988
+0xEBAB	0x898A
+0xEBAC	0x8993
+0xEBAD	0x8998
+0xEBAE	0x89A1
+0xEBAF	0x89A9
+0xEBB0	0x89A6
+0xEBB1	0x89AC
+0xEBB2	0x89AF
+0xEBB3	0x89B2
+0xEBB4	0x89BA
+0xEBB5	0x89BD
+0xEBB6	0x89BF
+0xEBB7	0x89C0
+0xEBB8	0x89DA
+0xEBB9	0x89DC
+0xEBBA	0x89DD
+0xEBBB	0x89E7
+0xEBBC	0x89F4
+0xEBBD	0x89F8
+0xEBBE	0x8A03
+0xEBBF	0x8A16
+0xEBC0	0x8A10
+0xEBC1	0x8A0C
+0xEBC2	0x8A1B
+0xEBC3	0x8A1D
+0xEBC4	0x8A25
+0xEBC5	0x8A36
+0xEBC6	0x8A41
+0xEBC7	0x8A5B
+0xEBC8	0x8A52
+0xEBC9	0x8A46
+0xEBCA	0x8A48
+0xEBCB	0x8A7C
+0xEBCC	0x8A6D
+0xEBCD	0x8A6C
+0xEBCE	0x8A62
+0xEBCF	0x8A85
+0xEBD0	0x8A82
+0xEBD1	0x8A84
+0xEBD2	0x8AA8
+0xEBD3	0x8AA1
+0xEBD4	0x8A91
+0xEBD5	0x8AA5
+0xEBD6	0x8AA6
+0xEBD7	0x8A9A
+0xEBD8	0x8AA3
+0xEBD9	0x8AC4
+0xEBDA	0x8ACD
+0xEBDB	0x8AC2
+0xEBDC	0x8ADA
+0xEBDD	0x8AEB
+0xEBDE	0x8AF3
+0xEBDF	0x8AE7
+0xEBE0	0x8AE4
+0xEBE1	0x8AF1
+0xEBE2	0x8B14
+0xEBE3	0x8AE0
+0xEBE4	0x8AE2
+0xEBE5	0x8AF7
+0xEBE6	0x8ADE
+0xEBE7	0x8ADB
+0xEBE8	0x8B0C
+0xEBE9	0x8B07
+0xEBEA	0x8B1A
+0xEBEB	0x8AE1
+0xEBEC	0x8B16
+0xEBED	0x8B10
+0xEBEE	0x8B17
+0xEBEF	0x8B20
+0xEBF0	0x8B33
+0xEBF1	0x97AB
+0xEBF2	0x8B26
+0xEBF3	0x8B2B
+0xEBF4	0x8B3E
+0xEBF5	0x8B28
+0xEBF6	0x8B41
+0xEBF7	0x8B4C
+0xEBF8	0x8B4F
+0xEBF9	0x8B4E
+0xEBFA	0x8B49
+0xEBFB	0x8B56
+0xEBFC	0x8B5B
+0xEBFD	0x8B5A
+0xEBFE	0x8B6B
+0xECA1	0x8B5F
+0xECA2	0x8B6C
+0xECA3	0x8B6F
+0xECA4	0x8B74
+0xECA5	0x8B7D
+0xECA6	0x8B80
+0xECA7	0x8B8C
+0xECA8	0x8B8E
+0xECA9	0x8B92
+0xECAA	0x8B93
+0xECAB	0x8B96
+0xECAC	0x8B99
+0xECAD	0x8B9A
+0xECAE	0x8C3A
+0xECAF	0x8C41
+0xECB0	0x8C3F
+0xECB1	0x8C48
+0xECB2	0x8C4C
+0xECB3	0x8C4E
+0xECB4	0x8C50
+0xECB5	0x8C55
+0xECB6	0x8C62
+0xECB7	0x8C6C
+0xECB8	0x8C78
+0xECB9	0x8C7A
+0xECBA	0x8C82
+0xECBB	0x8C89
+0xECBC	0x8C85
+0xECBD	0x8C8A
+0xECBE	0x8C8D
+0xECBF	0x8C8E
+0xECC0	0x8C94
+0xECC1	0x8C7C
+0xECC2	0x8C98
+0xECC3	0x621D
+0xECC4	0x8CAD
+0xECC5	0x8CAA
+0xECC6	0x8CBD
+0xECC7	0x8CB2
+0xECC8	0x8CB3
+0xECC9	0x8CAE
+0xECCA	0x8CB6
+0xECCB	0x8CC8
+0xECCC	0x8CC1
+0xECCD	0x8CE4
+0xECCE	0x8CE3
+0xECCF	0x8CDA
+0xECD0	0x8CFD
+0xECD1	0x8CFA
+0xECD2	0x8CFB
+0xECD3	0x8D04
+0xECD4	0x8D05
+0xECD5	0x8D0A
+0xECD6	0x8D07
+0xECD7	0x8D0F
+0xECD8	0x8D0D
+0xECD9	0x8D10
+0xECDA	0x9F4E
+0xECDB	0x8D13
+0xECDC	0x8CCD
+0xECDD	0x8D14
+0xECDE	0x8D16
+0xECDF	0x8D67
+0xECE0	0x8D6D
+0xECE1	0x8D71
+0xECE2	0x8D73
+0xECE3	0x8D81
+0xECE4	0x8D99
+0xECE5	0x8DC2
+0xECE6	0x8DBE
+0xECE7	0x8DBA
+0xECE8	0x8DCF
+0xECE9	0x8DDA
+0xECEA	0x8DD6
+0xECEB	0x8DCC
+0xECEC	0x8DDB
+0xECED	0x8DCB
+0xECEE	0x8DEA
+0xECEF	0x8DEB
+0xECF0	0x8DDF
+0xECF1	0x8DE3
+0xECF2	0x8DFC
+0xECF3	0x8E08
+0xECF4	0x8E09
+0xECF5	0x8DFF
+0xECF6	0x8E1D
+0xECF7	0x8E1E
+0xECF8	0x8E10
+0xECF9	0x8E1F
+0xECFA	0x8E42
+0xECFB	0x8E35
+0xECFC	0x8E30
+0xECFD	0x8E34
+0xECFE	0x8E4A
+0xEDA1	0x8E47
+0xEDA2	0x8E49
+0xEDA3	0x8E4C
+0xEDA4	0x8E50
+0xEDA5	0x8E48
+0xEDA6	0x8E59
+0xEDA7	0x8E64
+0xEDA8	0x8E60
+0xEDA9	0x8E2A
+0xEDAA	0x8E63
+0xEDAB	0x8E55
+0xEDAC	0x8E76
+0xEDAD	0x8E72
+0xEDAE	0x8E7C
+0xEDAF	0x8E81
+0xEDB0	0x8E87
+0xEDB1	0x8E85
+0xEDB2	0x8E84
+0xEDB3	0x8E8B
+0xEDB4	0x8E8A
+0xEDB5	0x8E93
+0xEDB6	0x8E91
+0xEDB7	0x8E94
+0xEDB8	0x8E99
+0xEDB9	0x8EAA
+0xEDBA	0x8EA1
+0xEDBB	0x8EAC
+0xEDBC	0x8EB0
+0xEDBD	0x8EC6
+0xEDBE	0x8EB1
+0xEDBF	0x8EBE
+0xEDC0	0x8EC5
+0xEDC1	0x8EC8
+0xEDC2	0x8ECB
+0xEDC3	0x8EDB
+0xEDC4	0x8EE3
+0xEDC5	0x8EFC
+0xEDC6	0x8EFB
+0xEDC7	0x8EEB
+0xEDC8	0x8EFE
+0xEDC9	0x8F0A
+0xEDCA	0x8F05
+0xEDCB	0x8F15
+0xEDCC	0x8F12
+0xEDCD	0x8F19
+0xEDCE	0x8F13
+0xEDCF	0x8F1C
+0xEDD0	0x8F1F
+0xEDD1	0x8F1B
+0xEDD2	0x8F0C
+0xEDD3	0x8F26
+0xEDD4	0x8F33
+0xEDD5	0x8F3B
+0xEDD6	0x8F39
+0xEDD7	0x8F45
+0xEDD8	0x8F42
+0xEDD9	0x8F3E
+0xEDDA	0x8F4C
+0xEDDB	0x8F49
+0xEDDC	0x8F46
+0xEDDD	0x8F4E
+0xEDDE	0x8F57
+0xEDDF	0x8F5C
+0xEDE0	0x8F62
+0xEDE1	0x8F63
+0xEDE2	0x8F64
+0xEDE3	0x8F9C
+0xEDE4	0x8F9F
+0xEDE5	0x8FA3
+0xEDE6	0x8FAD
+0xEDE7	0x8FAF
+0xEDE8	0x8FB7
+0xEDE9	0x8FDA
+0xEDEA	0x8FE5
+0xEDEB	0x8FE2
+0xEDEC	0x8FEA
+0xEDED	0x8FEF
+0xEDEE	0x9087
+0xEDEF	0x8FF4
+0xEDF0	0x9005
+0xEDF1	0x8FF9
+0xEDF2	0x8FFA
+0xEDF3	0x9011
+0xEDF4	0x9015
+0xEDF5	0x9021
+0xEDF6	0x900D
+0xEDF7	0x901E
+0xEDF8	0x9016
+0xEDF9	0x900B
+0xEDFA	0x9027
+0xEDFB	0x9036
+0xEDFC	0x9035
+0xEDFD	0x9039
+0xEDFE	0x8FF8
+0xEEA1	0x904F
+0xEEA2	0x9050
+0xEEA3	0x9051
+0xEEA4	0x9052
+0xEEA5	0x900E
+0xEEA6	0x9049
+0xEEA7	0x903E
+0xEEA8	0x9056
+0xEEA9	0x9058
+0xEEAA	0x905E
+0xEEAB	0x9068
+0xEEAC	0x906F
+0xEEAD	0x9076
+0xEEAE	0x96A8
+0xEEAF	0x9072
+0xEEB0	0x9082
+0xEEB1	0x907D
+0xEEB2	0x9081
+0xEEB3	0x9080
+0xEEB4	0x908A
+0xEEB5	0x9089
+0xEEB6	0x908F
+0xEEB7	0x90A8
+0xEEB8	0x90AF
+0xEEB9	0x90B1
+0xEEBA	0x90B5
+0xEEBB	0x90E2
+0xEEBC	0x90E4
+0xEEBD	0x6248
+0xEEBE	0x90DB
+0xEEBF	0x9102
+0xEEC0	0x9112
+0xEEC1	0x9119
+0xEEC2	0x9132
+0xEEC3	0x9130
+0xEEC4	0x914A
+0xEEC5	0x9156
+0xEEC6	0x9158
+0xEEC7	0x9163
+0xEEC8	0x9165
+0xEEC9	0x9169
+0xEECA	0x9173
+0xEECB	0x9172
+0xEECC	0x918B
+0xEECD	0x9189
+0xEECE	0x9182
+0xEECF	0x91A2
+0xEED0	0x91AB
+0xEED1	0x91AF
+0xEED2	0x91AA
+0xEED3	0x91B5
+0xEED4	0x91B4
+0xEED5	0x91BA
+0xEED6	0x91C0
+0xEED7	0x91C1
+0xEED8	0x91C9
+0xEED9	0x91CB
+0xEEDA	0x91D0
+0xEEDB	0x91D6
+0xEEDC	0x91DF
+0xEEDD	0x91E1
+0xEEDE	0x91DB
+0xEEDF	0x91FC
+0xEEE0	0x91F5
+0xEEE1	0x91F6
+0xEEE2	0x921E
+0xEEE3	0x91FF
+0xEEE4	0x9214
+0xEEE5	0x922C
+0xEEE6	0x9215
+0xEEE7	0x9211
+0xEEE8	0x925E
+0xEEE9	0x9257
+0xEEEA	0x9245
+0xEEEB	0x9249
+0xEEEC	0x9264
+0xEEED	0x9248
+0xEEEE	0x9295
+0xEEEF	0x923F
+0xEEF0	0x924B
+0xEEF1	0x9250
+0xEEF2	0x929C
+0xEEF3	0x9296
+0xEEF4	0x9293
+0xEEF5	0x929B
+0xEEF6	0x925A
+0xEEF7	0x92CF
+0xEEF8	0x92B9
+0xEEF9	0x92B7
+0xEEFA	0x92E9
+0xEEFB	0x930F
+0xEEFC	0x92FA
+0xEEFD	0x9344
+0xEEFE	0x932E
+0xEFA1	0x9319
+0xEFA2	0x9322
+0xEFA3	0x931A
+0xEFA4	0x9323
+0xEFA5	0x933A
+0xEFA6	0x9335
+0xEFA7	0x933B
+0xEFA8	0x935C
+0xEFA9	0x9360
+0xEFAA	0x937C
+0xEFAB	0x936E
+0xEFAC	0x9356
+0xEFAD	0x93B0
+0xEFAE	0x93AC
+0xEFAF	0x93AD
+0xEFB0	0x9394
+0xEFB1	0x93B9
+0xEFB2	0x93D6
+0xEFB3	0x93D7
+0xEFB4	0x93E8
+0xEFB5	0x93E5
+0xEFB6	0x93D8
+0xEFB7	0x93C3
+0xEFB8	0x93DD
+0xEFB9	0x93D0
+0xEFBA	0x93C8
+0xEFBB	0x93E4
+0xEFBC	0x941A
+0xEFBD	0x9414
+0xEFBE	0x9413
+0xEFBF	0x9403
+0xEFC0	0x9407
+0xEFC1	0x9410
+0xEFC2	0x9436
+0xEFC3	0x942B
+0xEFC4	0x9435
+0xEFC5	0x9421
+0xEFC6	0x943A
+0xEFC7	0x9441
+0xEFC8	0x9452
+0xEFC9	0x9444
+0xEFCA	0x945B
+0xEFCB	0x9460
+0xEFCC	0x9462
+0xEFCD	0x945E
+0xEFCE	0x946A
+0xEFCF	0x9229
+0xEFD0	0x9470
+0xEFD1	0x9475
+0xEFD2	0x9477
+0xEFD3	0x947D
+0xEFD4	0x945A
+0xEFD5	0x947C
+0xEFD6	0x947E
+0xEFD7	0x9481
+0xEFD8	0x947F
+0xEFD9	0x9582
+0xEFDA	0x9587
+0xEFDB	0x958A
+0xEFDC	0x9594
+0xEFDD	0x9596
+0xEFDE	0x9598
+0xEFDF	0x9599
+0xEFE0	0x95A0
+0xEFE1	0x95A8
+0xEFE2	0x95A7
+0xEFE3	0x95AD
+0xEFE4	0x95BC
+0xEFE5	0x95BB
+0xEFE6	0x95B9
+0xEFE7	0x95BE
+0xEFE8	0x95CA
+0xEFE9	0x6FF6
+0xEFEA	0x95C3
+0xEFEB	0x95CD
+0xEFEC	0x95CC
+0xEFED	0x95D5
+0xEFEE	0x95D4
+0xEFEF	0x95D6
+0xEFF0	0x95DC
+0xEFF1	0x95E1
+0xEFF2	0x95E5
+0xEFF3	0x95E2
+0xEFF4	0x9621
+0xEFF5	0x9628
+0xEFF6	0x962E
+0xEFF7	0x962F
+0xEFF8	0x9642
+0xEFF9	0x964C
+0xEFFA	0x964F
+0xEFFB	0x964B
+0xEFFC	0x9677
+0xEFFD	0x965C
+0xEFFE	0x965E
+0xF0A1	0x965D
+0xF0A2	0x965F
+0xF0A3	0x9666
+0xF0A4	0x9672
+0xF0A5	0x966C
+0xF0A6	0x968D
+0xF0A7	0x9698
+0xF0A8	0x9695
+0xF0A9	0x9697
+0xF0AA	0x96AA
+0xF0AB	0x96A7
+0xF0AC	0x96B1
+0xF0AD	0x96B2
+0xF0AE	0x96B0
+0xF0AF	0x96B4
+0xF0B0	0x96B6
+0xF0B1	0x96B8
+0xF0B2	0x96B9
+0xF0B3	0x96CE
+0xF0B4	0x96CB
+0xF0B5	0x96C9
+0xF0B6	0x96CD
+0xF0B7	0x894D
+0xF0B8	0x96DC
+0xF0B9	0x970D
+0xF0BA	0x96D5
+0xF0BB	0x96F9
+0xF0BC	0x9704
+0xF0BD	0x9706
+0xF0BE	0x9708
+0xF0BF	0x9713
+0xF0C0	0x970E
+0xF0C1	0x9711
+0xF0C2	0x970F
+0xF0C3	0x9716
+0xF0C4	0x9719
+0xF0C5	0x9724
+0xF0C6	0x972A
+0xF0C7	0x9730
+0xF0C8	0x9739
+0xF0C9	0x973D
+0xF0CA	0x973E
+0xF0CB	0x9744
+0xF0CC	0x9746
+0xF0CD	0x9748
+0xF0CE	0x9742
+0xF0CF	0x9749
+0xF0D0	0x975C
+0xF0D1	0x9760
+0xF0D2	0x9764
+0xF0D3	0x9766
+0xF0D4	0x9768
+0xF0D5	0x52D2
+0xF0D6	0x976B
+0xF0D7	0x9771
+0xF0D8	0x9779
+0xF0D9	0x9785
+0xF0DA	0x977C
+0xF0DB	0x9781
+0xF0DC	0x977A
+0xF0DD	0x9786
+0xF0DE	0x978B
+0xF0DF	0x978F
+0xF0E0	0x9790
+0xF0E1	0x979C
+0xF0E2	0x97A8
+0xF0E3	0x97A6
+0xF0E4	0x97A3
+0xF0E5	0x97B3
+0xF0E6	0x97B4
+0xF0E7	0x97C3
+0xF0E8	0x97C6
+0xF0E9	0x97C8
+0xF0EA	0x97CB
+0xF0EB	0x97DC
+0xF0EC	0x97ED
+0xF0ED	0x9F4F
+0xF0EE	0x97F2
+0xF0EF	0x7ADF
+0xF0F0	0x97F6
+0xF0F1	0x97F5
+0xF0F2	0x980F
+0xF0F3	0x980C
+0xF0F4	0x9838
+0xF0F5	0x9824
+0xF0F6	0x9821
+0xF0F7	0x9837
+0xF0F8	0x983D
+0xF0F9	0x9846
+0xF0FA	0x984F
+0xF0FB	0x984B
+0xF0FC	0x986B
+0xF0FD	0x986F
+0xF0FE	0x9870
+0xF1A1	0x9871
+0xF1A2	0x9874
+0xF1A3	0x9873
+0xF1A4	0x98AA
+0xF1A5	0x98AF
+0xF1A6	0x98B1
+0xF1A7	0x98B6
+0xF1A8	0x98C4
+0xF1A9	0x98C3
+0xF1AA	0x98C6
+0xF1AB	0x98E9
+0xF1AC	0x98EB
+0xF1AD	0x9903
+0xF1AE	0x9909
+0xF1AF	0x9912
+0xF1B0	0x9914
+0xF1B1	0x9918
+0xF1B2	0x9921
+0xF1B3	0x991D
+0xF1B4	0x991E
+0xF1B5	0x9924
+0xF1B6	0x9920
+0xF1B7	0x992C
+0xF1B8	0x992E
+0xF1B9	0x993D
+0xF1BA	0x993E
+0xF1BB	0x9942
+0xF1BC	0x9949
+0xF1BD	0x9945
+0xF1BE	0x9950
+0xF1BF	0x994B
+0xF1C0	0x9951
+0xF1C1	0x9952
+0xF1C2	0x994C
+0xF1C3	0x9955
+0xF1C4	0x9997
+0xF1C5	0x9998
+0xF1C6	0x99A5
+0xF1C7	0x99AD
+0xF1C8	0x99AE
+0xF1C9	0x99BC
+0xF1CA	0x99DF
+0xF1CB	0x99DB
+0xF1CC	0x99DD
+0xF1CD	0x99D8
+0xF1CE	0x99D1
+0xF1CF	0x99ED
+0xF1D0	0x99EE
+0xF1D1	0x99F1
+0xF1D2	0x99F2
+0xF1D3	0x99FB
+0xF1D4	0x99F8
+0xF1D5	0x9A01
+0xF1D6	0x9A0F
+0xF1D7	0x9A05
+0xF1D8	0x99E2
+0xF1D9	0x9A19
+0xF1DA	0x9A2B
+0xF1DB	0x9A37
+0xF1DC	0x9A45
+0xF1DD	0x9A42
+0xF1DE	0x9A40
+0xF1DF	0x9A43
+0xF1E0	0x9A3E
+0xF1E1	0x9A55
+0xF1E2	0x9A4D
+0xF1E3	0x9A5B
+0xF1E4	0x9A57
+0xF1E5	0x9A5F
+0xF1E6	0x9A62
+0xF1E7	0x9A65
+0xF1E8	0x9A64
+0xF1E9	0x9A69
+0xF1EA	0x9A6B
+0xF1EB	0x9A6A
+0xF1EC	0x9AAD
+0xF1ED	0x9AB0
+0xF1EE	0x9ABC
+0xF1EF	0x9AC0
+0xF1F0	0x9ACF
+0xF1F1	0x9AD1
+0xF1F2	0x9AD3
+0xF1F3	0x9AD4
+0xF1F4	0x9ADE
+0xF1F5	0x9ADF
+0xF1F6	0x9AE2
+0xF1F7	0x9AE3
+0xF1F8	0x9AE6
+0xF1F9	0x9AEF
+0xF1FA	0x9AEB
+0xF1FB	0x9AEE
+0xF1FC	0x9AF4
+0xF1FD	0x9AF1
+0xF1FE	0x9AF7
+0xF2A1	0x9AFB
+0xF2A2	0x9B06
+0xF2A3	0x9B18
+0xF2A4	0x9B1A
+0xF2A5	0x9B1F
+0xF2A6	0x9B22
+0xF2A7	0x9B23
+0xF2A8	0x9B25
+0xF2A9	0x9B27
+0xF2AA	0x9B28
+0xF2AB	0x9B29
+0xF2AC	0x9B2A
+0xF2AD	0x9B2E
+0xF2AE	0x9B2F
+0xF2AF	0x9B32
+0xF2B0	0x9B44
+0xF2B1	0x9B43
+0xF2B2	0x9B4F
+0xF2B3	0x9B4D
+0xF2B4	0x9B4E
+0xF2B5	0x9B51
+0xF2B6	0x9B58
+0xF2B7	0x9B74
+0xF2B8	0x9B93
+0xF2B9	0x9B83
+0xF2BA	0x9B91
+0xF2BB	0x9B96
+0xF2BC	0x9B97
+0xF2BD	0x9B9F
+0xF2BE	0x9BA0
+0xF2BF	0x9BA8
+0xF2C0	0x9BB4
+0xF2C1	0x9BC0
+0xF2C2	0x9BCA
+0xF2C3	0x9BB9
+0xF2C4	0x9BC6
+0xF2C5	0x9BCF
+0xF2C6	0x9BD1
+0xF2C7	0x9BD2
+0xF2C8	0x9BE3
+0xF2C9	0x9BE2
+0xF2CA	0x9BE4
+0xF2CB	0x9BD4
+0xF2CC	0x9BE1
+0xF2CD	0x9C3A
+0xF2CE	0x9BF2
+0xF2CF	0x9BF1
+0xF2D0	0x9BF0
+0xF2D1	0x9C15
+0xF2D2	0x9C14
+0xF2D3	0x9C09
+0xF2D4	0x9C13
+0xF2D5	0x9C0C
+0xF2D6	0x9C06
+0xF2D7	0x9C08
+0xF2D8	0x9C12
+0xF2D9	0x9C0A
+0xF2DA	0x9C04
+0xF2DB	0x9C2E
+0xF2DC	0x9C1B
+0xF2DD	0x9C25
+0xF2DE	0x9C24
+0xF2DF	0x9C21
+0xF2E0	0x9C30
+0xF2E1	0x9C47
+0xF2E2	0x9C32
+0xF2E3	0x9C46
+0xF2E4	0x9C3E
+0xF2E5	0x9C5A
+0xF2E6	0x9C60
+0xF2E7	0x9C67
+0xF2E8	0x9C76
+0xF2E9	0x9C78
+0xF2EA	0x9CE7
+0xF2EB	0x9CEC
+0xF2EC	0x9CF0
+0xF2ED	0x9D09
+0xF2EE	0x9D08
+0xF2EF	0x9CEB
+0xF2F0	0x9D03
+0xF2F1	0x9D06
+0xF2F2	0x9D2A
+0xF2F3	0x9D26
+0xF2F4	0x9DAF
+0xF2F5	0x9D23
+0xF2F6	0x9D1F
+0xF2F7	0x9D44
+0xF2F8	0x9D15
+0xF2F9	0x9D12
+0xF2FA	0x9D41
+0xF2FB	0x9D3F
+0xF2FC	0x9D3E
+0xF2FD	0x9D46
+0xF2FE	0x9D48
+0xF3A1	0x9D5D
+0xF3A2	0x9D5E
+0xF3A3	0x9D64
+0xF3A4	0x9D51
+0xF3A5	0x9D50
+0xF3A6	0x9D59
+0xF3A7	0x9D72
+0xF3A8	0x9D89
+0xF3A9	0x9D87
+0xF3AA	0x9DAB
+0xF3AB	0x9D6F
+0xF3AC	0x9D7A
+0xF3AD	0x9D9A
+0xF3AE	0x9DA4
+0xF3AF	0x9DA9
+0xF3B0	0x9DB2
+0xF3B1	0x9DC4
+0xF3B2	0x9DC1
+0xF3B3	0x9DBB
+0xF3B4	0x9DB8
+0xF3B5	0x9DBA
+0xF3B6	0x9DC6
+0xF3B7	0x9DCF
+0xF3B8	0x9DC2
+0xF3B9	0x9DD9
+0xF3BA	0x9DD3
+0xF3BB	0x9DF8
+0xF3BC	0x9DE6
+0xF3BD	0x9DED
+0xF3BE	0x9DEF
+0xF3BF	0x9DFD
+0xF3C0	0x9E1A
+0xF3C1	0x9E1B
+0xF3C2	0x9E1E
+0xF3C3	0x9E75
+0xF3C4	0x9E79
+0xF3C5	0x9E7D
+0xF3C6	0x9E81
+0xF3C7	0x9E88
+0xF3C8	0x9E8B
+0xF3C9	0x9E8C
+0xF3CA	0x9E92
+0xF3CB	0x9E95
+0xF3CC	0x9E91
+0xF3CD	0x9E9D
+0xF3CE	0x9EA5
+0xF3CF	0x9EA9
+0xF3D0	0x9EB8
+0xF3D1	0x9EAA
+0xF3D2	0x9EAD
+0xF3D3	0x9761
+0xF3D4	0x9ECC
+0xF3D5	0x9ECE
+0xF3D6	0x9ECF
+0xF3D7	0x9ED0
+0xF3D8	0x9ED4
+0xF3D9	0x9EDC
+0xF3DA	0x9EDE
+0xF3DB	0x9EDD
+0xF3DC	0x9EE0
+0xF3DD	0x9EE5
+0xF3DE	0x9EE8
+0xF3DF	0x9EEF
+0xF3E0	0x9EF4
+0xF3E1	0x9EF6
+0xF3E2	0x9EF7
+0xF3E3	0x9EF9
+0xF3E4	0x9EFB
+0xF3E5	0x9EFC
+0xF3E6	0x9EFD
+0xF3E7	0x9F07
+0xF3E8	0x9F08
+0xF3E9	0x76B7
+0xF3EA	0x9F15
+0xF3EB	0x9F21
+0xF3EC	0x9F2C
+0xF3ED	0x9F3E
+0xF3EE	0x9F4A
+0xF3EF	0x9F52
+0xF3F0	0x9F54
+0xF3F1	0x9F63
+0xF3F2	0x9F5F
+0xF3F3	0x9F60
+0xF3F4	0x9F61
+0xF3F5	0x9F66
+0xF3F6	0x9F67
+0xF3F7	0x9F6C
+0xF3F8	0x9F6A
+0xF3F9	0x9F77
+0xF3FA	0x9F72
+0xF3FB	0x9F76
+0xF3FC	0x9F95
+0xF3FD	0x9F9C
+0xF3FE	0x9FA0
+0xF4A1	0x582F
+0xF4A2	0x69C7
+0xF4A3	0x9059
+0xF4A4	0x7464
+0xF4A5	0x51DC
+0xF4A6	0x7199
+0xF9A1	0x7E8A
+0xF9A2	0x891C
+0xF9A3	0x9348
+0xF9A4	0x9288
+0xF9A5	0x84DC
+0xF9A6	0x4FC9
+0xF9A7	0x70BB
+0xF9A8	0x6631
+0xF9A9	0x68C8
+0xF9AA	0x92F9
+0xF9AB	0x66FB
+0xF9AC	0x5F45
+0xF9AD	0x4E28
+0xF9AE	0x4EE1
+0xF9AF	0x4EFC
+0xF9B0	0x4F00
+0xF9B1	0x4F03
+0xF9B2	0x4F39
+0xF9B3	0x4F56
+0xF9B4	0x4F92
+0xF9B5	0x4F8A
+0xF9B6	0x4F9A
+0xF9B7	0x4F94
+0xF9B8	0x4FCD
+0xF9B9	0x5040
+0xF9BA	0x5022
+0xF9BB	0x4FFF
+0xF9BC	0x501E
+0xF9BD	0x5046
+0xF9BE	0x5070
+0xF9BF	0x5042
+0xF9C0	0x5094
+0xF9C1	0x50F4
+0xF9C2	0x50D8
+0xF9C3	0x514A
+0xF9C4	0x5164
+0xF9C5	0x519D
+0xF9C6	0x51BE
+0xF9C7	0x51EC
+0xF9C8	0x5215
+0xF9C9	0x529C
+0xF9CA	0x52A6
+0xF9CB	0x52C0
+0xF9CC	0x52DB
+0xF9CD	0x5300
+0xF9CE	0x5307
+0xF9CF	0x5324
+0xF9D0	0x5372
+0xF9D1	0x5393
+0xF9D2	0x53B2
+0xF9D3	0x53DD
+0xF9D4	0xFA0E
+0xF9D5	0x549C
+0xF9D6	0x548A
+0xF9D7	0x54A9
+0xF9D8	0x54FF
+0xF9D9	0x5586
+0xF9DA	0x5759
+0xF9DB	0x5765
+0xF9DC	0x57AC
+0xF9DD	0x57C8
+0xF9DE	0x57C7
+0xF9DF	0xFA0F
+0xF9E0	0xFA10
+0xF9E1	0x589E
+0xF9E2	0x58B2
+0xF9E3	0x590B
+0xF9E4	0x5953
+0xF9E5	0x595B
+0xF9E6	0x595D
+0xF9E7	0x5963
+0xF9E8	0x59A4
+0xF9E9	0x59BA
+0xF9EA	0x5B56
+0xF9EB	0x5BC0
+0xF9EC	0x752F
+0xF9ED	0x5BD8
+0xF9EE	0x5BEC
+0xF9EF	0x5C1E
+0xF9F0	0x5CA6
+0xF9F1	0x5CBA
+0xF9F2	0x5CF5
+0xF9F3	0x5D27
+0xF9F4	0x5D53
+0xF9F5	0xFA11
+0xF9F6	0x5D42
+0xF9F7	0x5D6D
+0xF9F8	0x5DB8
+0xF9F9	0x5DB9
+0xF9FA	0x5DD0
+0xF9FB	0x5F21
+0xF9FC	0x5F34
+0xF9FD	0x5F67
+0xF9FE	0x5FB7
+0xFAA1	0x5FDE
+0xFAA2	0x605D
+0xFAA3	0x6085
+0xFAA4	0x608A
+0xFAA5	0x60DE
+0xFAA6	0x60D5
+0xFAA7	0x6120
+0xFAA8	0x60F2
+0xFAA9	0x6111
+0xFAAA	0x6137
+0xFAAB	0x6130
+0xFAAC	0x6198
+0xFAAD	0x6213
+0xFAAE	0x62A6
+0xFAAF	0x63F5
+0xFAB0	0x6460
+0xFAB1	0x649D
+0xFAB2	0x64CE
+0xFAB3	0x654E
+0xFAB4	0x6600
+0xFAB5	0x6615
+0xFAB6	0x663B
+0xFAB7	0x6609
+0xFAB8	0x662E
+0xFAB9	0x661E
+0xFABA	0x6624
+0xFABB	0x6665
+0xFABC	0x6657
+0xFABD	0x6659
+0xFABE	0xFA12
+0xFABF	0x6673
+0xFAC0	0x6699
+0xFAC1	0x66A0
+0xFAC2	0x66B2
+0xFAC3	0x66BF
+0xFAC4	0x66FA
+0xFAC5	0x670E
+0xFAC6	0xF929
+0xFAC7	0x6766
+0xFAC8	0x67BB
+0xFAC9	0x6852
+0xFACA	0x67C0
+0xFACB	0x6801
+0xFACC	0x6844
+0xFACD	0x68CF
+0xFACE	0xFA13
+0xFACF	0x6968
+0xFAD0	0xFA14
+0xFAD1	0x6998
+0xFAD2	0x69E2
+0xFAD3	0x6A30
+0xFAD4	0x6A6B
+0xFAD5	0x6A46
+0xFAD6	0x6A73
+0xFAD7	0x6A7E
+0xFAD8	0x6AE2
+0xFAD9	0x6AE4
+0xFADA	0x6BD6
+0xFADB	0x6C3F
+0xFADC	0x6C5C
+0xFADD	0x6C86
+0xFADE	0x6C6F
+0xFADF	0x6CDA
+0xFAE0	0x6D04
+0xFAE1	0x6D87
+0xFAE2	0x6D6F
+0xFAE3	0x6D96
+0xFAE4	0x6DAC
+0xFAE5	0x6DCF
+0xFAE6	0x6DF8
+0xFAE7	0x6DF2
+0xFAE8	0x6DFC
+0xFAE9	0x6E39
+0xFAEA	0x6E5C
+0xFAEB	0x6E27
+0xFAEC	0x6E3C
+0xFAED	0x6EBF
+0xFAEE	0x6F88
+0xFAEF	0x6FB5
+0xFAF0	0x6FF5
+0xFAF1	0x7005
+0xFAF2	0x7007
+0xFAF3	0x7028
+0xFAF4	0x7085
+0xFAF5	0x70AB
+0xFAF6	0x710F
+0xFAF7	0x7104
+0xFAF8	0x715C
+0xFAF9	0x7146
+0xFAFA	0x7147
+0xFAFB	0xFA15
+0xFAFC	0x71C1
+0xFAFD	0x71FE
+0xFAFE	0x72B1
+0xFBA1	0x72BE
+0xFBA2	0x7324
+0xFBA3	0xFA16
+0xFBA4	0x7377
+0xFBA5	0x73BD
+0xFBA6	0x73C9
+0xFBA7	0x73D6
+0xFBA8	0x73E3
+0xFBA9	0x73D2
+0xFBAA	0x7407
+0xFBAB	0x73F5
+0xFBAC	0x7426
+0xFBAD	0x742A
+0xFBAE	0x7429
+0xFBAF	0x742E
+0xFBB0	0x7462
+0xFBB1	0x7489
+0xFBB2	0x749F
+0xFBB3	0x7501
+0xFBB4	0x756F
+0xFBB5	0x7682
+0xFBB6	0x769C
+0xFBB7	0x769E
+0xFBB8	0x769B
+0xFBB9	0x76A6
+0xFBBA	0xFA17
+0xFBBB	0x7746
+0xFBBC	0x52AF
+0xFBBD	0x7821
+0xFBBE	0x784E
+0xFBBF	0x7864
+0xFBC0	0x787A
+0xFBC1	0x7930
+0xFBC2	0xFA18
+0xFBC3	0xFA19
+0xFBC4	0xFA1A
+0xFBC5	0x7994
+0xFBC6	0xFA1B
+0xFBC7	0x799B
+0xFBC8	0x7AD1
+0xFBC9	0x7AE7
+0xFBCA	0xFA1C
+0xFBCB	0x7AEB
+0xFBCC	0x7B9E
+0xFBCD	0xFA1D
+0xFBCE	0x7D48
+0xFBCF	0x7D5C
+0xFBD0	0x7DB7
+0xFBD1	0x7DA0
+0xFBD2	0x7DD6
+0xFBD3	0x7E52
+0xFBD4	0x7F47
+0xFBD5	0x7FA1
+0xFBD6	0xFA1E
+0xFBD7	0x8301
+0xFBD8	0x8362
+0xFBD9	0x837F
+0xFBDA	0x83C7
+0xFBDB	0x83F6
+0xFBDC	0x8448
+0xFBDD	0x84B4
+0xFBDE	0x8553
+0xFBDF	0x8559
+0xFBE0	0x856B
+0xFBE1	0xFA1F
+0xFBE2	0x85B0
+0xFBE3	0xFA20
+0xFBE4	0xFA21
+0xFBE5	0x8807
+0xFBE6	0x88F5
+0xFBE7	0x8A12
+0xFBE8	0x8A37
+0xFBE9	0x8A79
+0xFBEA	0x8AA7
+0xFBEB	0x8ABE
+0xFBEC	0x8ADF
+0xFBED	0xFA22
+0xFBEE	0x8AF6
+0xFBEF	0x8B53
+0xFBF0	0x8B7F
+0xFBF1	0x8CF0
+0xFBF2	0x8CF4
+0xFBF3	0x8D12
+0xFBF4	0x8D76
+0xFBF5	0xFA23
+0xFBF6	0x8ECF
+0xFBF7	0xFA24
+0xFBF8	0xFA25
+0xFBF9	0x9067
+0xFBFA	0x90DE
+0xFBFB	0xFA26
+0xFBFC	0x9115
+0xFBFD	0x9127
+0xFBFE	0x91DA
+0xFCA1	0x91D7
+0xFCA2	0x91DE
+0xFCA3	0x91ED
+0xFCA4	0x91EE
+0xFCA5	0x91E4
+0xFCA6	0x91E5
+0xFCA7	0x9206
+0xFCA8	0x9210
+0xFCA9	0x920A
+0xFCAA	0x923A
+0xFCAB	0x9240
+0xFCAC	0x923C
+0xFCAD	0x924E
+0xFCAE	0x9259
+0xFCAF	0x9251
+0xFCB0	0x9239
+0xFCB1	0x9267
+0xFCB2	0x92A7
+0xFCB3	0x9277
+0xFCB4	0x9278
+0xFCB5	0x92E7
+0xFCB6	0x92D7
+0xFCB7	0x92D9
+0xFCB8	0x92D0
+0xFCB9	0xFA27
+0xFCBA	0x92D5
+0xFCBB	0x92E0
+0xFCBC	0x92D3
+0xFCBD	0x9325
+0xFCBE	0x9321
+0xFCBF	0x92FB
+0xFCC0	0xFA28
+0xFCC1	0x931E
+0xFCC2	0x92FF
+0xFCC3	0x931D
+0xFCC4	0x9302
+0xFCC5	0x9370
+0xFCC6	0x9357
+0xFCC7	0x93A4
+0xFCC8	0x93C6
+0xFCC9	0x93DE
+0xFCCA	0x93F8
+0xFCCB	0x9431
+0xFCCC	0x9445
+0xFCCD	0x9448
+0xFCCE	0x9592
+0xFCCF	0xF9DC
+0xFCD0	0xFA29
+0xFCD1	0x969D
+0xFCD2	0x96AF
+0xFCD3	0x9733
+0xFCD4	0x973B
+0xFCD5	0x9743
+0xFCD6	0x974D
+0xFCD7	0x974F
+0xFCD8	0x9751
+0xFCD9	0x9755
+0xFCDA	0x9857
+0xFCDB	0x9865
+0xFCDC	0xFA2A
+0xFCDD	0xFA2B
+0xFCDE	0x9927
+0xFCDF	0xFA2C
+0xFCE0	0x999E
+0xFCE1	0x9A4E
+0xFCE2	0x9AD9
+0xFCE3	0x9ADC
+0xFCE4	0x9B75
+0xFCE5	0x9B72
+0xFCE6	0x9B8F
+0xFCE7	0x9BB1
+0xFCE8	0x9BBB
+0xFCE9	0x9C00
+0xFCEA	0x9D70
+0xFCEB	0x9D6B
+0xFCEC	0xFA2D
+0xFCED	0x9E19
+0xFCEE	0x9ED1
+0xFCF1	0x2170
+0xFCF2	0x2171
+0xFCF3	0x2172
+0xFCF4	0x2173
+0xFCF5	0x2174
+0xFCF6	0x2175
+0xFCF7	0x2176
+0xFCF8	0x2177
+0xFCF9	0x2178
+0xFCFA	0x2179
+0xFCFB	0xFFE2
+0xFCFC	0xFFE4
+0xFCFD	0xFF07
+0xFCFE	0xFF02
diff -uprN libiconv-1.15-old/tests/CP932.IRREVERSIBLE.TXT libiconv-1.15/tests/CP932.IRREVERSIBLE.TXT
--- libiconv-1.15-old/tests/CP932.IRREVERSIBLE.TXT	2009-06-21 20:17:33.000000000 +0900
+++ libiconv-1.15/tests/CP932.IRREVERSIBLE.TXT	2017-09-17 05:38:54.042990000 +0900
@@ -1,21 +1,10 @@
-0x8160	0xFF5E
-0x8161	0x2225
-0x817C	0xFF0D
-0x8191	0xFFE0
-0x8192	0xFFE1
-0x8754	0x2160
-0x8755	0x2161
-0x8756	0x2162
-0x8757	0x2163
-0x8758	0x2164
-0x8759	0x2165
-0x875A	0x2166
-0x875B	0x2167
-0x875C	0x2168
-0x875D	0x2169
-0x8782	0x2116
-0x8784	0x2121
-0x878A	0x3231
+0x815C	0x2014
+0x8160	0x301C
+0x8161	0x2016
+0x817C	0x2212
+0x8191	0x00A2
+0x8192	0x00A3
+0x81CA	0x00AC
 0x8790	0x2252
 0x8791	0x2261
 0x8792	0x222B
@@ -399,4 +388,18 @@
 0xEEFA	0xFFE4
 0xEEFB	0xFF07
 0xEEFC	0xFF02
+0xFA4A	0x2160
+0xFA4B	0x2161
+0xFA4C	0x2162
+0xFA4D	0x2163
+0xFA4E	0x2164
+0xFA4F	0x2165
+0xFA50	0x2166
+0xFA51	0x2167
+0xFA52	0x2168
+0xFA53	0x2169
+0xFA54	0xFFE2
+0xFA58	0x3231
+0xFA59	0x2116
+0xFA5A	0x2121
 0xFA5B	0x2235
diff -uprN libiconv-1.15-old/tests/CP932.TXT libiconv-1.15/tests/CP932.TXT
--- libiconv-1.15-old/tests/CP932.TXT	2009-06-21 20:17:33.000000000 +0900
+++ libiconv-1.15/tests/CP932.TXT	2017-09-17 05:38:54.045998000 +0900
@@ -158,8 +158,8 @@
 0x815D	0x2010
 0x815E	0xFF0F
 0x815F	0xFF3C
-0x8160	0x301C
-0x8161	0x2016
+0x8160	0xFF5E
+0x8161	0x2225
 0x8162	0xFF5C
 0x8163	0x2026
 0x8164	0x2025
@@ -186,7 +186,7 @@
 0x8179	0x3010
 0x817A	0x3011
 0x817B	0xFF0B
-0x817C	0x2212
+0x817C	0xFF0D
 0x817D	0x00B1
 0x817E	0x00D7
 0x8180	0x00F7
@@ -206,8 +206,8 @@
 0x818E	0x2103
 0x818F	0xFFE5
 0x8190	0xFF04
-0x8191	0x00A2
-0x8192	0x00A3
+0x8191	0xFFE0
+0x8192	0xFFE1
 0x8193	0xFF05
 0x8194	0xFF03
 0x8195	0xFF06
@@ -244,7 +244,7 @@
 0x81BF	0x2229
 0x81C8	0x2227
 0x81C9	0x2228
-0x81CA	0x00AC
+0x81CA	0xFFE2
 0x81CB	0x21D2
 0x81CC	0x21D4
 0x81CD	0x2200
diff -uprN libiconv-1.15-old/tests/DEC-KANJI.TXT libiconv-1.15/tests/DEC-KANJI.TXT
--- libiconv-1.15-old/tests/DEC-KANJI.TXT	2009-06-21 20:17:33.000000000 +0900
+++ libiconv-1.15/tests/DEC-KANJI.TXT	2017-09-17 05:38:54.048344000 +0900
@@ -154,7 +154,7 @@
 0xA1BA	0x3006
 0xA1BB	0x3007
 0xA1BC	0x30FC
-0xA1BD	0x2015
+0xA1BD	0x2014
 0xA1BE	0x2010
 0xA1BF	0xFF0F
 0xA1C0	0xFF3C
diff -uprN libiconv-1.15-old/tests/EUC-JP.TXT libiconv-1.15/tests/EUC-JP.TXT
--- libiconv-1.15-old/tests/EUC-JP.TXT	2009-06-21 20:17:33.000000000 +0900
+++ libiconv-1.15/tests/EUC-JP.TXT	2017-09-17 05:38:54.053679000 +0900
@@ -6256,946 +6256,6 @@
 0x8FEDE1	0x9FA2
 0x8FEDE2	0x9FA3
 0x8FEDE3	0x9FA5
-0x8FF5A1	0xE3AC
-0x8FF5A2	0xE3AD
-0x8FF5A3	0xE3AE
-0x8FF5A4	0xE3AF
-0x8FF5A5	0xE3B0
-0x8FF5A6	0xE3B1
-0x8FF5A7	0xE3B2
-0x8FF5A8	0xE3B3
-0x8FF5A9	0xE3B4
-0x8FF5AA	0xE3B5
-0x8FF5AB	0xE3B6
-0x8FF5AC	0xE3B7
-0x8FF5AD	0xE3B8
-0x8FF5AE	0xE3B9
-0x8FF5AF	0xE3BA
-0x8FF5B0	0xE3BB
-0x8FF5B1	0xE3BC
-0x8FF5B2	0xE3BD
-0x8FF5B3	0xE3BE
-0x8FF5B4	0xE3BF
-0x8FF5B5	0xE3C0
-0x8FF5B6	0xE3C1
-0x8FF5B7	0xE3C2
-0x8FF5B8	0xE3C3
-0x8FF5B9	0xE3C4
-0x8FF5BA	0xE3C5
-0x8FF5BB	0xE3C6
-0x8FF5BC	0xE3C7
-0x8FF5BD	0xE3C8
-0x8FF5BE	0xE3C9
-0x8FF5BF	0xE3CA
-0x8FF5C0	0xE3CB
-0x8FF5C1	0xE3CC
-0x8FF5C2	0xE3CD
-0x8FF5C3	0xE3CE
-0x8FF5C4	0xE3CF
-0x8FF5C5	0xE3D0
-0x8FF5C6	0xE3D1
-0x8FF5C7	0xE3D2
-0x8FF5C8	0xE3D3
-0x8FF5C9	0xE3D4
-0x8FF5CA	0xE3D5
-0x8FF5CB	0xE3D6
-0x8FF5CC	0xE3D7
-0x8FF5CD	0xE3D8
-0x8FF5CE	0xE3D9
-0x8FF5CF	0xE3DA
-0x8FF5D0	0xE3DB
-0x8FF5D1	0xE3DC
-0x8FF5D2	0xE3DD
-0x8FF5D3	0xE3DE
-0x8FF5D4	0xE3DF
-0x8FF5D5	0xE3E0
-0x8FF5D6	0xE3E1
-0x8FF5D7	0xE3E2
-0x8FF5D8	0xE3E3
-0x8FF5D9	0xE3E4
-0x8FF5DA	0xE3E5
-0x8FF5DB	0xE3E6
-0x8FF5DC	0xE3E7
-0x8FF5DD	0xE3E8
-0x8FF5DE	0xE3E9
-0x8FF5DF	0xE3EA
-0x8FF5E0	0xE3EB
-0x8FF5E1	0xE3EC
-0x8FF5E2	0xE3ED
-0x8FF5E3	0xE3EE
-0x8FF5E4	0xE3EF
-0x8FF5E5	0xE3F0
-0x8FF5E6	0xE3F1
-0x8FF5E7	0xE3F2
-0x8FF5E8	0xE3F3
-0x8FF5E9	0xE3F4
-0x8FF5EA	0xE3F5
-0x8FF5EB	0xE3F6
-0x8FF5EC	0xE3F7
-0x8FF5ED	0xE3F8
-0x8FF5EE	0xE3F9
-0x8FF5EF	0xE3FA
-0x8FF5F0	0xE3FB
-0x8FF5F1	0xE3FC
-0x8FF5F2	0xE3FD
-0x8FF5F3	0xE3FE
-0x8FF5F4	0xE3FF
-0x8FF5F5	0xE400
-0x8FF5F6	0xE401
-0x8FF5F7	0xE402
-0x8FF5F8	0xE403
-0x8FF5F9	0xE404
-0x8FF5FA	0xE405
-0x8FF5FB	0xE406
-0x8FF5FC	0xE407
-0x8FF5FD	0xE408
-0x8FF5FE	0xE409
-0x8FF6A1	0xE40A
-0x8FF6A2	0xE40B
-0x8FF6A3	0xE40C
-0x8FF6A4	0xE40D
-0x8FF6A5	0xE40E
-0x8FF6A6	0xE40F
-0x8FF6A7	0xE410
-0x8FF6A8	0xE411
-0x8FF6A9	0xE412
-0x8FF6AA	0xE413
-0x8FF6AB	0xE414
-0x8FF6AC	0xE415
-0x8FF6AD	0xE416
-0x8FF6AE	0xE417
-0x8FF6AF	0xE418
-0x8FF6B0	0xE419
-0x8FF6B1	0xE41A
-0x8FF6B2	0xE41B
-0x8FF6B3	0xE41C
-0x8FF6B4	0xE41D
-0x8FF6B5	0xE41E
-0x8FF6B6	0xE41F
-0x8FF6B7	0xE420
-0x8FF6B8	0xE421
-0x8FF6B9	0xE422
-0x8FF6BA	0xE423
-0x8FF6BB	0xE424
-0x8FF6BC	0xE425
-0x8FF6BD	0xE426
-0x8FF6BE	0xE427
-0x8FF6BF	0xE428
-0x8FF6C0	0xE429
-0x8FF6C1	0xE42A
-0x8FF6C2	0xE42B
-0x8FF6C3	0xE42C
-0x8FF6C4	0xE42D
-0x8FF6C5	0xE42E
-0x8FF6C6	0xE42F
-0x8FF6C7	0xE430
-0x8FF6C8	0xE431
-0x8FF6C9	0xE432
-0x8FF6CA	0xE433
-0x8FF6CB	0xE434
-0x8FF6CC	0xE435
-0x8FF6CD	0xE436
-0x8FF6CE	0xE437
-0x8FF6CF	0xE438
-0x8FF6D0	0xE439
-0x8FF6D1	0xE43A
-0x8FF6D2	0xE43B
-0x8FF6D3	0xE43C
-0x8FF6D4	0xE43D
-0x8FF6D5	0xE43E
-0x8FF6D6	0xE43F
-0x8FF6D7	0xE440
-0x8FF6D8	0xE441
-0x8FF6D9	0xE442
-0x8FF6DA	0xE443
-0x8FF6DB	0xE444
-0x8FF6DC	0xE445
-0x8FF6DD	0xE446
-0x8FF6DE	0xE447
-0x8FF6DF	0xE448
-0x8FF6E0	0xE449
-0x8FF6E1	0xE44A
-0x8FF6E2	0xE44B
-0x8FF6E3	0xE44C
-0x8FF6E4	0xE44D
-0x8FF6E5	0xE44E
-0x8FF6E6	0xE44F
-0x8FF6E7	0xE450
-0x8FF6E8	0xE451
-0x8FF6E9	0xE452
-0x8FF6EA	0xE453
-0x8FF6EB	0xE454
-0x8FF6EC	0xE455
-0x8FF6ED	0xE456
-0x8FF6EE	0xE457
-0x8FF6EF	0xE458
-0x8FF6F0	0xE459
-0x8FF6F1	0xE45A
-0x8FF6F2	0xE45B
-0x8FF6F3	0xE45C
-0x8FF6F4	0xE45D
-0x8FF6F5	0xE45E
-0x8FF6F6	0xE45F
-0x8FF6F7	0xE460
-0x8FF6F8	0xE461
-0x8FF6F9	0xE462
-0x8FF6FA	0xE463
-0x8FF6FB	0xE464
-0x8FF6FC	0xE465
-0x8FF6FD	0xE466
-0x8FF6FE	0xE467
-0x8FF7A1	0xE468
-0x8FF7A2	0xE469
-0x8FF7A3	0xE46A
-0x8FF7A4	0xE46B
-0x8FF7A5	0xE46C
-0x8FF7A6	0xE46D
-0x8FF7A7	0xE46E
-0x8FF7A8	0xE46F
-0x8FF7A9	0xE470
-0x8FF7AA	0xE471
-0x8FF7AB	0xE472
-0x8FF7AC	0xE473
-0x8FF7AD	0xE474
-0x8FF7AE	0xE475
-0x8FF7AF	0xE476
-0x8FF7B0	0xE477
-0x8FF7B1	0xE478
-0x8FF7B2	0xE479
-0x8FF7B3	0xE47A
-0x8FF7B4	0xE47B
-0x8FF7B5	0xE47C
-0x8FF7B6	0xE47D
-0x8FF7B7	0xE47E
-0x8FF7B8	0xE47F
-0x8FF7B9	0xE480
-0x8FF7BA	0xE481
-0x8FF7BB	0xE482
-0x8FF7BC	0xE483
-0x8FF7BD	0xE484
-0x8FF7BE	0xE485
-0x8FF7BF	0xE486
-0x8FF7C0	0xE487
-0x8FF7C1	0xE488
-0x8FF7C2	0xE489
-0x8FF7C3	0xE48A
-0x8FF7C4	0xE48B
-0x8FF7C5	0xE48C
-0x8FF7C6	0xE48D
-0x8FF7C7	0xE48E
-0x8FF7C8	0xE48F
-0x8FF7C9	0xE490
-0x8FF7CA	0xE491
-0x8FF7CB	0xE492
-0x8FF7CC	0xE493
-0x8FF7CD	0xE494
-0x8FF7CE	0xE495
-0x8FF7CF	0xE496
-0x8FF7D0	0xE497
-0x8FF7D1	0xE498
-0x8FF7D2	0xE499
-0x8FF7D3	0xE49A
-0x8FF7D4	0xE49B
-0x8FF7D5	0xE49C
-0x8FF7D6	0xE49D
-0x8FF7D7	0xE49E
-0x8FF7D8	0xE49F
-0x8FF7D9	0xE4A0
-0x8FF7DA	0xE4A1
-0x8FF7DB	0xE4A2
-0x8FF7DC	0xE4A3
-0x8FF7DD	0xE4A4
-0x8FF7DE	0xE4A5
-0x8FF7DF	0xE4A6
-0x8FF7E0	0xE4A7
-0x8FF7E1	0xE4A8
-0x8FF7E2	0xE4A9
-0x8FF7E3	0xE4AA
-0x8FF7E4	0xE4AB
-0x8FF7E5	0xE4AC
-0x8FF7E6	0xE4AD
-0x8FF7E7	0xE4AE
-0x8FF7E8	0xE4AF
-0x8FF7E9	0xE4B0
-0x8FF7EA	0xE4B1
-0x8FF7EB	0xE4B2
-0x8FF7EC	0xE4B3
-0x8FF7ED	0xE4B4
-0x8FF7EE	0xE4B5
-0x8FF7EF	0xE4B6
-0x8FF7F0	0xE4B7
-0x8FF7F1	0xE4B8
-0x8FF7F2	0xE4B9
-0x8FF7F3	0xE4BA
-0x8FF7F4	0xE4BB
-0x8FF7F5	0xE4BC
-0x8FF7F6	0xE4BD
-0x8FF7F7	0xE4BE
-0x8FF7F8	0xE4BF
-0x8FF7F9	0xE4C0
-0x8FF7FA	0xE4C1
-0x8FF7FB	0xE4C2
-0x8FF7FC	0xE4C3
-0x8FF7FD	0xE4C4
-0x8FF7FE	0xE4C5
-0x8FF8A1	0xE4C6
-0x8FF8A2	0xE4C7
-0x8FF8A3	0xE4C8
-0x8FF8A4	0xE4C9
-0x8FF8A5	0xE4CA
-0x8FF8A6	0xE4CB
-0x8FF8A7	0xE4CC
-0x8FF8A8	0xE4CD
-0x8FF8A9	0xE4CE
-0x8FF8AA	0xE4CF
-0x8FF8AB	0xE4D0
-0x8FF8AC	0xE4D1
-0x8FF8AD	0xE4D2
-0x8FF8AE	0xE4D3
-0x8FF8AF	0xE4D4
-0x8FF8B0	0xE4D5
-0x8FF8B1	0xE4D6
-0x8FF8B2	0xE4D7
-0x8FF8B3	0xE4D8
-0x8FF8B4	0xE4D9
-0x8FF8B5	0xE4DA
-0x8FF8B6	0xE4DB
-0x8FF8B7	0xE4DC
-0x8FF8B8	0xE4DD
-0x8FF8B9	0xE4DE
-0x8FF8BA	0xE4DF
-0x8FF8BB	0xE4E0
-0x8FF8BC	0xE4E1
-0x8FF8BD	0xE4E2
-0x8FF8BE	0xE4E3
-0x8FF8BF	0xE4E4
-0x8FF8C0	0xE4E5
-0x8FF8C1	0xE4E6
-0x8FF8C2	0xE4E7
-0x8FF8C3	0xE4E8
-0x8FF8C4	0xE4E9
-0x8FF8C5	0xE4EA
-0x8FF8C6	0xE4EB
-0x8FF8C7	0xE4EC
-0x8FF8C8	0xE4ED
-0x8FF8C9	0xE4EE
-0x8FF8CA	0xE4EF
-0x8FF8CB	0xE4F0
-0x8FF8CC	0xE4F1
-0x8FF8CD	0xE4F2
-0x8FF8CE	0xE4F3
-0x8FF8CF	0xE4F4
-0x8FF8D0	0xE4F5
-0x8FF8D1	0xE4F6
-0x8FF8D2	0xE4F7
-0x8FF8D3	0xE4F8
-0x8FF8D4	0xE4F9
-0x8FF8D5	0xE4FA
-0x8FF8D6	0xE4FB
-0x8FF8D7	0xE4FC
-0x8FF8D8	0xE4FD
-0x8FF8D9	0xE4FE
-0x8FF8DA	0xE4FF
-0x8FF8DB	0xE500
-0x8FF8DC	0xE501
-0x8FF8DD	0xE502
-0x8FF8DE	0xE503
-0x8FF8DF	0xE504
-0x8FF8E0	0xE505
-0x8FF8E1	0xE506
-0x8FF8E2	0xE507
-0x8FF8E3	0xE508
-0x8FF8E4	0xE509
-0x8FF8E5	0xE50A
-0x8FF8E6	0xE50B
-0x8FF8E7	0xE50C
-0x8FF8E8	0xE50D
-0x8FF8E9	0xE50E
-0x8FF8EA	0xE50F
-0x8FF8EB	0xE510
-0x8FF8EC	0xE511
-0x8FF8ED	0xE512
-0x8FF8EE	0xE513
-0x8FF8EF	0xE514
-0x8FF8F0	0xE515
-0x8FF8F1	0xE516
-0x8FF8F2	0xE517
-0x8FF8F3	0xE518
-0x8FF8F4	0xE519
-0x8FF8F5	0xE51A
-0x8FF8F6	0xE51B
-0x8FF8F7	0xE51C
-0x8FF8F8	0xE51D
-0x8FF8F9	0xE51E
-0x8FF8FA	0xE51F
-0x8FF8FB	0xE520
-0x8FF8FC	0xE521
-0x8FF8FD	0xE522
-0x8FF8FE	0xE523
-0x8FF9A1	0xE524
-0x8FF9A2	0xE525
-0x8FF9A3	0xE526
-0x8FF9A4	0xE527
-0x8FF9A5	0xE528
-0x8FF9A6	0xE529
-0x8FF9A7	0xE52A
-0x8FF9A8	0xE52B
-0x8FF9A9	0xE52C
-0x8FF9AA	0xE52D
-0x8FF9AB	0xE52E
-0x8FF9AC	0xE52F
-0x8FF9AD	0xE530
-0x8FF9AE	0xE531
-0x8FF9AF	0xE532
-0x8FF9B0	0xE533
-0x8FF9B1	0xE534
-0x8FF9B2	0xE535
-0x8FF9B3	0xE536
-0x8FF9B4	0xE537
-0x8FF9B5	0xE538
-0x8FF9B6	0xE539
-0x8FF9B7	0xE53A
-0x8FF9B8	0xE53B
-0x8FF9B9	0xE53C
-0x8FF9BA	0xE53D
-0x8FF9BB	0xE53E
-0x8FF9BC	0xE53F
-0x8FF9BD	0xE540
-0x8FF9BE	0xE541
-0x8FF9BF	0xE542
-0x8FF9C0	0xE543
-0x8FF9C1	0xE544
-0x8FF9C2	0xE545
-0x8FF9C3	0xE546
-0x8FF9C4	0xE547
-0x8FF9C5	0xE548
-0x8FF9C6	0xE549
-0x8FF9C7	0xE54A
-0x8FF9C8	0xE54B
-0x8FF9C9	0xE54C
-0x8FF9CA	0xE54D
-0x8FF9CB	0xE54E
-0x8FF9CC	0xE54F
-0x8FF9CD	0xE550
-0x8FF9CE	0xE551
-0x8FF9CF	0xE552
-0x8FF9D0	0xE553
-0x8FF9D1	0xE554
-0x8FF9D2	0xE555
-0x8FF9D3	0xE556
-0x8FF9D4	0xE557
-0x8FF9D5	0xE558
-0x8FF9D6	0xE559
-0x8FF9D7	0xE55A
-0x8FF9D8	0xE55B
-0x8FF9D9	0xE55C
-0x8FF9DA	0xE55D
-0x8FF9DB	0xE55E
-0x8FF9DC	0xE55F
-0x8FF9DD	0xE560
-0x8FF9DE	0xE561
-0x8FF9DF	0xE562
-0x8FF9E0	0xE563
-0x8FF9E1	0xE564
-0x8FF9E2	0xE565
-0x8FF9E3	0xE566
-0x8FF9E4	0xE567
-0x8FF9E5	0xE568
-0x8FF9E6	0xE569
-0x8FF9E7	0xE56A
-0x8FF9E8	0xE56B
-0x8FF9E9	0xE56C
-0x8FF9EA	0xE56D
-0x8FF9EB	0xE56E
-0x8FF9EC	0xE56F
-0x8FF9ED	0xE570
-0x8FF9EE	0xE571
-0x8FF9EF	0xE572
-0x8FF9F0	0xE573
-0x8FF9F1	0xE574
-0x8FF9F2	0xE575
-0x8FF9F3	0xE576
-0x8FF9F4	0xE577
-0x8FF9F5	0xE578
-0x8FF9F6	0xE579
-0x8FF9F7	0xE57A
-0x8FF9F8	0xE57B
-0x8FF9F9	0xE57C
-0x8FF9FA	0xE57D
-0x8FF9FB	0xE57E
-0x8FF9FC	0xE57F
-0x8FF9FD	0xE580
-0x8FF9FE	0xE581
-0x8FFAA1	0xE582
-0x8FFAA2	0xE583
-0x8FFAA3	0xE584
-0x8FFAA4	0xE585
-0x8FFAA5	0xE586
-0x8FFAA6	0xE587
-0x8FFAA7	0xE588
-0x8FFAA8	0xE589
-0x8FFAA9	0xE58A
-0x8FFAAA	0xE58B
-0x8FFAAB	0xE58C
-0x8FFAAC	0xE58D
-0x8FFAAD	0xE58E
-0x8FFAAE	0xE58F
-0x8FFAAF	0xE590
-0x8FFAB0	0xE591
-0x8FFAB1	0xE592
-0x8FFAB2	0xE593
-0x8FFAB3	0xE594
-0x8FFAB4	0xE595
-0x8FFAB5	0xE596
-0x8FFAB6	0xE597
-0x8FFAB7	0xE598
-0x8FFAB8	0xE599
-0x8FFAB9	0xE59A
-0x8FFABA	0xE59B
-0x8FFABB	0xE59C
-0x8FFABC	0xE59D
-0x8FFABD	0xE59E
-0x8FFABE	0xE59F
-0x8FFABF	0xE5A0
-0x8FFAC0	0xE5A1
-0x8FFAC1	0xE5A2
-0x8FFAC2	0xE5A3
-0x8FFAC3	0xE5A4
-0x8FFAC4	0xE5A5
-0x8FFAC5	0xE5A6
-0x8FFAC6	0xE5A7
-0x8FFAC7	0xE5A8
-0x8FFAC8	0xE5A9
-0x8FFAC9	0xE5AA
-0x8FFACA	0xE5AB
-0x8FFACB	0xE5AC
-0x8FFACC	0xE5AD
-0x8FFACD	0xE5AE
-0x8FFACE	0xE5AF
-0x8FFACF	0xE5B0
-0x8FFAD0	0xE5B1
-0x8FFAD1	0xE5B2
-0x8FFAD2	0xE5B3
-0x8FFAD3	0xE5B4
-0x8FFAD4	0xE5B5
-0x8FFAD5	0xE5B6
-0x8FFAD6	0xE5B7
-0x8FFAD7	0xE5B8
-0x8FFAD8	0xE5B9
-0x8FFAD9	0xE5BA
-0x8FFADA	0xE5BB
-0x8FFADB	0xE5BC
-0x8FFADC	0xE5BD
-0x8FFADD	0xE5BE
-0x8FFADE	0xE5BF
-0x8FFADF	0xE5C0
-0x8FFAE0	0xE5C1
-0x8FFAE1	0xE5C2
-0x8FFAE2	0xE5C3
-0x8FFAE3	0xE5C4
-0x8FFAE4	0xE5C5
-0x8FFAE5	0xE5C6
-0x8FFAE6	0xE5C7
-0x8FFAE7	0xE5C8
-0x8FFAE8	0xE5C9
-0x8FFAE9	0xE5CA
-0x8FFAEA	0xE5CB
-0x8FFAEB	0xE5CC
-0x8FFAEC	0xE5CD
-0x8FFAED	0xE5CE
-0x8FFAEE	0xE5CF
-0x8FFAEF	0xE5D0
-0x8FFAF0	0xE5D1
-0x8FFAF1	0xE5D2
-0x8FFAF2	0xE5D3
-0x8FFAF3	0xE5D4
-0x8FFAF4	0xE5D5
-0x8FFAF5	0xE5D6
-0x8FFAF6	0xE5D7
-0x8FFAF7	0xE5D8
-0x8FFAF8	0xE5D9
-0x8FFAF9	0xE5DA
-0x8FFAFA	0xE5DB
-0x8FFAFB	0xE5DC
-0x8FFAFC	0xE5DD
-0x8FFAFD	0xE5DE
-0x8FFAFE	0xE5DF
-0x8FFBA1	0xE5E0
-0x8FFBA2	0xE5E1
-0x8FFBA3	0xE5E2
-0x8FFBA4	0xE5E3
-0x8FFBA5	0xE5E4
-0x8FFBA6	0xE5E5
-0x8FFBA7	0xE5E6
-0x8FFBA8	0xE5E7
-0x8FFBA9	0xE5E8
-0x8FFBAA	0xE5E9
-0x8FFBAB	0xE5EA
-0x8FFBAC	0xE5EB
-0x8FFBAD	0xE5EC
-0x8FFBAE	0xE5ED
-0x8FFBAF	0xE5EE
-0x8FFBB0	0xE5EF
-0x8FFBB1	0xE5F0
-0x8FFBB2	0xE5F1
-0x8FFBB3	0xE5F2
-0x8FFBB4	0xE5F3
-0x8FFBB5	0xE5F4
-0x8FFBB6	0xE5F5
-0x8FFBB7	0xE5F6
-0x8FFBB8	0xE5F7
-0x8FFBB9	0xE5F8
-0x8FFBBA	0xE5F9
-0x8FFBBB	0xE5FA
-0x8FFBBC	0xE5FB
-0x8FFBBD	0xE5FC
-0x8FFBBE	0xE5FD
-0x8FFBBF	0xE5FE
-0x8FFBC0	0xE5FF
-0x8FFBC1	0xE600
-0x8FFBC2	0xE601
-0x8FFBC3	0xE602
-0x8FFBC4	0xE603
-0x8FFBC5	0xE604
-0x8FFBC6	0xE605
-0x8FFBC7	0xE606
-0x8FFBC8	0xE607
-0x8FFBC9	0xE608
-0x8FFBCA	0xE609
-0x8FFBCB	0xE60A
-0x8FFBCC	0xE60B
-0x8FFBCD	0xE60C
-0x8FFBCE	0xE60D
-0x8FFBCF	0xE60E
-0x8FFBD0	0xE60F
-0x8FFBD1	0xE610
-0x8FFBD2	0xE611
-0x8FFBD3	0xE612
-0x8FFBD4	0xE613
-0x8FFBD5	0xE614
-0x8FFBD6	0xE615
-0x8FFBD7	0xE616
-0x8FFBD8	0xE617
-0x8FFBD9	0xE618
-0x8FFBDA	0xE619
-0x8FFBDB	0xE61A
-0x8FFBDC	0xE61B
-0x8FFBDD	0xE61C
-0x8FFBDE	0xE61D
-0x8FFBDF	0xE61E
-0x8FFBE0	0xE61F
-0x8FFBE1	0xE620
-0x8FFBE2	0xE621
-0x8FFBE3	0xE622
-0x8FFBE4	0xE623
-0x8FFBE5	0xE624
-0x8FFBE6	0xE625
-0x8FFBE7	0xE626
-0x8FFBE8	0xE627
-0x8FFBE9	0xE628
-0x8FFBEA	0xE629
-0x8FFBEB	0xE62A
-0x8FFBEC	0xE62B
-0x8FFBED	0xE62C
-0x8FFBEE	0xE62D
-0x8FFBEF	0xE62E
-0x8FFBF0	0xE62F
-0x8FFBF1	0xE630
-0x8FFBF2	0xE631
-0x8FFBF3	0xE632
-0x8FFBF4	0xE633
-0x8FFBF5	0xE634
-0x8FFBF6	0xE635
-0x8FFBF7	0xE636
-0x8FFBF8	0xE637
-0x8FFBF9	0xE638
-0x8FFBFA	0xE639
-0x8FFBFB	0xE63A
-0x8FFBFC	0xE63B
-0x8FFBFD	0xE63C
-0x8FFBFE	0xE63D
-0x8FFCA1	0xE63E
-0x8FFCA2	0xE63F
-0x8FFCA3	0xE640
-0x8FFCA4	0xE641
-0x8FFCA5	0xE642
-0x8FFCA6	0xE643
-0x8FFCA7	0xE644
-0x8FFCA8	0xE645
-0x8FFCA9	0xE646
-0x8FFCAA	0xE647
-0x8FFCAB	0xE648
-0x8FFCAC	0xE649
-0x8FFCAD	0xE64A
-0x8FFCAE	0xE64B
-0x8FFCAF	0xE64C
-0x8FFCB0	0xE64D
-0x8FFCB1	0xE64E
-0x8FFCB2	0xE64F
-0x8FFCB3	0xE650
-0x8FFCB4	0xE651
-0x8FFCB5	0xE652
-0x8FFCB6	0xE653
-0x8FFCB7	0xE654
-0x8FFCB8	0xE655
-0x8FFCB9	0xE656
-0x8FFCBA	0xE657
-0x8FFCBB	0xE658
-0x8FFCBC	0xE659
-0x8FFCBD	0xE65A
-0x8FFCBE	0xE65B
-0x8FFCBF	0xE65C
-0x8FFCC0	0xE65D
-0x8FFCC1	0xE65E
-0x8FFCC2	0xE65F
-0x8FFCC3	0xE660
-0x8FFCC4	0xE661
-0x8FFCC5	0xE662
-0x8FFCC6	0xE663
-0x8FFCC7	0xE664
-0x8FFCC8	0xE665
-0x8FFCC9	0xE666
-0x8FFCCA	0xE667
-0x8FFCCB	0xE668
-0x8FFCCC	0xE669
-0x8FFCCD	0xE66A
-0x8FFCCE	0xE66B
-0x8FFCCF	0xE66C
-0x8FFCD0	0xE66D
-0x8FFCD1	0xE66E
-0x8FFCD2	0xE66F
-0x8FFCD3	0xE670
-0x8FFCD4	0xE671
-0x8FFCD5	0xE672
-0x8FFCD6	0xE673
-0x8FFCD7	0xE674
-0x8FFCD8	0xE675
-0x8FFCD9	0xE676
-0x8FFCDA	0xE677
-0x8FFCDB	0xE678
-0x8FFCDC	0xE679
-0x8FFCDD	0xE67A
-0x8FFCDE	0xE67B
-0x8FFCDF	0xE67C
-0x8FFCE0	0xE67D
-0x8FFCE1	0xE67E
-0x8FFCE2	0xE67F
-0x8FFCE3	0xE680
-0x8FFCE4	0xE681
-0x8FFCE5	0xE682
-0x8FFCE6	0xE683
-0x8FFCE7	0xE684
-0x8FFCE8	0xE685
-0x8FFCE9	0xE686
-0x8FFCEA	0xE687
-0x8FFCEB	0xE688
-0x8FFCEC	0xE689
-0x8FFCED	0xE68A
-0x8FFCEE	0xE68B
-0x8FFCEF	0xE68C
-0x8FFCF0	0xE68D
-0x8FFCF1	0xE68E
-0x8FFCF2	0xE68F
-0x8FFCF3	0xE690
-0x8FFCF4	0xE691
-0x8FFCF5	0xE692
-0x8FFCF6	0xE693
-0x8FFCF7	0xE694
-0x8FFCF8	0xE695
-0x8FFCF9	0xE696
-0x8FFCFA	0xE697
-0x8FFCFB	0xE698
-0x8FFCFC	0xE699
-0x8FFCFD	0xE69A
-0x8FFCFE	0xE69B
-0x8FFDA1	0xE69C
-0x8FFDA2	0xE69D
-0x8FFDA3	0xE69E
-0x8FFDA4	0xE69F
-0x8FFDA5	0xE6A0
-0x8FFDA6	0xE6A1
-0x8FFDA7	0xE6A2
-0x8FFDA8	0xE6A3
-0x8FFDA9	0xE6A4
-0x8FFDAA	0xE6A5
-0x8FFDAB	0xE6A6
-0x8FFDAC	0xE6A7
-0x8FFDAD	0xE6A8
-0x8FFDAE	0xE6A9
-0x8FFDAF	0xE6AA
-0x8FFDB0	0xE6AB
-0x8FFDB1	0xE6AC
-0x8FFDB2	0xE6AD
-0x8FFDB3	0xE6AE
-0x8FFDB4	0xE6AF
-0x8FFDB5	0xE6B0
-0x8FFDB6	0xE6B1
-0x8FFDB7	0xE6B2
-0x8FFDB8	0xE6B3
-0x8FFDB9	0xE6B4
-0x8FFDBA	0xE6B5
-0x8FFDBB	0xE6B6
-0x8FFDBC	0xE6B7
-0x8FFDBD	0xE6B8
-0x8FFDBE	0xE6B9
-0x8FFDBF	0xE6BA
-0x8FFDC0	0xE6BB
-0x8FFDC1	0xE6BC
-0x8FFDC2	0xE6BD
-0x8FFDC3	0xE6BE
-0x8FFDC4	0xE6BF
-0x8FFDC5	0xE6C0
-0x8FFDC6	0xE6C1
-0x8FFDC7	0xE6C2
-0x8FFDC8	0xE6C3
-0x8FFDC9	0xE6C4
-0x8FFDCA	0xE6C5
-0x8FFDCB	0xE6C6
-0x8FFDCC	0xE6C7
-0x8FFDCD	0xE6C8
-0x8FFDCE	0xE6C9
-0x8FFDCF	0xE6CA
-0x8FFDD0	0xE6CB
-0x8FFDD1	0xE6CC
-0x8FFDD2	0xE6CD
-0x8FFDD3	0xE6CE
-0x8FFDD4	0xE6CF
-0x8FFDD5	0xE6D0
-0x8FFDD6	0xE6D1
-0x8FFDD7	0xE6D2
-0x8FFDD8	0xE6D3
-0x8FFDD9	0xE6D4
-0x8FFDDA	0xE6D5
-0x8FFDDB	0xE6D6
-0x8FFDDC	0xE6D7
-0x8FFDDD	0xE6D8
-0x8FFDDE	0xE6D9
-0x8FFDDF	0xE6DA
-0x8FFDE0	0xE6DB
-0x8FFDE1	0xE6DC
-0x8FFDE2	0xE6DD
-0x8FFDE3	0xE6DE
-0x8FFDE4	0xE6DF
-0x8FFDE5	0xE6E0
-0x8FFDE6	0xE6E1
-0x8FFDE7	0xE6E2
-0x8FFDE8	0xE6E3
-0x8FFDE9	0xE6E4
-0x8FFDEA	0xE6E5
-0x8FFDEB	0xE6E6
-0x8FFDEC	0xE6E7
-0x8FFDED	0xE6E8
-0x8FFDEE	0xE6E9
-0x8FFDEF	0xE6EA
-0x8FFDF0	0xE6EB
-0x8FFDF1	0xE6EC
-0x8FFDF2	0xE6ED
-0x8FFDF3	0xE6EE
-0x8FFDF4	0xE6EF
-0x8FFDF5	0xE6F0
-0x8FFDF6	0xE6F1
-0x8FFDF7	0xE6F2
-0x8FFDF8	0xE6F3
-0x8FFDF9	0xE6F4
-0x8FFDFA	0xE6F5
-0x8FFDFB	0xE6F6
-0x8FFDFC	0xE6F7
-0x8FFDFD	0xE6F8
-0x8FFDFE	0xE6F9
-0x8FFEA1	0xE6FA
-0x8FFEA2	0xE6FB
-0x8FFEA3	0xE6FC
-0x8FFEA4	0xE6FD
-0x8FFEA5	0xE6FE
-0x8FFEA6	0xE6FF
-0x8FFEA7	0xE700
-0x8FFEA8	0xE701
-0x8FFEA9	0xE702
-0x8FFEAA	0xE703
-0x8FFEAB	0xE704
-0x8FFEAC	0xE705
-0x8FFEAD	0xE706
-0x8FFEAE	0xE707
-0x8FFEAF	0xE708
-0x8FFEB0	0xE709
-0x8FFEB1	0xE70A
-0x8FFEB2	0xE70B
-0x8FFEB3	0xE70C
-0x8FFEB4	0xE70D
-0x8FFEB5	0xE70E
-0x8FFEB6	0xE70F
-0x8FFEB7	0xE710
-0x8FFEB8	0xE711
-0x8FFEB9	0xE712
-0x8FFEBA	0xE713
-0x8FFEBB	0xE714
-0x8FFEBC	0xE715
-0x8FFEBD	0xE716
-0x8FFEBE	0xE717
-0x8FFEBF	0xE718
-0x8FFEC0	0xE719
-0x8FFEC1	0xE71A
-0x8FFEC2	0xE71B
-0x8FFEC3	0xE71C
-0x8FFEC4	0xE71D
-0x8FFEC5	0xE71E
-0x8FFEC6	0xE71F
-0x8FFEC7	0xE720
-0x8FFEC8	0xE721
-0x8FFEC9	0xE722
-0x8FFECA	0xE723
-0x8FFECB	0xE724
-0x8FFECC	0xE725
-0x8FFECD	0xE726
-0x8FFECE	0xE727
-0x8FFECF	0xE728
-0x8FFED0	0xE729
-0x8FFED1	0xE72A
-0x8FFED2	0xE72B
-0x8FFED3	0xE72C
-0x8FFED4	0xE72D
-0x8FFED5	0xE72E
-0x8FFED6	0xE72F
-0x8FFED7	0xE730
-0x8FFED8	0xE731
-0x8FFED9	0xE732
-0x8FFEDA	0xE733
-0x8FFEDB	0xE734
-0x8FFEDC	0xE735
-0x8FFEDD	0xE736
-0x8FFEDE	0xE737
-0x8FFEDF	0xE738
-0x8FFEE0	0xE739
-0x8FFEE1	0xE73A
-0x8FFEE2	0xE73B
-0x8FFEE3	0xE73C
-0x8FFEE4	0xE73D
-0x8FFEE5	0xE73E
-0x8FFEE6	0xE73F
-0x8FFEE7	0xE740
-0x8FFEE8	0xE741
-0x8FFEE9	0xE742
-0x8FFEEA	0xE743
-0x8FFEEB	0xE744
-0x8FFEEC	0xE745
-0x8FFEED	0xE746
-0x8FFEEE	0xE747
-0x8FFEEF	0xE748
-0x8FFEF0	0xE749
-0x8FFEF1	0xE74A
-0x8FFEF2	0xE74B
-0x8FFEF3	0xE74C
-0x8FFEF4	0xE74D
-0x8FFEF5	0xE74E
-0x8FFEF6	0xE74F
-0x8FFEF7	0xE750
-0x8FFEF8	0xE751
-0x8FFEF9	0xE752
-0x8FFEFA	0xE753
-0x8FFEFB	0xE754
-0x8FFEFC	0xE755
-0x8FFEFD	0xE756
-0x8FFEFE	0xE757
 0xA1A1	0x3000
 0xA1A2	0x3001
 0xA1A3	0x3002
@@ -7224,7 +6284,7 @@
 0xA1BA	0x3006
 0xA1BB	0x3007
 0xA1BC	0x30FC
-0xA1BD	0x2015
+0xA1BD	0x2014
 0xA1BE	0x2010
 0xA1BF	0xFF0F
 0xA1C0	0xFF3C
@@ -14075,943 +13135,3 @@
 0xF4A4	0x7464
 0xF4A5	0x51DC
 0xF4A6	0x7199
-0xF5A1	0xE000
-0xF5A2	0xE001
-0xF5A3	0xE002
-0xF5A4	0xE003
-0xF5A5	0xE004
-0xF5A6	0xE005
-0xF5A7	0xE006
-0xF5A8	0xE007
-0xF5A9	0xE008
-0xF5AA	0xE009
-0xF5AB	0xE00A
-0xF5AC	0xE00B
-0xF5AD	0xE00C
-0xF5AE	0xE00D
-0xF5AF	0xE00E
-0xF5B0	0xE00F
-0xF5B1	0xE010
-0xF5B2	0xE011
-0xF5B3	0xE012
-0xF5B4	0xE013
-0xF5B5	0xE014
-0xF5B6	0xE015
-0xF5B7	0xE016
-0xF5B8	0xE017
-0xF5B9	0xE018
-0xF5BA	0xE019
-0xF5BB	0xE01A
-0xF5BC	0xE01B
-0xF5BD	0xE01C
-0xF5BE	0xE01D
-0xF5BF	0xE01E
-0xF5C0	0xE01F
-0xF5C1	0xE020
-0xF5C2	0xE021
-0xF5C3	0xE022
-0xF5C4	0xE023
-0xF5C5	0xE024
-0xF5C6	0xE025
-0xF5C7	0xE026
-0xF5C8	0xE027
-0xF5C9	0xE028
-0xF5CA	0xE029
-0xF5CB	0xE02A
-0xF5CC	0xE02B
-0xF5CD	0xE02C
-0xF5CE	0xE02D
-0xF5CF	0xE02E
-0xF5D0	0xE02F
-0xF5D1	0xE030
-0xF5D2	0xE031
-0xF5D3	0xE032
-0xF5D4	0xE033
-0xF5D5	0xE034
-0xF5D6	0xE035
-0xF5D7	0xE036
-0xF5D8	0xE037
-0xF5D9	0xE038
-0xF5DA	0xE039
-0xF5DB	0xE03A
-0xF5DC	0xE03B
-0xF5DD	0xE03C
-0xF5DE	0xE03D
-0xF5DF	0xE03E
-0xF5E0	0xE03F
-0xF5E1	0xE040
-0xF5E2	0xE041
-0xF5E3	0xE042
-0xF5E4	0xE043
-0xF5E5	0xE044
-0xF5E6	0xE045
-0xF5E7	0xE046
-0xF5E8	0xE047
-0xF5E9	0xE048
-0xF5EA	0xE049
-0xF5EB	0xE04A
-0xF5EC	0xE04B
-0xF5ED	0xE04C
-0xF5EE	0xE04D
-0xF5EF	0xE04E
-0xF5F0	0xE04F
-0xF5F1	0xE050
-0xF5F2	0xE051
-0xF5F3	0xE052
-0xF5F4	0xE053
-0xF5F5	0xE054
-0xF5F6	0xE055
-0xF5F7	0xE056
-0xF5F8	0xE057
-0xF5F9	0xE058
-0xF5FA	0xE059
-0xF5FB	0xE05A
-0xF5FC	0xE05B
-0xF5FD	0xE05C
-0xF5FE	0xE05D
-0xF6A1	0xE05E
-0xF6A2	0xE05F
-0xF6A3	0xE060
-0xF6A4	0xE061
-0xF6A5	0xE062
-0xF6A6	0xE063
-0xF6A7	0xE064
-0xF6A8	0xE065
-0xF6A9	0xE066
-0xF6AA	0xE067
-0xF6AB	0xE068
-0xF6AC	0xE069
-0xF6AD	0xE06A
-0xF6AE	0xE06B
-0xF6AF	0xE06C
-0xF6B0	0xE06D
-0xF6B1	0xE06E
-0xF6B2	0xE06F
-0xF6B3	0xE070
-0xF6B4	0xE071
-0xF6B5	0xE072
-0xF6B6	0xE073
-0xF6B7	0xE074
-0xF6B8	0xE075
-0xF6B9	0xE076
-0xF6BA	0xE077
-0xF6BB	0xE078
-0xF6BC	0xE079
-0xF6BD	0xE07A
-0xF6BE	0xE07B
-0xF6BF	0xE07C
-0xF6C0	0xE07D
-0xF6C1	0xE07E
-0xF6C2	0xE07F
-0xF6C3	0xE080
-0xF6C4	0xE081
-0xF6C5	0xE082
-0xF6C6	0xE083
-0xF6C7	0xE084
-0xF6C8	0xE085
-0xF6C9	0xE086
-0xF6CA	0xE087
-0xF6CB	0xE088
-0xF6CC	0xE089
-0xF6CD	0xE08A
-0xF6CE	0xE08B
-0xF6CF	0xE08C
-0xF6D0	0xE08D
-0xF6D1	0xE08E
-0xF6D2	0xE08F
-0xF6D3	0xE090
-0xF6D4	0xE091
-0xF6D5	0xE092
-0xF6D6	0xE093
-0xF6D7	0xE094
-0xF6D8	0xE095
-0xF6D9	0xE096
-0xF6DA	0xE097
-0xF6DB	0xE098
-0xF6DC	0xE099
-0xF6DD	0xE09A
-0xF6DE	0xE09B
-0xF6DF	0xE09C
-0xF6E0	0xE09D
-0xF6E1	0xE09E
-0xF6E2	0xE09F
-0xF6E3	0xE0A0
-0xF6E4	0xE0A1
-0xF6E5	0xE0A2
-0xF6E6	0xE0A3
-0xF6E7	0xE0A4
-0xF6E8	0xE0A5
-0xF6E9	0xE0A6
-0xF6EA	0xE0A7
-0xF6EB	0xE0A8
-0xF6EC	0xE0A9
-0xF6ED	0xE0AA
-0xF6EE	0xE0AB
-0xF6EF	0xE0AC
-0xF6F0	0xE0AD
-0xF6F1	0xE0AE
-0xF6F2	0xE0AF
-0xF6F3	0xE0B0
-0xF6F4	0xE0B1
-0xF6F5	0xE0B2
-0xF6F6	0xE0B3
-0xF6F7	0xE0B4
-0xF6F8	0xE0B5
-0xF6F9	0xE0B6
-0xF6FA	0xE0B7
-0xF6FB	0xE0B8
-0xF6FC	0xE0B9
-0xF6FD	0xE0BA
-0xF6FE	0xE0BB
-0xF7A1	0xE0BC
-0xF7A2	0xE0BD
-0xF7A3	0xE0BE
-0xF7A4	0xE0BF
-0xF7A5	0xE0C0
-0xF7A6	0xE0C1
-0xF7A7	0xE0C2
-0xF7A8	0xE0C3
-0xF7A9	0xE0C4
-0xF7AA	0xE0C5
-0xF7AB	0xE0C6
-0xF7AC	0xE0C7
-0xF7AD	0xE0C8
-0xF7AE	0xE0C9
-0xF7AF	0xE0CA
-0xF7B0	0xE0CB
-0xF7B1	0xE0CC
-0xF7B2	0xE0CD
-0xF7B3	0xE0CE
-0xF7B4	0xE0CF
-0xF7B5	0xE0D0
-0xF7B6	0xE0D1
-0xF7B7	0xE0D2
-0xF7B8	0xE0D3
-0xF7B9	0xE0D4
-0xF7BA	0xE0D5
-0xF7BB	0xE0D6
-0xF7BC	0xE0D7
-0xF7BD	0xE0D8
-0xF7BE	0xE0D9
-0xF7BF	0xE0DA
-0xF7C0	0xE0DB
-0xF7C1	0xE0DC
-0xF7C2	0xE0DD
-0xF7C3	0xE0DE
-0xF7C4	0xE0DF
-0xF7C5	0xE0E0
-0xF7C6	0xE0E1
-0xF7C7	0xE0E2
-0xF7C8	0xE0E3
-0xF7C9	0xE0E4
-0xF7CA	0xE0E5
-0xF7CB	0xE0E6
-0xF7CC	0xE0E7
-0xF7CD	0xE0E8
-0xF7CE	0xE0E9
-0xF7CF	0xE0EA
-0xF7D0	0xE0EB
-0xF7D1	0xE0EC
-0xF7D2	0xE0ED
-0xF7D3	0xE0EE
-0xF7D4	0xE0EF
-0xF7D5	0xE0F0
-0xF7D6	0xE0F1
-0xF7D7	0xE0F2
-0xF7D8	0xE0F3
-0xF7D9	0xE0F4
-0xF7DA	0xE0F5
-0xF7DB	0xE0F6
-0xF7DC	0xE0F7
-0xF7DD	0xE0F8
-0xF7DE	0xE0F9
-0xF7DF	0xE0FA
-0xF7E0	0xE0FB
-0xF7E1	0xE0FC
-0xF7E2	0xE0FD
-0xF7E3	0xE0FE
-0xF7E4	0xE0FF
-0xF7E5	0xE100
-0xF7E6	0xE101
-0xF7E7	0xE102
-0xF7E8	0xE103
-0xF7E9	0xE104
-0xF7EA	0xE105
-0xF7EB	0xE106
-0xF7EC	0xE107
-0xF7ED	0xE108
-0xF7EE	0xE109
-0xF7EF	0xE10A
-0xF7F0	0xE10B
-0xF7F1	0xE10C
-0xF7F2	0xE10D
-0xF7F3	0xE10E
-0xF7F4	0xE10F
-0xF7F5	0xE110
-0xF7F6	0xE111
-0xF7F7	0xE112
-0xF7F8	0xE113
-0xF7F9	0xE114
-0xF7FA	0xE115
-0xF7FB	0xE116
-0xF7FC	0xE117
-0xF7FD	0xE118
-0xF7FE	0xE119
-0xF8A1	0xE11A
-0xF8A2	0xE11B
-0xF8A3	0xE11C
-0xF8A4	0xE11D
-0xF8A5	0xE11E
-0xF8A6	0xE11F
-0xF8A7	0xE120
-0xF8A8	0xE121
-0xF8A9	0xE122
-0xF8AA	0xE123
-0xF8AB	0xE124
-0xF8AC	0xE125
-0xF8AD	0xE126
-0xF8AE	0xE127
-0xF8AF	0xE128
-0xF8B0	0xE129
-0xF8B1	0xE12A
-0xF8B2	0xE12B
-0xF8B3	0xE12C
-0xF8B4	0xE12D
-0xF8B5	0xE12E
-0xF8B6	0xE12F
-0xF8B7	0xE130
-0xF8B8	0xE131
-0xF8B9	0xE132
-0xF8BA	0xE133
-0xF8BB	0xE134
-0xF8BC	0xE135
-0xF8BD	0xE136
-0xF8BE	0xE137
-0xF8BF	0xE138
-0xF8C0	0xE139
-0xF8C1	0xE13A
-0xF8C2	0xE13B
-0xF8C3	0xE13C
-0xF8C4	0xE13D
-0xF8C5	0xE13E
-0xF8C6	0xE13F
-0xF8C7	0xE140
-0xF8C8	0xE141
-0xF8C9	0xE142
-0xF8CA	0xE143
-0xF8CB	0xE144
-0xF8CC	0xE145
-0xF8CD	0xE146
-0xF8CE	0xE147
-0xF8CF	0xE148
-0xF8D0	0xE149
-0xF8D1	0xE14A
-0xF8D2	0xE14B
-0xF8D3	0xE14C
-0xF8D4	0xE14D
-0xF8D5	0xE14E
-0xF8D6	0xE14F
-0xF8D7	0xE150
-0xF8D8	0xE151
-0xF8D9	0xE152
-0xF8DA	0xE153
-0xF8DB	0xE154
-0xF8DC	0xE155
-0xF8DD	0xE156
-0xF8DE	0xE157
-0xF8DF	0xE158
-0xF8E0	0xE159
-0xF8E1	0xE15A
-0xF8E2	0xE15B
-0xF8E3	0xE15C
-0xF8E4	0xE15D
-0xF8E5	0xE15E
-0xF8E6	0xE15F
-0xF8E7	0xE160
-0xF8E8	0xE161
-0xF8E9	0xE162
-0xF8EA	0xE163
-0xF8EB	0xE164
-0xF8EC	0xE165
-0xF8ED	0xE166
-0xF8EE	0xE167
-0xF8EF	0xE168
-0xF8F0	0xE169
-0xF8F1	0xE16A
-0xF8F2	0xE16B
-0xF8F3	0xE16C
-0xF8F4	0xE16D
-0xF8F5	0xE16E
-0xF8F6	0xE16F
-0xF8F7	0xE170
-0xF8F8	0xE171
-0xF8F9	0xE172
-0xF8FA	0xE173
-0xF8FB	0xE174
-0xF8FC	0xE175
-0xF8FD	0xE176
-0xF8FE	0xE177
-0xF9A1	0xE178
-0xF9A2	0xE179
-0xF9A3	0xE17A
-0xF9A4	0xE17B
-0xF9A5	0xE17C
-0xF9A6	0xE17D
-0xF9A7	0xE17E
-0xF9A8	0xE17F
-0xF9A9	0xE180
-0xF9AA	0xE181
-0xF9AB	0xE182
-0xF9AC	0xE183
-0xF9AD	0xE184
-0xF9AE	0xE185
-0xF9AF	0xE186
-0xF9B0	0xE187
-0xF9B1	0xE188
-0xF9B2	0xE189
-0xF9B3	0xE18A
-0xF9B4	0xE18B
-0xF9B5	0xE18C
-0xF9B6	0xE18D
-0xF9B7	0xE18E
-0xF9B8	0xE18F
-0xF9B9	0xE190
-0xF9BA	0xE191
-0xF9BB	0xE192
-0xF9BC	0xE193
-0xF9BD	0xE194
-0xF9BE	0xE195
-0xF9BF	0xE196
-0xF9C0	0xE197
-0xF9C1	0xE198
-0xF9C2	0xE199
-0xF9C3	0xE19A
-0xF9C4	0xE19B
-0xF9C5	0xE19C
-0xF9C6	0xE19D
-0xF9C7	0xE19E
-0xF9C8	0xE19F
-0xF9C9	0xE1A0
-0xF9CA	0xE1A1
-0xF9CB	0xE1A2
-0xF9CC	0xE1A3
-0xF9CD	0xE1A4
-0xF9CE	0xE1A5
-0xF9CF	0xE1A6
-0xF9D0	0xE1A7
-0xF9D1	0xE1A8
-0xF9D2	0xE1A9
-0xF9D3	0xE1AA
-0xF9D4	0xE1AB
-0xF9D5	0xE1AC
-0xF9D6	0xE1AD
-0xF9D7	0xE1AE
-0xF9D8	0xE1AF
-0xF9D9	0xE1B0
-0xF9DA	0xE1B1
-0xF9DB	0xE1B2
-0xF9DC	0xE1B3
-0xF9DD	0xE1B4
-0xF9DE	0xE1B5
-0xF9DF	0xE1B6
-0xF9E0	0xE1B7
-0xF9E1	0xE1B8
-0xF9E2	0xE1B9
-0xF9E3	0xE1BA
-0xF9E4	0xE1BB
-0xF9E5	0xE1BC
-0xF9E6	0xE1BD
-0xF9E7	0xE1BE
-0xF9E8	0xE1BF
-0xF9E9	0xE1C0
-0xF9EA	0xE1C1
-0xF9EB	0xE1C2
-0xF9EC	0xE1C3
-0xF9ED	0xE1C4
-0xF9EE	0xE1C5
-0xF9EF	0xE1C6
-0xF9F0	0xE1C7
-0xF9F1	0xE1C8
-0xF9F2	0xE1C9
-0xF9F3	0xE1CA
-0xF9F4	0xE1CB
-0xF9F5	0xE1CC
-0xF9F6	0xE1CD
-0xF9F7	0xE1CE
-0xF9F8	0xE1CF
-0xF9F9	0xE1D0
-0xF9FA	0xE1D1
-0xF9FB	0xE1D2
-0xF9FC	0xE1D3
-0xF9FD	0xE1D4
-0xF9FE	0xE1D5
-0xFAA1	0xE1D6
-0xFAA2	0xE1D7
-0xFAA3	0xE1D8
-0xFAA4	0xE1D9
-0xFAA5	0xE1DA
-0xFAA6	0xE1DB
-0xFAA7	0xE1DC
-0xFAA8	0xE1DD
-0xFAA9	0xE1DE
-0xFAAA	0xE1DF
-0xFAAB	0xE1E0
-0xFAAC	0xE1E1
-0xFAAD	0xE1E2
-0xFAAE	0xE1E3
-0xFAAF	0xE1E4
-0xFAB0	0xE1E5
-0xFAB1	0xE1E6
-0xFAB2	0xE1E7
-0xFAB3	0xE1E8
-0xFAB4	0xE1E9
-0xFAB5	0xE1EA
-0xFAB6	0xE1EB
-0xFAB7	0xE1EC
-0xFAB8	0xE1ED
-0xFAB9	0xE1EE
-0xFABA	0xE1EF
-0xFABB	0xE1F0
-0xFABC	0xE1F1
-0xFABD	0xE1F2
-0xFABE	0xE1F3
-0xFABF	0xE1F4
-0xFAC0	0xE1F5
-0xFAC1	0xE1F6
-0xFAC2	0xE1F7
-0xFAC3	0xE1F8
-0xFAC4	0xE1F9
-0xFAC5	0xE1FA
-0xFAC6	0xE1FB
-0xFAC7	0xE1FC
-0xFAC8	0xE1FD
-0xFAC9	0xE1FE
-0xFACA	0xE1FF
-0xFACB	0xE200
-0xFACC	0xE201
-0xFACD	0xE202
-0xFACE	0xE203
-0xFACF	0xE204
-0xFAD0	0xE205
-0xFAD1	0xE206
-0xFAD2	0xE207
-0xFAD3	0xE208
-0xFAD4	0xE209
-0xFAD5	0xE20A
-0xFAD6	0xE20B
-0xFAD7	0xE20C
-0xFAD8	0xE20D
-0xFAD9	0xE20E
-0xFADA	0xE20F
-0xFADB	0xE210
-0xFADC	0xE211
-0xFADD	0xE212
-0xFADE	0xE213
-0xFADF	0xE214
-0xFAE0	0xE215
-0xFAE1	0xE216
-0xFAE2	0xE217
-0xFAE3	0xE218
-0xFAE4	0xE219
-0xFAE5	0xE21A
-0xFAE6	0xE21B
-0xFAE7	0xE21C
-0xFAE8	0xE21D
-0xFAE9	0xE21E
-0xFAEA	0xE21F
-0xFAEB	0xE220
-0xFAEC	0xE221
-0xFAED	0xE222
-0xFAEE	0xE223
-0xFAEF	0xE224
-0xFAF0	0xE225
-0xFAF1	0xE226
-0xFAF2	0xE227
-0xFAF3	0xE228
-0xFAF4	0xE229
-0xFAF5	0xE22A
-0xFAF6	0xE22B
-0xFAF7	0xE22C
-0xFAF8	0xE22D
-0xFAF9	0xE22E
-0xFAFA	0xE22F
-0xFAFB	0xE230
-0xFAFC	0xE231
-0xFAFD	0xE232
-0xFAFE	0xE233
-0xFBA1	0xE234
-0xFBA2	0xE235
-0xFBA3	0xE236
-0xFBA4	0xE237
-0xFBA5	0xE238
-0xFBA6	0xE239
-0xFBA7	0xE23A
-0xFBA8	0xE23B
-0xFBA9	0xE23C
-0xFBAA	0xE23D
-0xFBAB	0xE23E
-0xFBAC	0xE23F
-0xFBAD	0xE240
-0xFBAE	0xE241
-0xFBAF	0xE242
-0xFBB0	0xE243
-0xFBB1	0xE244
-0xFBB2	0xE245
-0xFBB3	0xE246
-0xFBB4	0xE247
-0xFBB5	0xE248
-0xFBB6	0xE249
-0xFBB7	0xE24A
-0xFBB8	0xE24B
-0xFBB9	0xE24C
-0xFBBA	0xE24D
-0xFBBB	0xE24E
-0xFBBC	0xE24F
-0xFBBD	0xE250
-0xFBBE	0xE251
-0xFBBF	0xE252
-0xFBC0	0xE253
-0xFBC1	0xE254
-0xFBC2	0xE255
-0xFBC3	0xE256
-0xFBC4	0xE257
-0xFBC5	0xE258
-0xFBC6	0xE259
-0xFBC7	0xE25A
-0xFBC8	0xE25B
-0xFBC9	0xE25C
-0xFBCA	0xE25D
-0xFBCB	0xE25E
-0xFBCC	0xE25F
-0xFBCD	0xE260
-0xFBCE	0xE261
-0xFBCF	0xE262
-0xFBD0	0xE263
-0xFBD1	0xE264
-0xFBD2	0xE265
-0xFBD3	0xE266
-0xFBD4	0xE267
-0xFBD5	0xE268
-0xFBD6	0xE269
-0xFBD7	0xE26A
-0xFBD8	0xE26B
-0xFBD9	0xE26C
-0xFBDA	0xE26D
-0xFBDB	0xE26E
-0xFBDC	0xE26F
-0xFBDD	0xE270
-0xFBDE	0xE271
-0xFBDF	0xE272
-0xFBE0	0xE273
-0xFBE1	0xE274
-0xFBE2	0xE275
-0xFBE3	0xE276
-0xFBE4	0xE277
-0xFBE5	0xE278
-0xFBE6	0xE279
-0xFBE7	0xE27A
-0xFBE8	0xE27B
-0xFBE9	0xE27C
-0xFBEA	0xE27D
-0xFBEB	0xE27E
-0xFBEC	0xE27F
-0xFBED	0xE280
-0xFBEE	0xE281
-0xFBEF	0xE282
-0xFBF0	0xE283
-0xFBF1	0xE284
-0xFBF2	0xE285
-0xFBF3	0xE286
-0xFBF4	0xE287
-0xFBF5	0xE288
-0xFBF6	0xE289
-0xFBF7	0xE28A
-0xFBF8	0xE28B
-0xFBF9	0xE28C
-0xFBFA	0xE28D
-0xFBFB	0xE28E
-0xFBFC	0xE28F
-0xFBFD	0xE290
-0xFBFE	0xE291
-0xFCA1	0xE292
-0xFCA2	0xE293
-0xFCA3	0xE294
-0xFCA4	0xE295
-0xFCA5	0xE296
-0xFCA6	0xE297
-0xFCA7	0xE298
-0xFCA8	0xE299
-0xFCA9	0xE29A
-0xFCAA	0xE29B
-0xFCAB	0xE29C
-0xFCAC	0xE29D
-0xFCAD	0xE29E
-0xFCAE	0xE29F
-0xFCAF	0xE2A0
-0xFCB0	0xE2A1
-0xFCB1	0xE2A2
-0xFCB2	0xE2A3
-0xFCB3	0xE2A4
-0xFCB4	0xE2A5
-0xFCB5	0xE2A6
-0xFCB6	0xE2A7
-0xFCB7	0xE2A8
-0xFCB8	0xE2A9
-0xFCB9	0xE2AA
-0xFCBA	0xE2AB
-0xFCBB	0xE2AC
-0xFCBC	0xE2AD
-0xFCBD	0xE2AE
-0xFCBE	0xE2AF
-0xFCBF	0xE2B0
-0xFCC0	0xE2B1
-0xFCC1	0xE2B2
-0xFCC2	0xE2B3
-0xFCC3	0xE2B4
-0xFCC4	0xE2B5
-0xFCC5	0xE2B6
-0xFCC6	0xE2B7
-0xFCC7	0xE2B8
-0xFCC8	0xE2B9
-0xFCC9	0xE2BA
-0xFCCA	0xE2BB
-0xFCCB	0xE2BC
-0xFCCC	0xE2BD
-0xFCCD	0xE2BE
-0xFCCE	0xE2BF
-0xFCCF	0xE2C0
-0xFCD0	0xE2C1
-0xFCD1	0xE2C2
-0xFCD2	0xE2C3
-0xFCD3	0xE2C4
-0xFCD4	0xE2C5
-0xFCD5	0xE2C6
-0xFCD6	0xE2C7
-0xFCD7	0xE2C8
-0xFCD8	0xE2C9
-0xFCD9	0xE2CA
-0xFCDA	0xE2CB
-0xFCDB	0xE2CC
-0xFCDC	0xE2CD
-0xFCDD	0xE2CE
-0xFCDE	0xE2CF
-0xFCDF	0xE2D0
-0xFCE0	0xE2D1
-0xFCE1	0xE2D2
-0xFCE2	0xE2D3
-0xFCE3	0xE2D4
-0xFCE4	0xE2D5
-0xFCE5	0xE2D6
-0xFCE6	0xE2D7
-0xFCE7	0xE2D8
-0xFCE8	0xE2D9
-0xFCE9	0xE2DA
-0xFCEA	0xE2DB
-0xFCEB	0xE2DC
-0xFCEC	0xE2DD
-0xFCED	0xE2DE
-0xFCEE	0xE2DF
-0xFCEF	0xE2E0
-0xFCF0	0xE2E1
-0xFCF1	0xE2E2
-0xFCF2	0xE2E3
-0xFCF3	0xE2E4
-0xFCF4	0xE2E5
-0xFCF5	0xE2E6
-0xFCF6	0xE2E7
-0xFCF7	0xE2E8
-0xFCF8	0xE2E9
-0xFCF9	0xE2EA
-0xFCFA	0xE2EB
-0xFCFB	0xE2EC
-0xFCFC	0xE2ED
-0xFCFD	0xE2EE
-0xFCFE	0xE2EF
-0xFDA1	0xE2F0
-0xFDA2	0xE2F1
-0xFDA3	0xE2F2
-0xFDA4	0xE2F3
-0xFDA5	0xE2F4
-0xFDA6	0xE2F5
-0xFDA7	0xE2F6
-0xFDA8	0xE2F7
-0xFDA9	0xE2F8
-0xFDAA	0xE2F9
-0xFDAB	0xE2FA
-0xFDAC	0xE2FB
-0xFDAD	0xE2FC
-0xFDAE	0xE2FD
-0xFDAF	0xE2FE
-0xFDB0	0xE2FF
-0xFDB1	0xE300
-0xFDB2	0xE301
-0xFDB3	0xE302
-0xFDB4	0xE303
-0xFDB5	0xE304
-0xFDB6	0xE305
-0xFDB7	0xE306
-0xFDB8	0xE307
-0xFDB9	0xE308
-0xFDBA	0xE309
-0xFDBB	0xE30A
-0xFDBC	0xE30B
-0xFDBD	0xE30C
-0xFDBE	0xE30D
-0xFDBF	0xE30E
-0xFDC0	0xE30F
-0xFDC1	0xE310
-0xFDC2	0xE311
-0xFDC3	0xE312
-0xFDC4	0xE313
-0xFDC5	0xE314
-0xFDC6	0xE315
-0xFDC7	0xE316
-0xFDC8	0xE317
-0xFDC9	0xE318
-0xFDCA	0xE319
-0xFDCB	0xE31A
-0xFDCC	0xE31B
-0xFDCD	0xE31C
-0xFDCE	0xE31D
-0xFDCF	0xE31E
-0xFDD0	0xE31F
-0xFDD1	0xE320
-0xFDD2	0xE321
-0xFDD3	0xE322
-0xFDD4	0xE323
-0xFDD5	0xE324
-0xFDD6	0xE325
-0xFDD7	0xE326
-0xFDD8	0xE327
-0xFDD9	0xE328
-0xFDDA	0xE329
-0xFDDB	0xE32A
-0xFDDC	0xE32B
-0xFDDD	0xE32C
-0xFDDE	0xE32D
-0xFDDF	0xE32E
-0xFDE0	0xE32F
-0xFDE1	0xE330
-0xFDE2	0xE331
-0xFDE3	0xE332
-0xFDE4	0xE333
-0xFDE5	0xE334
-0xFDE6	0xE335
-0xFDE7	0xE336
-0xFDE8	0xE337
-0xFDE9	0xE338
-0xFDEA	0xE339
-0xFDEB	0xE33A
-0xFDEC	0xE33B
-0xFDED	0xE33C
-0xFDEE	0xE33D
-0xFDEF	0xE33E
-0xFDF0	0xE33F
-0xFDF1	0xE340
-0xFDF2	0xE341
-0xFDF3	0xE342
-0xFDF4	0xE343
-0xFDF5	0xE344
-0xFDF6	0xE345
-0xFDF7	0xE346
-0xFDF8	0xE347
-0xFDF9	0xE348
-0xFDFA	0xE349
-0xFDFB	0xE34A
-0xFDFC	0xE34B
-0xFDFD	0xE34C
-0xFDFE	0xE34D
-0xFEA1	0xE34E
-0xFEA2	0xE34F
-0xFEA3	0xE350
-0xFEA4	0xE351
-0xFEA5	0xE352
-0xFEA6	0xE353
-0xFEA7	0xE354
-0xFEA8	0xE355
-0xFEA9	0xE356
-0xFEAA	0xE357
-0xFEAB	0xE358
-0xFEAC	0xE359
-0xFEAD	0xE35A
-0xFEAE	0xE35B
-0xFEAF	0xE35C
-0xFEB0	0xE35D
-0xFEB1	0xE35E
-0xFEB2	0xE35F
-0xFEB3	0xE360
-0xFEB4	0xE361
-0xFEB5	0xE362
-0xFEB6	0xE363
-0xFEB7	0xE364
-0xFEB8	0xE365
-0xFEB9	0xE366
-0xFEBA	0xE367
-0xFEBB	0xE368
-0xFEBC	0xE369
-0xFEBD	0xE36A
-0xFEBE	0xE36B
-0xFEBF	0xE36C
-0xFEC0	0xE36D
-0xFEC1	0xE36E
-0xFEC2	0xE36F
-0xFEC3	0xE370
-0xFEC4	0xE371
-0xFEC5	0xE372
-0xFEC6	0xE373
-0xFEC7	0xE374
-0xFEC8	0xE375
-0xFEC9	0xE376
-0xFECA	0xE377
-0xFECB	0xE378
-0xFECC	0xE379
-0xFECD	0xE37A
-0xFECE	0xE37B
-0xFECF	0xE37C
-0xFED0	0xE37D
-0xFED1	0xE37E
-0xFED2	0xE37F
-0xFED3	0xE380
-0xFED4	0xE381
-0xFED5	0xE382
-0xFED6	0xE383
-0xFED7	0xE384
-0xFED8	0xE385
-0xFED9	0xE386
-0xFEDA	0xE387
-0xFEDB	0xE388
-0xFEDC	0xE389
-0xFEDD	0xE38A
-0xFEDE	0xE38B
-0xFEDF	0xE38C
-0xFEE0	0xE38D
-0xFEE1	0xE38E
-0xFEE2	0xE38F
-0xFEE3	0xE390
-0xFEE4	0xE391
-0xFEE5	0xE392
-0xFEE6	0xE393
-0xFEE7	0xE394
-0xFEE8	0xE395
-0xFEE9	0xE396
-0xFEEA	0xE397
-0xFEEB	0xE398
-0xFEEC	0xE399
-0xFEED	0xE39A
-0xFEEE	0xE39B
-0xFEEF	0xE39C
-0xFEF0	0xE39D
-0xFEF1	0xE39E
-0xFEF2	0xE39F
-0xFEF3	0xE3A0
-0xFEF4	0xE3A1
-0xFEF5	0xE3A2
-0xFEF6	0xE3A3
-0xFEF7	0xE3A4
-0xFEF8	0xE3A5
-0xFEF9	0xE3A6
-0xFEFA	0xE3A7
-0xFEFB	0xE3A8
-0xFEFC	0xE3A9
-0xFEFD	0xE3AA
-0xFEFE	0xE3AB
diff -uprN libiconv-1.15-old/tests/EUCJP-MS.IRREVERSIBLE.TXT libiconv-1.15/tests/EUCJP-MS.IRREVERSIBLE.TXT
--- libiconv-1.15-old/tests/EUCJP-MS.IRREVERSIBLE.TXT	1970-01-01 09:00:00.000000000 +0900
+++ libiconv-1.15/tests/EUCJP-MS.IRREVERSIBLE.TXT	2017-09-17 05:38:54.054648000 +0900
@@ -0,0 +1,34 @@
+0x5C	0x00A5
+0x7E	0x203E
+0x8FA2B7	0xFF5E
+0x8FA2C3	0x00A6
+0x8FA2F1	0x2116
+0x8FF3FD	0x2160
+0x8FF3FE	0x2161
+0x8FF4A1	0x2162
+0x8FF4A2	0x2163
+0x8FF4A3	0x2164
+0x8FF4A4	0x2165
+0x8FF4A5	0x2166
+0x8FF4A6	0x2167
+0x8FF4A7	0x2168
+0x8FF4A8	0x2169
+0x8FF4AB	0x3231
+0x8FF4AC	0x2116
+0x8FF4AD	0x2121
+0xA1BD	0x2014
+0xA1C1	0x301C
+0xA1C2	0x2016
+0xA1DD	0x2212
+0xA1F1	0x00A2
+0xA1F2	0x00A3
+0xA2CC	0x00AC
+0xADF0	0x2252
+0xADF1	0x2261
+0xADF2	0x222B
+0xADF5	0x221A
+0xADF6	0x22A5
+0xADF7	0x2220
+0xADFA	0x2235
+0xADFB	0x2229
+0xADFC	0x222A
diff -uprN libiconv-1.15-old/tests/EUCJP-MS.TXT libiconv-1.15/tests/EUCJP-MS.TXT
--- libiconv-1.15-old/tests/EUCJP-MS.TXT	1970-01-01 09:00:00.000000000 +0900
+++ libiconv-1.15/tests/EUCJP-MS.TXT	2017-09-17 05:38:54.203265000 +0900
@@ -0,0 +1,15206 @@
+0x00	0x0000
+0x01	0x0001
+0x02	0x0002
+0x03	0x0003
+0x04	0x0004
+0x05	0x0005
+0x06	0x0006
+0x07	0x0007
+0x08	0x0008
+0x09	0x0009
+0x0A	0x000A
+0x0B	0x000B
+0x0C	0x000C
+0x0D	0x000D
+0x0E	0x000E
+0x0F	0x000F
+0x10	0x0010
+0x11	0x0011
+0x12	0x0012
+0x13	0x0013
+0x14	0x0014
+0x15	0x0015
+0x16	0x0016
+0x17	0x0017
+0x18	0x0018
+0x19	0x0019
+0x1A	0x001A
+0x1B	0x001B
+0x1C	0x001C
+0x1D	0x001D
+0x1E	0x001E
+0x1F	0x001F
+0x20	0x0020
+0x21	0x0021
+0x22	0x0022
+0x23	0x0023
+0x24	0x0024
+0x25	0x0025
+0x26	0x0026
+0x27	0x0027
+0x28	0x0028
+0x29	0x0029
+0x2A	0x002A
+0x2B	0x002B
+0x2C	0x002C
+0x2D	0x002D
+0x2E	0x002E
+0x2F	0x002F
+0x30	0x0030
+0x31	0x0031
+0x32	0x0032
+0x33	0x0033
+0x34	0x0034
+0x35	0x0035
+0x36	0x0036
+0x37	0x0037
+0x38	0x0038
+0x39	0x0039
+0x3A	0x003A
+0x3B	0x003B
+0x3C	0x003C
+0x3D	0x003D
+0x3E	0x003E
+0x3F	0x003F
+0x40	0x0040
+0x41	0x0041
+0x42	0x0042
+0x43	0x0043
+0x44	0x0044
+0x45	0x0045
+0x46	0x0046
+0x47	0x0047
+0x48	0x0048
+0x49	0x0049
+0x4A	0x004A
+0x4B	0x004B
+0x4C	0x004C
+0x4D	0x004D
+0x4E	0x004E
+0x4F	0x004F
+0x50	0x0050
+0x51	0x0051
+0x52	0x0052
+0x53	0x0053
+0x54	0x0054
+0x55	0x0055
+0x56	0x0056
+0x57	0x0057
+0x58	0x0058
+0x59	0x0059
+0x5A	0x005A
+0x5B	0x005B
+0x5C	0x005C
+0x5D	0x005D
+0x5E	0x005E
+0x5F	0x005F
+0x60	0x0060
+0x61	0x0061
+0x62	0x0062
+0x63	0x0063
+0x64	0x0064
+0x65	0x0065
+0x66	0x0066
+0x67	0x0067
+0x68	0x0068
+0x69	0x0069
+0x6A	0x006A
+0x6B	0x006B
+0x6C	0x006C
+0x6D	0x006D
+0x6E	0x006E
+0x6F	0x006F
+0x70	0x0070
+0x71	0x0071
+0x72	0x0072
+0x73	0x0073
+0x74	0x0074
+0x75	0x0075
+0x76	0x0076
+0x77	0x0077
+0x78	0x0078
+0x79	0x0079
+0x7A	0x007A
+0x7B	0x007B
+0x7C	0x007C
+0x7D	0x007D
+0x7E	0x007E
+0x7F	0x007F
+0x8EA1	0xFF61
+0x8EA2	0xFF62
+0x8EA3	0xFF63
+0x8EA4	0xFF64
+0x8EA5	0xFF65
+0x8EA6	0xFF66
+0x8EA7	0xFF67
+0x8EA8	0xFF68
+0x8EA9	0xFF69
+0x8EAA	0xFF6A
+0x8EAB	0xFF6B
+0x8EAC	0xFF6C
+0x8EAD	0xFF6D
+0x8EAE	0xFF6E
+0x8EAF	0xFF6F
+0x8EB0	0xFF70
+0x8EB1	0xFF71
+0x8EB2	0xFF72
+0x8EB3	0xFF73
+0x8EB4	0xFF74
+0x8EB5	0xFF75
+0x8EB6	0xFF76
+0x8EB7	0xFF77
+0x8EB8	0xFF78
+0x8EB9	0xFF79
+0x8EBA	0xFF7A
+0x8EBB	0xFF7B
+0x8EBC	0xFF7C
+0x8EBD	0xFF7D
+0x8EBE	0xFF7E
+0x8EBF	0xFF7F
+0x8EC0	0xFF80
+0x8EC1	0xFF81
+0x8EC2	0xFF82
+0x8EC3	0xFF83
+0x8EC4	0xFF84
+0x8EC5	0xFF85
+0x8EC6	0xFF86
+0x8EC7	0xFF87
+0x8EC8	0xFF88
+0x8EC9	0xFF89
+0x8ECA	0xFF8A
+0x8ECB	0xFF8B
+0x8ECC	0xFF8C
+0x8ECD	0xFF8D
+0x8ECE	0xFF8E
+0x8ECF	0xFF8F
+0x8ED0	0xFF90
+0x8ED1	0xFF91
+0x8ED2	0xFF92
+0x8ED3	0xFF93
+0x8ED4	0xFF94
+0x8ED5	0xFF95
+0x8ED6	0xFF96
+0x8ED7	0xFF97
+0x8ED8	0xFF98
+0x8ED9	0xFF99
+0x8EDA	0xFF9A
+0x8EDB	0xFF9B
+0x8EDC	0xFF9C
+0x8EDD	0xFF9D
+0x8EDE	0xFF9E
+0x8EDF	0xFF9F
+0x8FA2AF	0x02D8
+0x8FA2B0	0x02C7
+0x8FA2B1	0x00B8
+0x8FA2B2	0x02D9
+0x8FA2B3	0x02DD
+0x8FA2B4	0x00AF
+0x8FA2B5	0x02DB
+0x8FA2B6	0x02DA
+0x8FA2B7	0xFF5E
+0x8FA2B8	0x0384
+0x8FA2B9	0x0385
+0x8FA2C2	0x00A1
+0x8FA2C3	0xFFE4
+0x8FA2C4	0x00BF
+0x8FA2EB	0x00BA
+0x8FA2EC	0x00AA
+0x8FA2ED	0x00A9
+0x8FA2EE	0x00AE
+0x8FA2EF	0x2122
+0x8FA2F0	0x00A4
+0x8FA2F1	0x2116
+0x8FA6E1	0x0386
+0x8FA6E2	0x0388
+0x8FA6E3	0x0389
+0x8FA6E4	0x038A
+0x8FA6E5	0x03AA
+0x8FA6E7	0x038C
+0x8FA6E9	0x038E
+0x8FA6EA	0x03AB
+0x8FA6EC	0x038F
+0x8FA6F1	0x03AC
+0x8FA6F2	0x03AD
+0x8FA6F3	0x03AE
+0x8FA6F4	0x03AF
+0x8FA6F5	0x03CA
+0x8FA6F6	0x0390
+0x8FA6F7	0x03CC
+0x8FA6F8	0x03C2
+0x8FA6F9	0x03CD
+0x8FA6FA	0x03CB
+0x8FA6FB	0x03B0
+0x8FA6FC	0x03CE
+0x8FA7C2	0x0402
+0x8FA7C3	0x0403
+0x8FA7C4	0x0404
+0x8FA7C5	0x0405
+0x8FA7C6	0x0406
+0x8FA7C7	0x0407
+0x8FA7C8	0x0408
+0x8FA7C9	0x0409
+0x8FA7CA	0x040A
+0x8FA7CB	0x040B
+0x8FA7CC	0x040C
+0x8FA7CD	0x040E
+0x8FA7CE	0x040F
+0x8FA7F2	0x0452
+0x8FA7F3	0x0453
+0x8FA7F4	0x0454
+0x8FA7F5	0x0455
+0x8FA7F6	0x0456
+0x8FA7F7	0x0457
+0x8FA7F8	0x0458
+0x8FA7F9	0x0459
+0x8FA7FA	0x045A
+0x8FA7FB	0x045B
+0x8FA7FC	0x045C
+0x8FA7FD	0x045E
+0x8FA7FE	0x045F
+0x8FA9A1	0x00C6
+0x8FA9A2	0x0110
+0x8FA9A4	0x0126
+0x8FA9A6	0x0132
+0x8FA9A8	0x0141
+0x8FA9A9	0x013F
+0x8FA9AB	0x014A
+0x8FA9AC	0x00D8
+0x8FA9AD	0x0152
+0x8FA9AF	0x0166
+0x8FA9B0	0x00DE
+0x8FA9C1	0x00E6
+0x8FA9C2	0x0111
+0x8FA9C3	0x00F0
+0x8FA9C4	0x0127
+0x8FA9C5	0x0131
+0x8FA9C6	0x0133
+0x8FA9C7	0x0138
+0x8FA9C8	0x0142
+0x8FA9C9	0x0140
+0x8FA9CA	0x0149
+0x8FA9CB	0x014B
+0x8FA9CC	0x00F8
+0x8FA9CD	0x0153
+0x8FA9CE	0x00DF
+0x8FA9CF	0x0167
+0x8FA9D0	0x00FE
+0x8FAAA1	0x00C1
+0x8FAAA2	0x00C0
+0x8FAAA3	0x00C4
+0x8FAAA4	0x00C2
+0x8FAAA5	0x0102
+0x8FAAA6	0x01CD
+0x8FAAA7	0x0100
+0x8FAAA8	0x0104
+0x8FAAA9	0x00C5
+0x8FAAAA	0x00C3
+0x8FAAAB	0x0106
+0x8FAAAC	0x0108
+0x8FAAAD	0x010C
+0x8FAAAE	0x00C7
+0x8FAAAF	0x010A
+0x8FAAB0	0x010E
+0x8FAAB1	0x00C9
+0x8FAAB2	0x00C8
+0x8FAAB3	0x00CB
+0x8FAAB4	0x00CA
+0x8FAAB5	0x011A
+0x8FAAB6	0x0116
+0x8FAAB7	0x0112
+0x8FAAB8	0x0118
+0x8FAABA	0x011C
+0x8FAABB	0x011E
+0x8FAABC	0x0122
+0x8FAABD	0x0120
+0x8FAABE	0x0124
+0x8FAABF	0x00CD
+0x8FAAC0	0x00CC
+0x8FAAC1	0x00CF
+0x8FAAC2	0x00CE
+0x8FAAC3	0x01CF
+0x8FAAC4	0x0130
+0x8FAAC5	0x012A
+0x8FAAC6	0x012E
+0x8FAAC7	0x0128
+0x8FAAC8	0x0134
+0x8FAAC9	0x0136
+0x8FAACA	0x0139
+0x8FAACB	0x013D
+0x8FAACC	0x013B
+0x8FAACD	0x0143
+0x8FAACE	0x0147
+0x8FAACF	0x0145
+0x8FAAD0	0x00D1
+0x8FAAD1	0x00D3
+0x8FAAD2	0x00D2
+0x8FAAD3	0x00D6
+0x8FAAD4	0x00D4
+0x8FAAD5	0x01D1
+0x8FAAD6	0x0150
+0x8FAAD7	0x014C
+0x8FAAD8	0x00D5
+0x8FAAD9	0x0154
+0x8FAADA	0x0158
+0x8FAADB	0x0156
+0x8FAADC	0x015A
+0x8FAADD	0x015C
+0x8FAADE	0x0160
+0x8FAADF	0x015E
+0x8FAAE0	0x0164
+0x8FAAE1	0x0162
+0x8FAAE2	0x00DA
+0x8FAAE3	0x00D9
+0x8FAAE4	0x00DC
+0x8FAAE5	0x00DB
+0x8FAAE6	0x016C
+0x8FAAE7	0x01D3
+0x8FAAE8	0x0170
+0x8FAAE9	0x016A
+0x8FAAEA	0x0172
+0x8FAAEB	0x016E
+0x8FAAEC	0x0168
+0x8FAAED	0x01D7
+0x8FAAEE	0x01DB
+0x8FAAEF	0x01D9
+0x8FAAF0	0x01D5
+0x8FAAF1	0x0174
+0x8FAAF2	0x00DD
+0x8FAAF3	0x0178
+0x8FAAF4	0x0176
+0x8FAAF5	0x0179
+0x8FAAF6	0x017D
+0x8FAAF7	0x017B
+0x8FABA1	0x00E1
+0x8FABA2	0x00E0
+0x8FABA3	0x00E4
+0x8FABA4	0x00E2
+0x8FABA5	0x0103
+0x8FABA6	0x01CE
+0x8FABA7	0x0101
+0x8FABA8	0x0105
+0x8FABA9	0x00E5
+0x8FABAA	0x00E3
+0x8FABAB	0x0107
+0x8FABAC	0x0109
+0x8FABAD	0x010D
+0x8FABAE	0x00E7
+0x8FABAF	0x010B
+0x8FABB0	0x010F
+0x8FABB1	0x00E9
+0x8FABB2	0x00E8
+0x8FABB3	0x00EB
+0x8FABB4	0x00EA
+0x8FABB5	0x011B
+0x8FABB6	0x0117
+0x8FABB7	0x0113
+0x8FABB8	0x0119
+0x8FABB9	0x01F5
+0x8FABBA	0x011D
+0x8FABBB	0x011F
+0x8FABBD	0x0121
+0x8FABBE	0x0125
+0x8FABBF	0x00ED
+0x8FABC0	0x00EC
+0x8FABC1	0x00EF
+0x8FABC2	0x00EE
+0x8FABC3	0x01D0
+0x8FABC5	0x012B
+0x8FABC6	0x012F
+0x8FABC7	0x0129
+0x8FABC8	0x0135
+0x8FABC9	0x0137
+0x8FABCA	0x013A
+0x8FABCB	0x013E
+0x8FABCC	0x013C
+0x8FABCD	0x0144
+0x8FABCE	0x0148
+0x8FABCF	0x0146
+0x8FABD0	0x00F1
+0x8FABD1	0x00F3
+0x8FABD2	0x00F2
+0x8FABD3	0x00F6
+0x8FABD4	0x00F4
+0x8FABD5	0x01D2
+0x8FABD6	0x0151
+0x8FABD7	0x014D
+0x8FABD8	0x00F5
+0x8FABD9	0x0155
+0x8FABDA	0x0159
+0x8FABDB	0x0157
+0x8FABDC	0x015B
+0x8FABDD	0x015D
+0x8FABDE	0x0161
+0x8FABDF	0x015F
+0x8FABE0	0x0165
+0x8FABE1	0x0163
+0x8FABE2	0x00FA
+0x8FABE3	0x00F9
+0x8FABE4	0x00FC
+0x8FABE5	0x00FB
+0x8FABE6	0x016D
+0x8FABE7	0x01D4
+0x8FABE8	0x0171
+0x8FABE9	0x016B
+0x8FABEA	0x0173
+0x8FABEB	0x016F
+0x8FABEC	0x0169
+0x8FABED	0x01D8
+0x8FABEE	0x01DC
+0x8FABEF	0x01DA
+0x8FABF0	0x01D6
+0x8FABF1	0x0175
+0x8FABF2	0x00FD
+0x8FABF3	0x00FF
+0x8FABF4	0x0177
+0x8FABF5	0x017A
+0x8FABF6	0x017E
+0x8FABF7	0x017C
+0x8FB0A1	0x4E02
+0x8FB0A2	0x4E04
+0x8FB0A3	0x4E05
+0x8FB0A4	0x4E0C
+0x8FB0A5	0x4E12
+0x8FB0A6	0x4E1F
+0x8FB0A7	0x4E23
+0x8FB0A8	0x4E24
+0x8FB0A9	0x4E28
+0x8FB0AA	0x4E2B
+0x8FB0AB	0x4E2E
+0x8FB0AC	0x4E2F
+0x8FB0AD	0x4E30
+0x8FB0AE	0x4E35
+0x8FB0AF	0x4E40
+0x8FB0B0	0x4E41
+0x8FB0B1	0x4E44
+0x8FB0B2	0x4E47
+0x8FB0B3	0x4E51
+0x8FB0B4	0x4E5A
+0x8FB0B5	0x4E5C
+0x8FB0B6	0x4E63
+0x8FB0B7	0x4E68
+0x8FB0B8	0x4E69
+0x8FB0B9	0x4E74
+0x8FB0BA	0x4E75
+0x8FB0BB	0x4E79
+0x8FB0BC	0x4E7F
+0x8FB0BD	0x4E8D
+0x8FB0BE	0x4E96
+0x8FB0BF	0x4E97
+0x8FB0C0	0x4E9D
+0x8FB0C1	0x4EAF
+0x8FB0C2	0x4EB9
+0x8FB0C3	0x4EC3
+0x8FB0C4	0x4ED0
+0x8FB0C5	0x4EDA
+0x8FB0C6	0x4EDB
+0x8FB0C7	0x4EE0
+0x8FB0C8	0x4EE1
+0x8FB0C9	0x4EE2
+0x8FB0CA	0x4EE8
+0x8FB0CB	0x4EEF
+0x8FB0CC	0x4EF1
+0x8FB0CD	0x4EF3
+0x8FB0CE	0x4EF5
+0x8FB0CF	0x4EFD
+0x8FB0D0	0x4EFE
+0x8FB0D1	0x4EFF
+0x8FB0D2	0x4F00
+0x8FB0D3	0x4F02
+0x8FB0D4	0x4F03
+0x8FB0D5	0x4F08
+0x8FB0D6	0x4F0B
+0x8FB0D7	0x4F0C
+0x8FB0D8	0x4F12
+0x8FB0D9	0x4F15
+0x8FB0DA	0x4F16
+0x8FB0DB	0x4F17
+0x8FB0DC	0x4F19
+0x8FB0DD	0x4F2E
+0x8FB0DE	0x4F31
+0x8FB0DF	0x4F60
+0x8FB0E0	0x4F33
+0x8FB0E1	0x4F35
+0x8FB0E2	0x4F37
+0x8FB0E3	0x4F39
+0x8FB0E4	0x4F3B
+0x8FB0E5	0x4F3E
+0x8FB0E6	0x4F40
+0x8FB0E7	0x4F42
+0x8FB0E8	0x4F48
+0x8FB0E9	0x4F49
+0x8FB0EA	0x4F4B
+0x8FB0EB	0x4F4C
+0x8FB0EC	0x4F52
+0x8FB0ED	0x4F54
+0x8FB0EE	0x4F56
+0x8FB0EF	0x4F58
+0x8FB0F0	0x4F5F
+0x8FB0F1	0x4F63
+0x8FB0F2	0x4F6A
+0x8FB0F3	0x4F6C
+0x8FB0F4	0x4F6E
+0x8FB0F5	0x4F71
+0x8FB0F6	0x4F77
+0x8FB0F7	0x4F78
+0x8FB0F8	0x4F79
+0x8FB0F9	0x4F7A
+0x8FB0FA	0x4F7D
+0x8FB0FB	0x4F7E
+0x8FB0FC	0x4F81
+0x8FB0FD	0x4F82
+0x8FB0FE	0x4F84
+0x8FB1A1	0x4F85
+0x8FB1A2	0x4F89
+0x8FB1A3	0x4F8A
+0x8FB1A4	0x4F8C
+0x8FB1A5	0x4F8E
+0x8FB1A6	0x4F90
+0x8FB1A7	0x4F92
+0x8FB1A8	0x4F93
+0x8FB1A9	0x4F94
+0x8FB1AA	0x4F97
+0x8FB1AB	0x4F99
+0x8FB1AC	0x4F9A
+0x8FB1AD	0x4F9E
+0x8FB1AE	0x4F9F
+0x8FB1AF	0x4FB2
+0x8FB1B0	0x4FB7
+0x8FB1B1	0x4FB9
+0x8FB1B2	0x4FBB
+0x8FB1B3	0x4FBC
+0x8FB1B4	0x4FBD
+0x8FB1B5	0x4FBE
+0x8FB1B6	0x4FC0
+0x8FB1B7	0x4FC1
+0x8FB1B8	0x4FC5
+0x8FB1B9	0x4FC6
+0x8FB1BA	0x4FC8
+0x8FB1BB	0x4FC9
+0x8FB1BC	0x4FCB
+0x8FB1BD	0x4FCC
+0x8FB1BE	0x4FCD
+0x8FB1BF	0x4FCF
+0x8FB1C0	0x4FD2
+0x8FB1C1	0x4FDC
+0x8FB1C2	0x4FE0
+0x8FB1C3	0x4FE2
+0x8FB1C4	0x4FF0
+0x8FB1C5	0x4FF2
+0x8FB1C6	0x4FFC
+0x8FB1C7	0x4FFD
+0x8FB1C8	0x4FFF
+0x8FB1C9	0x5000
+0x8FB1CA	0x5001
+0x8FB1CB	0x5004
+0x8FB1CC	0x5007
+0x8FB1CD	0x500A
+0x8FB1CE	0x500C
+0x8FB1CF	0x500E
+0x8FB1D0	0x5010
+0x8FB1D1	0x5013
+0x8FB1D2	0x5017
+0x8FB1D3	0x5018
+0x8FB1D4	0x501B
+0x8FB1D5	0x501C
+0x8FB1D6	0x501D
+0x8FB1D7	0x501E
+0x8FB1D8	0x5022
+0x8FB1D9	0x5027
+0x8FB1DA	0x502E
+0x8FB1DB	0x5030
+0x8FB1DC	0x5032
+0x8FB1DD	0x5033
+0x8FB1DE	0x5035
+0x8FB1DF	0x5040
+0x8FB1E0	0x5041
+0x8FB1E1	0x5042
+0x8FB1E2	0x5045
+0x8FB1E3	0x5046
+0x8FB1E4	0x504A
+0x8FB1E5	0x504C
+0x8FB1E6	0x504E
+0x8FB1E7	0x5051
+0x8FB1E8	0x5052
+0x8FB1E9	0x5053
+0x8FB1EA	0x5057
+0x8FB1EB	0x5059
+0x8FB1EC	0x505F
+0x8FB1ED	0x5060
+0x8FB1EE	0x5062
+0x8FB1EF	0x5063
+0x8FB1F0	0x5066
+0x8FB1F1	0x5067
+0x8FB1F2	0x506A
+0x8FB1F3	0x506D
+0x8FB1F4	0x5070
+0x8FB1F5	0x5071
+0x8FB1F6	0x503B
+0x8FB1F7	0x5081
+0x8FB1F8	0x5083
+0x8FB1F9	0x5084
+0x8FB1FA	0x5086
+0x8FB1FB	0x508A
+0x8FB1FC	0x508E
+0x8FB1FD	0x508F
+0x8FB1FE	0x5090
+0x8FB2A1	0x5092
+0x8FB2A2	0x5093
+0x8FB2A3	0x5094
+0x8FB2A4	0x5096
+0x8FB2A5	0x509B
+0x8FB2A6	0x509C
+0x8FB2A7	0x509E
+0x8FB2A8	0x509F
+0x8FB2A9	0x50A0
+0x8FB2AA	0x50A1
+0x8FB2AB	0x50A2
+0x8FB2AC	0x50AA
+0x8FB2AD	0x50AF
+0x8FB2AE	0x50B0
+0x8FB2AF	0x50B9
+0x8FB2B0	0x50BA
+0x8FB2B1	0x50BD
+0x8FB2B2	0x50C0
+0x8FB2B3	0x50C3
+0x8FB2B4	0x50C4
+0x8FB2B5	0x50C7
+0x8FB2B6	0x50CC
+0x8FB2B7	0x50CE
+0x8FB2B8	0x50D0
+0x8FB2B9	0x50D3
+0x8FB2BA	0x50D4
+0x8FB2BB	0x50D8
+0x8FB2BC	0x50DC
+0x8FB2BD	0x50DD
+0x8FB2BE	0x50DF
+0x8FB2BF	0x50E2
+0x8FB2C0	0x50E4
+0x8FB2C1	0x50E6
+0x8FB2C2	0x50E8
+0x8FB2C3	0x50E9
+0x8FB2C4	0x50EF
+0x8FB2C5	0x50F1
+0x8FB2C6	0x50F6
+0x8FB2C7	0x50FA
+0x8FB2C8	0x50FE
+0x8FB2C9	0x5103
+0x8FB2CA	0x5106
+0x8FB2CB	0x5107
+0x8FB2CC	0x5108
+0x8FB2CD	0x510B
+0x8FB2CE	0x510C
+0x8FB2CF	0x510D
+0x8FB2D0	0x510E
+0x8FB2D1	0x50F2
+0x8FB2D2	0x5110
+0x8FB2D3	0x5117
+0x8FB2D4	0x5119
+0x8FB2D5	0x511B
+0x8FB2D6	0x511C
+0x8FB2D7	0x511D
+0x8FB2D8	0x511E
+0x8FB2D9	0x5123
+0x8FB2DA	0x5127
+0x8FB2DB	0x5128
+0x8FB2DC	0x512C
+0x8FB2DD	0x512D
+0x8FB2DE	0x512F
+0x8FB2DF	0x5131
+0x8FB2E0	0x5133
+0x8FB2E1	0x5134
+0x8FB2E2	0x5135
+0x8FB2E3	0x5138
+0x8FB2E4	0x5139
+0x8FB2E5	0x5142
+0x8FB2E6	0x514A
+0x8FB2E7	0x514F
+0x8FB2E8	0x5153
+0x8FB2E9	0x5155
+0x8FB2EA	0x5157
+0x8FB2EB	0x5158
+0x8FB2EC	0x515F
+0x8FB2ED	0x5164
+0x8FB2EE	0x5166
+0x8FB2EF	0x517E
+0x8FB2F0	0x5183
+0x8FB2F1	0x5184
+0x8FB2F2	0x518B
+0x8FB2F3	0x518E
+0x8FB2F4	0x5198
+0x8FB2F5	0x519D
+0x8FB2F6	0x51A1
+0x8FB2F7	0x51A3
+0x8FB2F8	0x51AD
+0x8FB2F9	0x51B8
+0x8FB2FA	0x51BA
+0x8FB2FB	0x51BC
+0x8FB2FC	0x51BE
+0x8FB2FD	0x51BF
+0x8FB2FE	0x51C2
+0x8FB3A1	0x51C8
+0x8FB3A2	0x51CF
+0x8FB3A3	0x51D1
+0x8FB3A4	0x51D2
+0x8FB3A5	0x51D3
+0x8FB3A6	0x51D5
+0x8FB3A7	0x51D8
+0x8FB3A8	0x51DE
+0x8FB3A9	0x51E2
+0x8FB3AA	0x51E5
+0x8FB3AB	0x51EE
+0x8FB3AC	0x51F2
+0x8FB3AD	0x51F3
+0x8FB3AE	0x51F4
+0x8FB3AF	0x51F7
+0x8FB3B0	0x5201
+0x8FB3B1	0x5202
+0x8FB3B2	0x5205
+0x8FB3B3	0x5212
+0x8FB3B4	0x5213
+0x8FB3B5	0x5215
+0x8FB3B6	0x5216
+0x8FB3B7	0x5218
+0x8FB3B8	0x5222
+0x8FB3B9	0x5228
+0x8FB3BA	0x5231
+0x8FB3BB	0x5232
+0x8FB3BC	0x5235
+0x8FB3BD	0x523C
+0x8FB3BE	0x5245
+0x8FB3BF	0x5249
+0x8FB3C0	0x5255
+0x8FB3C1	0x5257
+0x8FB3C2	0x5258
+0x8FB3C3	0x525A
+0x8FB3C4	0x525C
+0x8FB3C5	0x525F
+0x8FB3C6	0x5260
+0x8FB3C7	0x5261
+0x8FB3C8	0x5266
+0x8FB3C9	0x526E
+0x8FB3CA	0x5277
+0x8FB3CB	0x5278
+0x8FB3CC	0x5279
+0x8FB3CD	0x5280
+0x8FB3CE	0x5282
+0x8FB3CF	0x5285
+0x8FB3D0	0x528A
+0x8FB3D1	0x528C
+0x8FB3D2	0x5293
+0x8FB3D3	0x5295
+0x8FB3D4	0x5296
+0x8FB3D5	0x5297
+0x8FB3D6	0x5298
+0x8FB3D7	0x529A
+0x8FB3D8	0x529C
+0x8FB3D9	0x52A4
+0x8FB3DA	0x52A5
+0x8FB3DB	0x52A6
+0x8FB3DC	0x52A7
+0x8FB3DD	0x52AF
+0x8FB3DE	0x52B0
+0x8FB3DF	0x52B6
+0x8FB3E0	0x52B7
+0x8FB3E1	0x52B8
+0x8FB3E2	0x52BA
+0x8FB3E3	0x52BB
+0x8FB3E4	0x52BD
+0x8FB3E5	0x52C0
+0x8FB3E6	0x52C4
+0x8FB3E7	0x52C6
+0x8FB3E8	0x52C8
+0x8FB3E9	0x52CC
+0x8FB3EA	0x52CF
+0x8FB3EB	0x52D1
+0x8FB3EC	0x52D4
+0x8FB3ED	0x52D6
+0x8FB3EE	0x52DB
+0x8FB3EF	0x52DC
+0x8FB3F0	0x52E1
+0x8FB3F1	0x52E5
+0x8FB3F2	0x52E8
+0x8FB3F3	0x52E9
+0x8FB3F4	0x52EA
+0x8FB3F5	0x52EC
+0x8FB3F6	0x52F0
+0x8FB3F7	0x52F1
+0x8FB3F8	0x52F4
+0x8FB3F9	0x52F6
+0x8FB3FA	0x52F7
+0x8FB3FB	0x5300
+0x8FB3FC	0x5303
+0x8FB3FD	0x530A
+0x8FB3FE	0x530B
+0x8FB4A1	0x530C
+0x8FB4A2	0x5311
+0x8FB4A3	0x5313
+0x8FB4A4	0x5318
+0x8FB4A5	0x531B
+0x8FB4A6	0x531C
+0x8FB4A7	0x531E
+0x8FB4A8	0x531F
+0x8FB4A9	0x5325
+0x8FB4AA	0x5327
+0x8FB4AB	0x5328
+0x8FB4AC	0x5329
+0x8FB4AD	0x532B
+0x8FB4AE	0x532C
+0x8FB4AF	0x532D
+0x8FB4B0	0x5330
+0x8FB4B1	0x5332
+0x8FB4B2	0x5335
+0x8FB4B3	0x533C
+0x8FB4B4	0x533D
+0x8FB4B5	0x533E
+0x8FB4B6	0x5342
+0x8FB4B7	0x534C
+0x8FB4B8	0x534B
+0x8FB4B9	0x5359
+0x8FB4BA	0x535B
+0x8FB4BB	0x5361
+0x8FB4BC	0x5363
+0x8FB4BD	0x5365
+0x8FB4BE	0x536C
+0x8FB4BF	0x536D
+0x8FB4C0	0x5372
+0x8FB4C1	0x5379
+0x8FB4C2	0x537E
+0x8FB4C3	0x5383
+0x8FB4C4	0x5387
+0x8FB4C5	0x5388
+0x8FB4C6	0x538E
+0x8FB4C7	0x5393
+0x8FB4C8	0x5394
+0x8FB4C9	0x5399
+0x8FB4CA	0x539D
+0x8FB4CB	0x53A1
+0x8FB4CC	0x53A4
+0x8FB4CD	0x53AA
+0x8FB4CE	0x53AB
+0x8FB4CF	0x53AF
+0x8FB4D0	0x53B2
+0x8FB4D1	0x53B4
+0x8FB4D2	0x53B5
+0x8FB4D3	0x53B7
+0x8FB4D4	0x53B8
+0x8FB4D5	0x53BA
+0x8FB4D6	0x53BD
+0x8FB4D7	0x53C0
+0x8FB4D8	0x53C5
+0x8FB4D9	0x53CF
+0x8FB4DA	0x53D2
+0x8FB4DB	0x53D3
+0x8FB4DC	0x53D5
+0x8FB4DD	0x53DA
+0x8FB4DE	0x53DD
+0x8FB4DF	0x53DE
+0x8FB4E0	0x53E0
+0x8FB4E1	0x53E6
+0x8FB4E2	0x53E7
+0x8FB4E3	0x53F5
+0x8FB4E4	0x5402
+0x8FB4E5	0x5413
+0x8FB4E6	0x541A
+0x8FB4E7	0x5421
+0x8FB4E8	0x5427
+0x8FB4E9	0x5428
+0x8FB4EA	0x542A
+0x8FB4EB	0x542F
+0x8FB4EC	0x5431
+0x8FB4ED	0x5434
+0x8FB4EE	0x5435
+0x8FB4EF	0x5443
+0x8FB4F0	0x5444
+0x8FB4F1	0x5447
+0x8FB4F2	0x544D
+0x8FB4F3	0x544F
+0x8FB4F4	0x545E
+0x8FB4F5	0x5462
+0x8FB4F6	0x5464
+0x8FB4F7	0x5466
+0x8FB4F8	0x5467
+0x8FB4F9	0x5469
+0x8FB4FA	0x546B
+0x8FB4FB	0x546D
+0x8FB4FC	0x546E
+0x8FB4FD	0x5474
+0x8FB4FE	0x547F
+0x8FB5A1	0x5481
+0x8FB5A2	0x5483
+0x8FB5A3	0x5485
+0x8FB5A4	0x5488
+0x8FB5A5	0x5489
+0x8FB5A6	0x548D
+0x8FB5A7	0x5491
+0x8FB5A8	0x5495
+0x8FB5A9	0x5496
+0x8FB5AA	0x549C
+0x8FB5AB	0x549F
+0x8FB5AC	0x54A1
+0x8FB5AD	0x54A6
+0x8FB5AE	0x54A7
+0x8FB5AF	0x54A9
+0x8FB5B0	0x54AA
+0x8FB5B1	0x54AD
+0x8FB5B2	0x54AE
+0x8FB5B3	0x54B1
+0x8FB5B4	0x54B7
+0x8FB5B5	0x54B9
+0x8FB5B6	0x54BA
+0x8FB5B7	0x54BB
+0x8FB5B8	0x54BF
+0x8FB5B9	0x54C6
+0x8FB5BA	0x54CA
+0x8FB5BB	0x54CD
+0x8FB5BC	0x54CE
+0x8FB5BD	0x54E0
+0x8FB5BE	0x54EA
+0x8FB5BF	0x54EC
+0x8FB5C0	0x54EF
+0x8FB5C1	0x54F6
+0x8FB5C2	0x54FC
+0x8FB5C3	0x54FE
+0x8FB5C4	0x54FF
+0x8FB5C5	0x5500
+0x8FB5C6	0x5501
+0x8FB5C7	0x5505
+0x8FB5C8	0x5508
+0x8FB5C9	0x5509
+0x8FB5CA	0x550C
+0x8FB5CB	0x550D
+0x8FB5CC	0x550E
+0x8FB5CD	0x5515
+0x8FB5CE	0x552A
+0x8FB5CF	0x552B
+0x8FB5D0	0x5532
+0x8FB5D1	0x5535
+0x8FB5D2	0x5536
+0x8FB5D3	0x553B
+0x8FB5D4	0x553C
+0x8FB5D5	0x553D
+0x8FB5D6	0x5541
+0x8FB5D7	0x5547
+0x8FB5D8	0x5549
+0x8FB5D9	0x554A
+0x8FB5DA	0x554D
+0x8FB5DB	0x5550
+0x8FB5DC	0x5551
+0x8FB5DD	0x5558
+0x8FB5DE	0x555A
+0x8FB5DF	0x555B
+0x8FB5E0	0x555E
+0x8FB5E1	0x5560
+0x8FB5E2	0x5561
+0x8FB5E3	0x5564
+0x8FB5E4	0x5566
+0x8FB5E5	0x557F
+0x8FB5E6	0x5581
+0x8FB5E7	0x5582
+0x8FB5E8	0x5586
+0x8FB5E9	0x5588
+0x8FB5EA	0x558E
+0x8FB5EB	0x558F
+0x8FB5EC	0x5591
+0x8FB5ED	0x5592
+0x8FB5EE	0x5593
+0x8FB5EF	0x5594
+0x8FB5F0	0x5597
+0x8FB5F1	0x55A3
+0x8FB5F2	0x55A4
+0x8FB5F3	0x55AD
+0x8FB5F4	0x55B2
+0x8FB5F5	0x55BF
+0x8FB5F6	0x55C1
+0x8FB5F7	0x55C3
+0x8FB5F8	0x55C6
+0x8FB5F9	0x55C9
+0x8FB5FA	0x55CB
+0x8FB5FB	0x55CC
+0x8FB5FC	0x55CE
+0x8FB5FD	0x55D1
+0x8FB5FE	0x55D2
+0x8FB6A1	0x55D3
+0x8FB6A2	0x55D7
+0x8FB6A3	0x55D8
+0x8FB6A4	0x55DB
+0x8FB6A5	0x55DE
+0x8FB6A6	0x55E2
+0x8FB6A7	0x55E9
+0x8FB6A8	0x55F6
+0x8FB6A9	0x55FF
+0x8FB6AA	0x5605
+0x8FB6AB	0x5608
+0x8FB6AC	0x560A
+0x8FB6AD	0x560D
+0x8FB6AE	0x560E
+0x8FB6AF	0x560F
+0x8FB6B0	0x5610
+0x8FB6B1	0x5611
+0x8FB6B2	0x5612
+0x8FB6B3	0x5619
+0x8FB6B4	0x562C
+0x8FB6B5	0x5630
+0x8FB6B6	0x5633
+0x8FB6B7	0x5635
+0x8FB6B8	0x5637
+0x8FB6B9	0x5639
+0x8FB6BA	0x563B
+0x8FB6BB	0x563C
+0x8FB6BC	0x563D
+0x8FB6BD	0x563F
+0x8FB6BE	0x5640
+0x8FB6BF	0x5641
+0x8FB6C0	0x5643
+0x8FB6C1	0x5644
+0x8FB6C2	0x5646
+0x8FB6C3	0x5649
+0x8FB6C4	0x564B
+0x8FB6C5	0x564D
+0x8FB6C6	0x564F
+0x8FB6C7	0x5654
+0x8FB6C8	0x565E
+0x8FB6C9	0x5660
+0x8FB6CA	0x5661
+0x8FB6CB	0x5662
+0x8FB6CC	0x5663
+0x8FB6CD	0x5666
+0x8FB6CE	0x5669
+0x8FB6CF	0x566D
+0x8FB6D0	0x566F
+0x8FB6D1	0x5671
+0x8FB6D2	0x5672
+0x8FB6D3	0x5675
+0x8FB6D4	0x5684
+0x8FB6D5	0x5685
+0x8FB6D6	0x5688
+0x8FB6D7	0x568B
+0x8FB6D8	0x568C
+0x8FB6D9	0x5695
+0x8FB6DA	0x5699
+0x8FB6DB	0x569A
+0x8FB6DC	0x569D
+0x8FB6DD	0x569E
+0x8FB6DE	0x569F
+0x8FB6DF	0x56A6
+0x8FB6E0	0x56A7
+0x8FB6E1	0x56A8
+0x8FB6E2	0x56A9
+0x8FB6E3	0x56AB
+0x8FB6E4	0x56AC
+0x8FB6E5	0x56AD
+0x8FB6E6	0x56B1
+0x8FB6E7	0x56B3
+0x8FB6E8	0x56B7
+0x8FB6E9	0x56BE
+0x8FB6EA	0x56C5
+0x8FB6EB	0x56C9
+0x8FB6EC	0x56CA
+0x8FB6ED	0x56CB
+0x8FB6EE	0x56CF
+0x8FB6EF	0x56D0
+0x8FB6F0	0x56CC
+0x8FB6F1	0x56CD
+0x8FB6F2	0x56D9
+0x8FB6F3	0x56DC
+0x8FB6F4	0x56DD
+0x8FB6F5	0x56DF
+0x8FB6F6	0x56E1
+0x8FB6F7	0x56E4
+0x8FB6F8	0x56E5
+0x8FB6F9	0x56E6
+0x8FB6FA	0x56E7
+0x8FB6FB	0x56E8
+0x8FB6FC	0x56F1
+0x8FB6FD	0x56EB
+0x8FB6FE	0x56ED
+0x8FB7A1	0x56F6
+0x8FB7A2	0x56F7
+0x8FB7A3	0x5701
+0x8FB7A4	0x5702
+0x8FB7A5	0x5707
+0x8FB7A6	0x570A
+0x8FB7A7	0x570C
+0x8FB7A8	0x5711
+0x8FB7A9	0x5715
+0x8FB7AA	0x571A
+0x8FB7AB	0x571B
+0x8FB7AC	0x571D
+0x8FB7AD	0x5720
+0x8FB7AE	0x5722
+0x8FB7AF	0x5723
+0x8FB7B0	0x5724
+0x8FB7B1	0x5725
+0x8FB7B2	0x5729
+0x8FB7B3	0x572A
+0x8FB7B4	0x572C
+0x8FB7B5	0x572E
+0x8FB7B6	0x572F
+0x8FB7B7	0x5733
+0x8FB7B8	0x5734
+0x8FB7B9	0x573D
+0x8FB7BA	0x573E
+0x8FB7BB	0x573F
+0x8FB7BC	0x5745
+0x8FB7BD	0x5746
+0x8FB7BE	0x574C
+0x8FB7BF	0x574D
+0x8FB7C0	0x5752
+0x8FB7C1	0x5762
+0x8FB7C2	0x5765
+0x8FB7C3	0x5767
+0x8FB7C4	0x5768
+0x8FB7C5	0x576B
+0x8FB7C6	0x576D
+0x8FB7C7	0x576E
+0x8FB7C8	0x576F
+0x8FB7C9	0x5770
+0x8FB7CA	0x5771
+0x8FB7CB	0x5773
+0x8FB7CC	0x5774
+0x8FB7CD	0x5775
+0x8FB7CE	0x5777
+0x8FB7CF	0x5779
+0x8FB7D0	0x577A
+0x8FB7D1	0x577B
+0x8FB7D2	0x577C
+0x8FB7D3	0x577E
+0x8FB7D4	0x5781
+0x8FB7D5	0x5783
+0x8FB7D6	0x578C
+0x8FB7D7	0x5794
+0x8FB7D8	0x5797
+0x8FB7D9	0x5799
+0x8FB7DA	0x579A
+0x8FB7DB	0x579C
+0x8FB7DC	0x579D
+0x8FB7DD	0x579E
+0x8FB7DE	0x579F
+0x8FB7DF	0x57A1
+0x8FB7E0	0x5795
+0x8FB7E1	0x57A7
+0x8FB7E2	0x57A8
+0x8FB7E3	0x57A9
+0x8FB7E4	0x57AC
+0x8FB7E5	0x57B8
+0x8FB7E6	0x57BD
+0x8FB7E7	0x57C7
+0x8FB7E8	0x57C8
+0x8FB7E9	0x57CC
+0x8FB7EA	0x57CF
+0x8FB7EB	0x57D5
+0x8FB7EC	0x57DD
+0x8FB7ED	0x57DE
+0x8FB7EE	0x57E4
+0x8FB7EF	0x57E6
+0x8FB7F0	0x57E7
+0x8FB7F1	0x57E9
+0x8FB7F2	0x57ED
+0x8FB7F3	0x57F0
+0x8FB7F4	0x57F5
+0x8FB7F5	0x57F6
+0x8FB7F6	0x57F8
+0x8FB7F7	0x57FD
+0x8FB7F8	0x57FE
+0x8FB7F9	0x57FF
+0x8FB7FA	0x5803
+0x8FB7FB	0x5804
+0x8FB7FC	0x5808
+0x8FB7FD	0x5809
+0x8FB7FE	0x57E1
+0x8FB8A1	0x580C
+0x8FB8A2	0x580D
+0x8FB8A3	0x581B
+0x8FB8A4	0x581E
+0x8FB8A5	0x581F
+0x8FB8A6	0x5820
+0x8FB8A7	0x5826
+0x8FB8A8	0x5827
+0x8FB8A9	0x582D
+0x8FB8AA	0x5832
+0x8FB8AB	0x5839
+0x8FB8AC	0x583F
+0x8FB8AD	0x5849
+0x8FB8AE	0x584C
+0x8FB8AF	0x584D
+0x8FB8B0	0x584F
+0x8FB8B1	0x5850
+0x8FB8B2	0x5855
+0x8FB8B3	0x585F
+0x8FB8B4	0x5861
+0x8FB8B5	0x5864
+0x8FB8B6	0x5867
+0x8FB8B7	0x5868
+0x8FB8B8	0x5878
+0x8FB8B9	0x587C
+0x8FB8BA	0x587F
+0x8FB8BB	0x5880
+0x8FB8BC	0x5881
+0x8FB8BD	0x5887
+0x8FB8BE	0x5888
+0x8FB8BF	0x5889
+0x8FB8C0	0x588A
+0x8FB8C1	0x588C
+0x8FB8C2	0x588D
+0x8FB8C3	0x588F
+0x8FB8C4	0x5890
+0x8FB8C5	0x5894
+0x8FB8C6	0x5896
+0x8FB8C7	0x589D
+0x8FB8C8	0x58A0
+0x8FB8C9	0x58A1
+0x8FB8CA	0x58A2
+0x8FB8CB	0x58A6
+0x8FB8CC	0x58A9
+0x8FB8CD	0x58B1
+0x8FB8CE	0x58B2
+0x8FB8CF	0x58C4
+0x8FB8D0	0x58BC
+0x8FB8D1	0x58C2
+0x8FB8D2	0x58C8
+0x8FB8D3	0x58CD
+0x8FB8D4	0x58CE
+0x8FB8D5	0x58D0
+0x8FB8D6	0x58D2
+0x8FB8D7	0x58D4
+0x8FB8D8	0x58D6
+0x8FB8D9	0x58DA
+0x8FB8DA	0x58DD
+0x8FB8DB	0x58E1
+0x8FB8DC	0x58E2
+0x8FB8DD	0x58E9
+0x8FB8DE	0x58F3
+0x8FB8DF	0x5905
+0x8FB8E0	0x5906
+0x8FB8E1	0x590B
+0x8FB8E2	0x590C
+0x8FB8E3	0x5912
+0x8FB8E4	0x5913
+0x8FB8E5	0x5914
+0x8FB8E6	0x8641
+0x8FB8E7	0x591D
+0x8FB8E8	0x5921
+0x8FB8E9	0x5923
+0x8FB8EA	0x5924
+0x8FB8EB	0x5928
+0x8FB8EC	0x592F
+0x8FB8ED	0x5930
+0x8FB8EE	0x5933
+0x8FB8EF	0x5935
+0x8FB8F0	0x5936
+0x8FB8F1	0x593F
+0x8FB8F2	0x5943
+0x8FB8F3	0x5946
+0x8FB8F4	0x5952
+0x8FB8F5	0x5953
+0x8FB8F6	0x5959
+0x8FB8F7	0x595B
+0x8FB8F8	0x595D
+0x8FB8F9	0x595E
+0x8FB8FA	0x595F
+0x8FB8FB	0x5961
+0x8FB8FC	0x5963
+0x8FB8FD	0x596B
+0x8FB8FE	0x596D
+0x8FB9A1	0x596F
+0x8FB9A2	0x5972
+0x8FB9A3	0x5975
+0x8FB9A4	0x5976
+0x8FB9A5	0x5979
+0x8FB9A6	0x597B
+0x8FB9A7	0x597C
+0x8FB9A8	0x598B
+0x8FB9A9	0x598C
+0x8FB9AA	0x598E
+0x8FB9AB	0x5992
+0x8FB9AC	0x5995
+0x8FB9AD	0x5997
+0x8FB9AE	0x599F
+0x8FB9AF	0x59A4
+0x8FB9B0	0x59A7
+0x8FB9B1	0x59AD
+0x8FB9B2	0x59AE
+0x8FB9B3	0x59AF
+0x8FB9B4	0x59B0
+0x8FB9B5	0x59B3
+0x8FB9B6	0x59B7
+0x8FB9B7	0x59BA
+0x8FB9B8	0x59BC
+0x8FB9B9	0x59C1
+0x8FB9BA	0x59C3
+0x8FB9BB	0x59C4
+0x8FB9BC	0x59C8
+0x8FB9BD	0x59CA
+0x8FB9BE	0x59CD
+0x8FB9BF	0x59D2
+0x8FB9C0	0x59DD
+0x8FB9C1	0x59DE
+0x8FB9C2	0x59DF
+0x8FB9C3	0x59E3
+0x8FB9C4	0x59E4
+0x8FB9C5	0x59E7
+0x8FB9C6	0x59EE
+0x8FB9C7	0x59EF
+0x8FB9C8	0x59F1
+0x8FB9C9	0x59F2
+0x8FB9CA	0x59F4
+0x8FB9CB	0x59F7
+0x8FB9CC	0x5A00
+0x8FB9CD	0x5A04
+0x8FB9CE	0x5A0C
+0x8FB9CF	0x5A0D
+0x8FB9D0	0x5A0E
+0x8FB9D1	0x5A12
+0x8FB9D2	0x5A13
+0x8FB9D3	0x5A1E
+0x8FB9D4	0x5A23
+0x8FB9D5	0x5A24
+0x8FB9D6	0x5A27
+0x8FB9D7	0x5A28
+0x8FB9D8	0x5A2A
+0x8FB9D9	0x5A2D
+0x8FB9DA	0x5A30
+0x8FB9DB	0x5A44
+0x8FB9DC	0x5A45
+0x8FB9DD	0x5A47
+0x8FB9DE	0x5A48
+0x8FB9DF	0x5A4C
+0x8FB9E0	0x5A50
+0x8FB9E1	0x5A55
+0x8FB9E2	0x5A5E
+0x8FB9E3	0x5A63
+0x8FB9E4	0x5A65
+0x8FB9E5	0x5A67
+0x8FB9E6	0x5A6D
+0x8FB9E7	0x5A77
+0x8FB9E8	0x5A7A
+0x8FB9E9	0x5A7B
+0x8FB9EA	0x5A7E
+0x8FB9EB	0x5A8B
+0x8FB9EC	0x5A90
+0x8FB9ED	0x5A93
+0x8FB9EE	0x5A96
+0x8FB9EF	0x5A99
+0x8FB9F0	0x5A9C
+0x8FB9F1	0x5A9E
+0x8FB9F2	0x5A9F
+0x8FB9F3	0x5AA0
+0x8FB9F4	0x5AA2
+0x8FB9F5	0x5AA7
+0x8FB9F6	0x5AAC
+0x8FB9F7	0x5AB1
+0x8FB9F8	0x5AB2
+0x8FB9F9	0x5AB3
+0x8FB9FA	0x5AB5
+0x8FB9FB	0x5AB8
+0x8FB9FC	0x5ABA
+0x8FB9FD	0x5ABB
+0x8FB9FE	0x5ABF
+0x8FBAA1	0x5AC4
+0x8FBAA2	0x5AC6
+0x8FBAA3	0x5AC8
+0x8FBAA4	0x5ACF
+0x8FBAA5	0x5ADA
+0x8FBAA6	0x5ADC
+0x8FBAA7	0x5AE0
+0x8FBAA8	0x5AE5
+0x8FBAA9	0x5AEA
+0x8FBAAA	0x5AEE
+0x8FBAAB	0x5AF5
+0x8FBAAC	0x5AF6
+0x8FBAAD	0x5AFD
+0x8FBAAE	0x5B00
+0x8FBAAF	0x5B01
+0x8FBAB0	0x5B08
+0x8FBAB1	0x5B17
+0x8FBAB2	0x5B34
+0x8FBAB3	0x5B19
+0x8FBAB4	0x5B1B
+0x8FBAB5	0x5B1D
+0x8FBAB6	0x5B21
+0x8FBAB7	0x5B25
+0x8FBAB8	0x5B2D
+0x8FBAB9	0x5B38
+0x8FBABA	0x5B41
+0x8FBABB	0x5B4B
+0x8FBABC	0x5B4C
+0x8FBABD	0x5B52
+0x8FBABE	0x5B56
+0x8FBABF	0x5B5E
+0x8FBAC0	0x5B68
+0x8FBAC1	0x5B6E
+0x8FBAC2	0x5B6F
+0x8FBAC3	0x5B7C
+0x8FBAC4	0x5B7D
+0x8FBAC5	0x5B7E
+0x8FBAC6	0x5B7F
+0x8FBAC7	0x5B81
+0x8FBAC8	0x5B84
+0x8FBAC9	0x5B86
+0x8FBACA	0x5B8A
+0x8FBACB	0x5B8E
+0x8FBACC	0x5B90
+0x8FBACD	0x5B91
+0x8FBACE	0x5B93
+0x8FBACF	0x5B94
+0x8FBAD0	0x5B96
+0x8FBAD1	0x5BA8
+0x8FBAD2	0x5BA9
+0x8FBAD3	0x5BAC
+0x8FBAD4	0x5BAD
+0x8FBAD5	0x5BAF
+0x8FBAD6	0x5BB1
+0x8FBAD7	0x5BB2
+0x8FBAD8	0x5BB7
+0x8FBAD9	0x5BBA
+0x8FBADA	0x5BBC
+0x8FBADB	0x5BC0
+0x8FBADC	0x5BC1
+0x8FBADD	0x5BCD
+0x8FBADE	0x5BCF
+0x8FBADF	0x5BD6
+0x8FBAE0	0x5BD7
+0x8FBAE1	0x5BD8
+0x8FBAE2	0x5BD9
+0x8FBAE3	0x5BDA
+0x8FBAE4	0x5BE0
+0x8FBAE5	0x5BEF
+0x8FBAE6	0x5BF1
+0x8FBAE7	0x5BF4
+0x8FBAE8	0x5BFD
+0x8FBAE9	0x5C0C
+0x8FBAEA	0x5C17
+0x8FBAEB	0x5C1E
+0x8FBAEC	0x5C1F
+0x8FBAED	0x5C23
+0x8FBAEE	0x5C26
+0x8FBAEF	0x5C29
+0x8FBAF0	0x5C2B
+0x8FBAF1	0x5C2C
+0x8FBAF2	0x5C2E
+0x8FBAF3	0x5C30
+0x8FBAF4	0x5C32
+0x8FBAF5	0x5C35
+0x8FBAF6	0x5C36
+0x8FBAF7	0x5C59
+0x8FBAF8	0x5C5A
+0x8FBAF9	0x5C5C
+0x8FBAFA	0x5C62
+0x8FBAFB	0x5C63
+0x8FBAFC	0x5C67
+0x8FBAFD	0x5C68
+0x8FBAFE	0x5C69
+0x8FBBA1	0x5C6D
+0x8FBBA2	0x5C70
+0x8FBBA3	0x5C74
+0x8FBBA4	0x5C75
+0x8FBBA5	0x5C7A
+0x8FBBA6	0x5C7B
+0x8FBBA7	0x5C7C
+0x8FBBA8	0x5C7D
+0x8FBBA9	0x5C87
+0x8FBBAA	0x5C88
+0x8FBBAB	0x5C8A
+0x8FBBAC	0x5C8F
+0x8FBBAD	0x5C92
+0x8FBBAE	0x5C9D
+0x8FBBAF	0x5C9F
+0x8FBBB0	0x5CA0
+0x8FBBB1	0x5CA2
+0x8FBBB2	0x5CA3
+0x8FBBB3	0x5CA6
+0x8FBBB4	0x5CAA
+0x8FBBB5	0x5CB2
+0x8FBBB6	0x5CB4
+0x8FBBB7	0x5CB5
+0x8FBBB8	0x5CBA
+0x8FBBB9	0x5CC9
+0x8FBBBA	0x5CCB
+0x8FBBBB	0x5CD2
+0x8FBBBC	0x5CDD
+0x8FBBBD	0x5CD7
+0x8FBBBE	0x5CEE
+0x8FBBBF	0x5CF1
+0x8FBBC0	0x5CF2
+0x8FBBC1	0x5CF4
+0x8FBBC2	0x5D01
+0x8FBBC3	0x5D06
+0x8FBBC4	0x5D0D
+0x8FBBC5	0x5D12
+0x8FBBC6	0x5D2B
+0x8FBBC7	0x5D23
+0x8FBBC8	0x5D24
+0x8FBBC9	0x5D26
+0x8FBBCA	0x5D27
+0x8FBBCB	0x5D31
+0x8FBBCC	0x5D34
+0x8FBBCD	0x5D39
+0x8FBBCE	0x5D3D
+0x8FBBCF	0x5D3F
+0x8FBBD0	0x5D42
+0x8FBBD1	0x5D43
+0x8FBBD2	0x5D46
+0x8FBBD3	0x5D48
+0x8FBBD4	0x5D55
+0x8FBBD5	0x5D51
+0x8FBBD6	0x5D59
+0x8FBBD7	0x5D4A
+0x8FBBD8	0x5D5F
+0x8FBBD9	0x5D60
+0x8FBBDA	0x5D61
+0x8FBBDB	0x5D62
+0x8FBBDC	0x5D64
+0x8FBBDD	0x5D6A
+0x8FBBDE	0x5D6D
+0x8FBBDF	0x5D70
+0x8FBBE0	0x5D79
+0x8FBBE1	0x5D7A
+0x8FBBE2	0x5D7E
+0x8FBBE3	0x5D7F
+0x8FBBE4	0x5D81
+0x8FBBE5	0x5D83
+0x8FBBE6	0x5D88
+0x8FBBE7	0x5D8A
+0x8FBBE8	0x5D92
+0x8FBBE9	0x5D93
+0x8FBBEA	0x5D94
+0x8FBBEB	0x5D95
+0x8FBBEC	0x5D99
+0x8FBBED	0x5D9B
+0x8FBBEE	0x5D9F
+0x8FBBEF	0x5DA0
+0x8FBBF0	0x5DA7
+0x8FBBF1	0x5DAB
+0x8FBBF2	0x5DB0
+0x8FBBF3	0x5DB4
+0x8FBBF4	0x5DB8
+0x8FBBF5	0x5DB9
+0x8FBBF6	0x5DC3
+0x8FBBF7	0x5DC7
+0x8FBBF8	0x5DCB
+0x8FBBF9	0x5DD0
+0x8FBBFA	0x5DCE
+0x8FBBFB	0x5DD8
+0x8FBBFC	0x5DD9
+0x8FBBFD	0x5DE0
+0x8FBBFE	0x5DE4
+0x8FBCA1	0x5DE9
+0x8FBCA2	0x5DF8
+0x8FBCA3	0x5DF9
+0x8FBCA4	0x5E00
+0x8FBCA5	0x5E07
+0x8FBCA6	0x5E0D
+0x8FBCA7	0x5E12
+0x8FBCA8	0x5E14
+0x8FBCA9	0x5E15
+0x8FBCAA	0x5E18
+0x8FBCAB	0x5E1F
+0x8FBCAC	0x5E20
+0x8FBCAD	0x5E2E
+0x8FBCAE	0x5E28
+0x8FBCAF	0x5E32
+0x8FBCB0	0x5E35
+0x8FBCB1	0x5E3E
+0x8FBCB2	0x5E4B
+0x8FBCB3	0x5E50
+0x8FBCB4	0x5E49
+0x8FBCB5	0x5E51
+0x8FBCB6	0x5E56
+0x8FBCB7	0x5E58
+0x8FBCB8	0x5E5B
+0x8FBCB9	0x5E5C
+0x8FBCBA	0x5E5E
+0x8FBCBB	0x5E68
+0x8FBCBC	0x5E6A
+0x8FBCBD	0x5E6B
+0x8FBCBE	0x5E6C
+0x8FBCBF	0x5E6D
+0x8FBCC0	0x5E6E
+0x8FBCC1	0x5E70
+0x8FBCC2	0x5E80
+0x8FBCC3	0x5E8B
+0x8FBCC4	0x5E8E
+0x8FBCC5	0x5EA2
+0x8FBCC6	0x5EA4
+0x8FBCC7	0x5EA5
+0x8FBCC8	0x5EA8
+0x8FBCC9	0x5EAA
+0x8FBCCA	0x5EAC
+0x8FBCCB	0x5EB1
+0x8FBCCC	0x5EB3
+0x8FBCCD	0x5EBD
+0x8FBCCE	0x5EBE
+0x8FBCCF	0x5EBF
+0x8FBCD0	0x5EC6
+0x8FBCD1	0x5ECC
+0x8FBCD2	0x5ECB
+0x8FBCD3	0x5ECE
+0x8FBCD4	0x5ED1
+0x8FBCD5	0x5ED2
+0x8FBCD6	0x5ED4
+0x8FBCD7	0x5ED5
+0x8FBCD8	0x5EDC
+0x8FBCD9	0x5EDE
+0x8FBCDA	0x5EE5
+0x8FBCDB	0x5EEB
+0x8FBCDC	0x5F02
+0x8FBCDD	0x5F06
+0x8FBCDE	0x5F07
+0x8FBCDF	0x5F08
+0x8FBCE0	0x5F0E
+0x8FBCE1	0x5F19
+0x8FBCE2	0x5F1C
+0x8FBCE3	0x5F1D
+0x8FBCE4	0x5F21
+0x8FBCE5	0x5F22
+0x8FBCE6	0x5F23
+0x8FBCE7	0x5F24
+0x8FBCE8	0x5F28
+0x8FBCE9	0x5F2B
+0x8FBCEA	0x5F2C
+0x8FBCEB	0x5F2E
+0x8FBCEC	0x5F30
+0x8FBCED	0x5F34
+0x8FBCEE	0x5F36
+0x8FBCEF	0x5F3B
+0x8FBCF0	0x5F3D
+0x8FBCF1	0x5F3F
+0x8FBCF2	0x5F40
+0x8FBCF3	0x5F44
+0x8FBCF4	0x5F45
+0x8FBCF5	0x5F47
+0x8FBCF6	0x5F4D
+0x8FBCF7	0x5F50
+0x8FBCF8	0x5F54
+0x8FBCF9	0x5F58
+0x8FBCFA	0x5F5B
+0x8FBCFB	0x5F60
+0x8FBCFC	0x5F63
+0x8FBCFD	0x5F64
+0x8FBCFE	0x5F67
+0x8FBDA1	0x5F6F
+0x8FBDA2	0x5F72
+0x8FBDA3	0x5F74
+0x8FBDA4	0x5F75
+0x8FBDA5	0x5F78
+0x8FBDA6	0x5F7A
+0x8FBDA7	0x5F7D
+0x8FBDA8	0x5F7E
+0x8FBDA9	0x5F89
+0x8FBDAA	0x5F8D
+0x8FBDAB	0x5F8F
+0x8FBDAC	0x5F96
+0x8FBDAD	0x5F9C
+0x8FBDAE	0x5F9D
+0x8FBDAF	0x5FA2
+0x8FBDB0	0x5FA7
+0x8FBDB1	0x5FAB
+0x8FBDB2	0x5FA4
+0x8FBDB3	0x5FAC
+0x8FBDB4	0x5FAF
+0x8FBDB5	0x5FB0
+0x8FBDB6	0x5FB1
+0x8FBDB7	0x5FB8
+0x8FBDB8	0x5FC4
+0x8FBDB9	0x5FC7
+0x8FBDBA	0x5FC8
+0x8FBDBB	0x5FC9
+0x8FBDBC	0x5FCB
+0x8FBDBD	0x5FD0
+0x8FBDBE	0x5FD1
+0x8FBDBF	0x5FD2
+0x8FBDC0	0x5FD3
+0x8FBDC1	0x5FD4
+0x8FBDC2	0x5FDE
+0x8FBDC3	0x5FE1
+0x8FBDC4	0x5FE2
+0x8FBDC5	0x5FE8
+0x8FBDC6	0x5FE9
+0x8FBDC7	0x5FEA
+0x8FBDC8	0x5FEC
+0x8FBDC9	0x5FED
+0x8FBDCA	0x5FEE
+0x8FBDCB	0x5FEF
+0x8FBDCC	0x5FF2
+0x8FBDCD	0x5FF3
+0x8FBDCE	0x5FF6
+0x8FBDCF	0x5FFA
+0x8FBDD0	0x5FFC
+0x8FBDD1	0x6007
+0x8FBDD2	0x600A
+0x8FBDD3	0x600D
+0x8FBDD4	0x6013
+0x8FBDD5	0x6014
+0x8FBDD6	0x6017
+0x8FBDD7	0x6018
+0x8FBDD8	0x601A
+0x8FBDD9	0x601F
+0x8FBDDA	0x6024
+0x8FBDDB	0x602D
+0x8FBDDC	0x6033
+0x8FBDDD	0x6035
+0x8FBDDE	0x6040
+0x8FBDDF	0x6047
+0x8FBDE0	0x6048
+0x8FBDE1	0x6049
+0x8FBDE2	0x604C
+0x8FBDE3	0x6051
+0x8FBDE4	0x6054
+0x8FBDE5	0x6056
+0x8FBDE6	0x6057
+0x8FBDE7	0x605D
+0x8FBDE8	0x6061
+0x8FBDE9	0x6067
+0x8FBDEA	0x6071
+0x8FBDEB	0x607E
+0x8FBDEC	0x607F
+0x8FBDED	0x6082
+0x8FBDEE	0x6086
+0x8FBDEF	0x6088
+0x8FBDF0	0x608A
+0x8FBDF1	0x608E
+0x8FBDF2	0x6091
+0x8FBDF3	0x6093
+0x8FBDF4	0x6095
+0x8FBDF5	0x6098
+0x8FBDF6	0x609D
+0x8FBDF7	0x609E
+0x8FBDF8	0x60A2
+0x8FBDF9	0x60A4
+0x8FBDFA	0x60A5
+0x8FBDFB	0x60A8
+0x8FBDFC	0x60B0
+0x8FBDFD	0x60B1
+0x8FBDFE	0x60B7
+0x8FBEA1	0x60BB
+0x8FBEA2	0x60BE
+0x8FBEA3	0x60C2
+0x8FBEA4	0x60C4
+0x8FBEA5	0x60C8
+0x8FBEA6	0x60C9
+0x8FBEA7	0x60CA
+0x8FBEA8	0x60CB
+0x8FBEA9	0x60CE
+0x8FBEAA	0x60CF
+0x8FBEAB	0x60D4
+0x8FBEAC	0x60D5
+0x8FBEAD	0x60D9
+0x8FBEAE	0x60DB
+0x8FBEAF	0x60DD
+0x8FBEB0	0x60DE
+0x8FBEB1	0x60E2
+0x8FBEB2	0x60E5
+0x8FBEB3	0x60F2
+0x8FBEB4	0x60F5
+0x8FBEB5	0x60F8
+0x8FBEB6	0x60FC
+0x8FBEB7	0x60FD
+0x8FBEB8	0x6102
+0x8FBEB9	0x6107
+0x8FBEBA	0x610A
+0x8FBEBB	0x610C
+0x8FBEBC	0x6110
+0x8FBEBD	0x6111
+0x8FBEBE	0x6112
+0x8FBEBF	0x6113
+0x8FBEC0	0x6114
+0x8FBEC1	0x6116
+0x8FBEC2	0x6117
+0x8FBEC3	0x6119
+0x8FBEC4	0x611C
+0x8FBEC5	0x611E
+0x8FBEC6	0x6122
+0x8FBEC7	0x612A
+0x8FBEC8	0x612B
+0x8FBEC9	0x6130
+0x8FBECA	0x6131
+0x8FBECB	0x6135
+0x8FBECC	0x6136
+0x8FBECD	0x6137
+0x8FBECE	0x6139
+0x8FBECF	0x6141
+0x8FBED0	0x6145
+0x8FBED1	0x6146
+0x8FBED2	0x6149
+0x8FBED3	0x615E
+0x8FBED4	0x6160
+0x8FBED5	0x616C
+0x8FBED6	0x6172
+0x8FBED7	0x6178
+0x8FBED8	0x617B
+0x8FBED9	0x617C
+0x8FBEDA	0x617F
+0x8FBEDB	0x6180
+0x8FBEDC	0x6181
+0x8FBEDD	0x6183
+0x8FBEDE	0x6184
+0x8FBEDF	0x618B
+0x8FBEE0	0x618D
+0x8FBEE1	0x6192
+0x8FBEE2	0x6193
+0x8FBEE3	0x6197
+0x8FBEE4	0x6198
+0x8FBEE5	0x619C
+0x8FBEE6	0x619D
+0x8FBEE7	0x619F
+0x8FBEE8	0x61A0
+0x8FBEE9	0x61A5
+0x8FBEEA	0x61A8
+0x8FBEEB	0x61AA
+0x8FBEEC	0x61AD
+0x8FBEED	0x61B8
+0x8FBEEE	0x61B9
+0x8FBEEF	0x61BC
+0x8FBEF0	0x61C0
+0x8FBEF1	0x61C1
+0x8FBEF2	0x61C2
+0x8FBEF3	0x61CE
+0x8FBEF4	0x61CF
+0x8FBEF5	0x61D5
+0x8FBEF6	0x61DC
+0x8FBEF7	0x61DD
+0x8FBEF8	0x61DE
+0x8FBEF9	0x61DF
+0x8FBEFA	0x61E1
+0x8FBEFB	0x61E2
+0x8FBEFC	0x61E7
+0x8FBEFD	0x61E9
+0x8FBEFE	0x61E5
+0x8FBFA1	0x61EC
+0x8FBFA2	0x61ED
+0x8FBFA3	0x61EF
+0x8FBFA4	0x6201
+0x8FBFA5	0x6203
+0x8FBFA6	0x6204
+0x8FBFA7	0x6207
+0x8FBFA8	0x6213
+0x8FBFA9	0x6215
+0x8FBFAA	0x621C
+0x8FBFAB	0x6220
+0x8FBFAC	0x6222
+0x8FBFAD	0x6223
+0x8FBFAE	0x6227
+0x8FBFAF	0x6229
+0x8FBFB0	0x622B
+0x8FBFB1	0x6239
+0x8FBFB2	0x623D
+0x8FBFB3	0x6242
+0x8FBFB4	0x6243
+0x8FBFB5	0x6244
+0x8FBFB6	0x6246
+0x8FBFB7	0x624C
+0x8FBFB8	0x6250
+0x8FBFB9	0x6251
+0x8FBFBA	0x6252
+0x8FBFBB	0x6254
+0x8FBFBC	0x6256
+0x8FBFBD	0x625A
+0x8FBFBE	0x625C
+0x8FBFBF	0x6264
+0x8FBFC0	0x626D
+0x8FBFC1	0x626F
+0x8FBFC2	0x6273
+0x8FBFC3	0x627A
+0x8FBFC4	0x627D
+0x8FBFC5	0x628D
+0x8FBFC6	0x628E
+0x8FBFC7	0x628F
+0x8FBFC8	0x6290
+0x8FBFC9	0x62A6
+0x8FBFCA	0x62A8
+0x8FBFCB	0x62B3
+0x8FBFCC	0x62B6
+0x8FBFCD	0x62B7
+0x8FBFCE	0x62BA
+0x8FBFCF	0x62BE
+0x8FBFD0	0x62BF
+0x8FBFD1	0x62C4
+0x8FBFD2	0x62CE
+0x8FBFD3	0x62D5
+0x8FBFD4	0x62D6
+0x8FBFD5	0x62DA
+0x8FBFD6	0x62EA
+0x8FBFD7	0x62F2
+0x8FBFD8	0x62F4
+0x8FBFD9	0x62FC
+0x8FBFDA	0x62FD
+0x8FBFDB	0x6303
+0x8FBFDC	0x6304
+0x8FBFDD	0x630A
+0x8FBFDE	0x630B
+0x8FBFDF	0x630D
+0x8FBFE0	0x6310
+0x8FBFE1	0x6313
+0x8FBFE2	0x6316
+0x8FBFE3	0x6318
+0x8FBFE4	0x6329
+0x8FBFE5	0x632A
+0x8FBFE6	0x632D
+0x8FBFE7	0x6335
+0x8FBFE8	0x6336
+0x8FBFE9	0x6339
+0x8FBFEA	0x633C
+0x8FBFEB	0x6341
+0x8FBFEC	0x6342
+0x8FBFED	0x6343
+0x8FBFEE	0x6344
+0x8FBFEF	0x6346
+0x8FBFF0	0x634A
+0x8FBFF1	0x634B
+0x8FBFF2	0x634E
+0x8FBFF3	0x6352
+0x8FBFF4	0x6353
+0x8FBFF5	0x6354
+0x8FBFF6	0x6358
+0x8FBFF7	0x635B
+0x8FBFF8	0x6365
+0x8FBFF9	0x6366
+0x8FBFFA	0x636C
+0x8FBFFB	0x636D
+0x8FBFFC	0x6371
+0x8FBFFD	0x6374
+0x8FBFFE	0x6375
+0x8FC0A1	0x6378
+0x8FC0A2	0x637C
+0x8FC0A3	0x637D
+0x8FC0A4	0x637F
+0x8FC0A5	0x6382
+0x8FC0A6	0x6384
+0x8FC0A7	0x6387
+0x8FC0A8	0x638A
+0x8FC0A9	0x6390
+0x8FC0AA	0x6394
+0x8FC0AB	0x6395
+0x8FC0AC	0x6399
+0x8FC0AD	0x639A
+0x8FC0AE	0x639E
+0x8FC0AF	0x63A4
+0x8FC0B0	0x63A6
+0x8FC0B1	0x63AD
+0x8FC0B2	0x63AE
+0x8FC0B3	0x63AF
+0x8FC0B4	0x63BD
+0x8FC0B5	0x63C1
+0x8FC0B6	0x63C5
+0x8FC0B7	0x63C8
+0x8FC0B8	0x63CE
+0x8FC0B9	0x63D1
+0x8FC0BA	0x63D3
+0x8FC0BB	0x63D4
+0x8FC0BC	0x63D5
+0x8FC0BD	0x63DC
+0x8FC0BE	0x63E0
+0x8FC0BF	0x63E5
+0x8FC0C0	0x63EA
+0x8FC0C1	0x63EC
+0x8FC0C2	0x63F2
+0x8FC0C3	0x63F3
+0x8FC0C4	0x63F5
+0x8FC0C5	0x63F8
+0x8FC0C6	0x63F9
+0x8FC0C7	0x6409
+0x8FC0C8	0x640A
+0x8FC0C9	0x6410
+0x8FC0CA	0x6412
+0x8FC0CB	0x6414
+0x8FC0CC	0x6418
+0x8FC0CD	0x641E
+0x8FC0CE	0x6420
+0x8FC0CF	0x6422
+0x8FC0D0	0x6424
+0x8FC0D1	0x6425
+0x8FC0D2	0x6429
+0x8FC0D3	0x642A
+0x8FC0D4	0x642F
+0x8FC0D5	0x6430
+0x8FC0D6	0x6435
+0x8FC0D7	0x643D
+0x8FC0D8	0x643F
+0x8FC0D9	0x644B
+0x8FC0DA	0x644F
+0x8FC0DB	0x6451
+0x8FC0DC	0x6452
+0x8FC0DD	0x6453
+0x8FC0DE	0x6454
+0x8FC0DF	0x645A
+0x8FC0E0	0x645B
+0x8FC0E1	0x645C
+0x8FC0E2	0x645D
+0x8FC0E3	0x645F
+0x8FC0E4	0x6460
+0x8FC0E5	0x6461
+0x8FC0E6	0x6463
+0x8FC0E7	0x646D
+0x8FC0E8	0x6473
+0x8FC0E9	0x6474
+0x8FC0EA	0x647B
+0x8FC0EB	0x647D
+0x8FC0EC	0x6485
+0x8FC0ED	0x6487
+0x8FC0EE	0x648F
+0x8FC0EF	0x6490
+0x8FC0F0	0x6491
+0x8FC0F1	0x6498
+0x8FC0F2	0x6499
+0x8FC0F3	0x649B
+0x8FC0F4	0x649D
+0x8FC0F5	0x649F
+0x8FC0F6	0x64A1
+0x8FC0F7	0x64A3
+0x8FC0F8	0x64A6
+0x8FC0F9	0x64A8
+0x8FC0FA	0x64AC
+0x8FC0FB	0x64B3
+0x8FC0FC	0x64BD
+0x8FC0FD	0x64BE
+0x8FC0FE	0x64BF
+0x8FC1A1	0x64C4
+0x8FC1A2	0x64C9
+0x8FC1A3	0x64CA
+0x8FC1A4	0x64CB
+0x8FC1A5	0x64CC
+0x8FC1A6	0x64CE
+0x8FC1A7	0x64D0
+0x8FC1A8	0x64D1
+0x8FC1A9	0x64D5
+0x8FC1AA	0x64D7
+0x8FC1AB	0x64E4
+0x8FC1AC	0x64E5
+0x8FC1AD	0x64E9
+0x8FC1AE	0x64EA
+0x8FC1AF	0x64ED
+0x8FC1B0	0x64F0
+0x8FC1B1	0x64F5
+0x8FC1B2	0x64F7
+0x8FC1B3	0x64FB
+0x8FC1B4	0x64FF
+0x8FC1B5	0x6501
+0x8FC1B6	0x6504
+0x8FC1B7	0x6508
+0x8FC1B8	0x6509
+0x8FC1B9	0x650A
+0x8FC1BA	0x650F
+0x8FC1BB	0x6513
+0x8FC1BC	0x6514
+0x8FC1BD	0x6516
+0x8FC1BE	0x6519
+0x8FC1BF	0x651B
+0x8FC1C0	0x651E
+0x8FC1C1	0x651F
+0x8FC1C2	0x6522
+0x8FC1C3	0x6526
+0x8FC1C4	0x6529
+0x8FC1C5	0x652E
+0x8FC1C6	0x6531
+0x8FC1C7	0x653A
+0x8FC1C8	0x653C
+0x8FC1C9	0x653D
+0x8FC1CA	0x6543
+0x8FC1CB	0x6547
+0x8FC1CC	0x6549
+0x8FC1CD	0x6550
+0x8FC1CE	0x6552
+0x8FC1CF	0x6554
+0x8FC1D0	0x655F
+0x8FC1D1	0x6560
+0x8FC1D2	0x6567
+0x8FC1D3	0x656B
+0x8FC1D4	0x657A
+0x8FC1D5	0x657D
+0x8FC1D6	0x6581
+0x8FC1D7	0x6585
+0x8FC1D8	0x658A
+0x8FC1D9	0x6592
+0x8FC1DA	0x6595
+0x8FC1DB	0x6598
+0x8FC1DC	0x659D
+0x8FC1DD	0x65A0
+0x8FC1DE	0x65A3
+0x8FC1DF	0x65A6
+0x8FC1E0	0x65AE
+0x8FC1E1	0x65B2
+0x8FC1E2	0x65B3
+0x8FC1E3	0x65B4
+0x8FC1E4	0x65BF
+0x8FC1E5	0x65C2
+0x8FC1E6	0x65C8
+0x8FC1E7	0x65C9
+0x8FC1E8	0x65CE
+0x8FC1E9	0x65D0
+0x8FC1EA	0x65D4
+0x8FC1EB	0x65D6
+0x8FC1EC	0x65D8
+0x8FC1ED	0x65DF
+0x8FC1EE	0x65F0
+0x8FC1EF	0x65F2
+0x8FC1F0	0x65F4
+0x8FC1F1	0x65F5
+0x8FC1F2	0x65F9
+0x8FC1F3	0x65FE
+0x8FC1F4	0x65FF
+0x8FC1F5	0x6600
+0x8FC1F6	0x6604
+0x8FC1F7	0x6608
+0x8FC1F8	0x6609
+0x8FC1F9	0x660D
+0x8FC1FA	0x6611
+0x8FC1FB	0x6612
+0x8FC1FC	0x6615
+0x8FC1FD	0x6616
+0x8FC1FE	0x661D
+0x8FC2A1	0x661E
+0x8FC2A2	0x6621
+0x8FC2A3	0x6622
+0x8FC2A4	0x6623
+0x8FC2A5	0x6624
+0x8FC2A6	0x6626
+0x8FC2A7	0x6629
+0x8FC2A8	0x662A
+0x8FC2A9	0x662B
+0x8FC2AA	0x662C
+0x8FC2AB	0x662E
+0x8FC2AC	0x6630
+0x8FC2AD	0x6631
+0x8FC2AE	0x6633
+0x8FC2AF	0x6639
+0x8FC2B0	0x6637
+0x8FC2B1	0x6640
+0x8FC2B2	0x6645
+0x8FC2B3	0x6646
+0x8FC2B4	0x664A
+0x8FC2B5	0x664C
+0x8FC2B6	0x6651
+0x8FC2B7	0x664E
+0x8FC2B8	0x6657
+0x8FC2B9	0x6658
+0x8FC2BA	0x6659
+0x8FC2BB	0x665B
+0x8FC2BC	0x665C
+0x8FC2BD	0x6660
+0x8FC2BE	0x6661
+0x8FC2BF	0x66FB
+0x8FC2C0	0x666A
+0x8FC2C1	0x666B
+0x8FC2C2	0x666C
+0x8FC2C3	0x667E
+0x8FC2C4	0x6673
+0x8FC2C5	0x6675
+0x8FC2C6	0x667F
+0x8FC2C7	0x6677
+0x8FC2C8	0x6678
+0x8FC2C9	0x6679
+0x8FC2CA	0x667B
+0x8FC2CB	0x6680
+0x8FC2CC	0x667C
+0x8FC2CD	0x668B
+0x8FC2CE	0x668C
+0x8FC2CF	0x668D
+0x8FC2D0	0x6690
+0x8FC2D1	0x6692
+0x8FC2D2	0x6699
+0x8FC2D3	0x669A
+0x8FC2D4	0x669B
+0x8FC2D5	0x669C
+0x8FC2D6	0x669F
+0x8FC2D7	0x66A0
+0x8FC2D8	0x66A4
+0x8FC2D9	0x66AD
+0x8FC2DA	0x66B1
+0x8FC2DB	0x66B2
+0x8FC2DC	0x66B5
+0x8FC2DD	0x66BB
+0x8FC2DE	0x66BF
+0x8FC2DF	0x66C0
+0x8FC2E0	0x66C2
+0x8FC2E1	0x66C3
+0x8FC2E2	0x66C8
+0x8FC2E3	0x66CC
+0x8FC2E4	0x66CE
+0x8FC2E5	0x66CF
+0x8FC2E6	0x66D4
+0x8FC2E7	0x66DB
+0x8FC2E8	0x66DF
+0x8FC2E9	0x66E8
+0x8FC2EA	0x66EB
+0x8FC2EB	0x66EC
+0x8FC2EC	0x66EE
+0x8FC2ED	0x66FA
+0x8FC2EE	0x6705
+0x8FC2EF	0x6707
+0x8FC2F0	0x670E
+0x8FC2F1	0x6713
+0x8FC2F2	0x6719
+0x8FC2F3	0x671C
+0x8FC2F4	0x6720
+0x8FC2F5	0x6722
+0x8FC2F6	0x6733
+0x8FC2F7	0x673E
+0x8FC2F8	0x6745
+0x8FC2F9	0x6747
+0x8FC2FA	0x6748
+0x8FC2FB	0x674C
+0x8FC2FC	0x6754
+0x8FC2FD	0x6755
+0x8FC2FE	0x675D
+0x8FC3A1	0x6766
+0x8FC3A2	0x676C
+0x8FC3A3	0x676E
+0x8FC3A4	0x6774
+0x8FC3A5	0x6776
+0x8FC3A6	0x677B
+0x8FC3A7	0x6781
+0x8FC3A8	0x6784
+0x8FC3A9	0x678E
+0x8FC3AA	0x678F
+0x8FC3AB	0x6791
+0x8FC3AC	0x6793
+0x8FC3AD	0x6796
+0x8FC3AE	0x6798
+0x8FC3AF	0x6799
+0x8FC3B0	0x679B
+0x8FC3B1	0x67B0
+0x8FC3B2	0x67B1
+0x8FC3B3	0x67B2
+0x8FC3B4	0x67B5
+0x8FC3B5	0x67BB
+0x8FC3B6	0x67BC
+0x8FC3B7	0x67BD
+0x8FC3B8	0x67F9
+0x8FC3B9	0x67C0
+0x8FC3BA	0x67C2
+0x8FC3BB	0x67C3
+0x8FC3BC	0x67C5
+0x8FC3BD	0x67C8
+0x8FC3BE	0x67C9
+0x8FC3BF	0x67D2
+0x8FC3C0	0x67D7
+0x8FC3C1	0x67D9
+0x8FC3C2	0x67DC
+0x8FC3C3	0x67E1
+0x8FC3C4	0x67E6
+0x8FC3C5	0x67F0
+0x8FC3C6	0x67F2
+0x8FC3C7	0x67F6
+0x8FC3C8	0x67F7
+0x8FC3C9	0x6852
+0x8FC3CA	0x6814
+0x8FC3CB	0x6819
+0x8FC3CC	0x681D
+0x8FC3CD	0x681F
+0x8FC3CE	0x6828
+0x8FC3CF	0x6827
+0x8FC3D0	0x682C
+0x8FC3D1	0x682D
+0x8FC3D2	0x682F
+0x8FC3D3	0x6830
+0x8FC3D4	0x6831
+0x8FC3D5	0x6833
+0x8FC3D6	0x683B
+0x8FC3D7	0x683F
+0x8FC3D8	0x6844
+0x8FC3D9	0x6845
+0x8FC3DA	0x684A
+0x8FC3DB	0x684C
+0x8FC3DC	0x6855
+0x8FC3DD	0x6857
+0x8FC3DE	0x6858
+0x8FC3DF	0x685B
+0x8FC3E0	0x686B
+0x8FC3E1	0x686E
+0x8FC3E2	0x686F
+0x8FC3E3	0x6870
+0x8FC3E4	0x6871
+0x8FC3E5	0x6872
+0x8FC3E6	0x6875
+0x8FC3E7	0x6879
+0x8FC3E8	0x687A
+0x8FC3E9	0x687B
+0x8FC3EA	0x687C
+0x8FC3EB	0x6882
+0x8FC3EC	0x6884
+0x8FC3ED	0x6886
+0x8FC3EE	0x6888
+0x8FC3EF	0x6896
+0x8FC3F0	0x6898
+0x8FC3F1	0x689A
+0x8FC3F2	0x689C
+0x8FC3F3	0x68A1
+0x8FC3F4	0x68A3
+0x8FC3F5	0x68A5
+0x8FC3F6	0x68A9
+0x8FC3F7	0x68AA
+0x8FC3F8	0x68AE
+0x8FC3F9	0x68B2
+0x8FC3FA	0x68BB
+0x8FC3FB	0x68C5
+0x8FC3FC	0x68C8
+0x8FC3FD	0x68CC
+0x8FC3FE	0x68CF
+0x8FC4A1	0x68D0
+0x8FC4A2	0x68D1
+0x8FC4A3	0x68D3
+0x8FC4A4	0x68D6
+0x8FC4A5	0x68D9
+0x8FC4A6	0x68DC
+0x8FC4A7	0x68DD
+0x8FC4A8	0x68E5
+0x8FC4A9	0x68E8
+0x8FC4AA	0x68EA
+0x8FC4AB	0x68EB
+0x8FC4AC	0x68EC
+0x8FC4AD	0x68ED
+0x8FC4AE	0x68F0
+0x8FC4AF	0x68F1
+0x8FC4B0	0x68F5
+0x8FC4B1	0x68F6
+0x8FC4B2	0x68FB
+0x8FC4B3	0x68FC
+0x8FC4B4	0x68FD
+0x8FC4B5	0x6906
+0x8FC4B6	0x6909
+0x8FC4B7	0x690A
+0x8FC4B8	0x6910
+0x8FC4B9	0x6911
+0x8FC4BA	0x6913
+0x8FC4BB	0x6916
+0x8FC4BC	0x6917
+0x8FC4BD	0x6931
+0x8FC4BE	0x6933
+0x8FC4BF	0x6935
+0x8FC4C0	0x6938
+0x8FC4C1	0x693B
+0x8FC4C2	0x6942
+0x8FC4C3	0x6945
+0x8FC4C4	0x6949
+0x8FC4C5	0x694E
+0x8FC4C6	0x6957
+0x8FC4C7	0x695B
+0x8FC4C8	0x6963
+0x8FC4C9	0x6964
+0x8FC4CA	0x6965
+0x8FC4CB	0x6966
+0x8FC4CC	0x6968
+0x8FC4CD	0x6969
+0x8FC4CE	0x696C
+0x8FC4CF	0x6970
+0x8FC4D0	0x6971
+0x8FC4D1	0x6972
+0x8FC4D2	0x697A
+0x8FC4D3	0x697B
+0x8FC4D4	0x697F
+0x8FC4D5	0x6980
+0x8FC4D6	0x698D
+0x8FC4D7	0x6992
+0x8FC4D8	0x6996
+0x8FC4D9	0x6998
+0x8FC4DA	0x69A1
+0x8FC4DB	0x69A5
+0x8FC4DC	0x69A6
+0x8FC4DD	0x69A8
+0x8FC4DE	0x69AB
+0x8FC4DF	0x69AD
+0x8FC4E0	0x69AF
+0x8FC4E1	0x69B7
+0x8FC4E2	0x69B8
+0x8FC4E3	0x69BA
+0x8FC4E4	0x69BC
+0x8FC4E5	0x69C5
+0x8FC4E6	0x69C8
+0x8FC4E7	0x69D1
+0x8FC4E8	0x69D6
+0x8FC4E9	0x69D7
+0x8FC4EA	0x69E2
+0x8FC4EB	0x69E5
+0x8FC4EC	0x69EE
+0x8FC4ED	0x69EF
+0x8FC4EE	0x69F1
+0x8FC4EF	0x69F3
+0x8FC4F0	0x69F5
+0x8FC4F1	0x69FE
+0x8FC4F2	0x6A00
+0x8FC4F3	0x6A01
+0x8FC4F4	0x6A03
+0x8FC4F5	0x6A0F
+0x8FC4F6	0x6A11
+0x8FC4F7	0x6A15
+0x8FC4F8	0x6A1A
+0x8FC4F9	0x6A1D
+0x8FC4FA	0x6A20
+0x8FC4FB	0x6A24
+0x8FC4FC	0x6A28
+0x8FC4FD	0x6A30
+0x8FC4FE	0x6A32
+0x8FC5A1	0x6A34
+0x8FC5A2	0x6A37
+0x8FC5A3	0x6A3B
+0x8FC5A4	0x6A3E
+0x8FC5A5	0x6A3F
+0x8FC5A6	0x6A45
+0x8FC5A7	0x6A46
+0x8FC5A8	0x6A49
+0x8FC5A9	0x6A4A
+0x8FC5AA	0x6A4E
+0x8FC5AB	0x6A50
+0x8FC5AC	0x6A51
+0x8FC5AD	0x6A52
+0x8FC5AE	0x6A55
+0x8FC5AF	0x6A56
+0x8FC5B0	0x6A5B
+0x8FC5B1	0x6A64
+0x8FC5B2	0x6A67
+0x8FC5B3	0x6A6A
+0x8FC5B4	0x6A71
+0x8FC5B5	0x6A73
+0x8FC5B6	0x6A7E
+0x8FC5B7	0x6A81
+0x8FC5B8	0x6A83
+0x8FC5B9	0x6A86
+0x8FC5BA	0x6A87
+0x8FC5BB	0x6A89
+0x8FC5BC	0x6A8B
+0x8FC5BD	0x6A91
+0x8FC5BE	0x6A9B
+0x8FC5BF	0x6A9D
+0x8FC5C0	0x6A9E
+0x8FC5C1	0x6A9F
+0x8FC5C2	0x6AA5
+0x8FC5C3	0x6AAB
+0x8FC5C4	0x6AAF
+0x8FC5C5	0x6AB0
+0x8FC5C6	0x6AB1
+0x8FC5C7	0x6AB4
+0x8FC5C8	0x6ABD
+0x8FC5C9	0x6ABE
+0x8FC5CA	0x6ABF
+0x8FC5CB	0x6AC6
+0x8FC5CC	0x6AC9
+0x8FC5CD	0x6AC8
+0x8FC5CE	0x6ACC
+0x8FC5CF	0x6AD0
+0x8FC5D0	0x6AD4
+0x8FC5D1	0x6AD5
+0x8FC5D2	0x6AD6
+0x8FC5D3	0x6ADC
+0x8FC5D4	0x6ADD
+0x8FC5D5	0x6AE4
+0x8FC5D6	0x6AE7
+0x8FC5D7	0x6AEC
+0x8FC5D8	0x6AF0
+0x8FC5D9	0x6AF1
+0x8FC5DA	0x6AF2
+0x8FC5DB	0x6AFC
+0x8FC5DC	0x6AFD
+0x8FC5DD	0x6B02
+0x8FC5DE	0x6B03
+0x8FC5DF	0x6B06
+0x8FC5E0	0x6B07
+0x8FC5E1	0x6B09
+0x8FC5E2	0x6B0F
+0x8FC5E3	0x6B10
+0x8FC5E4	0x6B11
+0x8FC5E5	0x6B17
+0x8FC5E6	0x6B1B
+0x8FC5E7	0x6B1E
+0x8FC5E8	0x6B24
+0x8FC5E9	0x6B28
+0x8FC5EA	0x6B2B
+0x8FC5EB	0x6B2C
+0x8FC5EC	0x6B2F
+0x8FC5ED	0x6B35
+0x8FC5EE	0x6B36
+0x8FC5EF	0x6B3B
+0x8FC5F0	0x6B3F
+0x8FC5F1	0x6B46
+0x8FC5F2	0x6B4A
+0x8FC5F3	0x6B4D
+0x8FC5F4	0x6B52
+0x8FC5F5	0x6B56
+0x8FC5F6	0x6B58
+0x8FC5F7	0x6B5D
+0x8FC5F8	0x6B60
+0x8FC5F9	0x6B67
+0x8FC5FA	0x6B6B
+0x8FC5FB	0x6B6E
+0x8FC5FC	0x6B70
+0x8FC5FD	0x6B75
+0x8FC5FE	0x6B7D
+0x8FC6A1	0x6B7E
+0x8FC6A2	0x6B82
+0x8FC6A3	0x6B85
+0x8FC6A4	0x6B97
+0x8FC6A5	0x6B9B
+0x8FC6A6	0x6B9F
+0x8FC6A7	0x6BA0
+0x8FC6A8	0x6BA2
+0x8FC6A9	0x6BA3
+0x8FC6AA	0x6BA8
+0x8FC6AB	0x6BA9
+0x8FC6AC	0x6BAC
+0x8FC6AD	0x6BAD
+0x8FC6AE	0x6BAE
+0x8FC6AF	0x6BB0
+0x8FC6B0	0x6BB8
+0x8FC6B1	0x6BB9
+0x8FC6B2	0x6BBD
+0x8FC6B3	0x6BBE
+0x8FC6B4	0x6BC3
+0x8FC6B5	0x6BC4
+0x8FC6B6	0x6BC9
+0x8FC6B7	0x6BCC
+0x8FC6B8	0x6BD6
+0x8FC6B9	0x6BDA
+0x8FC6BA	0x6BE1
+0x8FC6BB	0x6BE3
+0x8FC6BC	0x6BE6
+0x8FC6BD	0x6BE7
+0x8FC6BE	0x6BEE
+0x8FC6BF	0x6BF1
+0x8FC6C0	0x6BF7
+0x8FC6C1	0x6BF9
+0x8FC6C2	0x6BFF
+0x8FC6C3	0x6C02
+0x8FC6C4	0x6C04
+0x8FC6C5	0x6C05
+0x8FC6C6	0x6C09
+0x8FC6C7	0x6C0D
+0x8FC6C8	0x6C0E
+0x8FC6C9	0x6C10
+0x8FC6CA	0x6C12
+0x8FC6CB	0x6C19
+0x8FC6CC	0x6C1F
+0x8FC6CD	0x6C26
+0x8FC6CE	0x6C27
+0x8FC6CF	0x6C28
+0x8FC6D0	0x6C2C
+0x8FC6D1	0x6C2E
+0x8FC6D2	0x6C33
+0x8FC6D3	0x6C35
+0x8FC6D4	0x6C36
+0x8FC6D5	0x6C3A
+0x8FC6D6	0x6C3B
+0x8FC6D7	0x6C3F
+0x8FC6D8	0x6C4A
+0x8FC6D9	0x6C4B
+0x8FC6DA	0x6C4D
+0x8FC6DB	0x6C4F
+0x8FC6DC	0x6C52
+0x8FC6DD	0x6C54
+0x8FC6DE	0x6C59
+0x8FC6DF	0x6C5B
+0x8FC6E0	0x6C5C
+0x8FC6E1	0x6C6B
+0x8FC6E2	0x6C6D
+0x8FC6E3	0x6C6F
+0x8FC6E4	0x6C74
+0x8FC6E5	0x6C76
+0x8FC6E6	0x6C78
+0x8FC6E7	0x6C79
+0x8FC6E8	0x6C7B
+0x8FC6E9	0x6C85
+0x8FC6EA	0x6C86
+0x8FC6EB	0x6C87
+0x8FC6EC	0x6C89
+0x8FC6ED	0x6C94
+0x8FC6EE	0x6C95
+0x8FC6EF	0x6C97
+0x8FC6F0	0x6C98
+0x8FC6F1	0x6C9C
+0x8FC6F2	0x6C9F
+0x8FC6F3	0x6CB0
+0x8FC6F4	0x6CB2
+0x8FC6F5	0x6CB4
+0x8FC6F6	0x6CC2
+0x8FC6F7	0x6CC6
+0x8FC6F8	0x6CCD
+0x8FC6F9	0x6CCF
+0x8FC6FA	0x6CD0
+0x8FC6FB	0x6CD1
+0x8FC6FC	0x6CD2
+0x8FC6FD	0x6CD4
+0x8FC6FE	0x6CD6
+0x8FC7A1	0x6CDA
+0x8FC7A2	0x6CDC
+0x8FC7A3	0x6CE0
+0x8FC7A4	0x6CE7
+0x8FC7A5	0x6CE9
+0x8FC7A6	0x6CEB
+0x8FC7A7	0x6CEC
+0x8FC7A8	0x6CEE
+0x8FC7A9	0x6CF2
+0x8FC7AA	0x6CF4
+0x8FC7AB	0x6D04
+0x8FC7AC	0x6D07
+0x8FC7AD	0x6D0A
+0x8FC7AE	0x6D0E
+0x8FC7AF	0x6D0F
+0x8FC7B0	0x6D11
+0x8FC7B1	0x6D13
+0x8FC7B2	0x6D1A
+0x8FC7B3	0x6D26
+0x8FC7B4	0x6D27
+0x8FC7B5	0x6D28
+0x8FC7B6	0x6C67
+0x8FC7B7	0x6D2E
+0x8FC7B8	0x6D2F
+0x8FC7B9	0x6D31
+0x8FC7BA	0x6D39
+0x8FC7BB	0x6D3C
+0x8FC7BC	0x6D3F
+0x8FC7BD	0x6D57
+0x8FC7BE	0x6D5E
+0x8FC7BF	0x6D5F
+0x8FC7C0	0x6D61
+0x8FC7C1	0x6D65
+0x8FC7C2	0x6D67
+0x8FC7C3	0x6D6F
+0x8FC7C4	0x6D70
+0x8FC7C5	0x6D7C
+0x8FC7C6	0x6D82
+0x8FC7C7	0x6D87
+0x8FC7C8	0x6D91
+0x8FC7C9	0x6D92
+0x8FC7CA	0x6D94
+0x8FC7CB	0x6D96
+0x8FC7CC	0x6D97
+0x8FC7CD	0x6D98
+0x8FC7CE	0x6DAA
+0x8FC7CF	0x6DAC
+0x8FC7D0	0x6DB4
+0x8FC7D1	0x6DB7
+0x8FC7D2	0x6DB9
+0x8FC7D3	0x6DBD
+0x8FC7D4	0x6DBF
+0x8FC7D5	0x6DC4
+0x8FC7D6	0x6DC8
+0x8FC7D7	0x6DCA
+0x8FC7D8	0x6DCE
+0x8FC7D9	0x6DCF
+0x8FC7DA	0x6DD6
+0x8FC7DB	0x6DDB
+0x8FC7DC	0x6DDD
+0x8FC7DD	0x6DDF
+0x8FC7DE	0x6DE0
+0x8FC7DF	0x6DE2
+0x8FC7E0	0x6DE5
+0x8FC7E1	0x6DE9
+0x8FC7E2	0x6DEF
+0x8FC7E3	0x6DF0
+0x8FC7E4	0x6DF4
+0x8FC7E5	0x6DF6
+0x8FC7E6	0x6DFC
+0x8FC7E7	0x6E00
+0x8FC7E8	0x6E04
+0x8FC7E9	0x6E1E
+0x8FC7EA	0x6E22
+0x8FC7EB	0x6E27
+0x8FC7EC	0x6E32
+0x8FC7ED	0x6E36
+0x8FC7EE	0x6E39
+0x8FC7EF	0x6E3B
+0x8FC7F0	0x6E3C
+0x8FC7F1	0x6E44
+0x8FC7F2	0x6E45
+0x8FC7F3	0x6E48
+0x8FC7F4	0x6E49
+0x8FC7F5	0x6E4B
+0x8FC7F6	0x6E4F
+0x8FC7F7	0x6E51
+0x8FC7F8	0x6E52
+0x8FC7F9	0x6E53
+0x8FC7FA	0x6E54
+0x8FC7FB	0x6E57
+0x8FC7FC	0x6E5C
+0x8FC7FD	0x6E5D
+0x8FC7FE	0x6E5E
+0x8FC8A1	0x6E62
+0x8FC8A2	0x6E63
+0x8FC8A3	0x6E68
+0x8FC8A4	0x6E73
+0x8FC8A5	0x6E7B
+0x8FC8A6	0x6E7D
+0x8FC8A7	0x6E8D
+0x8FC8A8	0x6E93
+0x8FC8A9	0x6E99
+0x8FC8AA	0x6EA0
+0x8FC8AB	0x6EA7
+0x8FC8AC	0x6EAD
+0x8FC8AD	0x6EAE
+0x8FC8AE	0x6EB1
+0x8FC8AF	0x6EB3
+0x8FC8B0	0x6EBB
+0x8FC8B1	0x6EBF
+0x8FC8B2	0x6EC0
+0x8FC8B3	0x6EC1
+0x8FC8B4	0x6EC3
+0x8FC8B5	0x6EC7
+0x8FC8B6	0x6EC8
+0x8FC8B7	0x6ECA
+0x8FC8B8	0x6ECD
+0x8FC8B9	0x6ECE
+0x8FC8BA	0x6ECF
+0x8FC8BB	0x6EEB
+0x8FC8BC	0x6EED
+0x8FC8BD	0x6EEE
+0x8FC8BE	0x6EF9
+0x8FC8BF	0x6EFB
+0x8FC8C0	0x6EFD
+0x8FC8C1	0x6F04
+0x8FC8C2	0x6F08
+0x8FC8C3	0x6F0A
+0x8FC8C4	0x6F0C
+0x8FC8C5	0x6F0D
+0x8FC8C6	0x6F16
+0x8FC8C7	0x6F18
+0x8FC8C8	0x6F1A
+0x8FC8C9	0x6F1B
+0x8FC8CA	0x6F26
+0x8FC8CB	0x6F29
+0x8FC8CC	0x6F2A
+0x8FC8CD	0x6F2F
+0x8FC8CE	0x6F30
+0x8FC8CF	0x6F33
+0x8FC8D0	0x6F36
+0x8FC8D1	0x6F3B
+0x8FC8D2	0x6F3C
+0x8FC8D3	0x6F2D
+0x8FC8D4	0x6F4F
+0x8FC8D5	0x6F51
+0x8FC8D6	0x6F52
+0x8FC8D7	0x6F53
+0x8FC8D8	0x6F57
+0x8FC8D9	0x6F59
+0x8FC8DA	0x6F5A
+0x8FC8DB	0x6F5D
+0x8FC8DC	0x6F5E
+0x8FC8DD	0x6F61
+0x8FC8DE	0x6F62
+0x8FC8DF	0x6F68
+0x8FC8E0	0x6F6C
+0x8FC8E1	0x6F7D
+0x8FC8E2	0x6F7E
+0x8FC8E3	0x6F83
+0x8FC8E4	0x6F87
+0x8FC8E5	0x6F88
+0x8FC8E6	0x6F8B
+0x8FC8E7	0x6F8C
+0x8FC8E8	0x6F8D
+0x8FC8E9	0x6F90
+0x8FC8EA	0x6F92
+0x8FC8EB	0x6F93
+0x8FC8EC	0x6F94
+0x8FC8ED	0x6F96
+0x8FC8EE	0x6F9A
+0x8FC8EF	0x6F9F
+0x8FC8F0	0x6FA0
+0x8FC8F1	0x6FA5
+0x8FC8F2	0x6FA6
+0x8FC8F3	0x6FA7
+0x8FC8F4	0x6FA8
+0x8FC8F5	0x6FAE
+0x8FC8F6	0x6FAF
+0x8FC8F7	0x6FB0
+0x8FC8F8	0x6FB5
+0x8FC8F9	0x6FB6
+0x8FC8FA	0x6FBC
+0x8FC8FB	0x6FC5
+0x8FC8FC	0x6FC7
+0x8FC8FD	0x6FC8
+0x8FC8FE	0x6FCA
+0x8FC9A1	0x6FDA
+0x8FC9A2	0x6FDE
+0x8FC9A3	0x6FE8
+0x8FC9A4	0x6FE9
+0x8FC9A5	0x6FF0
+0x8FC9A6	0x6FF5
+0x8FC9A7	0x6FF9
+0x8FC9A8	0x6FFC
+0x8FC9A9	0x6FFD
+0x8FC9AA	0x7000
+0x8FC9AB	0x7005
+0x8FC9AC	0x7006
+0x8FC9AD	0x7007
+0x8FC9AE	0x700D
+0x8FC9AF	0x7017
+0x8FC9B0	0x7020
+0x8FC9B1	0x7023
+0x8FC9B2	0x702F
+0x8FC9B3	0x7034
+0x8FC9B4	0x7037
+0x8FC9B5	0x7039
+0x8FC9B6	0x703C
+0x8FC9B7	0x7043
+0x8FC9B8	0x7044
+0x8FC9B9	0x7048
+0x8FC9BA	0x7049
+0x8FC9BB	0x704A
+0x8FC9BC	0x704B
+0x8FC9BD	0x7054
+0x8FC9BE	0x7055
+0x8FC9BF	0x705D
+0x8FC9C0	0x705E
+0x8FC9C1	0x704E
+0x8FC9C2	0x7064
+0x8FC9C3	0x7065
+0x8FC9C4	0x706C
+0x8FC9C5	0x706E
+0x8FC9C6	0x7075
+0x8FC9C7	0x7076
+0x8FC9C8	0x707E
+0x8FC9C9	0x7081
+0x8FC9CA	0x7085
+0x8FC9CB	0x7086
+0x8FC9CC	0x7094
+0x8FC9CD	0x7095
+0x8FC9CE	0x7096
+0x8FC9CF	0x7097
+0x8FC9D0	0x7098
+0x8FC9D1	0x709B
+0x8FC9D2	0x70A4
+0x8FC9D3	0x70AB
+0x8FC9D4	0x70B0
+0x8FC9D5	0x70B1
+0x8FC9D6	0x70B4
+0x8FC9D7	0x70B7
+0x8FC9D8	0x70CA
+0x8FC9D9	0x70D1
+0x8FC9DA	0x70D3
+0x8FC9DB	0x70D4
+0x8FC9DC	0x70D5
+0x8FC9DD	0x70D6
+0x8FC9DE	0x70D8
+0x8FC9DF	0x70DC
+0x8FC9E0	0x70E4
+0x8FC9E1	0x70FA
+0x8FC9E2	0x7103
+0x8FC9E3	0x7104
+0x8FC9E4	0x7105
+0x8FC9E5	0x7106
+0x8FC9E6	0x7107
+0x8FC9E7	0x710B
+0x8FC9E8	0x710C
+0x8FC9E9	0x710F
+0x8FC9EA	0x711E
+0x8FC9EB	0x7120
+0x8FC9EC	0x712B
+0x8FC9ED	0x712D
+0x8FC9EE	0x712F
+0x8FC9EF	0x7130
+0x8FC9F0	0x7131
+0x8FC9F1	0x7138
+0x8FC9F2	0x7141
+0x8FC9F3	0x7145
+0x8FC9F4	0x7146
+0x8FC9F5	0x7147
+0x8FC9F6	0x714A
+0x8FC9F7	0x714B
+0x8FC9F8	0x7150
+0x8FC9F9	0x7152
+0x8FC9FA	0x7157
+0x8FC9FB	0x715A
+0x8FC9FC	0x715C
+0x8FC9FD	0x715E
+0x8FC9FE	0x7160
+0x8FCAA1	0x7168
+0x8FCAA2	0x7179
+0x8FCAA3	0x7180
+0x8FCAA4	0x7185
+0x8FCAA5	0x7187
+0x8FCAA6	0x718C
+0x8FCAA7	0x7192
+0x8FCAA8	0x719A
+0x8FCAA9	0x719B
+0x8FCAAA	0x71A0
+0x8FCAAB	0x71A2
+0x8FCAAC	0x71AF
+0x8FCAAD	0x71B0
+0x8FCAAE	0x71B2
+0x8FCAAF	0x71B3
+0x8FCAB0	0x71BA
+0x8FCAB1	0x71BF
+0x8FCAB2	0x71C0
+0x8FCAB3	0x71C1
+0x8FCAB4	0x71C4
+0x8FCAB5	0x71CB
+0x8FCAB6	0x71CC
+0x8FCAB7	0x71D3
+0x8FCAB8	0x71D6
+0x8FCAB9	0x71D9
+0x8FCABA	0x71DA
+0x8FCABB	0x71DC
+0x8FCABC	0x71F8
+0x8FCABD	0x71FE
+0x8FCABE	0x7200
+0x8FCABF	0x7207
+0x8FCAC0	0x7208
+0x8FCAC1	0x7209
+0x8FCAC2	0x7213
+0x8FCAC3	0x7217
+0x8FCAC4	0x721A
+0x8FCAC5	0x721D
+0x8FCAC6	0x721F
+0x8FCAC7	0x7224
+0x8FCAC8	0x722B
+0x8FCAC9	0x722F
+0x8FCACA	0x7234
+0x8FCACB	0x7238
+0x8FCACC	0x7239
+0x8FCACD	0x7241
+0x8FCACE	0x7242
+0x8FCACF	0x7243
+0x8FCAD0	0x7245
+0x8FCAD1	0x724E
+0x8FCAD2	0x724F
+0x8FCAD3	0x7250
+0x8FCAD4	0x7253
+0x8FCAD5	0x7255
+0x8FCAD6	0x7256
+0x8FCAD7	0x725A
+0x8FCAD8	0x725C
+0x8FCAD9	0x725E
+0x8FCADA	0x7260
+0x8FCADB	0x7263
+0x8FCADC	0x7268
+0x8FCADD	0x726B
+0x8FCADE	0x726E
+0x8FCADF	0x726F
+0x8FCAE0	0x7271
+0x8FCAE1	0x7277
+0x8FCAE2	0x7278
+0x8FCAE3	0x727B
+0x8FCAE4	0x727C
+0x8FCAE5	0x727F
+0x8FCAE6	0x7284
+0x8FCAE7	0x7289
+0x8FCAE8	0x728D
+0x8FCAE9	0x728E
+0x8FCAEA	0x7293
+0x8FCAEB	0x729B
+0x8FCAEC	0x72A8
+0x8FCAED	0x72AD
+0x8FCAEE	0x72AE
+0x8FCAEF	0x72B1
+0x8FCAF0	0x72B4
+0x8FCAF1	0x72BE
+0x8FCAF2	0x72C1
+0x8FCAF3	0x72C7
+0x8FCAF4	0x72C9
+0x8FCAF5	0x72CC
+0x8FCAF6	0x72D5
+0x8FCAF7	0x72D6
+0x8FCAF8	0x72D8
+0x8FCAF9	0x72DF
+0x8FCAFA	0x72E5
+0x8FCAFB	0x72F3
+0x8FCAFC	0x72F4
+0x8FCAFD	0x72FA
+0x8FCAFE	0x72FB
+0x8FCBA1	0x72FE
+0x8FCBA2	0x7302
+0x8FCBA3	0x7304
+0x8FCBA4	0x7305
+0x8FCBA5	0x7307
+0x8FCBA6	0x730B
+0x8FCBA7	0x730D
+0x8FCBA8	0x7312
+0x8FCBA9	0x7313
+0x8FCBAA	0x7318
+0x8FCBAB	0x7319
+0x8FCBAC	0x731E
+0x8FCBAD	0x7322
+0x8FCBAE	0x7324
+0x8FCBAF	0x7327
+0x8FCBB0	0x7328
+0x8FCBB1	0x732C
+0x8FCBB2	0x7331
+0x8FCBB3	0x7332
+0x8FCBB4	0x7335
+0x8FCBB5	0x733A
+0x8FCBB6	0x733B
+0x8FCBB7	0x733D
+0x8FCBB8	0x7343
+0x8FCBB9	0x734D
+0x8FCBBA	0x7350
+0x8FCBBB	0x7352
+0x8FCBBC	0x7356
+0x8FCBBD	0x7358
+0x8FCBBE	0x735D
+0x8FCBBF	0x735E
+0x8FCBC0	0x735F
+0x8FCBC1	0x7360
+0x8FCBC2	0x7366
+0x8FCBC3	0x7367
+0x8FCBC4	0x7369
+0x8FCBC5	0x736B
+0x8FCBC6	0x736C
+0x8FCBC7	0x736E
+0x8FCBC8	0x736F
+0x8FCBC9	0x7371
+0x8FCBCA	0x7377
+0x8FCBCB	0x7379
+0x8FCBCC	0x737C
+0x8FCBCD	0x7380
+0x8FCBCE	0x7381
+0x8FCBCF	0x7383
+0x8FCBD0	0x7385
+0x8FCBD1	0x7386
+0x8FCBD2	0x738E
+0x8FCBD3	0x7390
+0x8FCBD4	0x7393
+0x8FCBD5	0x7395
+0x8FCBD6	0x7397
+0x8FCBD7	0x7398
+0x8FCBD8	0x739C
+0x8FCBD9	0x739E
+0x8FCBDA	0x739F
+0x8FCBDB	0x73A0
+0x8FCBDC	0x73A2
+0x8FCBDD	0x73A5
+0x8FCBDE	0x73A6
+0x8FCBDF	0x73AA
+0x8FCBE0	0x73AB
+0x8FCBE1	0x73AD
+0x8FCBE2	0x73B5
+0x8FCBE3	0x73B7
+0x8FCBE4	0x73B9
+0x8FCBE5	0x73BC
+0x8FCBE6	0x73BD
+0x8FCBE7	0x73BF
+0x8FCBE8	0x73C5
+0x8FCBE9	0x73C6
+0x8FCBEA	0x73C9
+0x8FCBEB	0x73CB
+0x8FCBEC	0x73CC
+0x8FCBED	0x73CF
+0x8FCBEE	0x73D2
+0x8FCBEF	0x73D3
+0x8FCBF0	0x73D6
+0x8FCBF1	0x73D9
+0x8FCBF2	0x73DD
+0x8FCBF3	0x73E1
+0x8FCBF4	0x73E3
+0x8FCBF5	0x73E6
+0x8FCBF6	0x73E7
+0x8FCBF7	0x73E9
+0x8FCBF8	0x73F4
+0x8FCBF9	0x73F5
+0x8FCBFA	0x73F7
+0x8FCBFB	0x73F9
+0x8FCBFC	0x73FA
+0x8FCBFD	0x73FB
+0x8FCBFE	0x73FD
+0x8FCCA1	0x73FF
+0x8FCCA2	0x7400
+0x8FCCA3	0x7401
+0x8FCCA4	0x7404
+0x8FCCA5	0x7407
+0x8FCCA6	0x740A
+0x8FCCA7	0x7411
+0x8FCCA8	0x741A
+0x8FCCA9	0x741B
+0x8FCCAA	0x7424
+0x8FCCAB	0x7426
+0x8FCCAC	0x7428
+0x8FCCAD	0x7429
+0x8FCCAE	0x742A
+0x8FCCAF	0x742B
+0x8FCCB0	0x742C
+0x8FCCB1	0x742D
+0x8FCCB2	0x742E
+0x8FCCB3	0x742F
+0x8FCCB4	0x7430
+0x8FCCB5	0x7431
+0x8FCCB6	0x7439
+0x8FCCB7	0x7440
+0x8FCCB8	0x7443
+0x8FCCB9	0x7444
+0x8FCCBA	0x7446
+0x8FCCBB	0x7447
+0x8FCCBC	0x744B
+0x8FCCBD	0x744D
+0x8FCCBE	0x7451
+0x8FCCBF	0x7452
+0x8FCCC0	0x7457
+0x8FCCC1	0x745D
+0x8FCCC2	0x7462
+0x8FCCC3	0x7466
+0x8FCCC4	0x7467
+0x8FCCC5	0x7468
+0x8FCCC6	0x746B
+0x8FCCC7	0x746D
+0x8FCCC8	0x746E
+0x8FCCC9	0x7471
+0x8FCCCA	0x7472
+0x8FCCCB	0x7480
+0x8FCCCC	0x7481
+0x8FCCCD	0x7485
+0x8FCCCE	0x7486
+0x8FCCCF	0x7487
+0x8FCCD0	0x7489
+0x8FCCD1	0x748F
+0x8FCCD2	0x7490
+0x8FCCD3	0x7491
+0x8FCCD4	0x7492
+0x8FCCD5	0x7498
+0x8FCCD6	0x7499
+0x8FCCD7	0x749A
+0x8FCCD8	0x749C
+0x8FCCD9	0x749F
+0x8FCCDA	0x74A0
+0x8FCCDB	0x74A1
+0x8FCCDC	0x74A3
+0x8FCCDD	0x74A6
+0x8FCCDE	0x74A8
+0x8FCCDF	0x74A9
+0x8FCCE0	0x74AA
+0x8FCCE1	0x74AB
+0x8FCCE2	0x74AE
+0x8FCCE3	0x74AF
+0x8FCCE4	0x74B1
+0x8FCCE5	0x74B2
+0x8FCCE6	0x74B5
+0x8FCCE7	0x74B9
+0x8FCCE8	0x74BB
+0x8FCCE9	0x74BF
+0x8FCCEA	0x74C8
+0x8FCCEB	0x74C9
+0x8FCCEC	0x74CC
+0x8FCCED	0x74D0
+0x8FCCEE	0x74D3
+0x8FCCEF	0x74D8
+0x8FCCF0	0x74DA
+0x8FCCF1	0x74DB
+0x8FCCF2	0x74DE
+0x8FCCF3	0x74DF
+0x8FCCF4	0x74E4
+0x8FCCF5	0x74E8
+0x8FCCF6	0x74EA
+0x8FCCF7	0x74EB
+0x8FCCF8	0x74EF
+0x8FCCF9	0x74F4
+0x8FCCFA	0x74FA
+0x8FCCFB	0x74FB
+0x8FCCFC	0x74FC
+0x8FCCFD	0x74FF
+0x8FCCFE	0x7506
+0x8FCDA1	0x7512
+0x8FCDA2	0x7516
+0x8FCDA3	0x7517
+0x8FCDA4	0x7520
+0x8FCDA5	0x7521
+0x8FCDA6	0x7524
+0x8FCDA7	0x7527
+0x8FCDA8	0x7529
+0x8FCDA9	0x752A
+0x8FCDAA	0x752F
+0x8FCDAB	0x7536
+0x8FCDAC	0x7539
+0x8FCDAD	0x753D
+0x8FCDAE	0x753E
+0x8FCDAF	0x753F
+0x8FCDB0	0x7540
+0x8FCDB1	0x7543
+0x8FCDB2	0x7547
+0x8FCDB3	0x7548
+0x8FCDB4	0x754E
+0x8FCDB5	0x7550
+0x8FCDB6	0x7552
+0x8FCDB7	0x7557
+0x8FCDB8	0x755E
+0x8FCDB9	0x755F
+0x8FCDBA	0x7561
+0x8FCDBB	0x756F
+0x8FCDBC	0x7571
+0x8FCDBD	0x7579
+0x8FCDBE	0x757A
+0x8FCDBF	0x757B
+0x8FCDC0	0x757C
+0x8FCDC1	0x757D
+0x8FCDC2	0x757E
+0x8FCDC3	0x7581
+0x8FCDC4	0x7585
+0x8FCDC5	0x7590
+0x8FCDC6	0x7592
+0x8FCDC7	0x7593
+0x8FCDC8	0x7595
+0x8FCDC9	0x7599
+0x8FCDCA	0x759C
+0x8FCDCB	0x75A2
+0x8FCDCC	0x75A4
+0x8FCDCD	0x75B4
+0x8FCDCE	0x75BA
+0x8FCDCF	0x75BF
+0x8FCDD0	0x75C0
+0x8FCDD1	0x75C1
+0x8FCDD2	0x75C4
+0x8FCDD3	0x75C6
+0x8FCDD4	0x75CC
+0x8FCDD5	0x75CE
+0x8FCDD6	0x75CF
+0x8FCDD7	0x75D7
+0x8FCDD8	0x75DC
+0x8FCDD9	0x75DF
+0x8FCDDA	0x75E0
+0x8FCDDB	0x75E1
+0x8FCDDC	0x75E4
+0x8FCDDD	0x75E7
+0x8FCDDE	0x75EC
+0x8FCDDF	0x75EE
+0x8FCDE0	0x75EF
+0x8FCDE1	0x75F1
+0x8FCDE2	0x75F9
+0x8FCDE3	0x7600
+0x8FCDE4	0x7602
+0x8FCDE5	0x7603
+0x8FCDE6	0x7604
+0x8FCDE7	0x7607
+0x8FCDE8	0x7608
+0x8FCDE9	0x760A
+0x8FCDEA	0x760C
+0x8FCDEB	0x760F
+0x8FCDEC	0x7612
+0x8FCDED	0x7613
+0x8FCDEE	0x7615
+0x8FCDEF	0x7616
+0x8FCDF0	0x7619
+0x8FCDF1	0x761B
+0x8FCDF2	0x761C
+0x8FCDF3	0x761D
+0x8FCDF4	0x761E
+0x8FCDF5	0x7623
+0x8FCDF6	0x7625
+0x8FCDF7	0x7626
+0x8FCDF8	0x7629
+0x8FCDF9	0x762D
+0x8FCDFA	0x7632
+0x8FCDFB	0x7633
+0x8FCDFC	0x7635
+0x8FCDFD	0x7638
+0x8FCDFE	0x7639
+0x8FCEA1	0x763A
+0x8FCEA2	0x763C
+0x8FCEA3	0x764A
+0x8FCEA4	0x7640
+0x8FCEA5	0x7641
+0x8FCEA6	0x7643
+0x8FCEA7	0x7644
+0x8FCEA8	0x7645
+0x8FCEA9	0x7649
+0x8FCEAA	0x764B
+0x8FCEAB	0x7655
+0x8FCEAC	0x7659
+0x8FCEAD	0x765F
+0x8FCEAE	0x7664
+0x8FCEAF	0x7665
+0x8FCEB0	0x766D
+0x8FCEB1	0x766E
+0x8FCEB2	0x766F
+0x8FCEB3	0x7671
+0x8FCEB4	0x7674
+0x8FCEB5	0x7681
+0x8FCEB6	0x7685
+0x8FCEB7	0x768C
+0x8FCEB8	0x768D
+0x8FCEB9	0x7695
+0x8FCEBA	0x769B
+0x8FCEBB	0x769C
+0x8FCEBC	0x769D
+0x8FCEBD	0x769F
+0x8FCEBE	0x76A0
+0x8FCEBF	0x76A2
+0x8FCEC0	0x76A3
+0x8FCEC1	0x76A4
+0x8FCEC2	0x76A5
+0x8FCEC3	0x76A6
+0x8FCEC4	0x76A7
+0x8FCEC5	0x76A8
+0x8FCEC6	0x76AA
+0x8FCEC7	0x76AD
+0x8FCEC8	0x76BD
+0x8FCEC9	0x76C1
+0x8FCECA	0x76C5
+0x8FCECB	0x76C9
+0x8FCECC	0x76CB
+0x8FCECD	0x76CC
+0x8FCECE	0x76CE
+0x8FCECF	0x76D4
+0x8FCED0	0x76D9
+0x8FCED1	0x76E0
+0x8FCED2	0x76E6
+0x8FCED3	0x76E8
+0x8FCED4	0x76EC
+0x8FCED5	0x76F0
+0x8FCED6	0x76F1
+0x8FCED7	0x76F6
+0x8FCED8	0x76F9
+0x8FCED9	0x76FC
+0x8FCEDA	0x7700
+0x8FCEDB	0x7706
+0x8FCEDC	0x770A
+0x8FCEDD	0x770E
+0x8FCEDE	0x7712
+0x8FCEDF	0x7714
+0x8FCEE0	0x7715
+0x8FCEE1	0x7717
+0x8FCEE2	0x7719
+0x8FCEE3	0x771A
+0x8FCEE4	0x771C
+0x8FCEE5	0x7722
+0x8FCEE6	0x7728
+0x8FCEE7	0x772D
+0x8FCEE8	0x772E
+0x8FCEE9	0x772F
+0x8FCEEA	0x7734
+0x8FCEEB	0x7735
+0x8FCEEC	0x7736
+0x8FCEED	0x7739
+0x8FCEEE	0x773D
+0x8FCEEF	0x773E
+0x8FCEF0	0x7742
+0x8FCEF1	0x7745
+0x8FCEF2	0x7746
+0x8FCEF3	0x774A
+0x8FCEF4	0x774D
+0x8FCEF5	0x774E
+0x8FCEF6	0x774F
+0x8FCEF7	0x7752
+0x8FCEF8	0x7756
+0x8FCEF9	0x7757
+0x8FCEFA	0x775C
+0x8FCEFB	0x775E
+0x8FCEFC	0x775F
+0x8FCEFD	0x7760
+0x8FCEFE	0x7762
+0x8FCFA1	0x7764
+0x8FCFA2	0x7767
+0x8FCFA3	0x776A
+0x8FCFA4	0x776C
+0x8FCFA5	0x7770
+0x8FCFA6	0x7772
+0x8FCFA7	0x7773
+0x8FCFA8	0x7774
+0x8FCFA9	0x777A
+0x8FCFAA	0x777D
+0x8FCFAB	0x7780
+0x8FCFAC	0x7784
+0x8FCFAD	0x778C
+0x8FCFAE	0x778D
+0x8FCFAF	0x7794
+0x8FCFB0	0x7795
+0x8FCFB1	0x7796
+0x8FCFB2	0x779A
+0x8FCFB3	0x779F
+0x8FCFB4	0x77A2
+0x8FCFB5	0x77A7
+0x8FCFB6	0x77AA
+0x8FCFB7	0x77AE
+0x8FCFB8	0x77AF
+0x8FCFB9	0x77B1
+0x8FCFBA	0x77B5
+0x8FCFBB	0x77BE
+0x8FCFBC	0x77C3
+0x8FCFBD	0x77C9
+0x8FCFBE	0x77D1
+0x8FCFBF	0x77D2
+0x8FCFC0	0x77D5
+0x8FCFC1	0x77D9
+0x8FCFC2	0x77DE
+0x8FCFC3	0x77DF
+0x8FCFC4	0x77E0
+0x8FCFC5	0x77E4
+0x8FCFC6	0x77E6
+0x8FCFC7	0x77EA
+0x8FCFC8	0x77EC
+0x8FCFC9	0x77F0
+0x8FCFCA	0x77F1
+0x8FCFCB	0x77F4
+0x8FCFCC	0x77F8
+0x8FCFCD	0x77FB
+0x8FCFCE	0x7805
+0x8FCFCF	0x7806
+0x8FCFD0	0x7809
+0x8FCFD1	0x780D
+0x8FCFD2	0x780E
+0x8FCFD3	0x7811
+0x8FCFD4	0x781D
+0x8FCFD5	0x7821
+0x8FCFD6	0x7822
+0x8FCFD7	0x7823
+0x8FCFD8	0x782D
+0x8FCFD9	0x782E
+0x8FCFDA	0x7830
+0x8FCFDB	0x7835
+0x8FCFDC	0x7837
+0x8FCFDD	0x7843
+0x8FCFDE	0x7844
+0x8FCFDF	0x7847
+0x8FCFE0	0x7848
+0x8FCFE1	0x784C
+0x8FCFE2	0x784E
+0x8FCFE3	0x7852
+0x8FCFE4	0x785C
+0x8FCFE5	0x785E
+0x8FCFE6	0x7860
+0x8FCFE7	0x7861
+0x8FCFE8	0x7863
+0x8FCFE9	0x7864
+0x8FCFEA	0x7868
+0x8FCFEB	0x786A
+0x8FCFEC	0x786E
+0x8FCFED	0x787A
+0x8FCFEE	0x787E
+0x8FCFEF	0x788A
+0x8FCFF0	0x788F
+0x8FCFF1	0x7894
+0x8FCFF2	0x7898
+0x8FCFF3	0x78A1
+0x8FCFF4	0x789D
+0x8FCFF5	0x789E
+0x8FCFF6	0x789F
+0x8FCFF7	0x78A4
+0x8FCFF8	0x78A8
+0x8FCFF9	0x78AC
+0x8FCFFA	0x78AD
+0x8FCFFB	0x78B0
+0x8FCFFC	0x78B1
+0x8FCFFD	0x78B2
+0x8FCFFE	0x78B3
+0x8FD0A1	0x78BB
+0x8FD0A2	0x78BD
+0x8FD0A3	0x78BF
+0x8FD0A4	0x78C7
+0x8FD0A5	0x78C8
+0x8FD0A6	0x78C9
+0x8FD0A7	0x78CC
+0x8FD0A8	0x78CE
+0x8FD0A9	0x78D2
+0x8FD0AA	0x78D3
+0x8FD0AB	0x78D5
+0x8FD0AC	0x78D6
+0x8FD0AD	0x78E4
+0x8FD0AE	0x78DB
+0x8FD0AF	0x78DF
+0x8FD0B0	0x78E0
+0x8FD0B1	0x78E1
+0x8FD0B2	0x78E6
+0x8FD0B3	0x78EA
+0x8FD0B4	0x78F2
+0x8FD0B5	0x78F3
+0x8FD0B6	0x7900
+0x8FD0B7	0x78F6
+0x8FD0B8	0x78F7
+0x8FD0B9	0x78FA
+0x8FD0BA	0x78FB
+0x8FD0BB	0x78FF
+0x8FD0BC	0x7906
+0x8FD0BD	0x790C
+0x8FD0BE	0x7910
+0x8FD0BF	0x791A
+0x8FD0C0	0x791C
+0x8FD0C1	0x791E
+0x8FD0C2	0x791F
+0x8FD0C3	0x7920
+0x8FD0C4	0x7925
+0x8FD0C5	0x7927
+0x8FD0C6	0x7929
+0x8FD0C7	0x792D
+0x8FD0C8	0x7931
+0x8FD0C9	0x7934
+0x8FD0CA	0x7935
+0x8FD0CB	0x793B
+0x8FD0CC	0x793D
+0x8FD0CD	0x793F
+0x8FD0CE	0x7944
+0x8FD0CF	0x7945
+0x8FD0D0	0x7946
+0x8FD0D1	0x794A
+0x8FD0D2	0x794B
+0x8FD0D3	0x794F
+0x8FD0D4	0x7951
+0x8FD0D5	0x7954
+0x8FD0D6	0x7958
+0x8FD0D7	0x795B
+0x8FD0D8	0x795C
+0x8FD0D9	0x7967
+0x8FD0DA	0x7969
+0x8FD0DB	0x796B
+0x8FD0DC	0x7972
+0x8FD0DD	0x7979
+0x8FD0DE	0x797B
+0x8FD0DF	0x797C
+0x8FD0E0	0x797E
+0x8FD0E1	0x798B
+0x8FD0E2	0x798C
+0x8FD0E3	0x7991
+0x8FD0E4	0x7993
+0x8FD0E5	0x7994
+0x8FD0E6	0x7995
+0x8FD0E7	0x7996
+0x8FD0E8	0x7998
+0x8FD0E9	0x799B
+0x8FD0EA	0x799C
+0x8FD0EB	0x79A1
+0x8FD0EC	0x79A8
+0x8FD0ED	0x79A9
+0x8FD0EE	0x79AB
+0x8FD0EF	0x79AF
+0x8FD0F0	0x79B1
+0x8FD0F1	0x79B4
+0x8FD0F2	0x79B8
+0x8FD0F3	0x79BB
+0x8FD0F4	0x79C2
+0x8FD0F5	0x79C4
+0x8FD0F6	0x79C7
+0x8FD0F7	0x79C8
+0x8FD0F8	0x79CA
+0x8FD0F9	0x79CF
+0x8FD0FA	0x79D4
+0x8FD0FB	0x79D6
+0x8FD0FC	0x79DA
+0x8FD0FD	0x79DD
+0x8FD0FE	0x79DE
+0x8FD1A1	0x79E0
+0x8FD1A2	0x79E2
+0x8FD1A3	0x79E5
+0x8FD1A4	0x79EA
+0x8FD1A5	0x79EB
+0x8FD1A6	0x79ED
+0x8FD1A7	0x79F1
+0x8FD1A8	0x79F8
+0x8FD1A9	0x79FC
+0x8FD1AA	0x7A02
+0x8FD1AB	0x7A03
+0x8FD1AC	0x7A07
+0x8FD1AD	0x7A09
+0x8FD1AE	0x7A0A
+0x8FD1AF	0x7A0C
+0x8FD1B0	0x7A11
+0x8FD1B1	0x7A15
+0x8FD1B2	0x7A1B
+0x8FD1B3	0x7A1E
+0x8FD1B4	0x7A21
+0x8FD1B5	0x7A27
+0x8FD1B6	0x7A2B
+0x8FD1B7	0x7A2D
+0x8FD1B8	0x7A2F
+0x8FD1B9	0x7A30
+0x8FD1BA	0x7A34
+0x8FD1BB	0x7A35
+0x8FD1BC	0x7A38
+0x8FD1BD	0x7A39
+0x8FD1BE	0x7A3A
+0x8FD1BF	0x7A44
+0x8FD1C0	0x7A45
+0x8FD1C1	0x7A47
+0x8FD1C2	0x7A48
+0x8FD1C3	0x7A4C
+0x8FD1C4	0x7A55
+0x8FD1C5	0x7A56
+0x8FD1C6	0x7A59
+0x8FD1C7	0x7A5C
+0x8FD1C8	0x7A5D
+0x8FD1C9	0x7A5F
+0x8FD1CA	0x7A60
+0x8FD1CB	0x7A65
+0x8FD1CC	0x7A67
+0x8FD1CD	0x7A6A
+0x8FD1CE	0x7A6D
+0x8FD1CF	0x7A75
+0x8FD1D0	0x7A78
+0x8FD1D1	0x7A7E
+0x8FD1D2	0x7A80
+0x8FD1D3	0x7A82
+0x8FD1D4	0x7A85
+0x8FD1D5	0x7A86
+0x8FD1D6	0x7A8A
+0x8FD1D7	0x7A8B
+0x8FD1D8	0x7A90
+0x8FD1D9	0x7A91
+0x8FD1DA	0x7A94
+0x8FD1DB	0x7A9E
+0x8FD1DC	0x7AA0
+0x8FD1DD	0x7AA3
+0x8FD1DE	0x7AAC
+0x8FD1DF	0x7AB3
+0x8FD1E0	0x7AB5
+0x8FD1E1	0x7AB9
+0x8FD1E2	0x7ABB
+0x8FD1E3	0x7ABC
+0x8FD1E4	0x7AC6
+0x8FD1E5	0x7AC9
+0x8FD1E6	0x7ACC
+0x8FD1E7	0x7ACE
+0x8FD1E8	0x7AD1
+0x8FD1E9	0x7ADB
+0x8FD1EA	0x7AE8
+0x8FD1EB	0x7AE9
+0x8FD1EC	0x7AEB
+0x8FD1ED	0x7AEC
+0x8FD1EE	0x7AF1
+0x8FD1EF	0x7AF4
+0x8FD1F0	0x7AFB
+0x8FD1F1	0x7AFD
+0x8FD1F2	0x7AFE
+0x8FD1F3	0x7B07
+0x8FD1F4	0x7B14
+0x8FD1F5	0x7B1F
+0x8FD1F6	0x7B23
+0x8FD1F7	0x7B27
+0x8FD1F8	0x7B29
+0x8FD1F9	0x7B2A
+0x8FD1FA	0x7B2B
+0x8FD1FB	0x7B2D
+0x8FD1FC	0x7B2E
+0x8FD1FD	0x7B2F
+0x8FD1FE	0x7B30
+0x8FD2A1	0x7B31
+0x8FD2A2	0x7B34
+0x8FD2A3	0x7B3D
+0x8FD2A4	0x7B3F
+0x8FD2A5	0x7B40
+0x8FD2A6	0x7B41
+0x8FD2A7	0x7B47
+0x8FD2A8	0x7B4E
+0x8FD2A9	0x7B55
+0x8FD2AA	0x7B60
+0x8FD2AB	0x7B64
+0x8FD2AC	0x7B66
+0x8FD2AD	0x7B69
+0x8FD2AE	0x7B6A
+0x8FD2AF	0x7B6D
+0x8FD2B0	0x7B6F
+0x8FD2B1	0x7B72
+0x8FD2B2	0x7B73
+0x8FD2B3	0x7B77
+0x8FD2B4	0x7B84
+0x8FD2B5	0x7B89
+0x8FD2B6	0x7B8E
+0x8FD2B7	0x7B90
+0x8FD2B8	0x7B91
+0x8FD2B9	0x7B96
+0x8FD2BA	0x7B9B
+0x8FD2BB	0x7B9E
+0x8FD2BC	0x7BA0
+0x8FD2BD	0x7BA5
+0x8FD2BE	0x7BAC
+0x8FD2BF	0x7BAF
+0x8FD2C0	0x7BB0
+0x8FD2C1	0x7BB2
+0x8FD2C2	0x7BB5
+0x8FD2C3	0x7BB6
+0x8FD2C4	0x7BBA
+0x8FD2C5	0x7BBB
+0x8FD2C6	0x7BBC
+0x8FD2C7	0x7BBD
+0x8FD2C8	0x7BC2
+0x8FD2C9	0x7BC5
+0x8FD2CA	0x7BC8
+0x8FD2CB	0x7BCA
+0x8FD2CC	0x7BD4
+0x8FD2CD	0x7BD6
+0x8FD2CE	0x7BD7
+0x8FD2CF	0x7BD9
+0x8FD2D0	0x7BDA
+0x8FD2D1	0x7BDB
+0x8FD2D2	0x7BE8
+0x8FD2D3	0x7BEA
+0x8FD2D4	0x7BF2
+0x8FD2D5	0x7BF4
+0x8FD2D6	0x7BF5
+0x8FD2D7	0x7BF8
+0x8FD2D8	0x7BF9
+0x8FD2D9	0x7BFA
+0x8FD2DA	0x7BFC
+0x8FD2DB	0x7BFE
+0x8FD2DC	0x7C01
+0x8FD2DD	0x7C02
+0x8FD2DE	0x7C03
+0x8FD2DF	0x7C04
+0x8FD2E0	0x7C06
+0x8FD2E1	0x7C09
+0x8FD2E2	0x7C0B
+0x8FD2E3	0x7C0C
+0x8FD2E4	0x7C0E
+0x8FD2E5	0x7C0F
+0x8FD2E6	0x7C19
+0x8FD2E7	0x7C1B
+0x8FD2E8	0x7C20
+0x8FD2E9	0x7C25
+0x8FD2EA	0x7C26
+0x8FD2EB	0x7C28
+0x8FD2EC	0x7C2C
+0x8FD2ED	0x7C31
+0x8FD2EE	0x7C33
+0x8FD2EF	0x7C34
+0x8FD2F0	0x7C36
+0x8FD2F1	0x7C39
+0x8FD2F2	0x7C3A
+0x8FD2F3	0x7C46
+0x8FD2F4	0x7C4A
+0x8FD2F5	0x7C55
+0x8FD2F6	0x7C51
+0x8FD2F7	0x7C52
+0x8FD2F8	0x7C53
+0x8FD2F9	0x7C59
+0x8FD2FA	0x7C5A
+0x8FD2FB	0x7C5B
+0x8FD2FC	0x7C5C
+0x8FD2FD	0x7C5D
+0x8FD2FE	0x7C5E
+0x8FD3A1	0x7C61
+0x8FD3A2	0x7C63
+0x8FD3A3	0x7C67
+0x8FD3A4	0x7C69
+0x8FD3A5	0x7C6D
+0x8FD3A6	0x7C6E
+0x8FD3A7	0x7C70
+0x8FD3A8	0x7C72
+0x8FD3A9	0x7C79
+0x8FD3AA	0x7C7C
+0x8FD3AB	0x7C7D
+0x8FD3AC	0x7C86
+0x8FD3AD	0x7C87
+0x8FD3AE	0x7C8F
+0x8FD3AF	0x7C94
+0x8FD3B0	0x7C9E
+0x8FD3B1	0x7CA0
+0x8FD3B2	0x7CA6
+0x8FD3B3	0x7CB0
+0x8FD3B4	0x7CB6
+0x8FD3B5	0x7CB7
+0x8FD3B6	0x7CBA
+0x8FD3B7	0x7CBB
+0x8FD3B8	0x7CBC
+0x8FD3B9	0x7CBF
+0x8FD3BA	0x7CC4
+0x8FD3BB	0x7CC7
+0x8FD3BC	0x7CC8
+0x8FD3BD	0x7CC9
+0x8FD3BE	0x7CCD
+0x8FD3BF	0x7CCF
+0x8FD3C0	0x7CD3
+0x8FD3C1	0x7CD4
+0x8FD3C2	0x7CD5
+0x8FD3C3	0x7CD7
+0x8FD3C4	0x7CD9
+0x8FD3C5	0x7CDA
+0x8FD3C6	0x7CDD
+0x8FD3C7	0x7CE6
+0x8FD3C8	0x7CE9
+0x8FD3C9	0x7CEB
+0x8FD3CA	0x7CF5
+0x8FD3CB	0x7D03
+0x8FD3CC	0x7D07
+0x8FD3CD	0x7D08
+0x8FD3CE	0x7D09
+0x8FD3CF	0x7D0F
+0x8FD3D0	0x7D11
+0x8FD3D1	0x7D12
+0x8FD3D2	0x7D13
+0x8FD3D3	0x7D16
+0x8FD3D4	0x7D1D
+0x8FD3D5	0x7D1E
+0x8FD3D6	0x7D23
+0x8FD3D7	0x7D26
+0x8FD3D8	0x7D2A
+0x8FD3D9	0x7D2D
+0x8FD3DA	0x7D31
+0x8FD3DB	0x7D3C
+0x8FD3DC	0x7D3D
+0x8FD3DD	0x7D3E
+0x8FD3DE	0x7D40
+0x8FD3DF	0x7D41
+0x8FD3E0	0x7D47
+0x8FD3E1	0x7D48
+0x8FD3E2	0x7D4D
+0x8FD3E3	0x7D51
+0x8FD3E4	0x7D53
+0x8FD3E5	0x7D57
+0x8FD3E6	0x7D59
+0x8FD3E7	0x7D5A
+0x8FD3E8	0x7D5C
+0x8FD3E9	0x7D5D
+0x8FD3EA	0x7D65
+0x8FD3EB	0x7D67
+0x8FD3EC	0x7D6A
+0x8FD3ED	0x7D70
+0x8FD3EE	0x7D78
+0x8FD3EF	0x7D7A
+0x8FD3F0	0x7D7B
+0x8FD3F1	0x7D7F
+0x8FD3F2	0x7D81
+0x8FD3F3	0x7D82
+0x8FD3F4	0x7D83
+0x8FD3F5	0x7D85
+0x8FD3F6	0x7D86
+0x8FD3F7	0x7D88
+0x8FD3F8	0x7D8B
+0x8FD3F9	0x7D8C
+0x8FD3FA	0x7D8D
+0x8FD3FB	0x7D91
+0x8FD3FC	0x7D96
+0x8FD3FD	0x7D97
+0x8FD3FE	0x7D9D
+0x8FD4A1	0x7D9E
+0x8FD4A2	0x7DA6
+0x8FD4A3	0x7DA7
+0x8FD4A4	0x7DAA
+0x8FD4A5	0x7DB3
+0x8FD4A6	0x7DB6
+0x8FD4A7	0x7DB7
+0x8FD4A8	0x7DB9
+0x8FD4A9	0x7DC2
+0x8FD4AA	0x7DC3
+0x8FD4AB	0x7DC4
+0x8FD4AC	0x7DC5
+0x8FD4AD	0x7DC6
+0x8FD4AE	0x7DCC
+0x8FD4AF	0x7DCD
+0x8FD4B0	0x7DCE
+0x8FD4B1	0x7DD7
+0x8FD4B2	0x7DD9
+0x8FD4B3	0x7E00
+0x8FD4B4	0x7DE2
+0x8FD4B5	0x7DE5
+0x8FD4B6	0x7DE6
+0x8FD4B7	0x7DEA
+0x8FD4B8	0x7DEB
+0x8FD4B9	0x7DED
+0x8FD4BA	0x7DF1
+0x8FD4BB	0x7DF5
+0x8FD4BC	0x7DF6
+0x8FD4BD	0x7DF9
+0x8FD4BE	0x7DFA
+0x8FD4BF	0x7E08
+0x8FD4C0	0x7E10
+0x8FD4C1	0x7E11
+0x8FD4C2	0x7E15
+0x8FD4C3	0x7E17
+0x8FD4C4	0x7E1C
+0x8FD4C5	0x7E1D
+0x8FD4C6	0x7E20
+0x8FD4C7	0x7E27
+0x8FD4C8	0x7E28
+0x8FD4C9	0x7E2C
+0x8FD4CA	0x7E2D
+0x8FD4CB	0x7E2F
+0x8FD4CC	0x7E33
+0x8FD4CD	0x7E36
+0x8FD4CE	0x7E3F
+0x8FD4CF	0x7E44
+0x8FD4D0	0x7E45
+0x8FD4D1	0x7E47
+0x8FD4D2	0x7E4E
+0x8FD4D3	0x7E50
+0x8FD4D4	0x7E52
+0x8FD4D5	0x7E58
+0x8FD4D6	0x7E5F
+0x8FD4D7	0x7E61
+0x8FD4D8	0x7E62
+0x8FD4D9	0x7E65
+0x8FD4DA	0x7E6B
+0x8FD4DB	0x7E6E
+0x8FD4DC	0x7E6F
+0x8FD4DD	0x7E73
+0x8FD4DE	0x7E78
+0x8FD4DF	0x7E7E
+0x8FD4E0	0x7E81
+0x8FD4E1	0x7E86
+0x8FD4E2	0x7E87
+0x8FD4E3	0x7E8A
+0x8FD4E4	0x7E8D
+0x8FD4E5	0x7E91
+0x8FD4E6	0x7E95
+0x8FD4E7	0x7E98
+0x8FD4E8	0x7E9A
+0x8FD4E9	0x7E9D
+0x8FD4EA	0x7E9E
+0x8FD4EB	0x7F3C
+0x8FD4EC	0x7F3B
+0x8FD4ED	0x7F3D
+0x8FD4EE	0x7F3E
+0x8FD4EF	0x7F3F
+0x8FD4F0	0x7F43
+0x8FD4F1	0x7F44
+0x8FD4F2	0x7F47
+0x8FD4F3	0x7F4F
+0x8FD4F4	0x7F52
+0x8FD4F5	0x7F53
+0x8FD4F6	0x7F5B
+0x8FD4F7	0x7F5C
+0x8FD4F8	0x7F5D
+0x8FD4F9	0x7F61
+0x8FD4FA	0x7F63
+0x8FD4FB	0x7F64
+0x8FD4FC	0x7F65
+0x8FD4FD	0x7F66
+0x8FD4FE	0x7F6D
+0x8FD5A1	0x7F71
+0x8FD5A2	0x7F7D
+0x8FD5A3	0x7F7E
+0x8FD5A4	0x7F7F
+0x8FD5A5	0x7F80
+0x8FD5A6	0x7F8B
+0x8FD5A7	0x7F8D
+0x8FD5A8	0x7F8F
+0x8FD5A9	0x7F90
+0x8FD5AA	0x7F91
+0x8FD5AB	0x7F96
+0x8FD5AC	0x7F97
+0x8FD5AD	0x7F9C
+0x8FD5AE	0x7FA1
+0x8FD5AF	0x7FA2
+0x8FD5B0	0x7FA6
+0x8FD5B1	0x7FAA
+0x8FD5B2	0x7FAD
+0x8FD5B3	0x7FB4
+0x8FD5B4	0x7FBC
+0x8FD5B5	0x7FBF
+0x8FD5B6	0x7FC0
+0x8FD5B7	0x7FC3
+0x8FD5B8	0x7FC8
+0x8FD5B9	0x7FCE
+0x8FD5BA	0x7FCF
+0x8FD5BB	0x7FDB
+0x8FD5BC	0x7FDF
+0x8FD5BD	0x7FE3
+0x8FD5BE	0x7FE5
+0x8FD5BF	0x7FE8
+0x8FD5C0	0x7FEC
+0x8FD5C1	0x7FEE
+0x8FD5C2	0x7FEF
+0x8FD5C3	0x7FF2
+0x8FD5C4	0x7FFA
+0x8FD5C5	0x7FFD
+0x8FD5C6	0x7FFE
+0x8FD5C7	0x7FFF
+0x8FD5C8	0x8007
+0x8FD5C9	0x8008
+0x8FD5CA	0x800A
+0x8FD5CB	0x800D
+0x8FD5CC	0x800E
+0x8FD5CD	0x800F
+0x8FD5CE	0x8011
+0x8FD5CF	0x8013
+0x8FD5D0	0x8014
+0x8FD5D1	0x8016
+0x8FD5D2	0x801D
+0x8FD5D3	0x801E
+0x8FD5D4	0x801F
+0x8FD5D5	0x8020
+0x8FD5D6	0x8024
+0x8FD5D7	0x8026
+0x8FD5D8	0x802C
+0x8FD5D9	0x802E
+0x8FD5DA	0x8030
+0x8FD5DB	0x8034
+0x8FD5DC	0x8035
+0x8FD5DD	0x8037
+0x8FD5DE	0x8039
+0x8FD5DF	0x803A
+0x8FD5E0	0x803C
+0x8FD5E1	0x803E
+0x8FD5E2	0x8040
+0x8FD5E3	0x8044
+0x8FD5E4	0x8060
+0x8FD5E5	0x8064
+0x8FD5E6	0x8066
+0x8FD5E7	0x806D
+0x8FD5E8	0x8071
+0x8FD5E9	0x8075
+0x8FD5EA	0x8081
+0x8FD5EB	0x8088
+0x8FD5EC	0x808E
+0x8FD5ED	0x809C
+0x8FD5EE	0x809E
+0x8FD5EF	0x80A6
+0x8FD5F0	0x80A7
+0x8FD5F1	0x80AB
+0x8FD5F2	0x80B8
+0x8FD5F3	0x80B9
+0x8FD5F4	0x80C8
+0x8FD5F5	0x80CD
+0x8FD5F6	0x80CF
+0x8FD5F7	0x80D2
+0x8FD5F8	0x80D4
+0x8FD5F9	0x80D5
+0x8FD5FA	0x80D7
+0x8FD5FB	0x80D8
+0x8FD5FC	0x80E0
+0x8FD5FD	0x80ED
+0x8FD5FE	0x80EE
+0x8FD6A1	0x80F0
+0x8FD6A2	0x80F2
+0x8FD6A3	0x80F3
+0x8FD6A4	0x80F6
+0x8FD6A5	0x80F9
+0x8FD6A6	0x80FA
+0x8FD6A7	0x80FE
+0x8FD6A8	0x8103
+0x8FD6A9	0x810B
+0x8FD6AA	0x8116
+0x8FD6AB	0x8117
+0x8FD6AC	0x8118
+0x8FD6AD	0x811C
+0x8FD6AE	0x811E
+0x8FD6AF	0x8120
+0x8FD6B0	0x8124
+0x8FD6B1	0x8127
+0x8FD6B2	0x812C
+0x8FD6B3	0x8130
+0x8FD6B4	0x8135
+0x8FD6B5	0x813A
+0x8FD6B6	0x813C
+0x8FD6B7	0x8145
+0x8FD6B8	0x8147
+0x8FD6B9	0x814A
+0x8FD6BA	0x814C
+0x8FD6BB	0x8152
+0x8FD6BC	0x8157
+0x8FD6BD	0x8160
+0x8FD6BE	0x8161
+0x8FD6BF	0x8167
+0x8FD6C0	0x8168
+0x8FD6C1	0x8169
+0x8FD6C2	0x816D
+0x8FD6C3	0x816F
+0x8FD6C4	0x8177
+0x8FD6C5	0x8181
+0x8FD6C6	0x8190
+0x8FD6C7	0x8184
+0x8FD6C8	0x8185
+0x8FD6C9	0x8186
+0x8FD6CA	0x818B
+0x8FD6CB	0x818E
+0x8FD6CC	0x8196
+0x8FD6CD	0x8198
+0x8FD6CE	0x819B
+0x8FD6CF	0x819E
+0x8FD6D0	0x81A2
+0x8FD6D1	0x81AE
+0x8FD6D2	0x81B2
+0x8FD6D3	0x81B4
+0x8FD6D4	0x81BB
+0x8FD6D5	0x81CB
+0x8FD6D6	0x81C3
+0x8FD6D7	0x81C5
+0x8FD6D8	0x81CA
+0x8FD6D9	0x81CE
+0x8FD6DA	0x81CF
+0x8FD6DB	0x81D5
+0x8FD6DC	0x81D7
+0x8FD6DD	0x81DB
+0x8FD6DE	0x81DD
+0x8FD6DF	0x81DE
+0x8FD6E0	0x81E1
+0x8FD6E1	0x81E4
+0x8FD6E2	0x81EB
+0x8FD6E3	0x81EC
+0x8FD6E4	0x81F0
+0x8FD6E5	0x81F1
+0x8FD6E6	0x81F2
+0x8FD6E7	0x81F5
+0x8FD6E8	0x81F6
+0x8FD6E9	0x81F8
+0x8FD6EA	0x81F9
+0x8FD6EB	0x81FD
+0x8FD6EC	0x81FF
+0x8FD6ED	0x8200
+0x8FD6EE	0x8203
+0x8FD6EF	0x820F
+0x8FD6F0	0x8213
+0x8FD6F1	0x8214
+0x8FD6F2	0x8219
+0x8FD6F3	0x821A
+0x8FD6F4	0x821D
+0x8FD6F5	0x8221
+0x8FD6F6	0x8222
+0x8FD6F7	0x8228
+0x8FD6F8	0x8232
+0x8FD6F9	0x8234
+0x8FD6FA	0x823A
+0x8FD6FB	0x8243
+0x8FD6FC	0x8244
+0x8FD6FD	0x8245
+0x8FD6FE	0x8246
+0x8FD7A1	0x824B
+0x8FD7A2	0x824E
+0x8FD7A3	0x824F
+0x8FD7A4	0x8251
+0x8FD7A5	0x8256
+0x8FD7A6	0x825C
+0x8FD7A7	0x8260
+0x8FD7A8	0x8263
+0x8FD7A9	0x8267
+0x8FD7AA	0x826D
+0x8FD7AB	0x8274
+0x8FD7AC	0x827B
+0x8FD7AD	0x827D
+0x8FD7AE	0x827F
+0x8FD7AF	0x8280
+0x8FD7B0	0x8281
+0x8FD7B1	0x8283
+0x8FD7B2	0x8284
+0x8FD7B3	0x8287
+0x8FD7B4	0x8289
+0x8FD7B5	0x828A
+0x8FD7B6	0x828E
+0x8FD7B7	0x8291
+0x8FD7B8	0x8294
+0x8FD7B9	0x8296
+0x8FD7BA	0x8298
+0x8FD7BB	0x829A
+0x8FD7BC	0x829B
+0x8FD7BD	0x82A0
+0x8FD7BE	0x82A1
+0x8FD7BF	0x82A3
+0x8FD7C0	0x82A4
+0x8FD7C1	0x82A7
+0x8FD7C2	0x82A8
+0x8FD7C3	0x82A9
+0x8FD7C4	0x82AA
+0x8FD7C5	0x82AE
+0x8FD7C6	0x82B0
+0x8FD7C7	0x82B2
+0x8FD7C8	0x82B4
+0x8FD7C9	0x82B7
+0x8FD7CA	0x82BA
+0x8FD7CB	0x82BC
+0x8FD7CC	0x82BE
+0x8FD7CD	0x82BF
+0x8FD7CE	0x82C6
+0x8FD7CF	0x82D0
+0x8FD7D0	0x82D5
+0x8FD7D1	0x82DA
+0x8FD7D2	0x82E0
+0x8FD7D3	0x82E2
+0x8FD7D4	0x82E4
+0x8FD7D5	0x82E8
+0x8FD7D6	0x82EA
+0x8FD7D7	0x82ED
+0x8FD7D8	0x82EF
+0x8FD7D9	0x82F6
+0x8FD7DA	0x82F7
+0x8FD7DB	0x82FD
+0x8FD7DC	0x82FE
+0x8FD7DD	0x8300
+0x8FD7DE	0x8301
+0x8FD7DF	0x8307
+0x8FD7E0	0x8308
+0x8FD7E1	0x830A
+0x8FD7E2	0x830B
+0x8FD7E3	0x8354
+0x8FD7E4	0x831B
+0x8FD7E5	0x831D
+0x8FD7E6	0x831E
+0x8FD7E7	0x831F
+0x8FD7E8	0x8321
+0x8FD7E9	0x8322
+0x8FD7EA	0x832C
+0x8FD7EB	0x832D
+0x8FD7EC	0x832E
+0x8FD7ED	0x8330
+0x8FD7EE	0x8333
+0x8FD7EF	0x8337
+0x8FD7F0	0x833A
+0x8FD7F1	0x833C
+0x8FD7F2	0x833D
+0x8FD7F3	0x8342
+0x8FD7F4	0x8343
+0x8FD7F5	0x8344
+0x8FD7F6	0x8347
+0x8FD7F7	0x834D
+0x8FD7F8	0x834E
+0x8FD7F9	0x8351
+0x8FD7FA	0x8355
+0x8FD7FB	0x8356
+0x8FD7FC	0x8357
+0x8FD7FD	0x8370
+0x8FD7FE	0x8378
+0x8FD8A1	0x837D
+0x8FD8A2	0x837F
+0x8FD8A3	0x8380
+0x8FD8A4	0x8382
+0x8FD8A5	0x8384
+0x8FD8A6	0x8386
+0x8FD8A7	0x838D
+0x8FD8A8	0x8392
+0x8FD8A9	0x8394
+0x8FD8AA	0x8395
+0x8FD8AB	0x8398
+0x8FD8AC	0x8399
+0x8FD8AD	0x839B
+0x8FD8AE	0x839C
+0x8FD8AF	0x839D
+0x8FD8B0	0x83A6
+0x8FD8B1	0x83A7
+0x8FD8B2	0x83A9
+0x8FD8B3	0x83AC
+0x8FD8B4	0x83BE
+0x8FD8B5	0x83BF
+0x8FD8B6	0x83C0
+0x8FD8B7	0x83C7
+0x8FD8B8	0x83C9
+0x8FD8B9	0x83CF
+0x8FD8BA	0x83D0
+0x8FD8BB	0x83D1
+0x8FD8BC	0x83D4
+0x8FD8BD	0x83DD
+0x8FD8BE	0x8353
+0x8FD8BF	0x83E8
+0x8FD8C0	0x83EA
+0x8FD8C1	0x83F6
+0x8FD8C2	0x83F8
+0x8FD8C3	0x83F9
+0x8FD8C4	0x83FC
+0x8FD8C5	0x8401
+0x8FD8C6	0x8406
+0x8FD8C7	0x840A
+0x8FD8C8	0x840F
+0x8FD8C9	0x8411
+0x8FD8CA	0x8415
+0x8FD8CB	0x8419
+0x8FD8CC	0x83AD
+0x8FD8CD	0x842F
+0x8FD8CE	0x8439
+0x8FD8CF	0x8445
+0x8FD8D0	0x8447
+0x8FD8D1	0x8448
+0x8FD8D2	0x844A
+0x8FD8D3	0x844D
+0x8FD8D4	0x844F
+0x8FD8D5	0x8451
+0x8FD8D6	0x8452
+0x8FD8D7	0x8456
+0x8FD8D8	0x8458
+0x8FD8D9	0x8459
+0x8FD8DA	0x845A
+0x8FD8DB	0x845C
+0x8FD8DC	0x8460
+0x8FD8DD	0x8464
+0x8FD8DE	0x8465
+0x8FD8DF	0x8467
+0x8FD8E0	0x846A
+0x8FD8E1	0x8470
+0x8FD8E2	0x8473
+0x8FD8E3	0x8474
+0x8FD8E4	0x8476
+0x8FD8E5	0x8478
+0x8FD8E6	0x847C
+0x8FD8E7	0x847D
+0x8FD8E8	0x8481
+0x8FD8E9	0x8485
+0x8FD8EA	0x8492
+0x8FD8EB	0x8493
+0x8FD8EC	0x8495
+0x8FD8ED	0x849E
+0x8FD8EE	0x84A6
+0x8FD8EF	0x84A8
+0x8FD8F0	0x84A9
+0x8FD8F1	0x84AA
+0x8FD8F2	0x84AF
+0x8FD8F3	0x84B1
+0x8FD8F4	0x84B4
+0x8FD8F5	0x84BA
+0x8FD8F6	0x84BD
+0x8FD8F7	0x84BE
+0x8FD8F8	0x84C0
+0x8FD8F9	0x84C2
+0x8FD8FA	0x84C7
+0x8FD8FB	0x84C8
+0x8FD8FC	0x84CC
+0x8FD8FD	0x84CF
+0x8FD8FE	0x84D3
+0x8FD9A1	0x84DC
+0x8FD9A2	0x84E7
+0x8FD9A3	0x84EA
+0x8FD9A4	0x84EF
+0x8FD9A5	0x84F0
+0x8FD9A6	0x84F1
+0x8FD9A7	0x84F2
+0x8FD9A8	0x84F7
+0x8FD9A9	0x8532
+0x8FD9AA	0x84FA
+0x8FD9AB	0x84FB
+0x8FD9AC	0x84FD
+0x8FD9AD	0x8502
+0x8FD9AE	0x8503
+0x8FD9AF	0x8507
+0x8FD9B0	0x850C
+0x8FD9B1	0x850E
+0x8FD9B2	0x8510
+0x8FD9B3	0x851C
+0x8FD9B4	0x851E
+0x8FD9B5	0x8522
+0x8FD9B6	0x8523
+0x8FD9B7	0x8524
+0x8FD9B8	0x8525
+0x8FD9B9	0x8527
+0x8FD9BA	0x852A
+0x8FD9BB	0x852B
+0x8FD9BC	0x852F
+0x8FD9BD	0x8533
+0x8FD9BE	0x8534
+0x8FD9BF	0x8536
+0x8FD9C0	0x853F
+0x8FD9C1	0x8546
+0x8FD9C2	0x854F
+0x8FD9C3	0x8550
+0x8FD9C4	0x8551
+0x8FD9C5	0x8552
+0x8FD9C6	0x8553
+0x8FD9C7	0x8556
+0x8FD9C8	0x8559
+0x8FD9C9	0x855C
+0x8FD9CA	0x855D
+0x8FD9CB	0x855E
+0x8FD9CC	0x855F
+0x8FD9CD	0x8560
+0x8FD9CE	0x8561
+0x8FD9CF	0x8562
+0x8FD9D0	0x8564
+0x8FD9D1	0x856B
+0x8FD9D2	0x856F
+0x8FD9D3	0x8579
+0x8FD9D4	0x857A
+0x8FD9D5	0x857B
+0x8FD9D6	0x857D
+0x8FD9D7	0x857F
+0x8FD9D8	0x8581
+0x8FD9D9	0x8585
+0x8FD9DA	0x8586
+0x8FD9DB	0x8589
+0x8FD9DC	0x858B
+0x8FD9DD	0x858C
+0x8FD9DE	0x858F
+0x8FD9DF	0x8593
+0x8FD9E0	0x8598
+0x8FD9E1	0x859D
+0x8FD9E2	0x859F
+0x8FD9E3	0x85A0
+0x8FD9E4	0x85A2
+0x8FD9E5	0x85A5
+0x8FD9E6	0x85A7
+0x8FD9E7	0x85B4
+0x8FD9E8	0x85B6
+0x8FD9E9	0x85B7
+0x8FD9EA	0x85B8
+0x8FD9EB	0x85BC
+0x8FD9EC	0x85BD
+0x8FD9ED	0x85BE
+0x8FD9EE	0x85BF
+0x8FD9EF	0x85C2
+0x8FD9F0	0x85C7
+0x8FD9F1	0x85CA
+0x8FD9F2	0x85CB
+0x8FD9F3	0x85CE
+0x8FD9F4	0x85AD
+0x8FD9F5	0x85D8
+0x8FD9F6	0x85DA
+0x8FD9F7	0x85DF
+0x8FD9F8	0x85E0
+0x8FD9F9	0x85E6
+0x8FD9FA	0x85E8
+0x8FD9FB	0x85ED
+0x8FD9FC	0x85F3
+0x8FD9FD	0x85F6
+0x8FD9FE	0x85FC
+0x8FDAA1	0x85FF
+0x8FDAA2	0x8600
+0x8FDAA3	0x8604
+0x8FDAA4	0x8605
+0x8FDAA5	0x860D
+0x8FDAA6	0x860E
+0x8FDAA7	0x8610
+0x8FDAA8	0x8611
+0x8FDAA9	0x8612
+0x8FDAAA	0x8618
+0x8FDAAB	0x8619
+0x8FDAAC	0x861B
+0x8FDAAD	0x861E
+0x8FDAAE	0x8621
+0x8FDAAF	0x8627
+0x8FDAB0	0x8629
+0x8FDAB1	0x8636
+0x8FDAB2	0x8638
+0x8FDAB3	0x863A
+0x8FDAB4	0x863C
+0x8FDAB5	0x863D
+0x8FDAB6	0x8640
+0x8FDAB7	0x8642
+0x8FDAB8	0x8646
+0x8FDAB9	0x8652
+0x8FDABA	0x8653
+0x8FDABB	0x8656
+0x8FDABC	0x8657
+0x8FDABD	0x8658
+0x8FDABE	0x8659
+0x8FDABF	0x865D
+0x8FDAC0	0x8660
+0x8FDAC1	0x8661
+0x8FDAC2	0x8662
+0x8FDAC3	0x8663
+0x8FDAC4	0x8664
+0x8FDAC5	0x8669
+0x8FDAC6	0x866C
+0x8FDAC7	0x866F
+0x8FDAC8	0x8675
+0x8FDAC9	0x8676
+0x8FDACA	0x8677
+0x8FDACB	0x867A
+0x8FDACC	0x868D
+0x8FDACD	0x8691
+0x8FDACE	0x8696
+0x8FDACF	0x8698
+0x8FDAD0	0x869A
+0x8FDAD1	0x869C
+0x8FDAD2	0x86A1
+0x8FDAD3	0x86A6
+0x8FDAD4	0x86A7
+0x8FDAD5	0x86A8
+0x8FDAD6	0x86AD
+0x8FDAD7	0x86B1
+0x8FDAD8	0x86B3
+0x8FDAD9	0x86B4
+0x8FDADA	0x86B5
+0x8FDADB	0x86B7
+0x8FDADC	0x86B8
+0x8FDADD	0x86B9
+0x8FDADE	0x86BF
+0x8FDADF	0x86C0
+0x8FDAE0	0x86C1
+0x8FDAE1	0x86C3
+0x8FDAE2	0x86C5
+0x8FDAE3	0x86D1
+0x8FDAE4	0x86D2
+0x8FDAE5	0x86D5
+0x8FDAE6	0x86D7
+0x8FDAE7	0x86DA
+0x8FDAE8	0x86DC
+0x8FDAE9	0x86E0
+0x8FDAEA	0x86E3
+0x8FDAEB	0x86E5
+0x8FDAEC	0x86E7
+0x8FDAED	0x8688
+0x8FDAEE	0x86FA
+0x8FDAEF	0x86FC
+0x8FDAF0	0x86FD
+0x8FDAF1	0x8704
+0x8FDAF2	0x8705
+0x8FDAF3	0x8707
+0x8FDAF4	0x870B
+0x8FDAF5	0x870E
+0x8FDAF6	0x870F
+0x8FDAF7	0x8710
+0x8FDAF8	0x8713
+0x8FDAF9	0x8714
+0x8FDAFA	0x8719
+0x8FDAFB	0x871E
+0x8FDAFC	0x871F
+0x8FDAFD	0x8721
+0x8FDAFE	0x8723
+0x8FDBA1	0x8728
+0x8FDBA2	0x872E
+0x8FDBA3	0x872F
+0x8FDBA4	0x8731
+0x8FDBA5	0x8732
+0x8FDBA6	0x8739
+0x8FDBA7	0x873A
+0x8FDBA8	0x873C
+0x8FDBA9	0x873D
+0x8FDBAA	0x873E
+0x8FDBAB	0x8740
+0x8FDBAC	0x8743
+0x8FDBAD	0x8745
+0x8FDBAE	0x874D
+0x8FDBAF	0x8758
+0x8FDBB0	0x875D
+0x8FDBB1	0x8761
+0x8FDBB2	0x8764
+0x8FDBB3	0x8765
+0x8FDBB4	0x876F
+0x8FDBB5	0x8771
+0x8FDBB6	0x8772
+0x8FDBB7	0x877B
+0x8FDBB8	0x8783
+0x8FDBB9	0x8784
+0x8FDBBA	0x8785
+0x8FDBBB	0x8786
+0x8FDBBC	0x8787
+0x8FDBBD	0x8788
+0x8FDBBE	0x8789
+0x8FDBBF	0x878B
+0x8FDBC0	0x878C
+0x8FDBC1	0x8790
+0x8FDBC2	0x8793
+0x8FDBC3	0x8795
+0x8FDBC4	0x8797
+0x8FDBC5	0x8798
+0x8FDBC6	0x8799
+0x8FDBC7	0x879E
+0x8FDBC8	0x87A0
+0x8FDBC9	0x87A3
+0x8FDBCA	0x87A7
+0x8FDBCB	0x87AC
+0x8FDBCC	0x87AD
+0x8FDBCD	0x87AE
+0x8FDBCE	0x87B1
+0x8FDBCF	0x87B5
+0x8FDBD0	0x87BE
+0x8FDBD1	0x87BF
+0x8FDBD2	0x87C1
+0x8FDBD3	0x87C8
+0x8FDBD4	0x87C9
+0x8FDBD5	0x87CA
+0x8FDBD6	0x87CE
+0x8FDBD7	0x87D5
+0x8FDBD8	0x87D6
+0x8FDBD9	0x87D9
+0x8FDBDA	0x87DA
+0x8FDBDB	0x87DC
+0x8FDBDC	0x87DF
+0x8FDBDD	0x87E2
+0x8FDBDE	0x87E3
+0x8FDBDF	0x87E4
+0x8FDBE0	0x87EA
+0x8FDBE1	0x87EB
+0x8FDBE2	0x87ED
+0x8FDBE3	0x87F1
+0x8FDBE4	0x87F3
+0x8FDBE5	0x87F8
+0x8FDBE6	0x87FA
+0x8FDBE7	0x87FF
+0x8FDBE8	0x8801
+0x8FDBE9	0x8803
+0x8FDBEA	0x8806
+0x8FDBEB	0x8809
+0x8FDBEC	0x880A
+0x8FDBED	0x880B
+0x8FDBEE	0x8810
+0x8FDBEF	0x8819
+0x8FDBF0	0x8812
+0x8FDBF1	0x8813
+0x8FDBF2	0x8814
+0x8FDBF3	0x8818
+0x8FDBF4	0x881A
+0x8FDBF5	0x881B
+0x8FDBF6	0x881C
+0x8FDBF7	0x881E
+0x8FDBF8	0x881F
+0x8FDBF9	0x8828
+0x8FDBFA	0x882D
+0x8FDBFB	0x882E
+0x8FDBFC	0x8830
+0x8FDBFD	0x8832
+0x8FDBFE	0x8835
+0x8FDCA1	0x883A
+0x8FDCA2	0x883C
+0x8FDCA3	0x8841
+0x8FDCA4	0x8843
+0x8FDCA5	0x8845
+0x8FDCA6	0x8848
+0x8FDCA7	0x8849
+0x8FDCA8	0x884A
+0x8FDCA9	0x884B
+0x8FDCAA	0x884E
+0x8FDCAB	0x8851
+0x8FDCAC	0x8855
+0x8FDCAD	0x8856
+0x8FDCAE	0x8858
+0x8FDCAF	0x885A
+0x8FDCB0	0x885C
+0x8FDCB1	0x885F
+0x8FDCB2	0x8860
+0x8FDCB3	0x8864
+0x8FDCB4	0x8869
+0x8FDCB5	0x8871
+0x8FDCB6	0x8879
+0x8FDCB7	0x887B
+0x8FDCB8	0x8880
+0x8FDCB9	0x8898
+0x8FDCBA	0x889A
+0x8FDCBB	0x889B
+0x8FDCBC	0x889C
+0x8FDCBD	0x889F
+0x8FDCBE	0x88A0
+0x8FDCBF	0x88A8
+0x8FDCC0	0x88AA
+0x8FDCC1	0x88BA
+0x8FDCC2	0x88BD
+0x8FDCC3	0x88BE
+0x8FDCC4	0x88C0
+0x8FDCC5	0x88CA
+0x8FDCC6	0x88CB
+0x8FDCC7	0x88CC
+0x8FDCC8	0x88CD
+0x8FDCC9	0x88CE
+0x8FDCCA	0x88D1
+0x8FDCCB	0x88D2
+0x8FDCCC	0x88D3
+0x8FDCCD	0x88DB
+0x8FDCCE	0x88DE
+0x8FDCCF	0x88E7
+0x8FDCD0	0x88EF
+0x8FDCD1	0x88F0
+0x8FDCD2	0x88F1
+0x8FDCD3	0x88F5
+0x8FDCD4	0x88F7
+0x8FDCD5	0x8901
+0x8FDCD6	0x8906
+0x8FDCD7	0x890D
+0x8FDCD8	0x890E
+0x8FDCD9	0x890F
+0x8FDCDA	0x8915
+0x8FDCDB	0x8916
+0x8FDCDC	0x8918
+0x8FDCDD	0x8919
+0x8FDCDE	0x891A
+0x8FDCDF	0x891C
+0x8FDCE0	0x8920
+0x8FDCE1	0x8926
+0x8FDCE2	0x8927
+0x8FDCE3	0x8928
+0x8FDCE4	0x8930
+0x8FDCE5	0x8931
+0x8FDCE6	0x8932
+0x8FDCE7	0x8935
+0x8FDCE8	0x8939
+0x8FDCE9	0x893A
+0x8FDCEA	0x893E
+0x8FDCEB	0x8940
+0x8FDCEC	0x8942
+0x8FDCED	0x8945
+0x8FDCEE	0x8946
+0x8FDCEF	0x8949
+0x8FDCF0	0x894F
+0x8FDCF1	0x8952
+0x8FDCF2	0x8957
+0x8FDCF3	0x895A
+0x8FDCF4	0x895B
+0x8FDCF5	0x895C
+0x8FDCF6	0x8961
+0x8FDCF7	0x8962
+0x8FDCF8	0x8963
+0x8FDCF9	0x896B
+0x8FDCFA	0x896E
+0x8FDCFB	0x8970
+0x8FDCFC	0x8973
+0x8FDCFD	0x8975
+0x8FDCFE	0x897A
+0x8FDDA1	0x897B
+0x8FDDA2	0x897C
+0x8FDDA3	0x897D
+0x8FDDA4	0x8989
+0x8FDDA5	0x898D
+0x8FDDA6	0x8990
+0x8FDDA7	0x8994
+0x8FDDA8	0x8995
+0x8FDDA9	0x899B
+0x8FDDAA	0x899C
+0x8FDDAB	0x899F
+0x8FDDAC	0x89A0
+0x8FDDAD	0x89A5
+0x8FDDAE	0x89B0
+0x8FDDAF	0x89B4
+0x8FDDB0	0x89B5
+0x8FDDB1	0x89B6
+0x8FDDB2	0x89B7
+0x8FDDB3	0x89BC
+0x8FDDB4	0x89D4
+0x8FDDB5	0x89D5
+0x8FDDB6	0x89D6
+0x8FDDB7	0x89D7
+0x8FDDB8	0x89D8
+0x8FDDB9	0x89E5
+0x8FDDBA	0x89E9
+0x8FDDBB	0x89EB
+0x8FDDBC	0x89ED
+0x8FDDBD	0x89F1
+0x8FDDBE	0x89F3
+0x8FDDBF	0x89F6
+0x8FDDC0	0x89F9
+0x8FDDC1	0x89FD
+0x8FDDC2	0x89FF
+0x8FDDC3	0x8A04
+0x8FDDC4	0x8A05
+0x8FDDC5	0x8A07
+0x8FDDC6	0x8A0F
+0x8FDDC7	0x8A11
+0x8FDDC8	0x8A12
+0x8FDDC9	0x8A14
+0x8FDDCA	0x8A15
+0x8FDDCB	0x8A1E
+0x8FDDCC	0x8A20
+0x8FDDCD	0x8A22
+0x8FDDCE	0x8A24
+0x8FDDCF	0x8A26
+0x8FDDD0	0x8A2B
+0x8FDDD1	0x8A2C
+0x8FDDD2	0x8A2F
+0x8FDDD3	0x8A35
+0x8FDDD4	0x8A37
+0x8FDDD5	0x8A3D
+0x8FDDD6	0x8A3E
+0x8FDDD7	0x8A40
+0x8FDDD8	0x8A43
+0x8FDDD9	0x8A45
+0x8FDDDA	0x8A47
+0x8FDDDB	0x8A49
+0x8FDDDC	0x8A4D
+0x8FDDDD	0x8A4E
+0x8FDDDE	0x8A53
+0x8FDDDF	0x8A56
+0x8FDDE0	0x8A57
+0x8FDDE1	0x8A58
+0x8FDDE2	0x8A5C
+0x8FDDE3	0x8A5D
+0x8FDDE4	0x8A61
+0x8FDDE5	0x8A65
+0x8FDDE6	0x8A67
+0x8FDDE7	0x8A75
+0x8FDDE8	0x8A76
+0x8FDDE9	0x8A77
+0x8FDDEA	0x8A79
+0x8FDDEB	0x8A7A
+0x8FDDEC	0x8A7B
+0x8FDDED	0x8A7E
+0x8FDDEE	0x8A7F
+0x8FDDEF	0x8A80
+0x8FDDF0	0x8A83
+0x8FDDF1	0x8A86
+0x8FDDF2	0x8A8B
+0x8FDDF3	0x8A8F
+0x8FDDF4	0x8A90
+0x8FDDF5	0x8A92
+0x8FDDF6	0x8A96
+0x8FDDF7	0x8A97
+0x8FDDF8	0x8A99
+0x8FDDF9	0x8A9F
+0x8FDDFA	0x8AA7
+0x8FDDFB	0x8AA9
+0x8FDDFC	0x8AAE
+0x8FDDFD	0x8AAF
+0x8FDDFE	0x8AB3
+0x8FDEA1	0x8AB6
+0x8FDEA2	0x8AB7
+0x8FDEA3	0x8ABB
+0x8FDEA4	0x8ABE
+0x8FDEA5	0x8AC3
+0x8FDEA6	0x8AC6
+0x8FDEA7	0x8AC8
+0x8FDEA8	0x8AC9
+0x8FDEA9	0x8ACA
+0x8FDEAA	0x8AD1
+0x8FDEAB	0x8AD3
+0x8FDEAC	0x8AD4
+0x8FDEAD	0x8AD5
+0x8FDEAE	0x8AD7
+0x8FDEAF	0x8ADD
+0x8FDEB0	0x8ADF
+0x8FDEB1	0x8AEC
+0x8FDEB2	0x8AF0
+0x8FDEB3	0x8AF4
+0x8FDEB4	0x8AF5
+0x8FDEB5	0x8AF6
+0x8FDEB6	0x8AFC
+0x8FDEB7	0x8AFF
+0x8FDEB8	0x8B05
+0x8FDEB9	0x8B06
+0x8FDEBA	0x8B0B
+0x8FDEBB	0x8B11
+0x8FDEBC	0x8B1C
+0x8FDEBD	0x8B1E
+0x8FDEBE	0x8B1F
+0x8FDEBF	0x8B0A
+0x8FDEC0	0x8B2D
+0x8FDEC1	0x8B30
+0x8FDEC2	0x8B37
+0x8FDEC3	0x8B3C
+0x8FDEC4	0x8B42
+0x8FDEC5	0x8B43
+0x8FDEC6	0x8B44
+0x8FDEC7	0x8B45
+0x8FDEC8	0x8B46
+0x8FDEC9	0x8B48
+0x8FDECA	0x8B52
+0x8FDECB	0x8B53
+0x8FDECC	0x8B54
+0x8FDECD	0x8B59
+0x8FDECE	0x8B4D
+0x8FDECF	0x8B5E
+0x8FDED0	0x8B63
+0x8FDED1	0x8B6D
+0x8FDED2	0x8B76
+0x8FDED3	0x8B78
+0x8FDED4	0x8B79
+0x8FDED5	0x8B7C
+0x8FDED6	0x8B7E
+0x8FDED7	0x8B81
+0x8FDED8	0x8B84
+0x8FDED9	0x8B85
+0x8FDEDA	0x8B8B
+0x8FDEDB	0x8B8D
+0x8FDEDC	0x8B8F
+0x8FDEDD	0x8B94
+0x8FDEDE	0x8B95
+0x8FDEDF	0x8B9C
+0x8FDEE0	0x8B9E
+0x8FDEE1	0x8B9F
+0x8FDEE2	0x8C38
+0x8FDEE3	0x8C39
+0x8FDEE4	0x8C3D
+0x8FDEE5	0x8C3E
+0x8FDEE6	0x8C45
+0x8FDEE7	0x8C47
+0x8FDEE8	0x8C49
+0x8FDEE9	0x8C4B
+0x8FDEEA	0x8C4F
+0x8FDEEB	0x8C51
+0x8FDEEC	0x8C53
+0x8FDEED	0x8C54
+0x8FDEEE	0x8C57
+0x8FDEEF	0x8C58
+0x8FDEF0	0x8C5B
+0x8FDEF1	0x8C5D
+0x8FDEF2	0x8C59
+0x8FDEF3	0x8C63
+0x8FDEF4	0x8C64
+0x8FDEF5	0x8C66
+0x8FDEF6	0x8C68
+0x8FDEF7	0x8C69
+0x8FDEF8	0x8C6D
+0x8FDEF9	0x8C73
+0x8FDEFA	0x8C75
+0x8FDEFB	0x8C76
+0x8FDEFC	0x8C7B
+0x8FDEFD	0x8C7E
+0x8FDEFE	0x8C86
+0x8FDFA1	0x8C87
+0x8FDFA2	0x8C8B
+0x8FDFA3	0x8C90
+0x8FDFA4	0x8C92
+0x8FDFA5	0x8C93
+0x8FDFA6	0x8C99
+0x8FDFA7	0x8C9B
+0x8FDFA8	0x8C9C
+0x8FDFA9	0x8CA4
+0x8FDFAA	0x8CB9
+0x8FDFAB	0x8CBA
+0x8FDFAC	0x8CC5
+0x8FDFAD	0x8CC6
+0x8FDFAE	0x8CC9
+0x8FDFAF	0x8CCB
+0x8FDFB0	0x8CCF
+0x8FDFB1	0x8CD6
+0x8FDFB2	0x8CD5
+0x8FDFB3	0x8CD9
+0x8FDFB4	0x8CDD
+0x8FDFB5	0x8CE1
+0x8FDFB6	0x8CE8
+0x8FDFB7	0x8CEC
+0x8FDFB8	0x8CEF
+0x8FDFB9	0x8CF0
+0x8FDFBA	0x8CF2
+0x8FDFBB	0x8CF5
+0x8FDFBC	0x8CF7
+0x8FDFBD	0x8CF8
+0x8FDFBE	0x8CFE
+0x8FDFBF	0x8CFF
+0x8FDFC0	0x8D01
+0x8FDFC1	0x8D03
+0x8FDFC2	0x8D09
+0x8FDFC3	0x8D12
+0x8FDFC4	0x8D17
+0x8FDFC5	0x8D1B
+0x8FDFC6	0x8D65
+0x8FDFC7	0x8D69
+0x8FDFC8	0x8D6C
+0x8FDFC9	0x8D6E
+0x8FDFCA	0x8D7F
+0x8FDFCB	0x8D82
+0x8FDFCC	0x8D84
+0x8FDFCD	0x8D88
+0x8FDFCE	0x8D8D
+0x8FDFCF	0x8D90
+0x8FDFD0	0x8D91
+0x8FDFD1	0x8D95
+0x8FDFD2	0x8D9E
+0x8FDFD3	0x8D9F
+0x8FDFD4	0x8DA0
+0x8FDFD5	0x8DA6
+0x8FDFD6	0x8DAB
+0x8FDFD7	0x8DAC
+0x8FDFD8	0x8DAF
+0x8FDFD9	0x8DB2
+0x8FDFDA	0x8DB5
+0x8FDFDB	0x8DB7
+0x8FDFDC	0x8DB9
+0x8FDFDD	0x8DBB
+0x8FDFDE	0x8DC0
+0x8FDFDF	0x8DC5
+0x8FDFE0	0x8DC6
+0x8FDFE1	0x8DC7
+0x8FDFE2	0x8DC8
+0x8FDFE3	0x8DCA
+0x8FDFE4	0x8DCE
+0x8FDFE5	0x8DD1
+0x8FDFE6	0x8DD4
+0x8FDFE7	0x8DD5
+0x8FDFE8	0x8DD7
+0x8FDFE9	0x8DD9
+0x8FDFEA	0x8DE4
+0x8FDFEB	0x8DE5
+0x8FDFEC	0x8DE7
+0x8FDFED	0x8DEC
+0x8FDFEE	0x8DF0
+0x8FDFEF	0x8DBC
+0x8FDFF0	0x8DF1
+0x8FDFF1	0x8DF2
+0x8FDFF2	0x8DF4
+0x8FDFF3	0x8DFD
+0x8FDFF4	0x8E01
+0x8FDFF5	0x8E04
+0x8FDFF6	0x8E05
+0x8FDFF7	0x8E06
+0x8FDFF8	0x8E0B
+0x8FDFF9	0x8E11
+0x8FDFFA	0x8E14
+0x8FDFFB	0x8E16
+0x8FDFFC	0x8E20
+0x8FDFFD	0x8E21
+0x8FDFFE	0x8E22
+0x8FE0A1	0x8E23
+0x8FE0A2	0x8E26
+0x8FE0A3	0x8E27
+0x8FE0A4	0x8E31
+0x8FE0A5	0x8E33
+0x8FE0A6	0x8E36
+0x8FE0A7	0x8E37
+0x8FE0A8	0x8E38
+0x8FE0A9	0x8E39
+0x8FE0AA	0x8E3D
+0x8FE0AB	0x8E40
+0x8FE0AC	0x8E41
+0x8FE0AD	0x8E4B
+0x8FE0AE	0x8E4D
+0x8FE0AF	0x8E4E
+0x8FE0B0	0x8E4F
+0x8FE0B1	0x8E54
+0x8FE0B2	0x8E5B
+0x8FE0B3	0x8E5C
+0x8FE0B4	0x8E5D
+0x8FE0B5	0x8E5E
+0x8FE0B6	0x8E61
+0x8FE0B7	0x8E62
+0x8FE0B8	0x8E69
+0x8FE0B9	0x8E6C
+0x8FE0BA	0x8E6D
+0x8FE0BB	0x8E6F
+0x8FE0BC	0x8E70
+0x8FE0BD	0x8E71
+0x8FE0BE	0x8E79
+0x8FE0BF	0x8E7A
+0x8FE0C0	0x8E7B
+0x8FE0C1	0x8E82
+0x8FE0C2	0x8E83
+0x8FE0C3	0x8E89
+0x8FE0C4	0x8E90
+0x8FE0C5	0x8E92
+0x8FE0C6	0x8E95
+0x8FE0C7	0x8E9A
+0x8FE0C8	0x8E9B
+0x8FE0C9	0x8E9D
+0x8FE0CA	0x8E9E
+0x8FE0CB	0x8EA2
+0x8FE0CC	0x8EA7
+0x8FE0CD	0x8EA9
+0x8FE0CE	0x8EAD
+0x8FE0CF	0x8EAE
+0x8FE0D0	0x8EB3
+0x8FE0D1	0x8EB5
+0x8FE0D2	0x8EBA
+0x8FE0D3	0x8EBB
+0x8FE0D4	0x8EC0
+0x8FE0D5	0x8EC1
+0x8FE0D6	0x8EC3
+0x8FE0D7	0x8EC4
+0x8FE0D8	0x8EC7
+0x8FE0D9	0x8ECF
+0x8FE0DA	0x8ED1
+0x8FE0DB	0x8ED4
+0x8FE0DC	0x8EDC
+0x8FE0DD	0x8EE8
+0x8FE0DE	0x8EEE
+0x8FE0DF	0x8EF0
+0x8FE0E0	0x8EF1
+0x8FE0E1	0x8EF7
+0x8FE0E2	0x8EF9
+0x8FE0E3	0x8EFA
+0x8FE0E4	0x8EED
+0x8FE0E5	0x8F00
+0x8FE0E6	0x8F02
+0x8FE0E7	0x8F07
+0x8FE0E8	0x8F08
+0x8FE0E9	0x8F0F
+0x8FE0EA	0x8F10
+0x8FE0EB	0x8F16
+0x8FE0EC	0x8F17
+0x8FE0ED	0x8F18
+0x8FE0EE	0x8F1E
+0x8FE0EF	0x8F20
+0x8FE0F0	0x8F21
+0x8FE0F1	0x8F23
+0x8FE0F2	0x8F25
+0x8FE0F3	0x8F27
+0x8FE0F4	0x8F28
+0x8FE0F5	0x8F2C
+0x8FE0F6	0x8F2D
+0x8FE0F7	0x8F2E
+0x8FE0F8	0x8F34
+0x8FE0F9	0x8F35
+0x8FE0FA	0x8F36
+0x8FE0FB	0x8F37
+0x8FE0FC	0x8F3A
+0x8FE0FD	0x8F40
+0x8FE0FE	0x8F41
+0x8FE1A1	0x8F43
+0x8FE1A2	0x8F47
+0x8FE1A3	0x8F4F
+0x8FE1A4	0x8F51
+0x8FE1A5	0x8F52
+0x8FE1A6	0x8F53
+0x8FE1A7	0x8F54
+0x8FE1A8	0x8F55
+0x8FE1A9	0x8F58
+0x8FE1AA	0x8F5D
+0x8FE1AB	0x8F5E
+0x8FE1AC	0x8F65
+0x8FE1AD	0x8F9D
+0x8FE1AE	0x8FA0
+0x8FE1AF	0x8FA1
+0x8FE1B0	0x8FA4
+0x8FE1B1	0x8FA5
+0x8FE1B2	0x8FA6
+0x8FE1B3	0x8FB5
+0x8FE1B4	0x8FB6
+0x8FE1B5	0x8FB8
+0x8FE1B6	0x8FBE
+0x8FE1B7	0x8FC0
+0x8FE1B8	0x8FC1
+0x8FE1B9	0x8FC6
+0x8FE1BA	0x8FCA
+0x8FE1BB	0x8FCB
+0x8FE1BC	0x8FCD
+0x8FE1BD	0x8FD0
+0x8FE1BE	0x8FD2
+0x8FE1BF	0x8FD3
+0x8FE1C0	0x8FD5
+0x8FE1C1	0x8FE0
+0x8FE1C2	0x8FE3
+0x8FE1C3	0x8FE4
+0x8FE1C4	0x8FE8
+0x8FE1C5	0x8FEE
+0x8FE1C6	0x8FF1
+0x8FE1C7	0x8FF5
+0x8FE1C8	0x8FF6
+0x8FE1C9	0x8FFB
+0x8FE1CA	0x8FFE
+0x8FE1CB	0x9002
+0x8FE1CC	0x9004
+0x8FE1CD	0x9008
+0x8FE1CE	0x900C
+0x8FE1CF	0x9018
+0x8FE1D0	0x901B
+0x8FE1D1	0x9028
+0x8FE1D2	0x9029
+0x8FE1D3	0x902F
+0x8FE1D4	0x902A
+0x8FE1D5	0x902C
+0x8FE1D6	0x902D
+0x8FE1D7	0x9033
+0x8FE1D8	0x9034
+0x8FE1D9	0x9037
+0x8FE1DA	0x903F
+0x8FE1DB	0x9043
+0x8FE1DC	0x9044
+0x8FE1DD	0x904C
+0x8FE1DE	0x905B
+0x8FE1DF	0x905D
+0x8FE1E0	0x9062
+0x8FE1E1	0x9066
+0x8FE1E2	0x9067
+0x8FE1E3	0x906C
+0x8FE1E4	0x9070
+0x8FE1E5	0x9074
+0x8FE1E6	0x9079
+0x8FE1E7	0x9085
+0x8FE1E8	0x9088
+0x8FE1E9	0x908B
+0x8FE1EA	0x908C
+0x8FE1EB	0x908E
+0x8FE1EC	0x9090
+0x8FE1ED	0x9095
+0x8FE1EE	0x9097
+0x8FE1EF	0x9098
+0x8FE1F0	0x9099
+0x8FE1F1	0x909B
+0x8FE1F2	0x90A0
+0x8FE1F3	0x90A1
+0x8FE1F4	0x90A2
+0x8FE1F5	0x90A5
+0x8FE1F6	0x90B0
+0x8FE1F7	0x90B2
+0x8FE1F8	0x90B3
+0x8FE1F9	0x90B4
+0x8FE1FA	0x90B6
+0x8FE1FB	0x90BD
+0x8FE1FC	0x90CC
+0x8FE1FD	0x90BE
+0x8FE1FE	0x90C3
+0x8FE2A1	0x90C4
+0x8FE2A2	0x90C5
+0x8FE2A3	0x90C7
+0x8FE2A4	0x90C8
+0x8FE2A5	0x90D5
+0x8FE2A6	0x90D7
+0x8FE2A7	0x90D8
+0x8FE2A8	0x90D9
+0x8FE2A9	0x90DC
+0x8FE2AA	0x90DD
+0x8FE2AB	0x90DF
+0x8FE2AC	0x90E5
+0x8FE2AD	0x90D2
+0x8FE2AE	0x90F6
+0x8FE2AF	0x90EB
+0x8FE2B0	0x90EF
+0x8FE2B1	0x90F0
+0x8FE2B2	0x90F4
+0x8FE2B3	0x90FE
+0x8FE2B4	0x90FF
+0x8FE2B5	0x9100
+0x8FE2B6	0x9104
+0x8FE2B7	0x9105
+0x8FE2B8	0x9106
+0x8FE2B9	0x9108
+0x8FE2BA	0x910D
+0x8FE2BB	0x9110
+0x8FE2BC	0x9114
+0x8FE2BD	0x9116
+0x8FE2BE	0x9117
+0x8FE2BF	0x9118
+0x8FE2C0	0x911A
+0x8FE2C1	0x911C
+0x8FE2C2	0x911E
+0x8FE2C3	0x9120
+0x8FE2C4	0x9125
+0x8FE2C5	0x9122
+0x8FE2C6	0x9123
+0x8FE2C7	0x9127
+0x8FE2C8	0x9129
+0x8FE2C9	0x912E
+0x8FE2CA	0x912F
+0x8FE2CB	0x9131
+0x8FE2CC	0x9134
+0x8FE2CD	0x9136
+0x8FE2CE	0x9137
+0x8FE2CF	0x9139
+0x8FE2D0	0x913A
+0x8FE2D1	0x913C
+0x8FE2D2	0x913D
+0x8FE2D3	0x9143
+0x8FE2D4	0x9147
+0x8FE2D5	0x9148
+0x8FE2D6	0x914F
+0x8FE2D7	0x9153
+0x8FE2D8	0x9157
+0x8FE2D9	0x9159
+0x8FE2DA	0x915A
+0x8FE2DB	0x915B
+0x8FE2DC	0x9161
+0x8FE2DD	0x9164
+0x8FE2DE	0x9167
+0x8FE2DF	0x916D
+0x8FE2E0	0x9174
+0x8FE2E1	0x9179
+0x8FE2E2	0x917A
+0x8FE2E3	0x917B
+0x8FE2E4	0x9181
+0x8FE2E5	0x9183
+0x8FE2E6	0x9185
+0x8FE2E7	0x9186
+0x8FE2E8	0x918A
+0x8FE2E9	0x918E
+0x8FE2EA	0x9191
+0x8FE2EB	0x9193
+0x8FE2EC	0x9194
+0x8FE2ED	0x9195
+0x8FE2EE	0x9198
+0x8FE2EF	0x919E
+0x8FE2F0	0x91A1
+0x8FE2F1	0x91A6
+0x8FE2F2	0x91A8
+0x8FE2F3	0x91AC
+0x8FE2F4	0x91AD
+0x8FE2F5	0x91AE
+0x8FE2F6	0x91B0
+0x8FE2F7	0x91B1
+0x8FE2F8	0x91B2
+0x8FE2F9	0x91B3
+0x8FE2FA	0x91B6
+0x8FE2FB	0x91BB
+0x8FE2FC	0x91BC
+0x8FE2FD	0x91BD
+0x8FE2FE	0x91BF
+0x8FE3A1	0x91C2
+0x8FE3A2	0x91C3
+0x8FE3A3	0x91C5
+0x8FE3A4	0x91D3
+0x8FE3A5	0x91D4
+0x8FE3A6	0x91D7
+0x8FE3A7	0x91D9
+0x8FE3A8	0x91DA
+0x8FE3A9	0x91DE
+0x8FE3AA	0x91E4
+0x8FE3AB	0x91E5
+0x8FE3AC	0x91E9
+0x8FE3AD	0x91EA
+0x8FE3AE	0x91EC
+0x8FE3AF	0x91ED
+0x8FE3B0	0x91EE
+0x8FE3B1	0x91EF
+0x8FE3B2	0x91F0
+0x8FE3B3	0x91F1
+0x8FE3B4	0x91F7
+0x8FE3B5	0x91F9
+0x8FE3B6	0x91FB
+0x8FE3B7	0x91FD
+0x8FE3B8	0x9200
+0x8FE3B9	0x9201
+0x8FE3BA	0x9204
+0x8FE3BB	0x9205
+0x8FE3BC	0x9206
+0x8FE3BD	0x9207
+0x8FE3BE	0x9209
+0x8FE3BF	0x920A
+0x8FE3C0	0x920C
+0x8FE3C1	0x9210
+0x8FE3C2	0x9212
+0x8FE3C3	0x9213
+0x8FE3C4	0x9216
+0x8FE3C5	0x9218
+0x8FE3C6	0x921C
+0x8FE3C7	0x921D
+0x8FE3C8	0x9223
+0x8FE3C9	0x9224
+0x8FE3CA	0x9225
+0x8FE3CB	0x9226
+0x8FE3CC	0x9228
+0x8FE3CD	0x922E
+0x8FE3CE	0x922F
+0x8FE3CF	0x9230
+0x8FE3D0	0x9233
+0x8FE3D1	0x9235
+0x8FE3D2	0x9236
+0x8FE3D3	0x9238
+0x8FE3D4	0x9239
+0x8FE3D5	0x923A
+0x8FE3D6	0x923C
+0x8FE3D7	0x923E
+0x8FE3D8	0x9240
+0x8FE3D9	0x9242
+0x8FE3DA	0x9243
+0x8FE3DB	0x9246
+0x8FE3DC	0x9247
+0x8FE3DD	0x924A
+0x8FE3DE	0x924D
+0x8FE3DF	0x924E
+0x8FE3E0	0x924F
+0x8FE3E1	0x9251
+0x8FE3E2	0x9258
+0x8FE3E3	0x9259
+0x8FE3E4	0x925C
+0x8FE3E5	0x925D
+0x8FE3E6	0x9260
+0x8FE3E7	0x9261
+0x8FE3E8	0x9265
+0x8FE3E9	0x9267
+0x8FE3EA	0x9268
+0x8FE3EB	0x9269
+0x8FE3EC	0x926E
+0x8FE3ED	0x926F
+0x8FE3EE	0x9270
+0x8FE3EF	0x9275
+0x8FE3F0	0x9276
+0x8FE3F1	0x9277
+0x8FE3F2	0x9278
+0x8FE3F3	0x9279
+0x8FE3F4	0x927B
+0x8FE3F5	0x927C
+0x8FE3F6	0x927D
+0x8FE3F7	0x927F
+0x8FE3F8	0x9288
+0x8FE3F9	0x9289
+0x8FE3FA	0x928A
+0x8FE3FB	0x928D
+0x8FE3FC	0x928E
+0x8FE3FD	0x9292
+0x8FE3FE	0x9297
+0x8FE4A1	0x9299
+0x8FE4A2	0x929F
+0x8FE4A3	0x92A0
+0x8FE4A4	0x92A4
+0x8FE4A5	0x92A5
+0x8FE4A6	0x92A7
+0x8FE4A7	0x92A8
+0x8FE4A8	0x92AB
+0x8FE4A9	0x92AF
+0x8FE4AA	0x92B2
+0x8FE4AB	0x92B6
+0x8FE4AC	0x92B8
+0x8FE4AD	0x92BA
+0x8FE4AE	0x92BB
+0x8FE4AF	0x92BC
+0x8FE4B0	0x92BD
+0x8FE4B1	0x92BF
+0x8FE4B2	0x92C0
+0x8FE4B3	0x92C1
+0x8FE4B4	0x92C2
+0x8FE4B5	0x92C3
+0x8FE4B6	0x92C5
+0x8FE4B7	0x92C6
+0x8FE4B8	0x92C7
+0x8FE4B9	0x92C8
+0x8FE4BA	0x92CB
+0x8FE4BB	0x92CC
+0x8FE4BC	0x92CD
+0x8FE4BD	0x92CE
+0x8FE4BE	0x92D0
+0x8FE4BF	0x92D3
+0x8FE4C0	0x92D5
+0x8FE4C1	0x92D7
+0x8FE4C2	0x92D8
+0x8FE4C3	0x92D9
+0x8FE4C4	0x92DC
+0x8FE4C5	0x92DD
+0x8FE4C6	0x92DF
+0x8FE4C7	0x92E0
+0x8FE4C8	0x92E1
+0x8FE4C9	0x92E3
+0x8FE4CA	0x92E5
+0x8FE4CB	0x92E7
+0x8FE4CC	0x92E8
+0x8FE4CD	0x92EC
+0x8FE4CE	0x92EE
+0x8FE4CF	0x92F0
+0x8FE4D0	0x92F9
+0x8FE4D1	0x92FB
+0x8FE4D2	0x92FF
+0x8FE4D3	0x9300
+0x8FE4D4	0x9302
+0x8FE4D5	0x9308
+0x8FE4D6	0x930D
+0x8FE4D7	0x9311
+0x8FE4D8	0x9314
+0x8FE4D9	0x9315
+0x8FE4DA	0x931C
+0x8FE4DB	0x931D
+0x8FE4DC	0x931E
+0x8FE4DD	0x931F
+0x8FE4DE	0x9321
+0x8FE4DF	0x9324
+0x8FE4E0	0x9325
+0x8FE4E1	0x9327
+0x8FE4E2	0x9329
+0x8FE4E3	0x932A
+0x8FE4E4	0x9333
+0x8FE4E5	0x9334
+0x8FE4E6	0x9336
+0x8FE4E7	0x9337
+0x8FE4E8	0x9347
+0x8FE4E9	0x9348
+0x8FE4EA	0x9349
+0x8FE4EB	0x9350
+0x8FE4EC	0x9351
+0x8FE4ED	0x9352
+0x8FE4EE	0x9355
+0x8FE4EF	0x9357
+0x8FE4F0	0x9358
+0x8FE4F1	0x935A
+0x8FE4F2	0x935E
+0x8FE4F3	0x9364
+0x8FE4F4	0x9365
+0x8FE4F5	0x9367
+0x8FE4F6	0x9369
+0x8FE4F7	0x936A
+0x8FE4F8	0x936D
+0x8FE4F9	0x936F
+0x8FE4FA	0x9370
+0x8FE4FB	0x9371
+0x8FE4FC	0x9373
+0x8FE4FD	0x9374
+0x8FE4FE	0x9376
+0x8FE5A1	0x937A
+0x8FE5A2	0x937D
+0x8FE5A3	0x937F
+0x8FE5A4	0x9380
+0x8FE5A5	0x9381
+0x8FE5A6	0x9382
+0x8FE5A7	0x9388
+0x8FE5A8	0x938A
+0x8FE5A9	0x938B
+0x8FE5AA	0x938D
+0x8FE5AB	0x938F
+0x8FE5AC	0x9392
+0x8FE5AD	0x9395
+0x8FE5AE	0x9398
+0x8FE5AF	0x939B
+0x8FE5B0	0x939E
+0x8FE5B1	0x93A1
+0x8FE5B2	0x93A3
+0x8FE5B3	0x93A4
+0x8FE5B4	0x93A6
+0x8FE5B5	0x93A8
+0x8FE5B6	0x93AB
+0x8FE5B7	0x93B4
+0x8FE5B8	0x93B5
+0x8FE5B9	0x93B6
+0x8FE5BA	0x93BA
+0x8FE5BB	0x93A9
+0x8FE5BC	0x93C1
+0x8FE5BD	0x93C4
+0x8FE5BE	0x93C5
+0x8FE5BF	0x93C6
+0x8FE5C0	0x93C7
+0x8FE5C1	0x93C9
+0x8FE5C2	0x93CA
+0x8FE5C3	0x93CB
+0x8FE5C4	0x93CC
+0x8FE5C5	0x93CD
+0x8FE5C6	0x93D3
+0x8FE5C7	0x93D9
+0x8FE5C8	0x93DC
+0x8FE5C9	0x93DE
+0x8FE5CA	0x93DF
+0x8FE5CB	0x93E2
+0x8FE5CC	0x93E6
+0x8FE5CD	0x93E7
+0x8FE5CE	0x93F9
+0x8FE5CF	0x93F7
+0x8FE5D0	0x93F8
+0x8FE5D1	0x93FA
+0x8FE5D2	0x93FB
+0x8FE5D3	0x93FD
+0x8FE5D4	0x9401
+0x8FE5D5	0x9402
+0x8FE5D6	0x9404
+0x8FE5D7	0x9408
+0x8FE5D8	0x9409
+0x8FE5D9	0x940D
+0x8FE5DA	0x940E
+0x8FE5DB	0x940F
+0x8FE5DC	0x9415
+0x8FE5DD	0x9416
+0x8FE5DE	0x9417
+0x8FE5DF	0x941F
+0x8FE5E0	0x942E
+0x8FE5E1	0x942F
+0x8FE5E2	0x9431
+0x8FE5E3	0x9432
+0x8FE5E4	0x9433
+0x8FE5E5	0x9434
+0x8FE5E6	0x943B
+0x8FE5E7	0x943F
+0x8FE5E8	0x943D
+0x8FE5E9	0x9443
+0x8FE5EA	0x9445
+0x8FE5EB	0x9448
+0x8FE5EC	0x944A
+0x8FE5ED	0x944C
+0x8FE5EE	0x9455
+0x8FE5EF	0x9459
+0x8FE5F0	0x945C
+0x8FE5F1	0x945F
+0x8FE5F2	0x9461
+0x8FE5F3	0x9463
+0x8FE5F4	0x9468
+0x8FE5F5	0x946B
+0x8FE5F6	0x946D
+0x8FE5F7	0x946E
+0x8FE5F8	0x946F
+0x8FE5F9	0x9471
+0x8FE5FA	0x9472
+0x8FE5FB	0x9484
+0x8FE5FC	0x9483
+0x8FE5FD	0x9578
+0x8FE5FE	0x9579
+0x8FE6A1	0x957E
+0x8FE6A2	0x9584
+0x8FE6A3	0x9588
+0x8FE6A4	0x958C
+0x8FE6A5	0x958D
+0x8FE6A6	0x958E
+0x8FE6A7	0x959D
+0x8FE6A8	0x959E
+0x8FE6A9	0x959F
+0x8FE6AA	0x95A1
+0x8FE6AB	0x95A6
+0x8FE6AC	0x95A9
+0x8FE6AD	0x95AB
+0x8FE6AE	0x95AC
+0x8FE6AF	0x95B4
+0x8FE6B0	0x95B6
+0x8FE6B1	0x95BA
+0x8FE6B2	0x95BD
+0x8FE6B3	0x95BF
+0x8FE6B4	0x95C6
+0x8FE6B5	0x95C8
+0x8FE6B6	0x95C9
+0x8FE6B7	0x95CB
+0x8FE6B8	0x95D0
+0x8FE6B9	0x95D1
+0x8FE6BA	0x95D2
+0x8FE6BB	0x95D3
+0x8FE6BC	0x95D9
+0x8FE6BD	0x95DA
+0x8FE6BE	0x95DD
+0x8FE6BF	0x95DE
+0x8FE6C0	0x95DF
+0x8FE6C1	0x95E0
+0x8FE6C2	0x95E4
+0x8FE6C3	0x95E6
+0x8FE6C4	0x961D
+0x8FE6C5	0x961E
+0x8FE6C6	0x9622
+0x8FE6C7	0x9624
+0x8FE6C8	0x9625
+0x8FE6C9	0x9626
+0x8FE6CA	0x962C
+0x8FE6CB	0x9631
+0x8FE6CC	0x9633
+0x8FE6CD	0x9637
+0x8FE6CE	0x9638
+0x8FE6CF	0x9639
+0x8FE6D0	0x963A
+0x8FE6D1	0x963C
+0x8FE6D2	0x963D
+0x8FE6D3	0x9641
+0x8FE6D4	0x9652
+0x8FE6D5	0x9654
+0x8FE6D6	0x9656
+0x8FE6D7	0x9657
+0x8FE6D8	0x9658
+0x8FE6D9	0x9661
+0x8FE6DA	0x966E
+0x8FE6DB	0x9674
+0x8FE6DC	0x967B
+0x8FE6DD	0x967C
+0x8FE6DE	0x967E
+0x8FE6DF	0x967F
+0x8FE6E0	0x9681
+0x8FE6E1	0x9682
+0x8FE6E2	0x9683
+0x8FE6E3	0x9684
+0x8FE6E4	0x9689
+0x8FE6E5	0x9691
+0x8FE6E6	0x9696
+0x8FE6E7	0x969A
+0x8FE6E8	0x969D
+0x8FE6E9	0x969F
+0x8FE6EA	0x96A4
+0x8FE6EB	0x96A5
+0x8FE6EC	0x96A6
+0x8FE6ED	0x96A9
+0x8FE6EE	0x96AE
+0x8FE6EF	0x96AF
+0x8FE6F0	0x96B3
+0x8FE6F1	0x96BA
+0x8FE6F2	0x96CA
+0x8FE6F3	0x96D2
+0x8FE6F4	0x5DB2
+0x8FE6F5	0x96D8
+0x8FE6F6	0x96DA
+0x8FE6F7	0x96DD
+0x8FE6F8	0x96DE
+0x8FE6F9	0x96DF
+0x8FE6FA	0x96E9
+0x8FE6FB	0x96EF
+0x8FE6FC	0x96F1
+0x8FE6FD	0x96FA
+0x8FE6FE	0x9702
+0x8FE7A1	0x9703
+0x8FE7A2	0x9705
+0x8FE7A3	0x9709
+0x8FE7A4	0x971A
+0x8FE7A5	0x971B
+0x8FE7A6	0x971D
+0x8FE7A7	0x9721
+0x8FE7A8	0x9722
+0x8FE7A9	0x9723
+0x8FE7AA	0x9728
+0x8FE7AB	0x9731
+0x8FE7AC	0x9733
+0x8FE7AD	0x9741
+0x8FE7AE	0x9743
+0x8FE7AF	0x974A
+0x8FE7B0	0x974E
+0x8FE7B1	0x974F
+0x8FE7B2	0x9755
+0x8FE7B3	0x9757
+0x8FE7B4	0x9758
+0x8FE7B5	0x975A
+0x8FE7B6	0x975B
+0x8FE7B7	0x9763
+0x8FE7B8	0x9767
+0x8FE7B9	0x976A
+0x8FE7BA	0x976E
+0x8FE7BB	0x9773
+0x8FE7BC	0x9776
+0x8FE7BD	0x9777
+0x8FE7BE	0x9778
+0x8FE7BF	0x977B
+0x8FE7C0	0x977D
+0x8FE7C1	0x977F
+0x8FE7C2	0x9780
+0x8FE7C3	0x9789
+0x8FE7C4	0x9795
+0x8FE7C5	0x9796
+0x8FE7C6	0x9797
+0x8FE7C7	0x9799
+0x8FE7C8	0x979A
+0x8FE7C9	0x979E
+0x8FE7CA	0x979F
+0x8FE7CB	0x97A2
+0x8FE7CC	0x97AC
+0x8FE7CD	0x97AE
+0x8FE7CE	0x97B1
+0x8FE7CF	0x97B2
+0x8FE7D0	0x97B5
+0x8FE7D1	0x97B6
+0x8FE7D2	0x97B8
+0x8FE7D3	0x97B9
+0x8FE7D4	0x97BA
+0x8FE7D5	0x97BC
+0x8FE7D6	0x97BE
+0x8FE7D7	0x97BF
+0x8FE7D8	0x97C1
+0x8FE7D9	0x97C4
+0x8FE7DA	0x97C5
+0x8FE7DB	0x97C7
+0x8FE7DC	0x97C9
+0x8FE7DD	0x97CA
+0x8FE7DE	0x97CC
+0x8FE7DF	0x97CD
+0x8FE7E0	0x97CE
+0x8FE7E1	0x97D0
+0x8FE7E2	0x97D1
+0x8FE7E3	0x97D4
+0x8FE7E4	0x97D7
+0x8FE7E5	0x97D8
+0x8FE7E6	0x97D9
+0x8FE7E7	0x97DD
+0x8FE7E8	0x97DE
+0x8FE7E9	0x97E0
+0x8FE7EA	0x97DB
+0x8FE7EB	0x97E1
+0x8FE7EC	0x97E4
+0x8FE7ED	0x97EF
+0x8FE7EE	0x97F1
+0x8FE7EF	0x97F4
+0x8FE7F0	0x97F7
+0x8FE7F1	0x97F8
+0x8FE7F2	0x97FA
+0x8FE7F3	0x9807
+0x8FE7F4	0x980A
+0x8FE7F5	0x9819
+0x8FE7F6	0x980D
+0x8FE7F7	0x980E
+0x8FE7F8	0x9814
+0x8FE7F9	0x9816
+0x8FE7FA	0x981C
+0x8FE7FB	0x981E
+0x8FE7FC	0x9820
+0x8FE7FD	0x9823
+0x8FE7FE	0x9826
+0x8FE8A1	0x982B
+0x8FE8A2	0x982E
+0x8FE8A3	0x982F
+0x8FE8A4	0x9830
+0x8FE8A5	0x9832
+0x8FE8A6	0x9833
+0x8FE8A7	0x9835
+0x8FE8A8	0x9825
+0x8FE8A9	0x983E
+0x8FE8AA	0x9844
+0x8FE8AB	0x9847
+0x8FE8AC	0x984A
+0x8FE8AD	0x9851
+0x8FE8AE	0x9852
+0x8FE8AF	0x9853
+0x8FE8B0	0x9856
+0x8FE8B1	0x9857
+0x8FE8B2	0x9859
+0x8FE8B3	0x985A
+0x8FE8B4	0x9862
+0x8FE8B5	0x9863
+0x8FE8B6	0x9865
+0x8FE8B7	0x9866
+0x8FE8B8	0x986A
+0x8FE8B9	0x986C
+0x8FE8BA	0x98AB
+0x8FE8BB	0x98AD
+0x8FE8BC	0x98AE
+0x8FE8BD	0x98B0
+0x8FE8BE	0x98B4
+0x8FE8BF	0x98B7
+0x8FE8C0	0x98B8
+0x8FE8C1	0x98BA
+0x8FE8C2	0x98BB
+0x8FE8C3	0x98BF
+0x8FE8C4	0x98C2
+0x8FE8C5	0x98C5
+0x8FE8C6	0x98C8
+0x8FE8C7	0x98CC
+0x8FE8C8	0x98E1
+0x8FE8C9	0x98E3
+0x8FE8CA	0x98E5
+0x8FE8CB	0x98E6
+0x8FE8CC	0x98E7
+0x8FE8CD	0x98EA
+0x8FE8CE	0x98F3
+0x8FE8CF	0x98F6
+0x8FE8D0	0x9902
+0x8FE8D1	0x9907
+0x8FE8D2	0x9908
+0x8FE8D3	0x9911
+0x8FE8D4	0x9915
+0x8FE8D5	0x9916
+0x8FE8D6	0x9917
+0x8FE8D7	0x991A
+0x8FE8D8	0x991B
+0x8FE8D9	0x991C
+0x8FE8DA	0x991F
+0x8FE8DB	0x9922
+0x8FE8DC	0x9926
+0x8FE8DD	0x9927
+0x8FE8DE	0x992B
+0x8FE8DF	0x9931
+0x8FE8E0	0x9932
+0x8FE8E1	0x9933
+0x8FE8E2	0x9934
+0x8FE8E3	0x9935
+0x8FE8E4	0x9939
+0x8FE8E5	0x993A
+0x8FE8E6	0x993B
+0x8FE8E7	0x993C
+0x8FE8E8	0x9940
+0x8FE8E9	0x9941
+0x8FE8EA	0x9946
+0x8FE8EB	0x9947
+0x8FE8EC	0x9948
+0x8FE8ED	0x994D
+0x8FE8EE	0x994E
+0x8FE8EF	0x9954
+0x8FE8F0	0x9958
+0x8FE8F1	0x9959
+0x8FE8F2	0x995B
+0x8FE8F3	0x995C
+0x8FE8F4	0x995E
+0x8FE8F5	0x995F
+0x8FE8F6	0x9960
+0x8FE8F7	0x999B
+0x8FE8F8	0x999D
+0x8FE8F9	0x999F
+0x8FE8FA	0x99A6
+0x8FE8FB	0x99B0
+0x8FE8FC	0x99B1
+0x8FE8FD	0x99B2
+0x8FE8FE	0x99B5
+0x8FE9A1	0x99B9
+0x8FE9A2	0x99BA
+0x8FE9A3	0x99BD
+0x8FE9A4	0x99BF
+0x8FE9A5	0x99C3
+0x8FE9A6	0x99C9
+0x8FE9A7	0x99D3
+0x8FE9A8	0x99D4
+0x8FE9A9	0x99D9
+0x8FE9AA	0x99DA
+0x8FE9AB	0x99DC
+0x8FE9AC	0x99DE
+0x8FE9AD	0x99E7
+0x8FE9AE	0x99EA
+0x8FE9AF	0x99EB
+0x8FE9B0	0x99EC
+0x8FE9B1	0x99F0
+0x8FE9B2	0x99F4
+0x8FE9B3	0x99F5
+0x8FE9B4	0x99F9
+0x8FE9B5	0x99FD
+0x8FE9B6	0x99FE
+0x8FE9B7	0x9A02
+0x8FE9B8	0x9A03
+0x8FE9B9	0x9A04
+0x8FE9BA	0x9A0B
+0x8FE9BB	0x9A0C
+0x8FE9BC	0x9A10
+0x8FE9BD	0x9A11
+0x8FE9BE	0x9A16
+0x8FE9BF	0x9A1E
+0x8FE9C0	0x9A20
+0x8FE9C1	0x9A22
+0x8FE9C2	0x9A23
+0x8FE9C3	0x9A24
+0x8FE9C4	0x9A27
+0x8FE9C5	0x9A2D
+0x8FE9C6	0x9A2E
+0x8FE9C7	0x9A33
+0x8FE9C8	0x9A35
+0x8FE9C9	0x9A36
+0x8FE9CA	0x9A38
+0x8FE9CB	0x9A47
+0x8FE9CC	0x9A41
+0x8FE9CD	0x9A44
+0x8FE9CE	0x9A4A
+0x8FE9CF	0x9A4B
+0x8FE9D0	0x9A4C
+0x8FE9D1	0x9A4E
+0x8FE9D2	0x9A51
+0x8FE9D3	0x9A54
+0x8FE9D4	0x9A56
+0x8FE9D5	0x9A5D
+0x8FE9D6	0x9AAA
+0x8FE9D7	0x9AAC
+0x8FE9D8	0x9AAE
+0x8FE9D9	0x9AAF
+0x8FE9DA	0x9AB2
+0x8FE9DB	0x9AB4
+0x8FE9DC	0x9AB5
+0x8FE9DD	0x9AB6
+0x8FE9DE	0x9AB9
+0x8FE9DF	0x9ABB
+0x8FE9E0	0x9ABE
+0x8FE9E1	0x9ABF
+0x8FE9E2	0x9AC1
+0x8FE9E3	0x9AC3
+0x8FE9E4	0x9AC6
+0x8FE9E5	0x9AC8
+0x8FE9E6	0x9ACE
+0x8FE9E7	0x9AD0
+0x8FE9E8	0x9AD2
+0x8FE9E9	0x9AD5
+0x8FE9EA	0x9AD6
+0x8FE9EB	0x9AD7
+0x8FE9EC	0x9ADB
+0x8FE9ED	0x9ADC
+0x8FE9EE	0x9AE0
+0x8FE9EF	0x9AE4
+0x8FE9F0	0x9AE5
+0x8FE9F1	0x9AE7
+0x8FE9F2	0x9AE9
+0x8FE9F3	0x9AEC
+0x8FE9F4	0x9AF2
+0x8FE9F5	0x9AF3
+0x8FE9F6	0x9AF5
+0x8FE9F7	0x9AF9
+0x8FE9F8	0x9AFA
+0x8FE9F9	0x9AFD
+0x8FE9FA	0x9AFF
+0x8FE9FB	0x9B00
+0x8FE9FC	0x9B01
+0x8FE9FD	0x9B02
+0x8FE9FE	0x9B03
+0x8FEAA1	0x9B04
+0x8FEAA2	0x9B05
+0x8FEAA3	0x9B08
+0x8FEAA4	0x9B09
+0x8FEAA5	0x9B0B
+0x8FEAA6	0x9B0C
+0x8FEAA7	0x9B0D
+0x8FEAA8	0x9B0E
+0x8FEAA9	0x9B10
+0x8FEAAA	0x9B12
+0x8FEAAB	0x9B16
+0x8FEAAC	0x9B19
+0x8FEAAD	0x9B1B
+0x8FEAAE	0x9B1C
+0x8FEAAF	0x9B20
+0x8FEAB0	0x9B26
+0x8FEAB1	0x9B2B
+0x8FEAB2	0x9B2D
+0x8FEAB3	0x9B33
+0x8FEAB4	0x9B34
+0x8FEAB5	0x9B35
+0x8FEAB6	0x9B37
+0x8FEAB7	0x9B39
+0x8FEAB8	0x9B3A
+0x8FEAB9	0x9B3D
+0x8FEABA	0x9B48
+0x8FEABB	0x9B4B
+0x8FEABC	0x9B4C
+0x8FEABD	0x9B55
+0x8FEABE	0x9B56
+0x8FEABF	0x9B57
+0x8FEAC0	0x9B5B
+0x8FEAC1	0x9B5E
+0x8FEAC2	0x9B61
+0x8FEAC3	0x9B63
+0x8FEAC4	0x9B65
+0x8FEAC5	0x9B66
+0x8FEAC6	0x9B68
+0x8FEAC7	0x9B6A
+0x8FEAC8	0x9B6B
+0x8FEAC9	0x9B6C
+0x8FEACA	0x9B6D
+0x8FEACB	0x9B6E
+0x8FEACC	0x9B73
+0x8FEACD	0x9B75
+0x8FEACE	0x9B77
+0x8FEACF	0x9B78
+0x8FEAD0	0x9B79
+0x8FEAD1	0x9B7F
+0x8FEAD2	0x9B80
+0x8FEAD3	0x9B84
+0x8FEAD4	0x9B85
+0x8FEAD5	0x9B86
+0x8FEAD6	0x9B87
+0x8FEAD7	0x9B89
+0x8FEAD8	0x9B8A
+0x8FEAD9	0x9B8B
+0x8FEADA	0x9B8D
+0x8FEADB	0x9B8F
+0x8FEADC	0x9B90
+0x8FEADD	0x9B94
+0x8FEADE	0x9B9A
+0x8FEADF	0x9B9D
+0x8FEAE0	0x9B9E
+0x8FEAE1	0x9BA6
+0x8FEAE2	0x9BA7
+0x8FEAE3	0x9BA9
+0x8FEAE4	0x9BAC
+0x8FEAE5	0x9BB0
+0x8FEAE6	0x9BB1
+0x8FEAE7	0x9BB2
+0x8FEAE8	0x9BB7
+0x8FEAE9	0x9BB8
+0x8FEAEA	0x9BBB
+0x8FEAEB	0x9BBC
+0x8FEAEC	0x9BBE
+0x8FEAED	0x9BBF
+0x8FEAEE	0x9BC1
+0x8FEAEF	0x9BC7
+0x8FEAF0	0x9BC8
+0x8FEAF1	0x9BCE
+0x8FEAF2	0x9BD0
+0x8FEAF3	0x9BD7
+0x8FEAF4	0x9BD8
+0x8FEAF5	0x9BDD
+0x8FEAF6	0x9BDF
+0x8FEAF7	0x9BE5
+0x8FEAF8	0x9BE7
+0x8FEAF9	0x9BEA
+0x8FEAFA	0x9BEB
+0x8FEAFB	0x9BEF
+0x8FEAFC	0x9BF3
+0x8FEAFD	0x9BF7
+0x8FEAFE	0x9BF8
+0x8FEBA1	0x9BF9
+0x8FEBA2	0x9BFA
+0x8FEBA3	0x9BFD
+0x8FEBA4	0x9BFF
+0x8FEBA5	0x9C00
+0x8FEBA6	0x9C02
+0x8FEBA7	0x9C0B
+0x8FEBA8	0x9C0F
+0x8FEBA9	0x9C11
+0x8FEBAA	0x9C16
+0x8FEBAB	0x9C18
+0x8FEBAC	0x9C19
+0x8FEBAD	0x9C1A
+0x8FEBAE	0x9C1C
+0x8FEBAF	0x9C1E
+0x8FEBB0	0x9C22
+0x8FEBB1	0x9C23
+0x8FEBB2	0x9C26
+0x8FEBB3	0x9C27
+0x8FEBB4	0x9C28
+0x8FEBB5	0x9C29
+0x8FEBB6	0x9C2A
+0x8FEBB7	0x9C31
+0x8FEBB8	0x9C35
+0x8FEBB9	0x9C36
+0x8FEBBA	0x9C37
+0x8FEBBB	0x9C3D
+0x8FEBBC	0x9C41
+0x8FEBBD	0x9C43
+0x8FEBBE	0x9C44
+0x8FEBBF	0x9C45
+0x8FEBC0	0x9C49
+0x8FEBC1	0x9C4A
+0x8FEBC2	0x9C4E
+0x8FEBC3	0x9C4F
+0x8FEBC4	0x9C50
+0x8FEBC5	0x9C53
+0x8FEBC6	0x9C54
+0x8FEBC7	0x9C56
+0x8FEBC8	0x9C58
+0x8FEBC9	0x9C5B
+0x8FEBCA	0x9C5D
+0x8FEBCB	0x9C5E
+0x8FEBCC	0x9C5F
+0x8FEBCD	0x9C63
+0x8FEBCE	0x9C69
+0x8FEBCF	0x9C6A
+0x8FEBD0	0x9C5C
+0x8FEBD1	0x9C6B
+0x8FEBD2	0x9C68
+0x8FEBD3	0x9C6E
+0x8FEBD4	0x9C70
+0x8FEBD5	0x9C72
+0x8FEBD6	0x9C75
+0x8FEBD7	0x9C77
+0x8FEBD8	0x9C7B
+0x8FEBD9	0x9CE6
+0x8FEBDA	0x9CF2
+0x8FEBDB	0x9CF7
+0x8FEBDC	0x9CF9
+0x8FEBDD	0x9D0B
+0x8FEBDE	0x9D02
+0x8FEBDF	0x9D11
+0x8FEBE0	0x9D17
+0x8FEBE1	0x9D18
+0x8FEBE2	0x9D1C
+0x8FEBE3	0x9D1D
+0x8FEBE4	0x9D1E
+0x8FEBE5	0x9D2F
+0x8FEBE6	0x9D30
+0x8FEBE7	0x9D32
+0x8FEBE8	0x9D33
+0x8FEBE9	0x9D34
+0x8FEBEA	0x9D3A
+0x8FEBEB	0x9D3C
+0x8FEBEC	0x9D45
+0x8FEBED	0x9D3D
+0x8FEBEE	0x9D42
+0x8FEBEF	0x9D43
+0x8FEBF0	0x9D47
+0x8FEBF1	0x9D4A
+0x8FEBF2	0x9D53
+0x8FEBF3	0x9D54
+0x8FEBF4	0x9D5F
+0x8FEBF5	0x9D63
+0x8FEBF6	0x9D62
+0x8FEBF7	0x9D65
+0x8FEBF8	0x9D69
+0x8FEBF9	0x9D6A
+0x8FEBFA	0x9D6B
+0x8FEBFB	0x9D70
+0x8FEBFC	0x9D76
+0x8FEBFD	0x9D77
+0x8FEBFE	0x9D7B
+0x8FECA1	0x9D7C
+0x8FECA2	0x9D7E
+0x8FECA3	0x9D83
+0x8FECA4	0x9D84
+0x8FECA5	0x9D86
+0x8FECA6	0x9D8A
+0x8FECA7	0x9D8D
+0x8FECA8	0x9D8E
+0x8FECA9	0x9D92
+0x8FECAA	0x9D93
+0x8FECAB	0x9D95
+0x8FECAC	0x9D96
+0x8FECAD	0x9D97
+0x8FECAE	0x9D98
+0x8FECAF	0x9DA1
+0x8FECB0	0x9DAA
+0x8FECB1	0x9DAC
+0x8FECB2	0x9DAE
+0x8FECB3	0x9DB1
+0x8FECB4	0x9DB5
+0x8FECB5	0x9DB9
+0x8FECB6	0x9DBC
+0x8FECB7	0x9DBF
+0x8FECB8	0x9DC3
+0x8FECB9	0x9DC7
+0x8FECBA	0x9DC9
+0x8FECBB	0x9DCA
+0x8FECBC	0x9DD4
+0x8FECBD	0x9DD5
+0x8FECBE	0x9DD6
+0x8FECBF	0x9DD7
+0x8FECC0	0x9DDA
+0x8FECC1	0x9DDE
+0x8FECC2	0x9DDF
+0x8FECC3	0x9DE0
+0x8FECC4	0x9DE5
+0x8FECC5	0x9DE7
+0x8FECC6	0x9DE9
+0x8FECC7	0x9DEB
+0x8FECC8	0x9DEE
+0x8FECC9	0x9DF0
+0x8FECCA	0x9DF3
+0x8FECCB	0x9DF4
+0x8FECCC	0x9DFE
+0x8FECCD	0x9E0A
+0x8FECCE	0x9E02
+0x8FECCF	0x9E07
+0x8FECD0	0x9E0E
+0x8FECD1	0x9E10
+0x8FECD2	0x9E11
+0x8FECD3	0x9E12
+0x8FECD4	0x9E15
+0x8FECD5	0x9E16
+0x8FECD6	0x9E19
+0x8FECD7	0x9E1C
+0x8FECD8	0x9E1D
+0x8FECD9	0x9E7A
+0x8FECDA	0x9E7B
+0x8FECDB	0x9E7C
+0x8FECDC	0x9E80
+0x8FECDD	0x9E82
+0x8FECDE	0x9E83
+0x8FECDF	0x9E84
+0x8FECE0	0x9E85
+0x8FECE1	0x9E87
+0x8FECE2	0x9E8E
+0x8FECE3	0x9E8F
+0x8FECE4	0x9E96
+0x8FECE5	0x9E98
+0x8FECE6	0x9E9B
+0x8FECE7	0x9E9E
+0x8FECE8	0x9EA4
+0x8FECE9	0x9EA8
+0x8FECEA	0x9EAC
+0x8FECEB	0x9EAE
+0x8FECEC	0x9EAF
+0x8FECED	0x9EB0
+0x8FECEE	0x9EB3
+0x8FECEF	0x9EB4
+0x8FECF0	0x9EB5
+0x8FECF1	0x9EC6
+0x8FECF2	0x9EC8
+0x8FECF3	0x9ECB
+0x8FECF4	0x9ED5
+0x8FECF5	0x9EDF
+0x8FECF6	0x9EE4
+0x8FECF7	0x9EE7
+0x8FECF8	0x9EEC
+0x8FECF9	0x9EED
+0x8FECFA	0x9EEE
+0x8FECFB	0x9EF0
+0x8FECFC	0x9EF1
+0x8FECFD	0x9EF2
+0x8FECFE	0x9EF5
+0x8FEDA1	0x9EF8
+0x8FEDA2	0x9EFF
+0x8FEDA3	0x9F02
+0x8FEDA4	0x9F03
+0x8FEDA5	0x9F09
+0x8FEDA6	0x9F0F
+0x8FEDA7	0x9F10
+0x8FEDA8	0x9F11
+0x8FEDA9	0x9F12
+0x8FEDAA	0x9F14
+0x8FEDAB	0x9F16
+0x8FEDAC	0x9F17
+0x8FEDAD	0x9F19
+0x8FEDAE	0x9F1A
+0x8FEDAF	0x9F1B
+0x8FEDB0	0x9F1F
+0x8FEDB1	0x9F22
+0x8FEDB2	0x9F26
+0x8FEDB3	0x9F2A
+0x8FEDB4	0x9F2B
+0x8FEDB5	0x9F2F
+0x8FEDB6	0x9F31
+0x8FEDB7	0x9F32
+0x8FEDB8	0x9F34
+0x8FEDB9	0x9F37
+0x8FEDBA	0x9F39
+0x8FEDBB	0x9F3A
+0x8FEDBC	0x9F3C
+0x8FEDBD	0x9F3D
+0x8FEDBE	0x9F3F
+0x8FEDBF	0x9F41
+0x8FEDC0	0x9F43
+0x8FEDC1	0x9F44
+0x8FEDC2	0x9F45
+0x8FEDC3	0x9F46
+0x8FEDC4	0x9F47
+0x8FEDC5	0x9F53
+0x8FEDC6	0x9F55
+0x8FEDC7	0x9F56
+0x8FEDC8	0x9F57
+0x8FEDC9	0x9F58
+0x8FEDCA	0x9F5A
+0x8FEDCB	0x9F5D
+0x8FEDCC	0x9F5E
+0x8FEDCD	0x9F68
+0x8FEDCE	0x9F69
+0x8FEDCF	0x9F6D
+0x8FEDD0	0x9F6E
+0x8FEDD1	0x9F6F
+0x8FEDD2	0x9F70
+0x8FEDD3	0x9F71
+0x8FEDD4	0x9F73
+0x8FEDD5	0x9F75
+0x8FEDD6	0x9F7A
+0x8FEDD7	0x9F7D
+0x8FEDD8	0x9F8F
+0x8FEDD9	0x9F90
+0x8FEDDA	0x9F91
+0x8FEDDB	0x9F92
+0x8FEDDC	0x9F94
+0x8FEDDD	0x9F96
+0x8FEDDE	0x9F97
+0x8FEDDF	0x9F9E
+0x8FEDE0	0x9FA1
+0x8FEDE1	0x9FA2
+0x8FEDE2	0x9FA3
+0x8FEDE3	0x9FA5
+0x8FF3F3	0x2170
+0x8FF3F4	0x2171
+0x8FF3F5	0x2172
+0x8FF3F6	0x2173
+0x8FF3F7	0x2174
+0x8FF3F8	0x2175
+0x8FF3F9	0x2176
+0x8FF3FA	0x2177
+0x8FF3FB	0x2178
+0x8FF3FC	0x2179
+0x8FF3FD	0x2160
+0x8FF3FE	0x2161
+0x8FF4A1	0x2162
+0x8FF4A2	0x2163
+0x8FF4A3	0x2164
+0x8FF4A4	0x2165
+0x8FF4A5	0x2166
+0x8FF4A6	0x2167
+0x8FF4A7	0x2168
+0x8FF4A8	0x2169
+0x8FF4A9	0xFF07
+0x8FF4AA	0xFF02
+0x8FF4AB	0x3231
+0x8FF4AC	0x2116
+0x8FF4AD	0x2121
+0x8FF4AE	0x70BB
+0x8FF4AF	0x4EFC
+0x8FF4B0	0x50F4
+0x8FF4B1	0x51EC
+0x8FF4B2	0x5307
+0x8FF4B3	0x5324
+0x8FF4B4	0xFA0E
+0x8FF4B5	0x548A
+0x8FF4B6	0x5759
+0x8FF4B7	0xFA0F
+0x8FF4B8	0xFA10
+0x8FF4B9	0x589E
+0x8FF4BA	0x5BEC
+0x8FF4BB	0x5CF5
+0x8FF4BC	0x5D53
+0x8FF4BD	0xFA11
+0x8FF4BE	0x5FB7
+0x8FF4BF	0x6085
+0x8FF4C0	0x6120
+0x8FF4C1	0x654E
+0x8FF4C2	0x663B
+0x8FF4C3	0x6665
+0x8FF4C4	0xFA12
+0x8FF4C5	0xF929
+0x8FF4C6	0x6801
+0x8FF4C7	0xFA13
+0x8FF4C8	0xFA14
+0x8FF4C9	0x6A6B
+0x8FF4CA	0x6AE2
+0x8FF4CB	0x6DF8
+0x8FF4CC	0x6DF2
+0x8FF4CD	0x7028
+0x8FF4CE	0xFA15
+0x8FF4CF	0xFA16
+0x8FF4D0	0x7501
+0x8FF4D1	0x7682
+0x8FF4D2	0x769E
+0x8FF4D3	0xFA17
+0x8FF4D4	0x7930
+0x8FF4D5	0xFA18
+0x8FF4D6	0xFA19
+0x8FF4D7	0xFA1A
+0x8FF4D8	0xFA1B
+0x8FF4D9	0x7AE7
+0x8FF4DA	0xFA1C
+0x8FF4DB	0xFA1D
+0x8FF4DC	0x7DA0
+0x8FF4DD	0x7DD6
+0x8FF4DE	0xFA1E
+0x8FF4DF	0x8362
+0x8FF4E0	0xFA1F
+0x8FF4E1	0x85B0
+0x8FF4E2	0xFA20
+0x8FF4E3	0xFA21
+0x8FF4E4	0x8807
+0x8FF4E5	0xFA22
+0x8FF4E6	0x8B7F
+0x8FF4E7	0x8CF4
+0x8FF4E8	0x8D76
+0x8FF4E9	0xFA23
+0x8FF4EA	0xFA24
+0x8FF4EB	0xFA25
+0x8FF4EC	0x90DE
+0x8FF4ED	0xFA26
+0x8FF4EE	0x9115
+0x8FF4EF	0xFA27
+0x8FF4F0	0xFA28
+0x8FF4F1	0x9592
+0x8FF4F2	0xF9DC
+0x8FF4F3	0xFA29
+0x8FF4F4	0x973B
+0x8FF4F5	0x974D
+0x8FF4F6	0x9751
+0x8FF4F7	0xFA2A
+0x8FF4F8	0xFA2B
+0x8FF4F9	0xFA2C
+0x8FF4FA	0x999E
+0x8FF4FB	0x9AD9
+0x8FF4FC	0x9B72
+0x8FF4FD	0xFA2D
+0x8FF4FE	0x9ED1
+0x8FF5A1	0xE3AC
+0x8FF5A2	0xE3AD
+0x8FF5A3	0xE3AE
+0x8FF5A4	0xE3AF
+0x8FF5A5	0xE3B0
+0x8FF5A6	0xE3B1
+0x8FF5A7	0xE3B2
+0x8FF5A8	0xE3B3
+0x8FF5A9	0xE3B4
+0x8FF5AA	0xE3B5
+0x8FF5AB	0xE3B6
+0x8FF5AC	0xE3B7
+0x8FF5AD	0xE3B8
+0x8FF5AE	0xE3B9
+0x8FF5AF	0xE3BA
+0x8FF5B0	0xE3BB
+0x8FF5B1	0xE3BC
+0x8FF5B2	0xE3BD
+0x8FF5B3	0xE3BE
+0x8FF5B4	0xE3BF
+0x8FF5B5	0xE3C0
+0x8FF5B6	0xE3C1
+0x8FF5B7	0xE3C2
+0x8FF5B8	0xE3C3
+0x8FF5B9	0xE3C4
+0x8FF5BA	0xE3C5
+0x8FF5BB	0xE3C6
+0x8FF5BC	0xE3C7
+0x8FF5BD	0xE3C8
+0x8FF5BE	0xE3C9
+0x8FF5BF	0xE3CA
+0x8FF5C0	0xE3CB
+0x8FF5C1	0xE3CC
+0x8FF5C2	0xE3CD
+0x8FF5C3	0xE3CE
+0x8FF5C4	0xE3CF
+0x8FF5C5	0xE3D0
+0x8FF5C6	0xE3D1
+0x8FF5C7	0xE3D2
+0x8FF5C8	0xE3D3
+0x8FF5C9	0xE3D4
+0x8FF5CA	0xE3D5
+0x8FF5CB	0xE3D6
+0x8FF5CC	0xE3D7
+0x8FF5CD	0xE3D8
+0x8FF5CE	0xE3D9
+0x8FF5CF	0xE3DA
+0x8FF5D0	0xE3DB
+0x8FF5D1	0xE3DC
+0x8FF5D2	0xE3DD
+0x8FF5D3	0xE3DE
+0x8FF5D4	0xE3DF
+0x8FF5D5	0xE3E0
+0x8FF5D6	0xE3E1
+0x8FF5D7	0xE3E2
+0x8FF5D8	0xE3E3
+0x8FF5D9	0xE3E4
+0x8FF5DA	0xE3E5
+0x8FF5DB	0xE3E6
+0x8FF5DC	0xE3E7
+0x8FF5DD	0xE3E8
+0x8FF5DE	0xE3E9
+0x8FF5DF	0xE3EA
+0x8FF5E0	0xE3EB
+0x8FF5E1	0xE3EC
+0x8FF5E2	0xE3ED
+0x8FF5E3	0xE3EE
+0x8FF5E4	0xE3EF
+0x8FF5E5	0xE3F0
+0x8FF5E6	0xE3F1
+0x8FF5E7	0xE3F2
+0x8FF5E8	0xE3F3
+0x8FF5E9	0xE3F4
+0x8FF5EA	0xE3F5
+0x8FF5EB	0xE3F6
+0x8FF5EC	0xE3F7
+0x8FF5ED	0xE3F8
+0x8FF5EE	0xE3F9
+0x8FF5EF	0xE3FA
+0x8FF5F0	0xE3FB
+0x8FF5F1	0xE3FC
+0x8FF5F2	0xE3FD
+0x8FF5F3	0xE3FE
+0x8FF5F4	0xE3FF
+0x8FF5F5	0xE400
+0x8FF5F6	0xE401
+0x8FF5F7	0xE402
+0x8FF5F8	0xE403
+0x8FF5F9	0xE404
+0x8FF5FA	0xE405
+0x8FF5FB	0xE406
+0x8FF5FC	0xE407
+0x8FF5FD	0xE408
+0x8FF5FE	0xE409
+0x8FF6A1	0xE40A
+0x8FF6A2	0xE40B
+0x8FF6A3	0xE40C
+0x8FF6A4	0xE40D
+0x8FF6A5	0xE40E
+0x8FF6A6	0xE40F
+0x8FF6A7	0xE410
+0x8FF6A8	0xE411
+0x8FF6A9	0xE412
+0x8FF6AA	0xE413
+0x8FF6AB	0xE414
+0x8FF6AC	0xE415
+0x8FF6AD	0xE416
+0x8FF6AE	0xE417
+0x8FF6AF	0xE418
+0x8FF6B0	0xE419
+0x8FF6B1	0xE41A
+0x8FF6B2	0xE41B
+0x8FF6B3	0xE41C
+0x8FF6B4	0xE41D
+0x8FF6B5	0xE41E
+0x8FF6B6	0xE41F
+0x8FF6B7	0xE420
+0x8FF6B8	0xE421
+0x8FF6B9	0xE422
+0x8FF6BA	0xE423
+0x8FF6BB	0xE424
+0x8FF6BC	0xE425
+0x8FF6BD	0xE426
+0x8FF6BE	0xE427
+0x8FF6BF	0xE428
+0x8FF6C0	0xE429
+0x8FF6C1	0xE42A
+0x8FF6C2	0xE42B
+0x8FF6C3	0xE42C
+0x8FF6C4	0xE42D
+0x8FF6C5	0xE42E
+0x8FF6C6	0xE42F
+0x8FF6C7	0xE430
+0x8FF6C8	0xE431
+0x8FF6C9	0xE432
+0x8FF6CA	0xE433
+0x8FF6CB	0xE434
+0x8FF6CC	0xE435
+0x8FF6CD	0xE436
+0x8FF6CE	0xE437
+0x8FF6CF	0xE438
+0x8FF6D0	0xE439
+0x8FF6D1	0xE43A
+0x8FF6D2	0xE43B
+0x8FF6D3	0xE43C
+0x8FF6D4	0xE43D
+0x8FF6D5	0xE43E
+0x8FF6D6	0xE43F
+0x8FF6D7	0xE440
+0x8FF6D8	0xE441
+0x8FF6D9	0xE442
+0x8FF6DA	0xE443
+0x8FF6DB	0xE444
+0x8FF6DC	0xE445
+0x8FF6DD	0xE446
+0x8FF6DE	0xE447
+0x8FF6DF	0xE448
+0x8FF6E0	0xE449
+0x8FF6E1	0xE44A
+0x8FF6E2	0xE44B
+0x8FF6E3	0xE44C
+0x8FF6E4	0xE44D
+0x8FF6E5	0xE44E
+0x8FF6E6	0xE44F
+0x8FF6E7	0xE450
+0x8FF6E8	0xE451
+0x8FF6E9	0xE452
+0x8FF6EA	0xE453
+0x8FF6EB	0xE454
+0x8FF6EC	0xE455
+0x8FF6ED	0xE456
+0x8FF6EE	0xE457
+0x8FF6EF	0xE458
+0x8FF6F0	0xE459
+0x8FF6F1	0xE45A
+0x8FF6F2	0xE45B
+0x8FF6F3	0xE45C
+0x8FF6F4	0xE45D
+0x8FF6F5	0xE45E
+0x8FF6F6	0xE45F
+0x8FF6F7	0xE460
+0x8FF6F8	0xE461
+0x8FF6F9	0xE462
+0x8FF6FA	0xE463
+0x8FF6FB	0xE464
+0x8FF6FC	0xE465
+0x8FF6FD	0xE466
+0x8FF6FE	0xE467
+0x8FF7A1	0xE468
+0x8FF7A2	0xE469
+0x8FF7A3	0xE46A
+0x8FF7A4	0xE46B
+0x8FF7A5	0xE46C
+0x8FF7A6	0xE46D
+0x8FF7A7	0xE46E
+0x8FF7A8	0xE46F
+0x8FF7A9	0xE470
+0x8FF7AA	0xE471
+0x8FF7AB	0xE472
+0x8FF7AC	0xE473
+0x8FF7AD	0xE474
+0x8FF7AE	0xE475
+0x8FF7AF	0xE476
+0x8FF7B0	0xE477
+0x8FF7B1	0xE478
+0x8FF7B2	0xE479
+0x8FF7B3	0xE47A
+0x8FF7B4	0xE47B
+0x8FF7B5	0xE47C
+0x8FF7B6	0xE47D
+0x8FF7B7	0xE47E
+0x8FF7B8	0xE47F
+0x8FF7B9	0xE480
+0x8FF7BA	0xE481
+0x8FF7BB	0xE482
+0x8FF7BC	0xE483
+0x8FF7BD	0xE484
+0x8FF7BE	0xE485
+0x8FF7BF	0xE486
+0x8FF7C0	0xE487
+0x8FF7C1	0xE488
+0x8FF7C2	0xE489
+0x8FF7C3	0xE48A
+0x8FF7C4	0xE48B
+0x8FF7C5	0xE48C
+0x8FF7C6	0xE48D
+0x8FF7C7	0xE48E
+0x8FF7C8	0xE48F
+0x8FF7C9	0xE490
+0x8FF7CA	0xE491
+0x8FF7CB	0xE492
+0x8FF7CC	0xE493
+0x8FF7CD	0xE494
+0x8FF7CE	0xE495
+0x8FF7CF	0xE496
+0x8FF7D0	0xE497
+0x8FF7D1	0xE498
+0x8FF7D2	0xE499
+0x8FF7D3	0xE49A
+0x8FF7D4	0xE49B
+0x8FF7D5	0xE49C
+0x8FF7D6	0xE49D
+0x8FF7D7	0xE49E
+0x8FF7D8	0xE49F
+0x8FF7D9	0xE4A0
+0x8FF7DA	0xE4A1
+0x8FF7DB	0xE4A2
+0x8FF7DC	0xE4A3
+0x8FF7DD	0xE4A4
+0x8FF7DE	0xE4A5
+0x8FF7DF	0xE4A6
+0x8FF7E0	0xE4A7
+0x8FF7E1	0xE4A8
+0x8FF7E2	0xE4A9
+0x8FF7E3	0xE4AA
+0x8FF7E4	0xE4AB
+0x8FF7E5	0xE4AC
+0x8FF7E6	0xE4AD
+0x8FF7E7	0xE4AE
+0x8FF7E8	0xE4AF
+0x8FF7E9	0xE4B0
+0x8FF7EA	0xE4B1
+0x8FF7EB	0xE4B2
+0x8FF7EC	0xE4B3
+0x8FF7ED	0xE4B4
+0x8FF7EE	0xE4B5
+0x8FF7EF	0xE4B6
+0x8FF7F0	0xE4B7
+0x8FF7F1	0xE4B8
+0x8FF7F2	0xE4B9
+0x8FF7F3	0xE4BA
+0x8FF7F4	0xE4BB
+0x8FF7F5	0xE4BC
+0x8FF7F6	0xE4BD
+0x8FF7F7	0xE4BE
+0x8FF7F8	0xE4BF
+0x8FF7F9	0xE4C0
+0x8FF7FA	0xE4C1
+0x8FF7FB	0xE4C2
+0x8FF7FC	0xE4C3
+0x8FF7FD	0xE4C4
+0x8FF7FE	0xE4C5
+0x8FF8A1	0xE4C6
+0x8FF8A2	0xE4C7
+0x8FF8A3	0xE4C8
+0x8FF8A4	0xE4C9
+0x8FF8A5	0xE4CA
+0x8FF8A6	0xE4CB
+0x8FF8A7	0xE4CC
+0x8FF8A8	0xE4CD
+0x8FF8A9	0xE4CE
+0x8FF8AA	0xE4CF
+0x8FF8AB	0xE4D0
+0x8FF8AC	0xE4D1
+0x8FF8AD	0xE4D2
+0x8FF8AE	0xE4D3
+0x8FF8AF	0xE4D4
+0x8FF8B0	0xE4D5
+0x8FF8B1	0xE4D6
+0x8FF8B2	0xE4D7
+0x8FF8B3	0xE4D8
+0x8FF8B4	0xE4D9
+0x8FF8B5	0xE4DA
+0x8FF8B6	0xE4DB
+0x8FF8B7	0xE4DC
+0x8FF8B8	0xE4DD
+0x8FF8B9	0xE4DE
+0x8FF8BA	0xE4DF
+0x8FF8BB	0xE4E0
+0x8FF8BC	0xE4E1
+0x8FF8BD	0xE4E2
+0x8FF8BE	0xE4E3
+0x8FF8BF	0xE4E4
+0x8FF8C0	0xE4E5
+0x8FF8C1	0xE4E6
+0x8FF8C2	0xE4E7
+0x8FF8C3	0xE4E8
+0x8FF8C4	0xE4E9
+0x8FF8C5	0xE4EA
+0x8FF8C6	0xE4EB
+0x8FF8C7	0xE4EC
+0x8FF8C8	0xE4ED
+0x8FF8C9	0xE4EE
+0x8FF8CA	0xE4EF
+0x8FF8CB	0xE4F0
+0x8FF8CC	0xE4F1
+0x8FF8CD	0xE4F2
+0x8FF8CE	0xE4F3
+0x8FF8CF	0xE4F4
+0x8FF8D0	0xE4F5
+0x8FF8D1	0xE4F6
+0x8FF8D2	0xE4F7
+0x8FF8D3	0xE4F8
+0x8FF8D4	0xE4F9
+0x8FF8D5	0xE4FA
+0x8FF8D6	0xE4FB
+0x8FF8D7	0xE4FC
+0x8FF8D8	0xE4FD
+0x8FF8D9	0xE4FE
+0x8FF8DA	0xE4FF
+0x8FF8DB	0xE500
+0x8FF8DC	0xE501
+0x8FF8DD	0xE502
+0x8FF8DE	0xE503
+0x8FF8DF	0xE504
+0x8FF8E0	0xE505
+0x8FF8E1	0xE506
+0x8FF8E2	0xE507
+0x8FF8E3	0xE508
+0x8FF8E4	0xE509
+0x8FF8E5	0xE50A
+0x8FF8E6	0xE50B
+0x8FF8E7	0xE50C
+0x8FF8E8	0xE50D
+0x8FF8E9	0xE50E
+0x8FF8EA	0xE50F
+0x8FF8EB	0xE510
+0x8FF8EC	0xE511
+0x8FF8ED	0xE512
+0x8FF8EE	0xE513
+0x8FF8EF	0xE514
+0x8FF8F0	0xE515
+0x8FF8F1	0xE516
+0x8FF8F2	0xE517
+0x8FF8F3	0xE518
+0x8FF8F4	0xE519
+0x8FF8F5	0xE51A
+0x8FF8F6	0xE51B
+0x8FF8F7	0xE51C
+0x8FF8F8	0xE51D
+0x8FF8F9	0xE51E
+0x8FF8FA	0xE51F
+0x8FF8FB	0xE520
+0x8FF8FC	0xE521
+0x8FF8FD	0xE522
+0x8FF8FE	0xE523
+0x8FF9A1	0xE524
+0x8FF9A2	0xE525
+0x8FF9A3	0xE526
+0x8FF9A4	0xE527
+0x8FF9A5	0xE528
+0x8FF9A6	0xE529
+0x8FF9A7	0xE52A
+0x8FF9A8	0xE52B
+0x8FF9A9	0xE52C
+0x8FF9AA	0xE52D
+0x8FF9AB	0xE52E
+0x8FF9AC	0xE52F
+0x8FF9AD	0xE530
+0x8FF9AE	0xE531
+0x8FF9AF	0xE532
+0x8FF9B0	0xE533
+0x8FF9B1	0xE534
+0x8FF9B2	0xE535
+0x8FF9B3	0xE536
+0x8FF9B4	0xE537
+0x8FF9B5	0xE538
+0x8FF9B6	0xE539
+0x8FF9B7	0xE53A
+0x8FF9B8	0xE53B
+0x8FF9B9	0xE53C
+0x8FF9BA	0xE53D
+0x8FF9BB	0xE53E
+0x8FF9BC	0xE53F
+0x8FF9BD	0xE540
+0x8FF9BE	0xE541
+0x8FF9BF	0xE542
+0x8FF9C0	0xE543
+0x8FF9C1	0xE544
+0x8FF9C2	0xE545
+0x8FF9C3	0xE546
+0x8FF9C4	0xE547
+0x8FF9C5	0xE548
+0x8FF9C6	0xE549
+0x8FF9C7	0xE54A
+0x8FF9C8	0xE54B
+0x8FF9C9	0xE54C
+0x8FF9CA	0xE54D
+0x8FF9CB	0xE54E
+0x8FF9CC	0xE54F
+0x8FF9CD	0xE550
+0x8FF9CE	0xE551
+0x8FF9CF	0xE552
+0x8FF9D0	0xE553
+0x8FF9D1	0xE554
+0x8FF9D2	0xE555
+0x8FF9D3	0xE556
+0x8FF9D4	0xE557
+0x8FF9D5	0xE558
+0x8FF9D6	0xE559
+0x8FF9D7	0xE55A
+0x8FF9D8	0xE55B
+0x8FF9D9	0xE55C
+0x8FF9DA	0xE55D
+0x8FF9DB	0xE55E
+0x8FF9DC	0xE55F
+0x8FF9DD	0xE560
+0x8FF9DE	0xE561
+0x8FF9DF	0xE562
+0x8FF9E0	0xE563
+0x8FF9E1	0xE564
+0x8FF9E2	0xE565
+0x8FF9E3	0xE566
+0x8FF9E4	0xE567
+0x8FF9E5	0xE568
+0x8FF9E6	0xE569
+0x8FF9E7	0xE56A
+0x8FF9E8	0xE56B
+0x8FF9E9	0xE56C
+0x8FF9EA	0xE56D
+0x8FF9EB	0xE56E
+0x8FF9EC	0xE56F
+0x8FF9ED	0xE570
+0x8FF9EE	0xE571
+0x8FF9EF	0xE572
+0x8FF9F0	0xE573
+0x8FF9F1	0xE574
+0x8FF9F2	0xE575
+0x8FF9F3	0xE576
+0x8FF9F4	0xE577
+0x8FF9F5	0xE578
+0x8FF9F6	0xE579
+0x8FF9F7	0xE57A
+0x8FF9F8	0xE57B
+0x8FF9F9	0xE57C
+0x8FF9FA	0xE57D
+0x8FF9FB	0xE57E
+0x8FF9FC	0xE57F
+0x8FF9FD	0xE580
+0x8FF9FE	0xE581
+0x8FFAA1	0xE582
+0x8FFAA2	0xE583
+0x8FFAA3	0xE584
+0x8FFAA4	0xE585
+0x8FFAA5	0xE586
+0x8FFAA6	0xE587
+0x8FFAA7	0xE588
+0x8FFAA8	0xE589
+0x8FFAA9	0xE58A
+0x8FFAAA	0xE58B
+0x8FFAAB	0xE58C
+0x8FFAAC	0xE58D
+0x8FFAAD	0xE58E
+0x8FFAAE	0xE58F
+0x8FFAAF	0xE590
+0x8FFAB0	0xE591
+0x8FFAB1	0xE592
+0x8FFAB2	0xE593
+0x8FFAB3	0xE594
+0x8FFAB4	0xE595
+0x8FFAB5	0xE596
+0x8FFAB6	0xE597
+0x8FFAB7	0xE598
+0x8FFAB8	0xE599
+0x8FFAB9	0xE59A
+0x8FFABA	0xE59B
+0x8FFABB	0xE59C
+0x8FFABC	0xE59D
+0x8FFABD	0xE59E
+0x8FFABE	0xE59F
+0x8FFABF	0xE5A0
+0x8FFAC0	0xE5A1
+0x8FFAC1	0xE5A2
+0x8FFAC2	0xE5A3
+0x8FFAC3	0xE5A4
+0x8FFAC4	0xE5A5
+0x8FFAC5	0xE5A6
+0x8FFAC6	0xE5A7
+0x8FFAC7	0xE5A8
+0x8FFAC8	0xE5A9
+0x8FFAC9	0xE5AA
+0x8FFACA	0xE5AB
+0x8FFACB	0xE5AC
+0x8FFACC	0xE5AD
+0x8FFACD	0xE5AE
+0x8FFACE	0xE5AF
+0x8FFACF	0xE5B0
+0x8FFAD0	0xE5B1
+0x8FFAD1	0xE5B2
+0x8FFAD2	0xE5B3
+0x8FFAD3	0xE5B4
+0x8FFAD4	0xE5B5
+0x8FFAD5	0xE5B6
+0x8FFAD6	0xE5B7
+0x8FFAD7	0xE5B8
+0x8FFAD8	0xE5B9
+0x8FFAD9	0xE5BA
+0x8FFADA	0xE5BB
+0x8FFADB	0xE5BC
+0x8FFADC	0xE5BD
+0x8FFADD	0xE5BE
+0x8FFADE	0xE5BF
+0x8FFADF	0xE5C0
+0x8FFAE0	0xE5C1
+0x8FFAE1	0xE5C2
+0x8FFAE2	0xE5C3
+0x8FFAE3	0xE5C4
+0x8FFAE4	0xE5C5
+0x8FFAE5	0xE5C6
+0x8FFAE6	0xE5C7
+0x8FFAE7	0xE5C8
+0x8FFAE8	0xE5C9
+0x8FFAE9	0xE5CA
+0x8FFAEA	0xE5CB
+0x8FFAEB	0xE5CC
+0x8FFAEC	0xE5CD
+0x8FFAED	0xE5CE
+0x8FFAEE	0xE5CF
+0x8FFAEF	0xE5D0
+0x8FFAF0	0xE5D1
+0x8FFAF1	0xE5D2
+0x8FFAF2	0xE5D3
+0x8FFAF3	0xE5D4
+0x8FFAF4	0xE5D5
+0x8FFAF5	0xE5D6
+0x8FFAF6	0xE5D7
+0x8FFAF7	0xE5D8
+0x8FFAF8	0xE5D9
+0x8FFAF9	0xE5DA
+0x8FFAFA	0xE5DB
+0x8FFAFB	0xE5DC
+0x8FFAFC	0xE5DD
+0x8FFAFD	0xE5DE
+0x8FFAFE	0xE5DF
+0x8FFBA1	0xE5E0
+0x8FFBA2	0xE5E1
+0x8FFBA3	0xE5E2
+0x8FFBA4	0xE5E3
+0x8FFBA5	0xE5E4
+0x8FFBA6	0xE5E5
+0x8FFBA7	0xE5E6
+0x8FFBA8	0xE5E7
+0x8FFBA9	0xE5E8
+0x8FFBAA	0xE5E9
+0x8FFBAB	0xE5EA
+0x8FFBAC	0xE5EB
+0x8FFBAD	0xE5EC
+0x8FFBAE	0xE5ED
+0x8FFBAF	0xE5EE
+0x8FFBB0	0xE5EF
+0x8FFBB1	0xE5F0
+0x8FFBB2	0xE5F1
+0x8FFBB3	0xE5F2
+0x8FFBB4	0xE5F3
+0x8FFBB5	0xE5F4
+0x8FFBB6	0xE5F5
+0x8FFBB7	0xE5F6
+0x8FFBB8	0xE5F7
+0x8FFBB9	0xE5F8
+0x8FFBBA	0xE5F9
+0x8FFBBB	0xE5FA
+0x8FFBBC	0xE5FB
+0x8FFBBD	0xE5FC
+0x8FFBBE	0xE5FD
+0x8FFBBF	0xE5FE
+0x8FFBC0	0xE5FF
+0x8FFBC1	0xE600
+0x8FFBC2	0xE601
+0x8FFBC3	0xE602
+0x8FFBC4	0xE603
+0x8FFBC5	0xE604
+0x8FFBC6	0xE605
+0x8FFBC7	0xE606
+0x8FFBC8	0xE607
+0x8FFBC9	0xE608
+0x8FFBCA	0xE609
+0x8FFBCB	0xE60A
+0x8FFBCC	0xE60B
+0x8FFBCD	0xE60C
+0x8FFBCE	0xE60D
+0x8FFBCF	0xE60E
+0x8FFBD0	0xE60F
+0x8FFBD1	0xE610
+0x8FFBD2	0xE611
+0x8FFBD3	0xE612
+0x8FFBD4	0xE613
+0x8FFBD5	0xE614
+0x8FFBD6	0xE615
+0x8FFBD7	0xE616
+0x8FFBD8	0xE617
+0x8FFBD9	0xE618
+0x8FFBDA	0xE619
+0x8FFBDB	0xE61A
+0x8FFBDC	0xE61B
+0x8FFBDD	0xE61C
+0x8FFBDE	0xE61D
+0x8FFBDF	0xE61E
+0x8FFBE0	0xE61F
+0x8FFBE1	0xE620
+0x8FFBE2	0xE621
+0x8FFBE3	0xE622
+0x8FFBE4	0xE623
+0x8FFBE5	0xE624
+0x8FFBE6	0xE625
+0x8FFBE7	0xE626
+0x8FFBE8	0xE627
+0x8FFBE9	0xE628
+0x8FFBEA	0xE629
+0x8FFBEB	0xE62A
+0x8FFBEC	0xE62B
+0x8FFBED	0xE62C
+0x8FFBEE	0xE62D
+0x8FFBEF	0xE62E
+0x8FFBF0	0xE62F
+0x8FFBF1	0xE630
+0x8FFBF2	0xE631
+0x8FFBF3	0xE632
+0x8FFBF4	0xE633
+0x8FFBF5	0xE634
+0x8FFBF6	0xE635
+0x8FFBF7	0xE636
+0x8FFBF8	0xE637
+0x8FFBF9	0xE638
+0x8FFBFA	0xE639
+0x8FFBFB	0xE63A
+0x8FFBFC	0xE63B
+0x8FFBFD	0xE63C
+0x8FFBFE	0xE63D
+0x8FFCA1	0xE63E
+0x8FFCA2	0xE63F
+0x8FFCA3	0xE640
+0x8FFCA4	0xE641
+0x8FFCA5	0xE642
+0x8FFCA6	0xE643
+0x8FFCA7	0xE644
+0x8FFCA8	0xE645
+0x8FFCA9	0xE646
+0x8FFCAA	0xE647
+0x8FFCAB	0xE648
+0x8FFCAC	0xE649
+0x8FFCAD	0xE64A
+0x8FFCAE	0xE64B
+0x8FFCAF	0xE64C
+0x8FFCB0	0xE64D
+0x8FFCB1	0xE64E
+0x8FFCB2	0xE64F
+0x8FFCB3	0xE650
+0x8FFCB4	0xE651
+0x8FFCB5	0xE652
+0x8FFCB6	0xE653
+0x8FFCB7	0xE654
+0x8FFCB8	0xE655
+0x8FFCB9	0xE656
+0x8FFCBA	0xE657
+0x8FFCBB	0xE658
+0x8FFCBC	0xE659
+0x8FFCBD	0xE65A
+0x8FFCBE	0xE65B
+0x8FFCBF	0xE65C
+0x8FFCC0	0xE65D
+0x8FFCC1	0xE65E
+0x8FFCC2	0xE65F
+0x8FFCC3	0xE660
+0x8FFCC4	0xE661
+0x8FFCC5	0xE662
+0x8FFCC6	0xE663
+0x8FFCC7	0xE664
+0x8FFCC8	0xE665
+0x8FFCC9	0xE666
+0x8FFCCA	0xE667
+0x8FFCCB	0xE668
+0x8FFCCC	0xE669
+0x8FFCCD	0xE66A
+0x8FFCCE	0xE66B
+0x8FFCCF	0xE66C
+0x8FFCD0	0xE66D
+0x8FFCD1	0xE66E
+0x8FFCD2	0xE66F
+0x8FFCD3	0xE670
+0x8FFCD4	0xE671
+0x8FFCD5	0xE672
+0x8FFCD6	0xE673
+0x8FFCD7	0xE674
+0x8FFCD8	0xE675
+0x8FFCD9	0xE676
+0x8FFCDA	0xE677
+0x8FFCDB	0xE678
+0x8FFCDC	0xE679
+0x8FFCDD	0xE67A
+0x8FFCDE	0xE67B
+0x8FFCDF	0xE67C
+0x8FFCE0	0xE67D
+0x8FFCE1	0xE67E
+0x8FFCE2	0xE67F
+0x8FFCE3	0xE680
+0x8FFCE4	0xE681
+0x8FFCE5	0xE682
+0x8FFCE6	0xE683
+0x8FFCE7	0xE684
+0x8FFCE8	0xE685
+0x8FFCE9	0xE686
+0x8FFCEA	0xE687
+0x8FFCEB	0xE688
+0x8FFCEC	0xE689
+0x8FFCED	0xE68A
+0x8FFCEE	0xE68B
+0x8FFCEF	0xE68C
+0x8FFCF0	0xE68D
+0x8FFCF1	0xE68E
+0x8FFCF2	0xE68F
+0x8FFCF3	0xE690
+0x8FFCF4	0xE691
+0x8FFCF5	0xE692
+0x8FFCF6	0xE693
+0x8FFCF7	0xE694
+0x8FFCF8	0xE695
+0x8FFCF9	0xE696
+0x8FFCFA	0xE697
+0x8FFCFB	0xE698
+0x8FFCFC	0xE699
+0x8FFCFD	0xE69A
+0x8FFCFE	0xE69B
+0x8FFDA1	0xE69C
+0x8FFDA2	0xE69D
+0x8FFDA3	0xE69E
+0x8FFDA4	0xE69F
+0x8FFDA5	0xE6A0
+0x8FFDA6	0xE6A1
+0x8FFDA7	0xE6A2
+0x8FFDA8	0xE6A3
+0x8FFDA9	0xE6A4
+0x8FFDAA	0xE6A5
+0x8FFDAB	0xE6A6
+0x8FFDAC	0xE6A7
+0x8FFDAD	0xE6A8
+0x8FFDAE	0xE6A9
+0x8FFDAF	0xE6AA
+0x8FFDB0	0xE6AB
+0x8FFDB1	0xE6AC
+0x8FFDB2	0xE6AD
+0x8FFDB3	0xE6AE
+0x8FFDB4	0xE6AF
+0x8FFDB5	0xE6B0
+0x8FFDB6	0xE6B1
+0x8FFDB7	0xE6B2
+0x8FFDB8	0xE6B3
+0x8FFDB9	0xE6B4
+0x8FFDBA	0xE6B5
+0x8FFDBB	0xE6B6
+0x8FFDBC	0xE6B7
+0x8FFDBD	0xE6B8
+0x8FFDBE	0xE6B9
+0x8FFDBF	0xE6BA
+0x8FFDC0	0xE6BB
+0x8FFDC1	0xE6BC
+0x8FFDC2	0xE6BD
+0x8FFDC3	0xE6BE
+0x8FFDC4	0xE6BF
+0x8FFDC5	0xE6C0
+0x8FFDC6	0xE6C1
+0x8FFDC7	0xE6C2
+0x8FFDC8	0xE6C3
+0x8FFDC9	0xE6C4
+0x8FFDCA	0xE6C5
+0x8FFDCB	0xE6C6
+0x8FFDCC	0xE6C7
+0x8FFDCD	0xE6C8
+0x8FFDCE	0xE6C9
+0x8FFDCF	0xE6CA
+0x8FFDD0	0xE6CB
+0x8FFDD1	0xE6CC
+0x8FFDD2	0xE6CD
+0x8FFDD3	0xE6CE
+0x8FFDD4	0xE6CF
+0x8FFDD5	0xE6D0
+0x8FFDD6	0xE6D1
+0x8FFDD7	0xE6D2
+0x8FFDD8	0xE6D3
+0x8FFDD9	0xE6D4
+0x8FFDDA	0xE6D5
+0x8FFDDB	0xE6D6
+0x8FFDDC	0xE6D7
+0x8FFDDD	0xE6D8
+0x8FFDDE	0xE6D9
+0x8FFDDF	0xE6DA
+0x8FFDE0	0xE6DB
+0x8FFDE1	0xE6DC
+0x8FFDE2	0xE6DD
+0x8FFDE3	0xE6DE
+0x8FFDE4	0xE6DF
+0x8FFDE5	0xE6E0
+0x8FFDE6	0xE6E1
+0x8FFDE7	0xE6E2
+0x8FFDE8	0xE6E3
+0x8FFDE9	0xE6E4
+0x8FFDEA	0xE6E5
+0x8FFDEB	0xE6E6
+0x8FFDEC	0xE6E7
+0x8FFDED	0xE6E8
+0x8FFDEE	0xE6E9
+0x8FFDEF	0xE6EA
+0x8FFDF0	0xE6EB
+0x8FFDF1	0xE6EC
+0x8FFDF2	0xE6ED
+0x8FFDF3	0xE6EE
+0x8FFDF4	0xE6EF
+0x8FFDF5	0xE6F0
+0x8FFDF6	0xE6F1
+0x8FFDF7	0xE6F2
+0x8FFDF8	0xE6F3
+0x8FFDF9	0xE6F4
+0x8FFDFA	0xE6F5
+0x8FFDFB	0xE6F6
+0x8FFDFC	0xE6F7
+0x8FFDFD	0xE6F8
+0x8FFDFE	0xE6F9
+0x8FFEA1	0xE6FA
+0x8FFEA2	0xE6FB
+0x8FFEA3	0xE6FC
+0x8FFEA4	0xE6FD
+0x8FFEA5	0xE6FE
+0x8FFEA6	0xE6FF
+0x8FFEA7	0xE700
+0x8FFEA8	0xE701
+0x8FFEA9	0xE702
+0x8FFEAA	0xE703
+0x8FFEAB	0xE704
+0x8FFEAC	0xE705
+0x8FFEAD	0xE706
+0x8FFEAE	0xE707
+0x8FFEAF	0xE708
+0x8FFEB0	0xE709
+0x8FFEB1	0xE70A
+0x8FFEB2	0xE70B
+0x8FFEB3	0xE70C
+0x8FFEB4	0xE70D
+0x8FFEB5	0xE70E
+0x8FFEB6	0xE70F
+0x8FFEB7	0xE710
+0x8FFEB8	0xE711
+0x8FFEB9	0xE712
+0x8FFEBA	0xE713
+0x8FFEBB	0xE714
+0x8FFEBC	0xE715
+0x8FFEBD	0xE716
+0x8FFEBE	0xE717
+0x8FFEBF	0xE718
+0x8FFEC0	0xE719
+0x8FFEC1	0xE71A
+0x8FFEC2	0xE71B
+0x8FFEC3	0xE71C
+0x8FFEC4	0xE71D
+0x8FFEC5	0xE71E
+0x8FFEC6	0xE71F
+0x8FFEC7	0xE720
+0x8FFEC8	0xE721
+0x8FFEC9	0xE722
+0x8FFECA	0xE723
+0x8FFECB	0xE724
+0x8FFECC	0xE725
+0x8FFECD	0xE726
+0x8FFECE	0xE727
+0x8FFECF	0xE728
+0x8FFED0	0xE729
+0x8FFED1	0xE72A
+0x8FFED2	0xE72B
+0x8FFED3	0xE72C
+0x8FFED4	0xE72D
+0x8FFED5	0xE72E
+0x8FFED6	0xE72F
+0x8FFED7	0xE730
+0x8FFED8	0xE731
+0x8FFED9	0xE732
+0x8FFEDA	0xE733
+0x8FFEDB	0xE734
+0x8FFEDC	0xE735
+0x8FFEDD	0xE736
+0x8FFEDE	0xE737
+0x8FFEDF	0xE738
+0x8FFEE0	0xE739
+0x8FFEE1	0xE73A
+0x8FFEE2	0xE73B
+0x8FFEE3	0xE73C
+0x8FFEE4	0xE73D
+0x8FFEE5	0xE73E
+0x8FFEE6	0xE73F
+0x8FFEE7	0xE740
+0x8FFEE8	0xE741
+0x8FFEE9	0xE742
+0x8FFEEA	0xE743
+0x8FFEEB	0xE744
+0x8FFEEC	0xE745
+0x8FFEED	0xE746
+0x8FFEEE	0xE747
+0x8FFEEF	0xE748
+0x8FFEF0	0xE749
+0x8FFEF1	0xE74A
+0x8FFEF2	0xE74B
+0x8FFEF3	0xE74C
+0x8FFEF4	0xE74D
+0x8FFEF5	0xE74E
+0x8FFEF6	0xE74F
+0x8FFEF7	0xE750
+0x8FFEF8	0xE751
+0x8FFEF9	0xE752
+0x8FFEFA	0xE753
+0x8FFEFB	0xE754
+0x8FFEFC	0xE755
+0x8FFEFD	0xE756
+0x8FFEFE	0xE757
+0xA1A1	0x3000
+0xA1A2	0x3001
+0xA1A3	0x3002
+0xA1A4	0xFF0C
+0xA1A5	0xFF0E
+0xA1A6	0x30FB
+0xA1A7	0xFF1A
+0xA1A8	0xFF1B
+0xA1A9	0xFF1F
+0xA1AA	0xFF01
+0xA1AB	0x309B
+0xA1AC	0x309C
+0xA1AD	0x00B4
+0xA1AE	0xFF40
+0xA1AF	0x00A8
+0xA1B0	0xFF3E
+0xA1B1	0xFFE3
+0xA1B2	0xFF3F
+0xA1B3	0x30FD
+0xA1B4	0x30FE
+0xA1B5	0x309D
+0xA1B6	0x309E
+0xA1B7	0x3003
+0xA1B8	0x4EDD
+0xA1B9	0x3005
+0xA1BA	0x3006
+0xA1BB	0x3007
+0xA1BC	0x30FC
+0xA1BD	0x2015
+0xA1BE	0x2010
+0xA1BF	0xFF0F
+0xA1C0	0xFF3C
+0xA1C1	0xFF5E
+0xA1C2	0x2225
+0xA1C3	0xFF5C
+0xA1C4	0x2026
+0xA1C5	0x2025
+0xA1C6	0x2018
+0xA1C7	0x2019
+0xA1C8	0x201C
+0xA1C9	0x201D
+0xA1CA	0xFF08
+0xA1CB	0xFF09
+0xA1CC	0x3014
+0xA1CD	0x3015
+0xA1CE	0xFF3B
+0xA1CF	0xFF3D
+0xA1D0	0xFF5B
+0xA1D1	0xFF5D
+0xA1D2	0x3008
+0xA1D3	0x3009
+0xA1D4	0x300A
+0xA1D5	0x300B
+0xA1D6	0x300C
+0xA1D7	0x300D
+0xA1D8	0x300E
+0xA1D9	0x300F
+0xA1DA	0x3010
+0xA1DB	0x3011
+0xA1DC	0xFF0B
+0xA1DD	0xFF0D
+0xA1DE	0x00B1
+0xA1DF	0x00D7
+0xA1E0	0x00F7
+0xA1E1	0xFF1D
+0xA1E2	0x2260
+0xA1E3	0xFF1C
+0xA1E4	0xFF1E
+0xA1E5	0x2266
+0xA1E6	0x2267
+0xA1E7	0x221E
+0xA1E8	0x2234
+0xA1E9	0x2642
+0xA1EA	0x2640
+0xA1EB	0x00B0
+0xA1EC	0x2032
+0xA1ED	0x2033
+0xA1EE	0x2103
+0xA1EF	0xFFE5
+0xA1F0	0xFF04
+0xA1F1	0xFFE0
+0xA1F2	0xFFE1
+0xA1F3	0xFF05
+0xA1F4	0xFF03
+0xA1F5	0xFF06
+0xA1F6	0xFF0A
+0xA1F7	0xFF20
+0xA1F8	0x00A7
+0xA1F9	0x2606
+0xA1FA	0x2605
+0xA1FB	0x25CB
+0xA1FC	0x25CF
+0xA1FD	0x25CE
+0xA1FE	0x25C7
+0xA2A1	0x25C6
+0xA2A2	0x25A1
+0xA2A3	0x25A0
+0xA2A4	0x25B3
+0xA2A5	0x25B2
+0xA2A6	0x25BD
+0xA2A7	0x25BC
+0xA2A8	0x203B
+0xA2A9	0x3012
+0xA2AA	0x2192
+0xA2AB	0x2190
+0xA2AC	0x2191
+0xA2AD	0x2193
+0xA2AE	0x3013
+0xA2BA	0x2208
+0xA2BB	0x220B
+0xA2BC	0x2286
+0xA2BD	0x2287
+0xA2BE	0x2282
+0xA2BF	0x2283
+0xA2C0	0x222A
+0xA2C1	0x2229
+0xA2CA	0x2227
+0xA2CB	0x2228
+0xA2CC	0xFFE2
+0xA2CD	0x21D2
+0xA2CE	0x21D4
+0xA2CF	0x2200
+0xA2D0	0x2203
+0xA2DC	0x2220
+0xA2DD	0x22A5
+0xA2DE	0x2312
+0xA2DF	0x2202
+0xA2E0	0x2207
+0xA2E1	0x2261
+0xA2E2	0x2252
+0xA2E3	0x226A
+0xA2E4	0x226B
+0xA2E5	0x221A
+0xA2E6	0x223D
+0xA2E7	0x221D
+0xA2E8	0x2235
+0xA2E9	0x222B
+0xA2EA	0x222C
+0xA2F2	0x212B
+0xA2F3	0x2030
+0xA2F4	0x266F
+0xA2F5	0x266D
+0xA2F6	0x266A
+0xA2F7	0x2020
+0xA2F8	0x2021
+0xA2F9	0x00B6
+0xA2FE	0x25EF
+0xA3B0	0xFF10
+0xA3B1	0xFF11
+0xA3B2	0xFF12
+0xA3B3	0xFF13
+0xA3B4	0xFF14
+0xA3B5	0xFF15
+0xA3B6	0xFF16
+0xA3B7	0xFF17
+0xA3B8	0xFF18
+0xA3B9	0xFF19
+0xA3C1	0xFF21
+0xA3C2	0xFF22
+0xA3C3	0xFF23
+0xA3C4	0xFF24
+0xA3C5	0xFF25
+0xA3C6	0xFF26
+0xA3C7	0xFF27
+0xA3C8	0xFF28
+0xA3C9	0xFF29
+0xA3CA	0xFF2A
+0xA3CB	0xFF2B
+0xA3CC	0xFF2C
+0xA3CD	0xFF2D
+0xA3CE	0xFF2E
+0xA3CF	0xFF2F
+0xA3D0	0xFF30
+0xA3D1	0xFF31
+0xA3D2	0xFF32
+0xA3D3	0xFF33
+0xA3D4	0xFF34
+0xA3D5	0xFF35
+0xA3D6	0xFF36
+0xA3D7	0xFF37
+0xA3D8	0xFF38
+0xA3D9	0xFF39
+0xA3DA	0xFF3A
+0xA3E1	0xFF41
+0xA3E2	0xFF42
+0xA3E3	0xFF43
+0xA3E4	0xFF44
+0xA3E5	0xFF45
+0xA3E6	0xFF46
+0xA3E7	0xFF47
+0xA3E8	0xFF48
+0xA3E9	0xFF49
+0xA3EA	0xFF4A
+0xA3EB	0xFF4B
+0xA3EC	0xFF4C
+0xA3ED	0xFF4D
+0xA3EE	0xFF4E
+0xA3EF	0xFF4F
+0xA3F0	0xFF50
+0xA3F1	0xFF51
+0xA3F2	0xFF52
+0xA3F3	0xFF53
+0xA3F4	0xFF54
+0xA3F5	0xFF55
+0xA3F6	0xFF56
+0xA3F7	0xFF57
+0xA3F8	0xFF58
+0xA3F9	0xFF59
+0xA3FA	0xFF5A
+0xA4A1	0x3041
+0xA4A2	0x3042
+0xA4A3	0x3043
+0xA4A4	0x3044
+0xA4A5	0x3045
+0xA4A6	0x3046
+0xA4A7	0x3047
+0xA4A8	0x3048
+0xA4A9	0x3049
+0xA4AA	0x304A
+0xA4AB	0x304B
+0xA4AC	0x304C
+0xA4AD	0x304D
+0xA4AE	0x304E
+0xA4AF	0x304F
+0xA4B0	0x3050
+0xA4B1	0x3051
+0xA4B2	0x3052
+0xA4B3	0x3053
+0xA4B4	0x3054
+0xA4B5	0x3055
+0xA4B6	0x3056
+0xA4B7	0x3057
+0xA4B8	0x3058
+0xA4B9	0x3059
+0xA4BA	0x305A
+0xA4BB	0x305B
+0xA4BC	0x305C
+0xA4BD	0x305D
+0xA4BE	0x305E
+0xA4BF	0x305F
+0xA4C0	0x3060
+0xA4C1	0x3061
+0xA4C2	0x3062
+0xA4C3	0x3063
+0xA4C4	0x3064
+0xA4C5	0x3065
+0xA4C6	0x3066
+0xA4C7	0x3067
+0xA4C8	0x3068
+0xA4C9	0x3069
+0xA4CA	0x306A
+0xA4CB	0x306B
+0xA4CC	0x306C
+0xA4CD	0x306D
+0xA4CE	0x306E
+0xA4CF	0x306F
+0xA4D0	0x3070
+0xA4D1	0x3071
+0xA4D2	0x3072
+0xA4D3	0x3073
+0xA4D4	0x3074
+0xA4D5	0x3075
+0xA4D6	0x3076
+0xA4D7	0x3077
+0xA4D8	0x3078
+0xA4D9	0x3079
+0xA4DA	0x307A
+0xA4DB	0x307B
+0xA4DC	0x307C
+0xA4DD	0x307D
+0xA4DE	0x307E
+0xA4DF	0x307F
+0xA4E0	0x3080
+0xA4E1	0x3081
+0xA4E2	0x3082
+0xA4E3	0x3083
+0xA4E4	0x3084
+0xA4E5	0x3085
+0xA4E6	0x3086
+0xA4E7	0x3087
+0xA4E8	0x3088
+0xA4E9	0x3089
+0xA4EA	0x308A
+0xA4EB	0x308B
+0xA4EC	0x308C
+0xA4ED	0x308D
+0xA4EE	0x308E
+0xA4EF	0x308F
+0xA4F0	0x3090
+0xA4F1	0x3091
+0xA4F2	0x3092
+0xA4F3	0x3093
+0xA5A1	0x30A1
+0xA5A2	0x30A2
+0xA5A3	0x30A3
+0xA5A4	0x30A4
+0xA5A5	0x30A5
+0xA5A6	0x30A6
+0xA5A7	0x30A7
+0xA5A8	0x30A8
+0xA5A9	0x30A9
+0xA5AA	0x30AA
+0xA5AB	0x30AB
+0xA5AC	0x30AC
+0xA5AD	0x30AD
+0xA5AE	0x30AE
+0xA5AF	0x30AF
+0xA5B0	0x30B0
+0xA5B1	0x30B1
+0xA5B2	0x30B2
+0xA5B3	0x30B3
+0xA5B4	0x30B4
+0xA5B5	0x30B5
+0xA5B6	0x30B6
+0xA5B7	0x30B7
+0xA5B8	0x30B8
+0xA5B9	0x30B9
+0xA5BA	0x30BA
+0xA5BB	0x30BB
+0xA5BC	0x30BC
+0xA5BD	0x30BD
+0xA5BE	0x30BE
+0xA5BF	0x30BF
+0xA5C0	0x30C0
+0xA5C1	0x30C1
+0xA5C2	0x30C2
+0xA5C3	0x30C3
+0xA5C4	0x30C4
+0xA5C5	0x30C5
+0xA5C6	0x30C6
+0xA5C7	0x30C7
+0xA5C8	0x30C8
+0xA5C9	0x30C9
+0xA5CA	0x30CA
+0xA5CB	0x30CB
+0xA5CC	0x30CC
+0xA5CD	0x30CD
+0xA5CE	0x30CE
+0xA5CF	0x30CF
+0xA5D0	0x30D0
+0xA5D1	0x30D1
+0xA5D2	0x30D2
+0xA5D3	0x30D3
+0xA5D4	0x30D4
+0xA5D5	0x30D5
+0xA5D6	0x30D6
+0xA5D7	0x30D7
+0xA5D8	0x30D8
+0xA5D9	0x30D9
+0xA5DA	0x30DA
+0xA5DB	0x30DB
+0xA5DC	0x30DC
+0xA5DD	0x30DD
+0xA5DE	0x30DE
+0xA5DF	0x30DF
+0xA5E0	0x30E0
+0xA5E1	0x30E1
+0xA5E2	0x30E2
+0xA5E3	0x30E3
+0xA5E4	0x30E4
+0xA5E5	0x30E5
+0xA5E6	0x30E6
+0xA5E7	0x30E7
+0xA5E8	0x30E8
+0xA5E9	0x30E9
+0xA5EA	0x30EA
+0xA5EB	0x30EB
+0xA5EC	0x30EC
+0xA5ED	0x30ED
+0xA5EE	0x30EE
+0xA5EF	0x30EF
+0xA5F0	0x30F0
+0xA5F1	0x30F1
+0xA5F2	0x30F2
+0xA5F3	0x30F3
+0xA5F4	0x30F4
+0xA5F5	0x30F5
+0xA5F6	0x30F6
+0xA6A1	0x0391
+0xA6A2	0x0392
+0xA6A3	0x0393
+0xA6A4	0x0394
+0xA6A5	0x0395
+0xA6A6	0x0396
+0xA6A7	0x0397
+0xA6A8	0x0398
+0xA6A9	0x0399
+0xA6AA	0x039A
+0xA6AB	0x039B
+0xA6AC	0x039C
+0xA6AD	0x039D
+0xA6AE	0x039E
+0xA6AF	0x039F
+0xA6B0	0x03A0
+0xA6B1	0x03A1
+0xA6B2	0x03A3
+0xA6B3	0x03A4
+0xA6B4	0x03A5
+0xA6B5	0x03A6
+0xA6B6	0x03A7
+0xA6B7	0x03A8
+0xA6B8	0x03A9
+0xA6C1	0x03B1
+0xA6C2	0x03B2
+0xA6C3	0x03B3
+0xA6C4	0x03B4
+0xA6C5	0x03B5
+0xA6C6	0x03B6
+0xA6C7	0x03B7
+0xA6C8	0x03B8
+0xA6C9	0x03B9
+0xA6CA	0x03BA
+0xA6CB	0x03BB
+0xA6CC	0x03BC
+0xA6CD	0x03BD
+0xA6CE	0x03BE
+0xA6CF	0x03BF
+0xA6D0	0x03C0
+0xA6D1	0x03C1
+0xA6D2	0x03C3
+0xA6D3	0x03C4
+0xA6D4	0x03C5
+0xA6D5	0x03C6
+0xA6D6	0x03C7
+0xA6D7	0x03C8
+0xA6D8	0x03C9
+0xA7A1	0x0410
+0xA7A2	0x0411
+0xA7A3	0x0412
+0xA7A4	0x0413
+0xA7A5	0x0414
+0xA7A6	0x0415
+0xA7A7	0x0401
+0xA7A8	0x0416
+0xA7A9	0x0417
+0xA7AA	0x0418
+0xA7AB	0x0419
+0xA7AC	0x041A
+0xA7AD	0x041B
+0xA7AE	0x041C
+0xA7AF	0x041D
+0xA7B0	0x041E
+0xA7B1	0x041F
+0xA7B2	0x0420
+0xA7B3	0x0421
+0xA7B4	0x0422
+0xA7B5	0x0423
+0xA7B6	0x0424
+0xA7B7	0x0425
+0xA7B8	0x0426
+0xA7B9	0x0427
+0xA7BA	0x0428
+0xA7BB	0x0429
+0xA7BC	0x042A
+0xA7BD	0x042B
+0xA7BE	0x042C
+0xA7BF	0x042D
+0xA7C0	0x042E
+0xA7C1	0x042F
+0xA7D1	0x0430
+0xA7D2	0x0431
+0xA7D3	0x0432
+0xA7D4	0x0433
+0xA7D5	0x0434
+0xA7D6	0x0435
+0xA7D7	0x0451
+0xA7D8	0x0436
+0xA7D9	0x0437
+0xA7DA	0x0438
+0xA7DB	0x0439
+0xA7DC	0x043A
+0xA7DD	0x043B
+0xA7DE	0x043C
+0xA7DF	0x043D
+0xA7E0	0x043E
+0xA7E1	0x043F
+0xA7E2	0x0440
+0xA7E3	0x0441
+0xA7E4	0x0442
+0xA7E5	0x0443
+0xA7E6	0x0444
+0xA7E7	0x0445
+0xA7E8	0x0446
+0xA7E9	0x0447
+0xA7EA	0x0448
+0xA7EB	0x0449
+0xA7EC	0x044A
+0xA7ED	0x044B
+0xA7EE	0x044C
+0xA7EF	0x044D
+0xA7F0	0x044E
+0xA7F1	0x044F
+0xA8A1	0x2500
+0xA8A2	0x2502
+0xA8A3	0x250C
+0xA8A4	0x2510
+0xA8A5	0x2518
+0xA8A6	0x2514
+0xA8A7	0x251C
+0xA8A8	0x252C
+0xA8A9	0x2524
+0xA8AA	0x2534
+0xA8AB	0x253C
+0xA8AC	0x2501
+0xA8AD	0x2503
+0xA8AE	0x250F
+0xA8AF	0x2513
+0xA8B0	0x251B
+0xA8B1	0x2517
+0xA8B2	0x2523
+0xA8B3	0x2533
+0xA8B4	0x252B
+0xA8B5	0x253B
+0xA8B6	0x254B
+0xA8B7	0x2520
+0xA8B8	0x252F
+0xA8B9	0x2528
+0xA8BA	0x2537
+0xA8BB	0x253F
+0xA8BC	0x251D
+0xA8BD	0x2530
+0xA8BE	0x2525
+0xA8BF	0x2538
+0xA8C0	0x2542
+0xADA1	0x2460
+0xADA2	0x2461
+0xADA3	0x2462
+0xADA4	0x2463
+0xADA5	0x2464
+0xADA6	0x2465
+0xADA7	0x2466
+0xADA8	0x2467
+0xADA9	0x2468
+0xADAA	0x2469
+0xADAB	0x246A
+0xADAC	0x246B
+0xADAD	0x246C
+0xADAE	0x246D
+0xADAF	0x246E
+0xADB0	0x246F
+0xADB1	0x2470
+0xADB2	0x2471
+0xADB3	0x2472
+0xADB4	0x2473
+0xADB5	0x2160
+0xADB6	0x2161
+0xADB7	0x2162
+0xADB8	0x2163
+0xADB9	0x2164
+0xADBA	0x2165
+0xADBB	0x2166
+0xADBC	0x2167
+0xADBD	0x2168
+0xADBE	0x2169
+0xADC0	0x3349
+0xADC1	0x3314
+0xADC2	0x3322
+0xADC3	0x334D
+0xADC4	0x3318
+0xADC5	0x3327
+0xADC6	0x3303
+0xADC7	0x3336
+0xADC8	0x3351
+0xADC9	0x3357
+0xADCA	0x330D
+0xADCB	0x3326
+0xADCC	0x3323
+0xADCD	0x332B
+0xADCE	0x334A
+0xADCF	0x333B
+0xADD0	0x339C
+0xADD1	0x339D
+0xADD2	0x339E
+0xADD3	0x338E
+0xADD4	0x338F
+0xADD5	0x33C4
+0xADD6	0x33A1
+0xADDF	0x337B
+0xADE0	0x301D
+0xADE1	0x301F
+0xADE2	0x2116
+0xADE3	0x33CD
+0xADE4	0x2121
+0xADE5	0x32A4
+0xADE6	0x32A5
+0xADE7	0x32A6
+0xADE8	0x32A7
+0xADE9	0x32A8
+0xADEA	0x3231
+0xADEB	0x3232
+0xADEC	0x3239
+0xADED	0x337E
+0xADEE	0x337D
+0xADEF	0x337C
+0xADF0	0x2252
+0xADF1	0x2261
+0xADF2	0x222B
+0xADF3	0x222E
+0xADF4	0x2211
+0xADF5	0x221A
+0xADF6	0x22A5
+0xADF7	0x2220
+0xADF8	0x221F
+0xADF9	0x22BF
+0xADFA	0x2235
+0xADFB	0x2229
+0xADFC	0x222A
+0xB0A1	0x4E9C
+0xB0A2	0x5516
+0xB0A3	0x5A03
+0xB0A4	0x963F
+0xB0A5	0x54C0
+0xB0A6	0x611B
+0xB0A7	0x6328
+0xB0A8	0x59F6
+0xB0A9	0x9022
+0xB0AA	0x8475
+0xB0AB	0x831C
+0xB0AC	0x7A50
+0xB0AD	0x60AA
+0xB0AE	0x63E1
+0xB0AF	0x6E25
+0xB0B0	0x65ED
+0xB0B1	0x8466
+0xB0B2	0x82A6
+0xB0B3	0x9BF5
+0xB0B4	0x6893
+0xB0B5	0x5727
+0xB0B6	0x65A1
+0xB0B7	0x6271
+0xB0B8	0x5B9B
+0xB0B9	0x59D0
+0xB0BA	0x867B
+0xB0BB	0x98F4
+0xB0BC	0x7D62
+0xB0BD	0x7DBE
+0xB0BE	0x9B8E
+0xB0BF	0x6216
+0xB0C0	0x7C9F
+0xB0C1	0x88B7
+0xB0C2	0x5B89
+0xB0C3	0x5EB5
+0xB0C4	0x6309
+0xB0C5	0x6697
+0xB0C6	0x6848
+0xB0C7	0x95C7
+0xB0C8	0x978D
+0xB0C9	0x674F
+0xB0CA	0x4EE5
+0xB0CB	0x4F0A
+0xB0CC	0x4F4D
+0xB0CD	0x4F9D
+0xB0CE	0x5049
+0xB0CF	0x56F2
+0xB0D0	0x5937
+0xB0D1	0x59D4
+0xB0D2	0x5A01
+0xB0D3	0x5C09
+0xB0D4	0x60DF
+0xB0D5	0x610F
+0xB0D6	0x6170
+0xB0D7	0x6613
+0xB0D8	0x6905
+0xB0D9	0x70BA
+0xB0DA	0x754F
+0xB0DB	0x7570
+0xB0DC	0x79FB
+0xB0DD	0x7DAD
+0xB0DE	0x7DEF
+0xB0DF	0x80C3
+0xB0E0	0x840E
+0xB0E1	0x8863
+0xB0E2	0x8B02
+0xB0E3	0x9055
+0xB0E4	0x907A
+0xB0E5	0x533B
+0xB0E6	0x4E95
+0xB0E7	0x4EA5
+0xB0E8	0x57DF
+0xB0E9	0x80B2
+0xB0EA	0x90C1
+0xB0EB	0x78EF
+0xB0EC	0x4E00
+0xB0ED	0x58F1
+0xB0EE	0x6EA2
+0xB0EF	0x9038
+0xB0F0	0x7A32
+0xB0F1	0x8328
+0xB0F2	0x828B
+0xB0F3	0x9C2F
+0xB0F4	0x5141
+0xB0F5	0x5370
+0xB0F6	0x54BD
+0xB0F7	0x54E1
+0xB0F8	0x56E0
+0xB0F9	0x59FB
+0xB0FA	0x5F15
+0xB0FB	0x98F2
+0xB0FC	0x6DEB
+0xB0FD	0x80E4
+0xB0FE	0x852D
+0xB1A1	0x9662
+0xB1A2	0x9670
+0xB1A3	0x96A0
+0xB1A4	0x97FB
+0xB1A5	0x540B
+0xB1A6	0x53F3
+0xB1A7	0x5B87
+0xB1A8	0x70CF
+0xB1A9	0x7FBD
+0xB1AA	0x8FC2
+0xB1AB	0x96E8
+0xB1AC	0x536F
+0xB1AD	0x9D5C
+0xB1AE	0x7ABA
+0xB1AF	0x4E11
+0xB1B0	0x7893
+0xB1B1	0x81FC
+0xB1B2	0x6E26
+0xB1B3	0x5618
+0xB1B4	0x5504
+0xB1B5	0x6B1D
+0xB1B6	0x851A
+0xB1B7	0x9C3B
+0xB1B8	0x59E5
+0xB1B9	0x53A9
+0xB1BA	0x6D66
+0xB1BB	0x74DC
+0xB1BC	0x958F
+0xB1BD	0x5642
+0xB1BE	0x4E91
+0xB1BF	0x904B
+0xB1C0	0x96F2
+0xB1C1	0x834F
+0xB1C2	0x990C
+0xB1C3	0x53E1
+0xB1C4	0x55B6
+0xB1C5	0x5B30
+0xB1C6	0x5F71
+0xB1C7	0x6620
+0xB1C8	0x66F3
+0xB1C9	0x6804
+0xB1CA	0x6C38
+0xB1CB	0x6CF3
+0xB1CC	0x6D29
+0xB1CD	0x745B
+0xB1CE	0x76C8
+0xB1CF	0x7A4E
+0xB1D0	0x9834
+0xB1D1	0x82F1
+0xB1D2	0x885B
+0xB1D3	0x8A60
+0xB1D4	0x92ED
+0xB1D5	0x6DB2
+0xB1D6	0x75AB
+0xB1D7	0x76CA
+0xB1D8	0x99C5
+0xB1D9	0x60A6
+0xB1DA	0x8B01
+0xB1DB	0x8D8A
+0xB1DC	0x95B2
+0xB1DD	0x698E
+0xB1DE	0x53AD
+0xB1DF	0x5186
+0xB1E0	0x5712
+0xB1E1	0x5830
+0xB1E2	0x5944
+0xB1E3	0x5BB4
+0xB1E4	0x5EF6
+0xB1E5	0x6028
+0xB1E6	0x63A9
+0xB1E7	0x63F4
+0xB1E8	0x6CBF
+0xB1E9	0x6F14
+0xB1EA	0x708E
+0xB1EB	0x7114
+0xB1EC	0x7159
+0xB1ED	0x71D5
+0xB1EE	0x733F
+0xB1EF	0x7E01
+0xB1F0	0x8276
+0xB1F1	0x82D1
+0xB1F2	0x8597
+0xB1F3	0x9060
+0xB1F4	0x925B
+0xB1F5	0x9D1B
+0xB1F6	0x5869
+0xB1F7	0x65BC
+0xB1F8	0x6C5A
+0xB1F9	0x7525
+0xB1FA	0x51F9
+0xB1FB	0x592E
+0xB1FC	0x5965
+0xB1FD	0x5F80
+0xB1FE	0x5FDC
+0xB2A1	0x62BC
+0xB2A2	0x65FA
+0xB2A3	0x6A2A
+0xB2A4	0x6B27
+0xB2A5	0x6BB4
+0xB2A6	0x738B
+0xB2A7	0x7FC1
+0xB2A8	0x8956
+0xB2A9	0x9D2C
+0xB2AA	0x9D0E
+0xB2AB	0x9EC4
+0xB2AC	0x5CA1
+0xB2AD	0x6C96
+0xB2AE	0x837B
+0xB2AF	0x5104
+0xB2B0	0x5C4B
+0xB2B1	0x61B6
+0xB2B2	0x81C6
+0xB2B3	0x6876
+0xB2B4	0x7261
+0xB2B5	0x4E59
+0xB2B6	0x4FFA
+0xB2B7	0x5378
+0xB2B8	0x6069
+0xB2B9	0x6E29
+0xB2BA	0x7A4F
+0xB2BB	0x97F3
+0xB2BC	0x4E0B
+0xB2BD	0x5316
+0xB2BE	0x4EEE
+0xB2BF	0x4F55
+0xB2C0	0x4F3D
+0xB2C1	0x4FA1
+0xB2C2	0x4F73
+0xB2C3	0x52A0
+0xB2C4	0x53EF
+0xB2C5	0x5609
+0xB2C6	0x590F
+0xB2C7	0x5AC1
+0xB2C8	0x5BB6
+0xB2C9	0x5BE1
+0xB2CA	0x79D1
+0xB2CB	0x6687
+0xB2CC	0x679C
+0xB2CD	0x67B6
+0xB2CE	0x6B4C
+0xB2CF	0x6CB3
+0xB2D0	0x706B
+0xB2D1	0x73C2
+0xB2D2	0x798D
+0xB2D3	0x79BE
+0xB2D4	0x7A3C
+0xB2D5	0x7B87
+0xB2D6	0x82B1
+0xB2D7	0x82DB
+0xB2D8	0x8304
+0xB2D9	0x8377
+0xB2DA	0x83EF
+0xB2DB	0x83D3
+0xB2DC	0x8766
+0xB2DD	0x8AB2
+0xB2DE	0x5629
+0xB2DF	0x8CA8
+0xB2E0	0x8FE6
+0xB2E1	0x904E
+0xB2E2	0x971E
+0xB2E3	0x868A
+0xB2E4	0x4FC4
+0xB2E5	0x5CE8
+0xB2E6	0x6211
+0xB2E7	0x7259
+0xB2E8	0x753B
+0xB2E9	0x81E5
+0xB2EA	0x82BD
+0xB2EB	0x86FE
+0xB2EC	0x8CC0
+0xB2ED	0x96C5
+0xB2EE	0x9913
+0xB2EF	0x99D5
+0xB2F0	0x4ECB
+0xB2F1	0x4F1A
+0xB2F2	0x89E3
+0xB2F3	0x56DE
+0xB2F4	0x584A
+0xB2F5	0x58CA
+0xB2F6	0x5EFB
+0xB2F7	0x5FEB
+0xB2F8	0x602A
+0xB2F9	0x6094
+0xB2FA	0x6062
+0xB2FB	0x61D0
+0xB2FC	0x6212
+0xB2FD	0x62D0
+0xB2FE	0x6539
+0xB3A1	0x9B41
+0xB3A2	0x6666
+0xB3A3	0x68B0
+0xB3A4	0x6D77
+0xB3A5	0x7070
+0xB3A6	0x754C
+0xB3A7	0x7686
+0xB3A8	0x7D75
+0xB3A9	0x82A5
+0xB3AA	0x87F9
+0xB3AB	0x958B
+0xB3AC	0x968E
+0xB3AD	0x8C9D
+0xB3AE	0x51F1
+0xB3AF	0x52BE
+0xB3B0	0x5916
+0xB3B1	0x54B3
+0xB3B2	0x5BB3
+0xB3B3	0x5D16
+0xB3B4	0x6168
+0xB3B5	0x6982
+0xB3B6	0x6DAF
+0xB3B7	0x788D
+0xB3B8	0x84CB
+0xB3B9	0x8857
+0xB3BA	0x8A72
+0xB3BB	0x93A7
+0xB3BC	0x9AB8
+0xB3BD	0x6D6C
+0xB3BE	0x99A8
+0xB3BF	0x86D9
+0xB3C0	0x57A3
+0xB3C1	0x67FF
+0xB3C2	0x86CE
+0xB3C3	0x920E
+0xB3C4	0x5283
+0xB3C5	0x5687
+0xB3C6	0x5404
+0xB3C7	0x5ED3
+0xB3C8	0x62E1
+0xB3C9	0x64B9
+0xB3CA	0x683C
+0xB3CB	0x6838
+0xB3CC	0x6BBB
+0xB3CD	0x7372
+0xB3CE	0x78BA
+0xB3CF	0x7A6B
+0xB3D0	0x899A
+0xB3D1	0x89D2
+0xB3D2	0x8D6B
+0xB3D3	0x8F03
+0xB3D4	0x90ED
+0xB3D5	0x95A3
+0xB3D6	0x9694
+0xB3D7	0x9769
+0xB3D8	0x5B66
+0xB3D9	0x5CB3
+0xB3DA	0x697D
+0xB3DB	0x984D
+0xB3DC	0x984E
+0xB3DD	0x639B
+0xB3DE	0x7B20
+0xB3DF	0x6A2B
+0xB3E0	0x6A7F
+0xB3E1	0x68B6
+0xB3E2	0x9C0D
+0xB3E3	0x6F5F
+0xB3E4	0x5272
+0xB3E5	0x559D
+0xB3E6	0x6070
+0xB3E7	0x62EC
+0xB3E8	0x6D3B
+0xB3E9	0x6E07
+0xB3EA	0x6ED1
+0xB3EB	0x845B
+0xB3EC	0x8910
+0xB3ED	0x8F44
+0xB3EE	0x4E14
+0xB3EF	0x9C39
+0xB3F0	0x53F6
+0xB3F1	0x691B
+0xB3F2	0x6A3A
+0xB3F3	0x9784
+0xB3F4	0x682A
+0xB3F5	0x515C
+0xB3F6	0x7AC3
+0xB3F7	0x84B2
+0xB3F8	0x91DC
+0xB3F9	0x938C
+0xB3FA	0x565B
+0xB3FB	0x9D28
+0xB3FC	0x6822
+0xB3FD	0x8305
+0xB3FE	0x8431
+0xB4A1	0x7CA5
+0xB4A2	0x5208
+0xB4A3	0x82C5
+0xB4A4	0x74E6
+0xB4A5	0x4E7E
+0xB4A6	0x4F83
+0xB4A7	0x51A0
+0xB4A8	0x5BD2
+0xB4A9	0x520A
+0xB4AA	0x52D8
+0xB4AB	0x52E7
+0xB4AC	0x5DFB
+0xB4AD	0x559A
+0xB4AE	0x582A
+0xB4AF	0x59E6
+0xB4B0	0x5B8C
+0xB4B1	0x5B98
+0xB4B2	0x5BDB
+0xB4B3	0x5E72
+0xB4B4	0x5E79
+0xB4B5	0x60A3
+0xB4B6	0x611F
+0xB4B7	0x6163
+0xB4B8	0x61BE
+0xB4B9	0x63DB
+0xB4BA	0x6562
+0xB4BB	0x67D1
+0xB4BC	0x6853
+0xB4BD	0x68FA
+0xB4BE	0x6B3E
+0xB4BF	0x6B53
+0xB4C0	0x6C57
+0xB4C1	0x6F22
+0xB4C2	0x6F97
+0xB4C3	0x6F45
+0xB4C4	0x74B0
+0xB4C5	0x7518
+0xB4C6	0x76E3
+0xB4C7	0x770B
+0xB4C8	0x7AFF
+0xB4C9	0x7BA1
+0xB4CA	0x7C21
+0xB4CB	0x7DE9
+0xB4CC	0x7F36
+0xB4CD	0x7FF0
+0xB4CE	0x809D
+0xB4CF	0x8266
+0xB4D0	0x839E
+0xB4D1	0x89B3
+0xB4D2	0x8ACC
+0xB4D3	0x8CAB
+0xB4D4	0x9084
+0xB4D5	0x9451
+0xB4D6	0x9593
+0xB4D7	0x9591
+0xB4D8	0x95A2
+0xB4D9	0x9665
+0xB4DA	0x97D3
+0xB4DB	0x9928
+0xB4DC	0x8218
+0xB4DD	0x4E38
+0xB4DE	0x542B
+0xB4DF	0x5CB8
+0xB4E0	0x5DCC
+0xB4E1	0x73A9
+0xB4E2	0x764C
+0xB4E3	0x773C
+0xB4E4	0x5CA9
+0xB4E5	0x7FEB
+0xB4E6	0x8D0B
+0xB4E7	0x96C1
+0xB4E8	0x9811
+0xB4E9	0x9854
+0xB4EA	0x9858
+0xB4EB	0x4F01
+0xB4EC	0x4F0E
+0xB4ED	0x5371
+0xB4EE	0x559C
+0xB4EF	0x5668
+0xB4F0	0x57FA
+0xB4F1	0x5947
+0xB4F2	0x5B09
+0xB4F3	0x5BC4
+0xB4F4	0x5C90
+0xB4F5	0x5E0C
+0xB4F6	0x5E7E
+0xB4F7	0x5FCC
+0xB4F8	0x63EE
+0xB4F9	0x673A
+0xB4FA	0x65D7
+0xB4FB	0x65E2
+0xB4FC	0x671F
+0xB4FD	0x68CB
+0xB4FE	0x68C4
+0xB5A1	0x6A5F
+0xB5A2	0x5E30
+0xB5A3	0x6BC5
+0xB5A4	0x6C17
+0xB5A5	0x6C7D
+0xB5A6	0x757F
+0xB5A7	0x7948
+0xB5A8	0x5B63
+0xB5A9	0x7A00
+0xB5AA	0x7D00
+0xB5AB	0x5FBD
+0xB5AC	0x898F
+0xB5AD	0x8A18
+0xB5AE	0x8CB4
+0xB5AF	0x8D77
+0xB5B0	0x8ECC
+0xB5B1	0x8F1D
+0xB5B2	0x98E2
+0xB5B3	0x9A0E
+0xB5B4	0x9B3C
+0xB5B5	0x4E80
+0xB5B6	0x507D
+0xB5B7	0x5100
+0xB5B8	0x5993
+0xB5B9	0x5B9C
+0xB5BA	0x622F
+0xB5BB	0x6280
+0xB5BC	0x64EC
+0xB5BD	0x6B3A
+0xB5BE	0x72A0
+0xB5BF	0x7591
+0xB5C0	0x7947
+0xB5C1	0x7FA9
+0xB5C2	0x87FB
+0xB5C3	0x8ABC
+0xB5C4	0x8B70
+0xB5C5	0x63AC
+0xB5C6	0x83CA
+0xB5C7	0x97A0
+0xB5C8	0x5409
+0xB5C9	0x5403
+0xB5CA	0x55AB
+0xB5CB	0x6854
+0xB5CC	0x6A58
+0xB5CD	0x8A70
+0xB5CE	0x7827
+0xB5CF	0x6775
+0xB5D0	0x9ECD
+0xB5D1	0x5374
+0xB5D2	0x5BA2
+0xB5D3	0x811A
+0xB5D4	0x8650
+0xB5D5	0x9006
+0xB5D6	0x4E18
+0xB5D7	0x4E45
+0xB5D8	0x4EC7
+0xB5D9	0x4F11
+0xB5DA	0x53CA
+0xB5DB	0x5438
+0xB5DC	0x5BAE
+0xB5DD	0x5F13
+0xB5DE	0x6025
+0xB5DF	0x6551
+0xB5E0	0x673D
+0xB5E1	0x6C42
+0xB5E2	0x6C72
+0xB5E3	0x6CE3
+0xB5E4	0x7078
+0xB5E5	0x7403
+0xB5E6	0x7A76
+0xB5E7	0x7AAE
+0xB5E8	0x7B08
+0xB5E9	0x7D1A
+0xB5EA	0x7CFE
+0xB5EB	0x7D66
+0xB5EC	0x65E7
+0xB5ED	0x725B
+0xB5EE	0x53BB
+0xB5EF	0x5C45
+0xB5F0	0x5DE8
+0xB5F1	0x62D2
+0xB5F2	0x62E0
+0xB5F3	0x6319
+0xB5F4	0x6E20
+0xB5F5	0x865A
+0xB5F6	0x8A31
+0xB5F7	0x8DDD
+0xB5F8	0x92F8
+0xB5F9	0x6F01
+0xB5FA	0x79A6
+0xB5FB	0x9B5A
+0xB5FC	0x4EA8
+0xB5FD	0x4EAB
+0xB5FE	0x4EAC
+0xB6A1	0x4F9B
+0xB6A2	0x4FA0
+0xB6A3	0x50D1
+0xB6A4	0x5147
+0xB6A5	0x7AF6
+0xB6A6	0x5171
+0xB6A7	0x51F6
+0xB6A8	0x5354
+0xB6A9	0x5321
+0xB6AA	0x537F
+0xB6AB	0x53EB
+0xB6AC	0x55AC
+0xB6AD	0x5883
+0xB6AE	0x5CE1
+0xB6AF	0x5F37
+0xB6B0	0x5F4A
+0xB6B1	0x602F
+0xB6B2	0x6050
+0xB6B3	0x606D
+0xB6B4	0x631F
+0xB6B5	0x6559
+0xB6B6	0x6A4B
+0xB6B7	0x6CC1
+0xB6B8	0x72C2
+0xB6B9	0x72ED
+0xB6BA	0x77EF
+0xB6BB	0x80F8
+0xB6BC	0x8105
+0xB6BD	0x8208
+0xB6BE	0x854E
+0xB6BF	0x90F7
+0xB6C0	0x93E1
+0xB6C1	0x97FF
+0xB6C2	0x9957
+0xB6C3	0x9A5A
+0xB6C4	0x4EF0
+0xB6C5	0x51DD
+0xB6C6	0x5C2D
+0xB6C7	0x6681
+0xB6C8	0x696D
+0xB6C9	0x5C40
+0xB6CA	0x66F2
+0xB6CB	0x6975
+0xB6CC	0x7389
+0xB6CD	0x6850
+0xB6CE	0x7C81
+0xB6CF	0x50C5
+0xB6D0	0x52E4
+0xB6D1	0x5747
+0xB6D2	0x5DFE
+0xB6D3	0x9326
+0xB6D4	0x65A4
+0xB6D5	0x6B23
+0xB6D6	0x6B3D
+0xB6D7	0x7434
+0xB6D8	0x7981
+0xB6D9	0x79BD
+0xB6DA	0x7B4B
+0xB6DB	0x7DCA
+0xB6DC	0x82B9
+0xB6DD	0x83CC
+0xB6DE	0x887F
+0xB6DF	0x895F
+0xB6E0	0x8B39
+0xB6E1	0x8FD1
+0xB6E2	0x91D1
+0xB6E3	0x541F
+0xB6E4	0x9280
+0xB6E5	0x4E5D
+0xB6E6	0x5036
+0xB6E7	0x53E5
+0xB6E8	0x533A
+0xB6E9	0x72D7
+0xB6EA	0x7396
+0xB6EB	0x77E9
+0xB6EC	0x82E6
+0xB6ED	0x8EAF
+0xB6EE	0x99C6
+0xB6EF	0x99C8
+0xB6F0	0x99D2
+0xB6F1	0x5177
+0xB6F2	0x611A
+0xB6F3	0x865E
+0xB6F4	0x55B0
+0xB6F5	0x7A7A
+0xB6F6	0x5076
+0xB6F7	0x5BD3
+0xB6F8	0x9047
+0xB6F9	0x9685
+0xB6FA	0x4E32
+0xB6FB	0x6ADB
+0xB6FC	0x91E7
+0xB6FD	0x5C51
+0xB6FE	0x5C48
+0xB7A1	0x6398
+0xB7A2	0x7A9F
+0xB7A3	0x6C93
+0xB7A4	0x9774
+0xB7A5	0x8F61
+0xB7A6	0x7AAA
+0xB7A7	0x718A
+0xB7A8	0x9688
+0xB7A9	0x7C82
+0xB7AA	0x6817
+0xB7AB	0x7E70
+0xB7AC	0x6851
+0xB7AD	0x936C
+0xB7AE	0x52F2
+0xB7AF	0x541B
+0xB7B0	0x85AB
+0xB7B1	0x8A13
+0xB7B2	0x7FA4
+0xB7B3	0x8ECD
+0xB7B4	0x90E1
+0xB7B5	0x5366
+0xB7B6	0x8888
+0xB7B7	0x7941
+0xB7B8	0x4FC2
+0xB7B9	0x50BE
+0xB7BA	0x5211
+0xB7BB	0x5144
+0xB7BC	0x5553
+0xB7BD	0x572D
+0xB7BE	0x73EA
+0xB7BF	0x578B
+0xB7C0	0x5951
+0xB7C1	0x5F62
+0xB7C2	0x5F84
+0xB7C3	0x6075
+0xB7C4	0x6176
+0xB7C5	0x6167
+0xB7C6	0x61A9
+0xB7C7	0x63B2
+0xB7C8	0x643A
+0xB7C9	0x656C
+0xB7CA	0x666F
+0xB7CB	0x6842
+0xB7CC	0x6E13
+0xB7CD	0x7566
+0xB7CE	0x7A3D
+0xB7CF	0x7CFB
+0xB7D0	0x7D4C
+0xB7D1	0x7D99
+0xB7D2	0x7E4B
+0xB7D3	0x7F6B
+0xB7D4	0x830E
+0xB7D5	0x834A
+0xB7D6	0x86CD
+0xB7D7	0x8A08
+0xB7D8	0x8A63
+0xB7D9	0x8B66
+0xB7DA	0x8EFD
+0xB7DB	0x981A
+0xB7DC	0x9D8F
+0xB7DD	0x82B8
+0xB7DE	0x8FCE
+0xB7DF	0x9BE8
+0xB7E0	0x5287
+0xB7E1	0x621F
+0xB7E2	0x6483
+0xB7E3	0x6FC0
+0xB7E4	0x9699
+0xB7E5	0x6841
+0xB7E6	0x5091
+0xB7E7	0x6B20
+0xB7E8	0x6C7A
+0xB7E9	0x6F54
+0xB7EA	0x7A74
+0xB7EB	0x7D50
+0xB7EC	0x8840
+0xB7ED	0x8A23
+0xB7EE	0x6708
+0xB7EF	0x4EF6
+0xB7F0	0x5039
+0xB7F1	0x5026
+0xB7F2	0x5065
+0xB7F3	0x517C
+0xB7F4	0x5238
+0xB7F5	0x5263
+0xB7F6	0x55A7
+0xB7F7	0x570F
+0xB7F8	0x5805
+0xB7F9	0x5ACC
+0xB7FA	0x5EFA
+0xB7FB	0x61B2
+0xB7FC	0x61F8
+0xB7FD	0x62F3
+0xB7FE	0x6372
+0xB8A1	0x691C
+0xB8A2	0x6A29
+0xB8A3	0x727D
+0xB8A4	0x72AC
+0xB8A5	0x732E
+0xB8A6	0x7814
+0xB8A7	0x786F
+0xB8A8	0x7D79
+0xB8A9	0x770C
+0xB8AA	0x80A9
+0xB8AB	0x898B
+0xB8AC	0x8B19
+0xB8AD	0x8CE2
+0xB8AE	0x8ED2
+0xB8AF	0x9063
+0xB8B0	0x9375
+0xB8B1	0x967A
+0xB8B2	0x9855
+0xB8B3	0x9A13
+0xB8B4	0x9E78
+0xB8B5	0x5143
+0xB8B6	0x539F
+0xB8B7	0x53B3
+0xB8B8	0x5E7B
+0xB8B9	0x5F26
+0xB8BA	0x6E1B
+0xB8BB	0x6E90
+0xB8BC	0x7384
+0xB8BD	0x73FE
+0xB8BE	0x7D43
+0xB8BF	0x8237
+0xB8C0	0x8A00
+0xB8C1	0x8AFA
+0xB8C2	0x9650
+0xB8C3	0x4E4E
+0xB8C4	0x500B
+0xB8C5	0x53E4
+0xB8C6	0x547C
+0xB8C7	0x56FA
+0xB8C8	0x59D1
+0xB8C9	0x5B64
+0xB8CA	0x5DF1
+0xB8CB	0x5EAB
+0xB8CC	0x5F27
+0xB8CD	0x6238
+0xB8CE	0x6545
+0xB8CF	0x67AF
+0xB8D0	0x6E56
+0xB8D1	0x72D0
+0xB8D2	0x7CCA
+0xB8D3	0x88B4
+0xB8D4	0x80A1
+0xB8D5	0x80E1
+0xB8D6	0x83F0
+0xB8D7	0x864E
+0xB8D8	0x8A87
+0xB8D9	0x8DE8
+0xB8DA	0x9237
+0xB8DB	0x96C7
+0xB8DC	0x9867
+0xB8DD	0x9F13
+0xB8DE	0x4E94
+0xB8DF	0x4E92
+0xB8E0	0x4F0D
+0xB8E1	0x5348
+0xB8E2	0x5449
+0xB8E3	0x543E
+0xB8E4	0x5A2F
+0xB8E5	0x5F8C
+0xB8E6	0x5FA1
+0xB8E7	0x609F
+0xB8E8	0x68A7
+0xB8E9	0x6A8E
+0xB8EA	0x745A
+0xB8EB	0x7881
+0xB8EC	0x8A9E
+0xB8ED	0x8AA4
+0xB8EE	0x8B77
+0xB8EF	0x9190
+0xB8F0	0x4E5E
+0xB8F1	0x9BC9
+0xB8F2	0x4EA4
+0xB8F3	0x4F7C
+0xB8F4	0x4FAF
+0xB8F5	0x5019
+0xB8F6	0x5016
+0xB8F7	0x5149
+0xB8F8	0x516C
+0xB8F9	0x529F
+0xB8FA	0x52B9
+0xB8FB	0x52FE
+0xB8FC	0x539A
+0xB8FD	0x53E3
+0xB8FE	0x5411
+0xB9A1	0x540E
+0xB9A2	0x5589
+0xB9A3	0x5751
+0xB9A4	0x57A2
+0xB9A5	0x597D
+0xB9A6	0x5B54
+0xB9A7	0x5B5D
+0xB9A8	0x5B8F
+0xB9A9	0x5DE5
+0xB9AA	0x5DE7
+0xB9AB	0x5DF7
+0xB9AC	0x5E78
+0xB9AD	0x5E83
+0xB9AE	0x5E9A
+0xB9AF	0x5EB7
+0xB9B0	0x5F18
+0xB9B1	0x6052
+0xB9B2	0x614C
+0xB9B3	0x6297
+0xB9B4	0x62D8
+0xB9B5	0x63A7
+0xB9B6	0x653B
+0xB9B7	0x6602
+0xB9B8	0x6643
+0xB9B9	0x66F4
+0xB9BA	0x676D
+0xB9BB	0x6821
+0xB9BC	0x6897
+0xB9BD	0x69CB
+0xB9BE	0x6C5F
+0xB9BF	0x6D2A
+0xB9C0	0x6D69
+0xB9C1	0x6E2F
+0xB9C2	0x6E9D
+0xB9C3	0x7532
+0xB9C4	0x7687
+0xB9C5	0x786C
+0xB9C6	0x7A3F
+0xB9C7	0x7CE0
+0xB9C8	0x7D05
+0xB9C9	0x7D18
+0xB9CA	0x7D5E
+0xB9CB	0x7DB1
+0xB9CC	0x8015
+0xB9CD	0x8003
+0xB9CE	0x80AF
+0xB9CF	0x80B1
+0xB9D0	0x8154
+0xB9D1	0x818F
+0xB9D2	0x822A
+0xB9D3	0x8352
+0xB9D4	0x884C
+0xB9D5	0x8861
+0xB9D6	0x8B1B
+0xB9D7	0x8CA2
+0xB9D8	0x8CFC
+0xB9D9	0x90CA
+0xB9DA	0x9175
+0xB9DB	0x9271
+0xB9DC	0x783F
+0xB9DD	0x92FC
+0xB9DE	0x95A4
+0xB9DF	0x964D
+0xB9E0	0x9805
+0xB9E1	0x9999
+0xB9E2	0x9AD8
+0xB9E3	0x9D3B
+0xB9E4	0x525B
+0xB9E5	0x52AB
+0xB9E6	0x53F7
+0xB9E7	0x5408
+0xB9E8	0x58D5
+0xB9E9	0x62F7
+0xB9EA	0x6FE0
+0xB9EB	0x8C6A
+0xB9EC	0x8F5F
+0xB9ED	0x9EB9
+0xB9EE	0x514B
+0xB9EF	0x523B
+0xB9F0	0x544A
+0xB9F1	0x56FD
+0xB9F2	0x7A40
+0xB9F3	0x9177
+0xB9F4	0x9D60
+0xB9F5	0x9ED2
+0xB9F6	0x7344
+0xB9F7	0x6F09
+0xB9F8	0x8170
+0xB9F9	0x7511
+0xB9FA	0x5FFD
+0xB9FB	0x60DA
+0xB9FC	0x9AA8
+0xB9FD	0x72DB
+0xB9FE	0x8FBC
+0xBAA1	0x6B64
+0xBAA2	0x9803
+0xBAA3	0x4ECA
+0xBAA4	0x56F0
+0xBAA5	0x5764
+0xBAA6	0x58BE
+0xBAA7	0x5A5A
+0xBAA8	0x6068
+0xBAA9	0x61C7
+0xBAAA	0x660F
+0xBAAB	0x6606
+0xBAAC	0x6839
+0xBAAD	0x68B1
+0xBAAE	0x6DF7
+0xBAAF	0x75D5
+0xBAB0	0x7D3A
+0xBAB1	0x826E
+0xBAB2	0x9B42
+0xBAB3	0x4E9B
+0xBAB4	0x4F50
+0xBAB5	0x53C9
+0xBAB6	0x5506
+0xBAB7	0x5D6F
+0xBAB8	0x5DE6
+0xBAB9	0x5DEE
+0xBABA	0x67FB
+0xBABB	0x6C99
+0xBABC	0x7473
+0xBABD	0x7802
+0xBABE	0x8A50
+0xBABF	0x9396
+0xBAC0	0x88DF
+0xBAC1	0x5750
+0xBAC2	0x5EA7
+0xBAC3	0x632B
+0xBAC4	0x50B5
+0xBAC5	0x50AC
+0xBAC6	0x518D
+0xBAC7	0x6700
+0xBAC8	0x54C9
+0xBAC9	0x585E
+0xBACA	0x59BB
+0xBACB	0x5BB0
+0xBACC	0x5F69
+0xBACD	0x624D
+0xBACE	0x63A1
+0xBACF	0x683D
+0xBAD0	0x6B73
+0xBAD1	0x6E08
+0xBAD2	0x707D
+0xBAD3	0x91C7
+0xBAD4	0x7280
+0xBAD5	0x7815
+0xBAD6	0x7826
+0xBAD7	0x796D
+0xBAD8	0x658E
+0xBAD9	0x7D30
+0xBADA	0x83DC
+0xBADB	0x88C1
+0xBADC	0x8F09
+0xBADD	0x969B
+0xBADE	0x5264
+0xBADF	0x5728
+0xBAE0	0x6750
+0xBAE1	0x7F6A
+0xBAE2	0x8CA1
+0xBAE3	0x51B4
+0xBAE4	0x5742
+0xBAE5	0x962A
+0xBAE6	0x583A
+0xBAE7	0x698A
+0xBAE8	0x80B4
+0xBAE9	0x54B2
+0xBAEA	0x5D0E
+0xBAEB	0x57FC
+0xBAEC	0x7895
+0xBAED	0x9DFA
+0xBAEE	0x4F5C
+0xBAEF	0x524A
+0xBAF0	0x548B
+0xBAF1	0x643E
+0xBAF2	0x6628
+0xBAF3	0x6714
+0xBAF4	0x67F5
+0xBAF5	0x7A84
+0xBAF6	0x7B56
+0xBAF7	0x7D22
+0xBAF8	0x932F
+0xBAF9	0x685C
+0xBAFA	0x9BAD
+0xBAFB	0x7B39
+0xBAFC	0x5319
+0xBAFD	0x518A
+0xBAFE	0x5237
+0xBBA1	0x5BDF
+0xBBA2	0x62F6
+0xBBA3	0x64AE
+0xBBA4	0x64E6
+0xBBA5	0x672D
+0xBBA6	0x6BBA
+0xBBA7	0x85A9
+0xBBA8	0x96D1
+0xBBA9	0x7690
+0xBBAA	0x9BD6
+0xBBAB	0x634C
+0xBBAC	0x9306
+0xBBAD	0x9BAB
+0xBBAE	0x76BF
+0xBBAF	0x6652
+0xBBB0	0x4E09
+0xBBB1	0x5098
+0xBBB2	0x53C2
+0xBBB3	0x5C71
+0xBBB4	0x60E8
+0xBBB5	0x6492
+0xBBB6	0x6563
+0xBBB7	0x685F
+0xBBB8	0x71E6
+0xBBB9	0x73CA
+0xBBBA	0x7523
+0xBBBB	0x7B97
+0xBBBC	0x7E82
+0xBBBD	0x8695
+0xBBBE	0x8B83
+0xBBBF	0x8CDB
+0xBBC0	0x9178
+0xBBC1	0x9910
+0xBBC2	0x65AC
+0xBBC3	0x66AB
+0xBBC4	0x6B8B
+0xBBC5	0x4ED5
+0xBBC6	0x4ED4
+0xBBC7	0x4F3A
+0xBBC8	0x4F7F
+0xBBC9	0x523A
+0xBBCA	0x53F8
+0xBBCB	0x53F2
+0xBBCC	0x55E3
+0xBBCD	0x56DB
+0xBBCE	0x58EB
+0xBBCF	0x59CB
+0xBBD0	0x59C9
+0xBBD1	0x59FF
+0xBBD2	0x5B50
+0xBBD3	0x5C4D
+0xBBD4	0x5E02
+0xBBD5	0x5E2B
+0xBBD6	0x5FD7
+0xBBD7	0x601D
+0xBBD8	0x6307
+0xBBD9	0x652F
+0xBBDA	0x5B5C
+0xBBDB	0x65AF
+0xBBDC	0x65BD
+0xBBDD	0x65E8
+0xBBDE	0x679D
+0xBBDF	0x6B62
+0xBBE0	0x6B7B
+0xBBE1	0x6C0F
+0xBBE2	0x7345
+0xBBE3	0x7949
+0xBBE4	0x79C1
+0xBBE5	0x7CF8
+0xBBE6	0x7D19
+0xBBE7	0x7D2B
+0xBBE8	0x80A2
+0xBBE9	0x8102
+0xBBEA	0x81F3
+0xBBEB	0x8996
+0xBBEC	0x8A5E
+0xBBED	0x8A69
+0xBBEE	0x8A66
+0xBBEF	0x8A8C
+0xBBF0	0x8AEE
+0xBBF1	0x8CC7
+0xBBF2	0x8CDC
+0xBBF3	0x96CC
+0xBBF4	0x98FC
+0xBBF5	0x6B6F
+0xBBF6	0x4E8B
+0xBBF7	0x4F3C
+0xBBF8	0x4F8D
+0xBBF9	0x5150
+0xBBFA	0x5B57
+0xBBFB	0x5BFA
+0xBBFC	0x6148
+0xBBFD	0x6301
+0xBBFE	0x6642
+0xBCA1	0x6B21
+0xBCA2	0x6ECB
+0xBCA3	0x6CBB
+0xBCA4	0x723E
+0xBCA5	0x74BD
+0xBCA6	0x75D4
+0xBCA7	0x78C1
+0xBCA8	0x793A
+0xBCA9	0x800C
+0xBCAA	0x8033
+0xBCAB	0x81EA
+0xBCAC	0x8494
+0xBCAD	0x8F9E
+0xBCAE	0x6C50
+0xBCAF	0x9E7F
+0xBCB0	0x5F0F
+0xBCB1	0x8B58
+0xBCB2	0x9D2B
+0xBCB3	0x7AFA
+0xBCB4	0x8EF8
+0xBCB5	0x5B8D
+0xBCB6	0x96EB
+0xBCB7	0x4E03
+0xBCB8	0x53F1
+0xBCB9	0x57F7
+0xBCBA	0x5931
+0xBCBB	0x5AC9
+0xBCBC	0x5BA4
+0xBCBD	0x6089
+0xBCBE	0x6E7F
+0xBCBF	0x6F06
+0xBCC0	0x75BE
+0xBCC1	0x8CEA
+0xBCC2	0x5B9F
+0xBCC3	0x8500
+0xBCC4	0x7BE0
+0xBCC5	0x5072
+0xBCC6	0x67F4
+0xBCC7	0x829D
+0xBCC8	0x5C61
+0xBCC9	0x854A
+0xBCCA	0x7E1E
+0xBCCB	0x820E
+0xBCCC	0x5199
+0xBCCD	0x5C04
+0xBCCE	0x6368
+0xBCCF	0x8D66
+0xBCD0	0x659C
+0xBCD1	0x716E
+0xBCD2	0x793E
+0xBCD3	0x7D17
+0xBCD4	0x8005
+0xBCD5	0x8B1D
+0xBCD6	0x8ECA
+0xBCD7	0x906E
+0xBCD8	0x86C7
+0xBCD9	0x90AA
+0xBCDA	0x501F
+0xBCDB	0x52FA
+0xBCDC	0x5C3A
+0xBCDD	0x6753
+0xBCDE	0x707C
+0xBCDF	0x7235
+0xBCE0	0x914C
+0xBCE1	0x91C8
+0xBCE2	0x932B
+0xBCE3	0x82E5
+0xBCE4	0x5BC2
+0xBCE5	0x5F31
+0xBCE6	0x60F9
+0xBCE7	0x4E3B
+0xBCE8	0x53D6
+0xBCE9	0x5B88
+0xBCEA	0x624B
+0xBCEB	0x6731
+0xBCEC	0x6B8A
+0xBCED	0x72E9
+0xBCEE	0x73E0
+0xBCEF	0x7A2E
+0xBCF0	0x816B
+0xBCF1	0x8DA3
+0xBCF2	0x9152
+0xBCF3	0x9996
+0xBCF4	0x5112
+0xBCF5	0x53D7
+0xBCF6	0x546A
+0xBCF7	0x5BFF
+0xBCF8	0x6388
+0xBCF9	0x6A39
+0xBCFA	0x7DAC
+0xBCFB	0x9700
+0xBCFC	0x56DA
+0xBCFD	0x53CE
+0xBCFE	0x5468
+0xBDA1	0x5B97
+0xBDA2	0x5C31
+0xBDA3	0x5DDE
+0xBDA4	0x4FEE
+0xBDA5	0x6101
+0xBDA6	0x62FE
+0xBDA7	0x6D32
+0xBDA8	0x79C0
+0xBDA9	0x79CB
+0xBDAA	0x7D42
+0xBDAB	0x7E4D
+0xBDAC	0x7FD2
+0xBDAD	0x81ED
+0xBDAE	0x821F
+0xBDAF	0x8490
+0xBDB0	0x8846
+0xBDB1	0x8972
+0xBDB2	0x8B90
+0xBDB3	0x8E74
+0xBDB4	0x8F2F
+0xBDB5	0x9031
+0xBDB6	0x914B
+0xBDB7	0x916C
+0xBDB8	0x96C6
+0xBDB9	0x919C
+0xBDBA	0x4EC0
+0xBDBB	0x4F4F
+0xBDBC	0x5145
+0xBDBD	0x5341
+0xBDBE	0x5F93
+0xBDBF	0x620E
+0xBDC0	0x67D4
+0xBDC1	0x6C41
+0xBDC2	0x6E0B
+0xBDC3	0x7363
+0xBDC4	0x7E26
+0xBDC5	0x91CD
+0xBDC6	0x9283
+0xBDC7	0x53D4
+0xBDC8	0x5919
+0xBDC9	0x5BBF
+0xBDCA	0x6DD1
+0xBDCB	0x795D
+0xBDCC	0x7E2E
+0xBDCD	0x7C9B
+0xBDCE	0x587E
+0xBDCF	0x719F
+0xBDD0	0x51FA
+0xBDD1	0x8853
+0xBDD2	0x8FF0
+0xBDD3	0x4FCA
+0xBDD4	0x5CFB
+0xBDD5	0x6625
+0xBDD6	0x77AC
+0xBDD7	0x7AE3
+0xBDD8	0x821C
+0xBDD9	0x99FF
+0xBDDA	0x51C6
+0xBDDB	0x5FAA
+0xBDDC	0x65EC
+0xBDDD	0x696F
+0xBDDE	0x6B89
+0xBDDF	0x6DF3
+0xBDE0	0x6E96
+0xBDE1	0x6F64
+0xBDE2	0x76FE
+0xBDE3	0x7D14
+0xBDE4	0x5DE1
+0xBDE5	0x9075
+0xBDE6	0x9187
+0xBDE7	0x9806
+0xBDE8	0x51E6
+0xBDE9	0x521D
+0xBDEA	0x6240
+0xBDEB	0x6691
+0xBDEC	0x66D9
+0xBDED	0x6E1A
+0xBDEE	0x5EB6
+0xBDEF	0x7DD2
+0xBDF0	0x7F72
+0xBDF1	0x66F8
+0xBDF2	0x85AF
+0xBDF3	0x85F7
+0xBDF4	0x8AF8
+0xBDF5	0x52A9
+0xBDF6	0x53D9
+0xBDF7	0x5973
+0xBDF8	0x5E8F
+0xBDF9	0x5F90
+0xBDFA	0x6055
+0xBDFB	0x92E4
+0xBDFC	0x9664
+0xBDFD	0x50B7
+0xBDFE	0x511F
+0xBEA1	0x52DD
+0xBEA2	0x5320
+0xBEA3	0x5347
+0xBEA4	0x53EC
+0xBEA5	0x54E8
+0xBEA6	0x5546
+0xBEA7	0x5531
+0xBEA8	0x5617
+0xBEA9	0x5968
+0xBEAA	0x59BE
+0xBEAB	0x5A3C
+0xBEAC	0x5BB5
+0xBEAD	0x5C06
+0xBEAE	0x5C0F
+0xBEAF	0x5C11
+0xBEB0	0x5C1A
+0xBEB1	0x5E84
+0xBEB2	0x5E8A
+0xBEB3	0x5EE0
+0xBEB4	0x5F70
+0xBEB5	0x627F
+0xBEB6	0x6284
+0xBEB7	0x62DB
+0xBEB8	0x638C
+0xBEB9	0x6377
+0xBEBA	0x6607
+0xBEBB	0x660C
+0xBEBC	0x662D
+0xBEBD	0x6676
+0xBEBE	0x677E
+0xBEBF	0x68A2
+0xBEC0	0x6A1F
+0xBEC1	0x6A35
+0xBEC2	0x6CBC
+0xBEC3	0x6D88
+0xBEC4	0x6E09
+0xBEC5	0x6E58
+0xBEC6	0x713C
+0xBEC7	0x7126
+0xBEC8	0x7167
+0xBEC9	0x75C7
+0xBECA	0x7701
+0xBECB	0x785D
+0xBECC	0x7901
+0xBECD	0x7965
+0xBECE	0x79F0
+0xBECF	0x7AE0
+0xBED0	0x7B11
+0xBED1	0x7CA7
+0xBED2	0x7D39
+0xBED3	0x8096
+0xBED4	0x83D6
+0xBED5	0x848B
+0xBED6	0x8549
+0xBED7	0x885D
+0xBED8	0x88F3
+0xBED9	0x8A1F
+0xBEDA	0x8A3C
+0xBEDB	0x8A54
+0xBEDC	0x8A73
+0xBEDD	0x8C61
+0xBEDE	0x8CDE
+0xBEDF	0x91A4
+0xBEE0	0x9266
+0xBEE1	0x937E
+0xBEE2	0x9418
+0xBEE3	0x969C
+0xBEE4	0x9798
+0xBEE5	0x4E0A
+0xBEE6	0x4E08
+0xBEE7	0x4E1E
+0xBEE8	0x4E57
+0xBEE9	0x5197
+0xBEEA	0x5270
+0xBEEB	0x57CE
+0xBEEC	0x5834
+0xBEED	0x58CC
+0xBEEE	0x5B22
+0xBEEF	0x5E38
+0xBEF0	0x60C5
+0xBEF1	0x64FE
+0xBEF2	0x6761
+0xBEF3	0x6756
+0xBEF4	0x6D44
+0xBEF5	0x72B6
+0xBEF6	0x7573
+0xBEF7	0x7A63
+0xBEF8	0x84B8
+0xBEF9	0x8B72
+0xBEFA	0x91B8
+0xBEFB	0x9320
+0xBEFC	0x5631
+0xBEFD	0x57F4
+0xBEFE	0x98FE
+0xBFA1	0x62ED
+0xBFA2	0x690D
+0xBFA3	0x6B96
+0xBFA4	0x71ED
+0xBFA5	0x7E54
+0xBFA6	0x8077
+0xBFA7	0x8272
+0xBFA8	0x89E6
+0xBFA9	0x98DF
+0xBFAA	0x8755
+0xBFAB	0x8FB1
+0xBFAC	0x5C3B
+0xBFAD	0x4F38
+0xBFAE	0x4FE1
+0xBFAF	0x4FB5
+0xBFB0	0x5507
+0xBFB1	0x5A20
+0xBFB2	0x5BDD
+0xBFB3	0x5BE9
+0xBFB4	0x5FC3
+0xBFB5	0x614E
+0xBFB6	0x632F
+0xBFB7	0x65B0
+0xBFB8	0x664B
+0xBFB9	0x68EE
+0xBFBA	0x699B
+0xBFBB	0x6D78
+0xBFBC	0x6DF1
+0xBFBD	0x7533
+0xBFBE	0x75B9
+0xBFBF	0x771F
+0xBFC0	0x795E
+0xBFC1	0x79E6
+0xBFC2	0x7D33
+0xBFC3	0x81E3
+0xBFC4	0x82AF
+0xBFC5	0x85AA
+0xBFC6	0x89AA
+0xBFC7	0x8A3A
+0xBFC8	0x8EAB
+0xBFC9	0x8F9B
+0xBFCA	0x9032
+0xBFCB	0x91DD
+0xBFCC	0x9707
+0xBFCD	0x4EBA
+0xBFCE	0x4EC1
+0xBFCF	0x5203
+0xBFD0	0x5875
+0xBFD1	0x58EC
+0xBFD2	0x5C0B
+0xBFD3	0x751A
+0xBFD4	0x5C3D
+0xBFD5	0x814E
+0xBFD6	0x8A0A
+0xBFD7	0x8FC5
+0xBFD8	0x9663
+0xBFD9	0x976D
+0xBFDA	0x7B25
+0xBFDB	0x8ACF
+0xBFDC	0x9808
+0xBFDD	0x9162
+0xBFDE	0x56F3
+0xBFDF	0x53A8
+0xBFE0	0x9017
+0xBFE1	0x5439
+0xBFE2	0x5782
+0xBFE3	0x5E25
+0xBFE4	0x63A8
+0xBFE5	0x6C34
+0xBFE6	0x708A
+0xBFE7	0x7761
+0xBFE8	0x7C8B
+0xBFE9	0x7FE0
+0xBFEA	0x8870
+0xBFEB	0x9042
+0xBFEC	0x9154
+0xBFED	0x9310
+0xBFEE	0x9318
+0xBFEF	0x968F
+0xBFF0	0x745E
+0xBFF1	0x9AC4
+0xBFF2	0x5D07
+0xBFF3	0x5D69
+0xBFF4	0x6570
+0xBFF5	0x67A2
+0xBFF6	0x8DA8
+0xBFF7	0x96DB
+0xBFF8	0x636E
+0xBFF9	0x6749
+0xBFFA	0x6919
+0xBFFB	0x83C5
+0xBFFC	0x9817
+0xBFFD	0x96C0
+0xBFFE	0x88FE
+0xC0A1	0x6F84
+0xC0A2	0x647A
+0xC0A3	0x5BF8
+0xC0A4	0x4E16
+0xC0A5	0x702C
+0xC0A6	0x755D
+0xC0A7	0x662F
+0xC0A8	0x51C4
+0xC0A9	0x5236
+0xC0AA	0x52E2
+0xC0AB	0x59D3
+0xC0AC	0x5F81
+0xC0AD	0x6027
+0xC0AE	0x6210
+0xC0AF	0x653F
+0xC0B0	0x6574
+0xC0B1	0x661F
+0xC0B2	0x6674
+0xC0B3	0x68F2
+0xC0B4	0x6816
+0xC0B5	0x6B63
+0xC0B6	0x6E05
+0xC0B7	0x7272
+0xC0B8	0x751F
+0xC0B9	0x76DB
+0xC0BA	0x7CBE
+0xC0BB	0x8056
+0xC0BC	0x58F0
+0xC0BD	0x88FD
+0xC0BE	0x897F
+0xC0BF	0x8AA0
+0xC0C0	0x8A93
+0xC0C1	0x8ACB
+0xC0C2	0x901D
+0xC0C3	0x9192
+0xC0C4	0x9752
+0xC0C5	0x9759
+0xC0C6	0x6589
+0xC0C7	0x7A0E
+0xC0C8	0x8106
+0xC0C9	0x96BB
+0xC0CA	0x5E2D
+0xC0CB	0x60DC
+0xC0CC	0x621A
+0xC0CD	0x65A5
+0xC0CE	0x6614
+0xC0CF	0x6790
+0xC0D0	0x77F3
+0xC0D1	0x7A4D
+0xC0D2	0x7C4D
+0xC0D3	0x7E3E
+0xC0D4	0x810A
+0xC0D5	0x8CAC
+0xC0D6	0x8D64
+0xC0D7	0x8DE1
+0xC0D8	0x8E5F
+0xC0D9	0x78A9
+0xC0DA	0x5207
+0xC0DB	0x62D9
+0xC0DC	0x63A5
+0xC0DD	0x6442
+0xC0DE	0x6298
+0xC0DF	0x8A2D
+0xC0E0	0x7A83
+0xC0E1	0x7BC0
+0xC0E2	0x8AAC
+0xC0E3	0x96EA
+0xC0E4	0x7D76
+0xC0E5	0x820C
+0xC0E6	0x8749
+0xC0E7	0x4ED9
+0xC0E8	0x5148
+0xC0E9	0x5343
+0xC0EA	0x5360
+0xC0EB	0x5BA3
+0xC0EC	0x5C02
+0xC0ED	0x5C16
+0xC0EE	0x5DDD
+0xC0EF	0x6226
+0xC0F0	0x6247
+0xC0F1	0x64B0
+0xC0F2	0x6813
+0xC0F3	0x6834
+0xC0F4	0x6CC9
+0xC0F5	0x6D45
+0xC0F6	0x6D17
+0xC0F7	0x67D3
+0xC0F8	0x6F5C
+0xC0F9	0x714E
+0xC0FA	0x717D
+0xC0FB	0x65CB
+0xC0FC	0x7A7F
+0xC0FD	0x7BAD
+0xC0FE	0x7DDA
+0xC1A1	0x7E4A
+0xC1A2	0x7FA8
+0xC1A3	0x817A
+0xC1A4	0x821B
+0xC1A5	0x8239
+0xC1A6	0x85A6
+0xC1A7	0x8A6E
+0xC1A8	0x8CCE
+0xC1A9	0x8DF5
+0xC1AA	0x9078
+0xC1AB	0x9077
+0xC1AC	0x92AD
+0xC1AD	0x9291
+0xC1AE	0x9583
+0xC1AF	0x9BAE
+0xC1B0	0x524D
+0xC1B1	0x5584
+0xC1B2	0x6F38
+0xC1B3	0x7136
+0xC1B4	0x5168
+0xC1B5	0x7985
+0xC1B6	0x7E55
+0xC1B7	0x81B3
+0xC1B8	0x7CCE
+0xC1B9	0x564C
+0xC1BA	0x5851
+0xC1BB	0x5CA8
+0xC1BC	0x63AA
+0xC1BD	0x66FE
+0xC1BE	0x66FD
+0xC1BF	0x695A
+0xC1C0	0x72D9
+0xC1C1	0x758F
+0xC1C2	0x758E
+0xC1C3	0x790E
+0xC1C4	0x7956
+0xC1C5	0x79DF
+0xC1C6	0x7C97
+0xC1C7	0x7D20
+0xC1C8	0x7D44
+0xC1C9	0x8607
+0xC1CA	0x8A34
+0xC1CB	0x963B
+0xC1CC	0x9061
+0xC1CD	0x9F20
+0xC1CE	0x50E7
+0xC1CF	0x5275
+0xC1D0	0x53CC
+0xC1D1	0x53E2
+0xC1D2	0x5009
+0xC1D3	0x55AA
+0xC1D4	0x58EE
+0xC1D5	0x594F
+0xC1D6	0x723D
+0xC1D7	0x5B8B
+0xC1D8	0x5C64
+0xC1D9	0x531D
+0xC1DA	0x60E3
+0xC1DB	0x60F3
+0xC1DC	0x635C
+0xC1DD	0x6383
+0xC1DE	0x633F
+0xC1DF	0x63BB
+0xC1E0	0x64CD
+0xC1E1	0x65E9
+0xC1E2	0x66F9
+0xC1E3	0x5DE3
+0xC1E4	0x69CD
+0xC1E5	0x69FD
+0xC1E6	0x6F15
+0xC1E7	0x71E5
+0xC1E8	0x4E89
+0xC1E9	0x75E9
+0xC1EA	0x76F8
+0xC1EB	0x7A93
+0xC1EC	0x7CDF
+0xC1ED	0x7DCF
+0xC1EE	0x7D9C
+0xC1EF	0x8061
+0xC1F0	0x8349
+0xC1F1	0x8358
+0xC1F2	0x846C
+0xC1F3	0x84BC
+0xC1F4	0x85FB
+0xC1F5	0x88C5
+0xC1F6	0x8D70
+0xC1F7	0x9001
+0xC1F8	0x906D
+0xC1F9	0x9397
+0xC1FA	0x971C
+0xC1FB	0x9A12
+0xC1FC	0x50CF
+0xC1FD	0x5897
+0xC1FE	0x618E
+0xC2A1	0x81D3
+0xC2A2	0x8535
+0xC2A3	0x8D08
+0xC2A4	0x9020
+0xC2A5	0x4FC3
+0xC2A6	0x5074
+0xC2A7	0x5247
+0xC2A8	0x5373
+0xC2A9	0x606F
+0xC2AA	0x6349
+0xC2AB	0x675F
+0xC2AC	0x6E2C
+0xC2AD	0x8DB3
+0xC2AE	0x901F
+0xC2AF	0x4FD7
+0xC2B0	0x5C5E
+0xC2B1	0x8CCA
+0xC2B2	0x65CF
+0xC2B3	0x7D9A
+0xC2B4	0x5352
+0xC2B5	0x8896
+0xC2B6	0x5176
+0xC2B7	0x63C3
+0xC2B8	0x5B58
+0xC2B9	0x5B6B
+0xC2BA	0x5C0A
+0xC2BB	0x640D
+0xC2BC	0x6751
+0xC2BD	0x905C
+0xC2BE	0x4ED6
+0xC2BF	0x591A
+0xC2C0	0x592A
+0xC2C1	0x6C70
+0xC2C2	0x8A51
+0xC2C3	0x553E
+0xC2C4	0x5815
+0xC2C5	0x59A5
+0xC2C6	0x60F0
+0xC2C7	0x6253
+0xC2C8	0x67C1
+0xC2C9	0x8235
+0xC2CA	0x6955
+0xC2CB	0x9640
+0xC2CC	0x99C4
+0xC2CD	0x9A28
+0xC2CE	0x4F53
+0xC2CF	0x5806
+0xC2D0	0x5BFE
+0xC2D1	0x8010
+0xC2D2	0x5CB1
+0xC2D3	0x5E2F
+0xC2D4	0x5F85
+0xC2D5	0x6020
+0xC2D6	0x614B
+0xC2D7	0x6234
+0xC2D8	0x66FF
+0xC2D9	0x6CF0
+0xC2DA	0x6EDE
+0xC2DB	0x80CE
+0xC2DC	0x817F
+0xC2DD	0x82D4
+0xC2DE	0x888B
+0xC2DF	0x8CB8
+0xC2E0	0x9000
+0xC2E1	0x902E
+0xC2E2	0x968A
+0xC2E3	0x9EDB
+0xC2E4	0x9BDB
+0xC2E5	0x4EE3
+0xC2E6	0x53F0
+0xC2E7	0x5927
+0xC2E8	0x7B2C
+0xC2E9	0x918D
+0xC2EA	0x984C
+0xC2EB	0x9DF9
+0xC2EC	0x6EDD
+0xC2ED	0x7027
+0xC2EE	0x5353
+0xC2EF	0x5544
+0xC2F0	0x5B85
+0xC2F1	0x6258
+0xC2F2	0x629E
+0xC2F3	0x62D3
+0xC2F4	0x6CA2
+0xC2F5	0x6FEF
+0xC2F6	0x7422
+0xC2F7	0x8A17
+0xC2F8	0x9438
+0xC2F9	0x6FC1
+0xC2FA	0x8AFE
+0xC2FB	0x8338
+0xC2FC	0x51E7
+0xC2FD	0x86F8
+0xC2FE	0x53EA
+0xC3A1	0x53E9
+0xC3A2	0x4F46
+0xC3A3	0x9054
+0xC3A4	0x8FB0
+0xC3A5	0x596A
+0xC3A6	0x8131
+0xC3A7	0x5DFD
+0xC3A8	0x7AEA
+0xC3A9	0x8FBF
+0xC3AA	0x68DA
+0xC3AB	0x8C37
+0xC3AC	0x72F8
+0xC3AD	0x9C48
+0xC3AE	0x6A3D
+0xC3AF	0x8AB0
+0xC3B0	0x4E39
+0xC3B1	0x5358
+0xC3B2	0x5606
+0xC3B3	0x5766
+0xC3B4	0x62C5
+0xC3B5	0x63A2
+0xC3B6	0x65E6
+0xC3B7	0x6B4E
+0xC3B8	0x6DE1
+0xC3B9	0x6E5B
+0xC3BA	0x70AD
+0xC3BB	0x77ED
+0xC3BC	0x7AEF
+0xC3BD	0x7BAA
+0xC3BE	0x7DBB
+0xC3BF	0x803D
+0xC3C0	0x80C6
+0xC3C1	0x86CB
+0xC3C2	0x8A95
+0xC3C3	0x935B
+0xC3C4	0x56E3
+0xC3C5	0x58C7
+0xC3C6	0x5F3E
+0xC3C7	0x65AD
+0xC3C8	0x6696
+0xC3C9	0x6A80
+0xC3CA	0x6BB5
+0xC3CB	0x7537
+0xC3CC	0x8AC7
+0xC3CD	0x5024
+0xC3CE	0x77E5
+0xC3CF	0x5730
+0xC3D0	0x5F1B
+0xC3D1	0x6065
+0xC3D2	0x667A
+0xC3D3	0x6C60
+0xC3D4	0x75F4
+0xC3D5	0x7A1A
+0xC3D6	0x7F6E
+0xC3D7	0x81F4
+0xC3D8	0x8718
+0xC3D9	0x9045
+0xC3DA	0x99B3
+0xC3DB	0x7BC9
+0xC3DC	0x755C
+0xC3DD	0x7AF9
+0xC3DE	0x7B51
+0xC3DF	0x84C4
+0xC3E0	0x9010
+0xC3E1	0x79E9
+0xC3E2	0x7A92
+0xC3E3	0x8336
+0xC3E4	0x5AE1
+0xC3E5	0x7740
+0xC3E6	0x4E2D
+0xC3E7	0x4EF2
+0xC3E8	0x5B99
+0xC3E9	0x5FE0
+0xC3EA	0x62BD
+0xC3EB	0x663C
+0xC3EC	0x67F1
+0xC3ED	0x6CE8
+0xC3EE	0x866B
+0xC3EF	0x8877
+0xC3F0	0x8A3B
+0xC3F1	0x914E
+0xC3F2	0x92F3
+0xC3F3	0x99D0
+0xC3F4	0x6A17
+0xC3F5	0x7026
+0xC3F6	0x732A
+0xC3F7	0x82E7
+0xC3F8	0x8457
+0xC3F9	0x8CAF
+0xC3FA	0x4E01
+0xC3FB	0x5146
+0xC3FC	0x51CB
+0xC3FD	0x558B
+0xC3FE	0x5BF5
+0xC4A1	0x5E16
+0xC4A2	0x5E33
+0xC4A3	0x5E81
+0xC4A4	0x5F14
+0xC4A5	0x5F35
+0xC4A6	0x5F6B
+0xC4A7	0x5FB4
+0xC4A8	0x61F2
+0xC4A9	0x6311
+0xC4AA	0x66A2
+0xC4AB	0x671D
+0xC4AC	0x6F6E
+0xC4AD	0x7252
+0xC4AE	0x753A
+0xC4AF	0x773A
+0xC4B0	0x8074
+0xC4B1	0x8139
+0xC4B2	0x8178
+0xC4B3	0x8776
+0xC4B4	0x8ABF
+0xC4B5	0x8ADC
+0xC4B6	0x8D85
+0xC4B7	0x8DF3
+0xC4B8	0x929A
+0xC4B9	0x9577
+0xC4BA	0x9802
+0xC4BB	0x9CE5
+0xC4BC	0x52C5
+0xC4BD	0x6357
+0xC4BE	0x76F4
+0xC4BF	0x6715
+0xC4C0	0x6C88
+0xC4C1	0x73CD
+0xC4C2	0x8CC3
+0xC4C3	0x93AE
+0xC4C4	0x9673
+0xC4C5	0x6D25
+0xC4C6	0x589C
+0xC4C7	0x690E
+0xC4C8	0x69CC
+0xC4C9	0x8FFD
+0xC4CA	0x939A
+0xC4CB	0x75DB
+0xC4CC	0x901A
+0xC4CD	0x585A
+0xC4CE	0x6802
+0xC4CF	0x63B4
+0xC4D0	0x69FB
+0xC4D1	0x4F43
+0xC4D2	0x6F2C
+0xC4D3	0x67D8
+0xC4D4	0x8FBB
+0xC4D5	0x8526
+0xC4D6	0x7DB4
+0xC4D7	0x9354
+0xC4D8	0x693F
+0xC4D9	0x6F70
+0xC4DA	0x576A
+0xC4DB	0x58F7
+0xC4DC	0x5B2C
+0xC4DD	0x7D2C
+0xC4DE	0x722A
+0xC4DF	0x540A
+0xC4E0	0x91E3
+0xC4E1	0x9DB4
+0xC4E2	0x4EAD
+0xC4E3	0x4F4E
+0xC4E4	0x505C
+0xC4E5	0x5075
+0xC4E6	0x5243
+0xC4E7	0x8C9E
+0xC4E8	0x5448
+0xC4E9	0x5824
+0xC4EA	0x5B9A
+0xC4EB	0x5E1D
+0xC4EC	0x5E95
+0xC4ED	0x5EAD
+0xC4EE	0x5EF7
+0xC4EF	0x5F1F
+0xC4F0	0x608C
+0xC4F1	0x62B5
+0xC4F2	0x633A
+0xC4F3	0x63D0
+0xC4F4	0x68AF
+0xC4F5	0x6C40
+0xC4F6	0x7887
+0xC4F7	0x798E
+0xC4F8	0x7A0B
+0xC4F9	0x7DE0
+0xC4FA	0x8247
+0xC4FB	0x8A02
+0xC4FC	0x8AE6
+0xC4FD	0x8E44
+0xC4FE	0x9013
+0xC5A1	0x90B8
+0xC5A2	0x912D
+0xC5A3	0x91D8
+0xC5A4	0x9F0E
+0xC5A5	0x6CE5
+0xC5A6	0x6458
+0xC5A7	0x64E2
+0xC5A8	0x6575
+0xC5A9	0x6EF4
+0xC5AA	0x7684
+0xC5AB	0x7B1B
+0xC5AC	0x9069
+0xC5AD	0x93D1
+0xC5AE	0x6EBA
+0xC5AF	0x54F2
+0xC5B0	0x5FB9
+0xC5B1	0x64A4
+0xC5B2	0x8F4D
+0xC5B3	0x8FED
+0xC5B4	0x9244
+0xC5B5	0x5178
+0xC5B6	0x586B
+0xC5B7	0x5929
+0xC5B8	0x5C55
+0xC5B9	0x5E97
+0xC5BA	0x6DFB
+0xC5BB	0x7E8F
+0xC5BC	0x751C
+0xC5BD	0x8CBC
+0xC5BE	0x8EE2
+0xC5BF	0x985B
+0xC5C0	0x70B9
+0xC5C1	0x4F1D
+0xC5C2	0x6BBF
+0xC5C3	0x6FB1
+0xC5C4	0x7530
+0xC5C5	0x96FB
+0xC5C6	0x514E
+0xC5C7	0x5410
+0xC5C8	0x5835
+0xC5C9	0x5857
+0xC5CA	0x59AC
+0xC5CB	0x5C60
+0xC5CC	0x5F92
+0xC5CD	0x6597
+0xC5CE	0x675C
+0xC5CF	0x6E21
+0xC5D0	0x767B
+0xC5D1	0x83DF
+0xC5D2	0x8CED
+0xC5D3	0x9014
+0xC5D4	0x90FD
+0xC5D5	0x934D
+0xC5D6	0x7825
+0xC5D7	0x783A
+0xC5D8	0x52AA
+0xC5D9	0x5EA6
+0xC5DA	0x571F
+0xC5DB	0x5974
+0xC5DC	0x6012
+0xC5DD	0x5012
+0xC5DE	0x515A
+0xC5DF	0x51AC
+0xC5E0	0x51CD
+0xC5E1	0x5200
+0xC5E2	0x5510
+0xC5E3	0x5854
+0xC5E4	0x5858
+0xC5E5	0x5957
+0xC5E6	0x5B95
+0xC5E7	0x5CF6
+0xC5E8	0x5D8B
+0xC5E9	0x60BC
+0xC5EA	0x6295
+0xC5EB	0x642D
+0xC5EC	0x6771
+0xC5ED	0x6843
+0xC5EE	0x68BC
+0xC5EF	0x68DF
+0xC5F0	0x76D7
+0xC5F1	0x6DD8
+0xC5F2	0x6E6F
+0xC5F3	0x6D9B
+0xC5F4	0x706F
+0xC5F5	0x71C8
+0xC5F6	0x5F53
+0xC5F7	0x75D8
+0xC5F8	0x7977
+0xC5F9	0x7B49
+0xC5FA	0x7B54
+0xC5FB	0x7B52
+0xC5FC	0x7CD6
+0xC5FD	0x7D71
+0xC5FE	0x5230
+0xC6A1	0x8463
+0xC6A2	0x8569
+0xC6A3	0x85E4
+0xC6A4	0x8A0E
+0xC6A5	0x8B04
+0xC6A6	0x8C46
+0xC6A7	0x8E0F
+0xC6A8	0x9003
+0xC6A9	0x900F
+0xC6AA	0x9419
+0xC6AB	0x9676
+0xC6AC	0x982D
+0xC6AD	0x9A30
+0xC6AE	0x95D8
+0xC6AF	0x50CD
+0xC6B0	0x52D5
+0xC6B1	0x540C
+0xC6B2	0x5802
+0xC6B3	0x5C0E
+0xC6B4	0x61A7
+0xC6B5	0x649E
+0xC6B6	0x6D1E
+0xC6B7	0x77B3
+0xC6B8	0x7AE5
+0xC6B9	0x80F4
+0xC6BA	0x8404
+0xC6BB	0x9053
+0xC6BC	0x9285
+0xC6BD	0x5CE0
+0xC6BE	0x9D07
+0xC6BF	0x533F
+0xC6C0	0x5F97
+0xC6C1	0x5FB3
+0xC6C2	0x6D9C
+0xC6C3	0x7279
+0xC6C4	0x7763
+0xC6C5	0x79BF
+0xC6C6	0x7BE4
+0xC6C7	0x6BD2
+0xC6C8	0x72EC
+0xC6C9	0x8AAD
+0xC6CA	0x6803
+0xC6CB	0x6A61
+0xC6CC	0x51F8
+0xC6CD	0x7A81
+0xC6CE	0x6934
+0xC6CF	0x5C4A
+0xC6D0	0x9CF6
+0xC6D1	0x82EB
+0xC6D2	0x5BC5
+0xC6D3	0x9149
+0xC6D4	0x701E
+0xC6D5	0x5678
+0xC6D6	0x5C6F
+0xC6D7	0x60C7
+0xC6D8	0x6566
+0xC6D9	0x6C8C
+0xC6DA	0x8C5A
+0xC6DB	0x9041
+0xC6DC	0x9813
+0xC6DD	0x5451
+0xC6DE	0x66C7
+0xC6DF	0x920D
+0xC6E0	0x5948
+0xC6E1	0x90A3
+0xC6E2	0x5185
+0xC6E3	0x4E4D
+0xC6E4	0x51EA
+0xC6E5	0x8599
+0xC6E6	0x8B0E
+0xC6E7	0x7058
+0xC6E8	0x637A
+0xC6E9	0x934B
+0xC6EA	0x6962
+0xC6EB	0x99B4
+0xC6EC	0x7E04
+0xC6ED	0x7577
+0xC6EE	0x5357
+0xC6EF	0x6960
+0xC6F0	0x8EDF
+0xC6F1	0x96E3
+0xC6F2	0x6C5D
+0xC6F3	0x4E8C
+0xC6F4	0x5C3C
+0xC6F5	0x5F10
+0xC6F6	0x8FE9
+0xC6F7	0x5302
+0xC6F8	0x8CD1
+0xC6F9	0x8089
+0xC6FA	0x8679
+0xC6FB	0x5EFF
+0xC6FC	0x65E5
+0xC6FD	0x4E73
+0xC6FE	0x5165
+0xC7A1	0x5982
+0xC7A2	0x5C3F
+0xC7A3	0x97EE
+0xC7A4	0x4EFB
+0xC7A5	0x598A
+0xC7A6	0x5FCD
+0xC7A7	0x8A8D
+0xC7A8	0x6FE1
+0xC7A9	0x79B0
+0xC7AA	0x7962
+0xC7AB	0x5BE7
+0xC7AC	0x8471
+0xC7AD	0x732B
+0xC7AE	0x71B1
+0xC7AF	0x5E74
+0xC7B0	0x5FF5
+0xC7B1	0x637B
+0xC7B2	0x649A
+0xC7B3	0x71C3
+0xC7B4	0x7C98
+0xC7B5	0x4E43
+0xC7B6	0x5EFC
+0xC7B7	0x4E4B
+0xC7B8	0x57DC
+0xC7B9	0x56A2
+0xC7BA	0x60A9
+0xC7BB	0x6FC3
+0xC7BC	0x7D0D
+0xC7BD	0x80FD
+0xC7BE	0x8133
+0xC7BF	0x81BF
+0xC7C0	0x8FB2
+0xC7C1	0x8997
+0xC7C2	0x86A4
+0xC7C3	0x5DF4
+0xC7C4	0x628A
+0xC7C5	0x64AD
+0xC7C6	0x8987
+0xC7C7	0x6777
+0xC7C8	0x6CE2
+0xC7C9	0x6D3E
+0xC7CA	0x7436
+0xC7CB	0x7834
+0xC7CC	0x5A46
+0xC7CD	0x7F75
+0xC7CE	0x82AD
+0xC7CF	0x99AC
+0xC7D0	0x4FF3
+0xC7D1	0x5EC3
+0xC7D2	0x62DD
+0xC7D3	0x6392
+0xC7D4	0x6557
+0xC7D5	0x676F
+0xC7D6	0x76C3
+0xC7D7	0x724C
+0xC7D8	0x80CC
+0xC7D9	0x80BA
+0xC7DA	0x8F29
+0xC7DB	0x914D
+0xC7DC	0x500D
+0xC7DD	0x57F9
+0xC7DE	0x5A92
+0xC7DF	0x6885
+0xC7E0	0x6973
+0xC7E1	0x7164
+0xC7E2	0x72FD
+0xC7E3	0x8CB7
+0xC7E4	0x58F2
+0xC7E5	0x8CE0
+0xC7E6	0x966A
+0xC7E7	0x9019
+0xC7E8	0x877F
+0xC7E9	0x79E4
+0xC7EA	0x77E7
+0xC7EB	0x8429
+0xC7EC	0x4F2F
+0xC7ED	0x5265
+0xC7EE	0x535A
+0xC7EF	0x62CD
+0xC7F0	0x67CF
+0xC7F1	0x6CCA
+0xC7F2	0x767D
+0xC7F3	0x7B94
+0xC7F4	0x7C95
+0xC7F5	0x8236
+0xC7F6	0x8584
+0xC7F7	0x8FEB
+0xC7F8	0x66DD
+0xC7F9	0x6F20
+0xC7FA	0x7206
+0xC7FB	0x7E1B
+0xC7FC	0x83AB
+0xC7FD	0x99C1
+0xC7FE	0x9EA6
+0xC8A1	0x51FD
+0xC8A2	0x7BB1
+0xC8A3	0x7872
+0xC8A4	0x7BB8
+0xC8A5	0x8087
+0xC8A6	0x7B48
+0xC8A7	0x6AE8
+0xC8A8	0x5E61
+0xC8A9	0x808C
+0xC8AA	0x7551
+0xC8AB	0x7560
+0xC8AC	0x516B
+0xC8AD	0x9262
+0xC8AE	0x6E8C
+0xC8AF	0x767A
+0xC8B0	0x9197
+0xC8B1	0x9AEA
+0xC8B2	0x4F10
+0xC8B3	0x7F70
+0xC8B4	0x629C
+0xC8B5	0x7B4F
+0xC8B6	0x95A5
+0xC8B7	0x9CE9
+0xC8B8	0x567A
+0xC8B9	0x5859
+0xC8BA	0x86E4
+0xC8BB	0x96BC
+0xC8BC	0x4F34
+0xC8BD	0x5224
+0xC8BE	0x534A
+0xC8BF	0x53CD
+0xC8C0	0x53DB
+0xC8C1	0x5E06
+0xC8C2	0x642C
+0xC8C3	0x6591
+0xC8C4	0x677F
+0xC8C5	0x6C3E
+0xC8C6	0x6C4E
+0xC8C7	0x7248
+0xC8C8	0x72AF
+0xC8C9	0x73ED
+0xC8CA	0x7554
+0xC8CB	0x7E41
+0xC8CC	0x822C
+0xC8CD	0x85E9
+0xC8CE	0x8CA9
+0xC8CF	0x7BC4
+0xC8D0	0x91C6
+0xC8D1	0x7169
+0xC8D2	0x9812
+0xC8D3	0x98EF
+0xC8D4	0x633D
+0xC8D5	0x6669
+0xC8D6	0x756A
+0xC8D7	0x76E4
+0xC8D8	0x78D0
+0xC8D9	0x8543
+0xC8DA	0x86EE
+0xC8DB	0x532A
+0xC8DC	0x5351
+0xC8DD	0x5426
+0xC8DE	0x5983
+0xC8DF	0x5E87
+0xC8E0	0x5F7C
+0xC8E1	0x60B2
+0xC8E2	0x6249
+0xC8E3	0x6279
+0xC8E4	0x62AB
+0xC8E5	0x6590
+0xC8E6	0x6BD4
+0xC8E7	0x6CCC
+0xC8E8	0x75B2
+0xC8E9	0x76AE
+0xC8EA	0x7891
+0xC8EB	0x79D8
+0xC8EC	0x7DCB
+0xC8ED	0x7F77
+0xC8EE	0x80A5
+0xC8EF	0x88AB
+0xC8F0	0x8AB9
+0xC8F1	0x8CBB
+0xC8F2	0x907F
+0xC8F3	0x975E
+0xC8F4	0x98DB
+0xC8F5	0x6A0B
+0xC8F6	0x7C38
+0xC8F7	0x5099
+0xC8F8	0x5C3E
+0xC8F9	0x5FAE
+0xC8FA	0x6787
+0xC8FB	0x6BD8
+0xC8FC	0x7435
+0xC8FD	0x7709
+0xC8FE	0x7F8E
+0xC9A1	0x9F3B
+0xC9A2	0x67CA
+0xC9A3	0x7A17
+0xC9A4	0x5339
+0xC9A5	0x758B
+0xC9A6	0x9AED
+0xC9A7	0x5F66
+0xC9A8	0x819D
+0xC9A9	0x83F1
+0xC9AA	0x8098
+0xC9AB	0x5F3C
+0xC9AC	0x5FC5
+0xC9AD	0x7562
+0xC9AE	0x7B46
+0xC9AF	0x903C
+0xC9B0	0x6867
+0xC9B1	0x59EB
+0xC9B2	0x5A9B
+0xC9B3	0x7D10
+0xC9B4	0x767E
+0xC9B5	0x8B2C
+0xC9B6	0x4FF5
+0xC9B7	0x5F6A
+0xC9B8	0x6A19
+0xC9B9	0x6C37
+0xC9BA	0x6F02
+0xC9BB	0x74E2
+0xC9BC	0x7968
+0xC9BD	0x8868
+0xC9BE	0x8A55
+0xC9BF	0x8C79
+0xC9C0	0x5EDF
+0xC9C1	0x63CF
+0xC9C2	0x75C5
+0xC9C3	0x79D2
+0xC9C4	0x82D7
+0xC9C5	0x9328
+0xC9C6	0x92F2
+0xC9C7	0x849C
+0xC9C8	0x86ED
+0xC9C9	0x9C2D
+0xC9CA	0x54C1
+0xC9CB	0x5F6C
+0xC9CC	0x658C
+0xC9CD	0x6D5C
+0xC9CE	0x7015
+0xC9CF	0x8CA7
+0xC9D0	0x8CD3
+0xC9D1	0x983B
+0xC9D2	0x654F
+0xC9D3	0x74F6
+0xC9D4	0x4E0D
+0xC9D5	0x4ED8
+0xC9D6	0x57E0
+0xC9D7	0x592B
+0xC9D8	0x5A66
+0xC9D9	0x5BCC
+0xC9DA	0x51A8
+0xC9DB	0x5E03
+0xC9DC	0x5E9C
+0xC9DD	0x6016
+0xC9DE	0x6276
+0xC9DF	0x6577
+0xC9E0	0x65A7
+0xC9E1	0x666E
+0xC9E2	0x6D6E
+0xC9E3	0x7236
+0xC9E4	0x7B26
+0xC9E5	0x8150
+0xC9E6	0x819A
+0xC9E7	0x8299
+0xC9E8	0x8B5C
+0xC9E9	0x8CA0
+0xC9EA	0x8CE6
+0xC9EB	0x8D74
+0xC9EC	0x961C
+0xC9ED	0x9644
+0xC9EE	0x4FAE
+0xC9EF	0x64AB
+0xC9F0	0x6B66
+0xC9F1	0x821E
+0xC9F2	0x8461
+0xC9F3	0x856A
+0xC9F4	0x90E8
+0xC9F5	0x5C01
+0xC9F6	0x6953
+0xC9F7	0x98A8
+0xC9F8	0x847A
+0xC9F9	0x8557
+0xC9FA	0x4F0F
+0xC9FB	0x526F
+0xC9FC	0x5FA9
+0xC9FD	0x5E45
+0xC9FE	0x670D
+0xCAA1	0x798F
+0xCAA2	0x8179
+0xCAA3	0x8907
+0xCAA4	0x8986
+0xCAA5	0x6DF5
+0xCAA6	0x5F17
+0xCAA7	0x6255
+0xCAA8	0x6CB8
+0xCAA9	0x4ECF
+0xCAAA	0x7269
+0xCAAB	0x9B92
+0xCAAC	0x5206
+0xCAAD	0x543B
+0xCAAE	0x5674
+0xCAAF	0x58B3
+0xCAB0	0x61A4
+0xCAB1	0x626E
+0xCAB2	0x711A
+0xCAB3	0x596E
+0xCAB4	0x7C89
+0xCAB5	0x7CDE
+0xCAB6	0x7D1B
+0xCAB7	0x96F0
+0xCAB8	0x6587
+0xCAB9	0x805E
+0xCABA	0x4E19
+0xCABB	0x4F75
+0xCABC	0x5175
+0xCABD	0x5840
+0xCABE	0x5E63
+0xCABF	0x5E73
+0xCAC0	0x5F0A
+0xCAC1	0x67C4
+0xCAC2	0x4E26
+0xCAC3	0x853D
+0xCAC4	0x9589
+0xCAC5	0x965B
+0xCAC6	0x7C73
+0xCAC7	0x9801
+0xCAC8	0x50FB
+0xCAC9	0x58C1
+0xCACA	0x7656
+0xCACB	0x78A7
+0xCACC	0x5225
+0xCACD	0x77A5
+0xCACE	0x8511
+0xCACF	0x7B86
+0xCAD0	0x504F
+0xCAD1	0x5909
+0xCAD2	0x7247
+0xCAD3	0x7BC7
+0xCAD4	0x7DE8
+0xCAD5	0x8FBA
+0xCAD6	0x8FD4
+0xCAD7	0x904D
+0xCAD8	0x4FBF
+0xCAD9	0x52C9
+0xCADA	0x5A29
+0xCADB	0x5F01
+0xCADC	0x97AD
+0xCADD	0x4FDD
+0xCADE	0x8217
+0xCADF	0x92EA
+0xCAE0	0x5703
+0xCAE1	0x6355
+0xCAE2	0x6B69
+0xCAE3	0x752B
+0xCAE4	0x88DC
+0xCAE5	0x8F14
+0xCAE6	0x7A42
+0xCAE7	0x52DF
+0xCAE8	0x5893
+0xCAE9	0x6155
+0xCAEA	0x620A
+0xCAEB	0x66AE
+0xCAEC	0x6BCD
+0xCAED	0x7C3F
+0xCAEE	0x83E9
+0xCAEF	0x5023
+0xCAF0	0x4FF8
+0xCAF1	0x5305
+0xCAF2	0x5446
+0xCAF3	0x5831
+0xCAF4	0x5949
+0xCAF5	0x5B9D
+0xCAF6	0x5CF0
+0xCAF7	0x5CEF
+0xCAF8	0x5D29
+0xCAF9	0x5E96
+0xCAFA	0x62B1
+0xCAFB	0x6367
+0xCAFC	0x653E
+0xCAFD	0x65B9
+0xCAFE	0x670B
+0xCBA1	0x6CD5
+0xCBA2	0x6CE1
+0xCBA3	0x70F9
+0xCBA4	0x7832
+0xCBA5	0x7E2B
+0xCBA6	0x80DE
+0xCBA7	0x82B3
+0xCBA8	0x840C
+0xCBA9	0x84EC
+0xCBAA	0x8702
+0xCBAB	0x8912
+0xCBAC	0x8A2A
+0xCBAD	0x8C4A
+0xCBAE	0x90A6
+0xCBAF	0x92D2
+0xCBB0	0x98FD
+0xCBB1	0x9CF3
+0xCBB2	0x9D6C
+0xCBB3	0x4E4F
+0xCBB4	0x4EA1
+0xCBB5	0x508D
+0xCBB6	0x5256
+0xCBB7	0x574A
+0xCBB8	0x59A8
+0xCBB9	0x5E3D
+0xCBBA	0x5FD8
+0xCBBB	0x5FD9
+0xCBBC	0x623F
+0xCBBD	0x66B4
+0xCBBE	0x671B
+0xCBBF	0x67D0
+0xCBC0	0x68D2
+0xCBC1	0x5192
+0xCBC2	0x7D21
+0xCBC3	0x80AA
+0xCBC4	0x81A8
+0xCBC5	0x8B00
+0xCBC6	0x8C8C
+0xCBC7	0x8CBF
+0xCBC8	0x927E
+0xCBC9	0x9632
+0xCBCA	0x5420
+0xCBCB	0x982C
+0xCBCC	0x5317
+0xCBCD	0x50D5
+0xCBCE	0x535C
+0xCBCF	0x58A8
+0xCBD0	0x64B2
+0xCBD1	0x6734
+0xCBD2	0x7267
+0xCBD3	0x7766
+0xCBD4	0x7A46
+0xCBD5	0x91E6
+0xCBD6	0x52C3
+0xCBD7	0x6CA1
+0xCBD8	0x6B86
+0xCBD9	0x5800
+0xCBDA	0x5E4C
+0xCBDB	0x5954
+0xCBDC	0x672C
+0xCBDD	0x7FFB
+0xCBDE	0x51E1
+0xCBDF	0x76C6
+0xCBE0	0x6469
+0xCBE1	0x78E8
+0xCBE2	0x9B54
+0xCBE3	0x9EBB
+0xCBE4	0x57CB
+0xCBE5	0x59B9
+0xCBE6	0x6627
+0xCBE7	0x679A
+0xCBE8	0x6BCE
+0xCBE9	0x54E9
+0xCBEA	0x69D9
+0xCBEB	0x5E55
+0xCBEC	0x819C
+0xCBED	0x6795
+0xCBEE	0x9BAA
+0xCBEF	0x67FE
+0xCBF0	0x9C52
+0xCBF1	0x685D
+0xCBF2	0x4EA6
+0xCBF3	0x4FE3
+0xCBF4	0x53C8
+0xCBF5	0x62B9
+0xCBF6	0x672B
+0xCBF7	0x6CAB
+0xCBF8	0x8FC4
+0xCBF9	0x4FAD
+0xCBFA	0x7E6D
+0xCBFB	0x9EBF
+0xCBFC	0x4E07
+0xCBFD	0x6162
+0xCBFE	0x6E80
+0xCCA1	0x6F2B
+0xCCA2	0x8513
+0xCCA3	0x5473
+0xCCA4	0x672A
+0xCCA5	0x9B45
+0xCCA6	0x5DF3
+0xCCA7	0x7B95
+0xCCA8	0x5CAC
+0xCCA9	0x5BC6
+0xCCAA	0x871C
+0xCCAB	0x6E4A
+0xCCAC	0x84D1
+0xCCAD	0x7A14
+0xCCAE	0x8108
+0xCCAF	0x5999
+0xCCB0	0x7C8D
+0xCCB1	0x6C11
+0xCCB2	0x7720
+0xCCB3	0x52D9
+0xCCB4	0x5922
+0xCCB5	0x7121
+0xCCB6	0x725F
+0xCCB7	0x77DB
+0xCCB8	0x9727
+0xCCB9	0x9D61
+0xCCBA	0x690B
+0xCCBB	0x5A7F
+0xCCBC	0x5A18
+0xCCBD	0x51A5
+0xCCBE	0x540D
+0xCCBF	0x547D
+0xCCC0	0x660E
+0xCCC1	0x76DF
+0xCCC2	0x8FF7
+0xCCC3	0x9298
+0xCCC4	0x9CF4
+0xCCC5	0x59EA
+0xCCC6	0x725D
+0xCCC7	0x6EC5
+0xCCC8	0x514D
+0xCCC9	0x68C9
+0xCCCA	0x7DBF
+0xCCCB	0x7DEC
+0xCCCC	0x9762
+0xCCCD	0x9EBA
+0xCCCE	0x6478
+0xCCCF	0x6A21
+0xCCD0	0x8302
+0xCCD1	0x5984
+0xCCD2	0x5B5F
+0xCCD3	0x6BDB
+0xCCD4	0x731B
+0xCCD5	0x76F2
+0xCCD6	0x7DB2
+0xCCD7	0x8017
+0xCCD8	0x8499
+0xCCD9	0x5132
+0xCCDA	0x6728
+0xCCDB	0x9ED9
+0xCCDC	0x76EE
+0xCCDD	0x6762
+0xCCDE	0x52FF
+0xCCDF	0x9905
+0xCCE0	0x5C24
+0xCCE1	0x623B
+0xCCE2	0x7C7E
+0xCCE3	0x8CB0
+0xCCE4	0x554F
+0xCCE5	0x60B6
+0xCCE6	0x7D0B
+0xCCE7	0x9580
+0xCCE8	0x5301
+0xCCE9	0x4E5F
+0xCCEA	0x51B6
+0xCCEB	0x591C
+0xCCEC	0x723A
+0xCCED	0x8036
+0xCCEE	0x91CE
+0xCCEF	0x5F25
+0xCCF0	0x77E2
+0xCCF1	0x5384
+0xCCF2	0x5F79
+0xCCF3	0x7D04
+0xCCF4	0x85AC
+0xCCF5	0x8A33
+0xCCF6	0x8E8D
+0xCCF7	0x9756
+0xCCF8	0x67F3
+0xCCF9	0x85AE
+0xCCFA	0x9453
+0xCCFB	0x6109
+0xCCFC	0x6108
+0xCCFD	0x6CB9
+0xCCFE	0x7652
+0xCDA1	0x8AED
+0xCDA2	0x8F38
+0xCDA3	0x552F
+0xCDA4	0x4F51
+0xCDA5	0x512A
+0xCDA6	0x52C7
+0xCDA7	0x53CB
+0xCDA8	0x5BA5
+0xCDA9	0x5E7D
+0xCDAA	0x60A0
+0xCDAB	0x6182
+0xCDAC	0x63D6
+0xCDAD	0x6709
+0xCDAE	0x67DA
+0xCDAF	0x6E67
+0xCDB0	0x6D8C
+0xCDB1	0x7336
+0xCDB2	0x7337
+0xCDB3	0x7531
+0xCDB4	0x7950
+0xCDB5	0x88D5
+0xCDB6	0x8A98
+0xCDB7	0x904A
+0xCDB8	0x9091
+0xCDB9	0x90F5
+0xCDBA	0x96C4
+0xCDBB	0x878D
+0xCDBC	0x5915
+0xCDBD	0x4E88
+0xCDBE	0x4F59
+0xCDBF	0x4E0E
+0xCDC0	0x8A89
+0xCDC1	0x8F3F
+0xCDC2	0x9810
+0xCDC3	0x50AD
+0xCDC4	0x5E7C
+0xCDC5	0x5996
+0xCDC6	0x5BB9
+0xCDC7	0x5EB8
+0xCDC8	0x63DA
+0xCDC9	0x63FA
+0xCDCA	0x64C1
+0xCDCB	0x66DC
+0xCDCC	0x694A
+0xCDCD	0x69D8
+0xCDCE	0x6D0B
+0xCDCF	0x6EB6
+0xCDD0	0x7194
+0xCDD1	0x7528
+0xCDD2	0x7AAF
+0xCDD3	0x7F8A
+0xCDD4	0x8000
+0xCDD5	0x8449
+0xCDD6	0x84C9
+0xCDD7	0x8981
+0xCDD8	0x8B21
+0xCDD9	0x8E0A
+0xCDDA	0x9065
+0xCDDB	0x967D
+0xCDDC	0x990A
+0xCDDD	0x617E
+0xCDDE	0x6291
+0xCDDF	0x6B32
+0xCDE0	0x6C83
+0xCDE1	0x6D74
+0xCDE2	0x7FCC
+0xCDE3	0x7FFC
+0xCDE4	0x6DC0
+0xCDE5	0x7F85
+0xCDE6	0x87BA
+0xCDE7	0x88F8
+0xCDE8	0x6765
+0xCDE9	0x83B1
+0xCDEA	0x983C
+0xCDEB	0x96F7
+0xCDEC	0x6D1B
+0xCDED	0x7D61
+0xCDEE	0x843D
+0xCDEF	0x916A
+0xCDF0	0x4E71
+0xCDF1	0x5375
+0xCDF2	0x5D50
+0xCDF3	0x6B04
+0xCDF4	0x6FEB
+0xCDF5	0x85CD
+0xCDF6	0x862D
+0xCDF7	0x89A7
+0xCDF8	0x5229
+0xCDF9	0x540F
+0xCDFA	0x5C65
+0xCDFB	0x674E
+0xCDFC	0x68A8
+0xCDFD	0x7406
+0xCDFE	0x7483
+0xCEA1	0x75E2
+0xCEA2	0x88CF
+0xCEA3	0x88E1
+0xCEA4	0x91CC
+0xCEA5	0x96E2
+0xCEA6	0x9678
+0xCEA7	0x5F8B
+0xCEA8	0x7387
+0xCEA9	0x7ACB
+0xCEAA	0x844E
+0xCEAB	0x63A0
+0xCEAC	0x7565
+0xCEAD	0x5289
+0xCEAE	0x6D41
+0xCEAF	0x6E9C
+0xCEB0	0x7409
+0xCEB1	0x7559
+0xCEB2	0x786B
+0xCEB3	0x7C92
+0xCEB4	0x9686
+0xCEB5	0x7ADC
+0xCEB6	0x9F8D
+0xCEB7	0x4FB6
+0xCEB8	0x616E
+0xCEB9	0x65C5
+0xCEBA	0x865C
+0xCEBB	0x4E86
+0xCEBC	0x4EAE
+0xCEBD	0x50DA
+0xCEBE	0x4E21
+0xCEBF	0x51CC
+0xCEC0	0x5BEE
+0xCEC1	0x6599
+0xCEC2	0x6881
+0xCEC3	0x6DBC
+0xCEC4	0x731F
+0xCEC5	0x7642
+0xCEC6	0x77AD
+0xCEC7	0x7A1C
+0xCEC8	0x7CE7
+0xCEC9	0x826F
+0xCECA	0x8AD2
+0xCECB	0x907C
+0xCECC	0x91CF
+0xCECD	0x9675
+0xCECE	0x9818
+0xCECF	0x529B
+0xCED0	0x7DD1
+0xCED1	0x502B
+0xCED2	0x5398
+0xCED3	0x6797
+0xCED4	0x6DCB
+0xCED5	0x71D0
+0xCED6	0x7433
+0xCED7	0x81E8
+0xCED8	0x8F2A
+0xCED9	0x96A3
+0xCEDA	0x9C57
+0xCEDB	0x9E9F
+0xCEDC	0x7460
+0xCEDD	0x5841
+0xCEDE	0x6D99
+0xCEDF	0x7D2F
+0xCEE0	0x985E
+0xCEE1	0x4EE4
+0xCEE2	0x4F36
+0xCEE3	0x4F8B
+0xCEE4	0x51B7
+0xCEE5	0x52B1
+0xCEE6	0x5DBA
+0xCEE7	0x601C
+0xCEE8	0x73B2
+0xCEE9	0x793C
+0xCEEA	0x82D3
+0xCEEB	0x9234
+0xCEEC	0x96B7
+0xCEED	0x96F6
+0xCEEE	0x970A
+0xCEEF	0x9E97
+0xCEF0	0x9F62
+0xCEF1	0x66A6
+0xCEF2	0x6B74
+0xCEF3	0x5217
+0xCEF4	0x52A3
+0xCEF5	0x70C8
+0xCEF6	0x88C2
+0xCEF7	0x5EC9
+0xCEF8	0x604B
+0xCEF9	0x6190
+0xCEFA	0x6F23
+0xCEFB	0x7149
+0xCEFC	0x7C3E
+0xCEFD	0x7DF4
+0xCEFE	0x806F
+0xCFA1	0x84EE
+0xCFA2	0x9023
+0xCFA3	0x932C
+0xCFA4	0x5442
+0xCFA5	0x9B6F
+0xCFA6	0x6AD3
+0xCFA7	0x7089
+0xCFA8	0x8CC2
+0xCFA9	0x8DEF
+0xCFAA	0x9732
+0xCFAB	0x52B4
+0xCFAC	0x5A41
+0xCFAD	0x5ECA
+0xCFAE	0x5F04
+0xCFAF	0x6717
+0xCFB0	0x697C
+0xCFB1	0x6994
+0xCFB2	0x6D6A
+0xCFB3	0x6F0F
+0xCFB4	0x7262
+0xCFB5	0x72FC
+0xCFB6	0x7BED
+0xCFB7	0x8001
+0xCFB8	0x807E
+0xCFB9	0x874B
+0xCFBA	0x90CE
+0xCFBB	0x516D
+0xCFBC	0x9E93
+0xCFBD	0x7984
+0xCFBE	0x808B
+0xCFBF	0x9332
+0xCFC0	0x8AD6
+0xCFC1	0x502D
+0xCFC2	0x548C
+0xCFC3	0x8A71
+0xCFC4	0x6B6A
+0xCFC5	0x8CC4
+0xCFC6	0x8107
+0xCFC7	0x60D1
+0xCFC8	0x67A0
+0xCFC9	0x9DF2
+0xCFCA	0x4E99
+0xCFCB	0x4E98
+0xCFCC	0x9C10
+0xCFCD	0x8A6B
+0xCFCE	0x85C1
+0xCFCF	0x8568
+0xCFD0	0x6900
+0xCFD1	0x6E7E
+0xCFD2	0x7897
+0xCFD3	0x8155
+0xD0A1	0x5F0C
+0xD0A2	0x4E10
+0xD0A3	0x4E15
+0xD0A4	0x4E2A
+0xD0A5	0x4E31
+0xD0A6	0x4E36
+0xD0A7	0x4E3C
+0xD0A8	0x4E3F
+0xD0A9	0x4E42
+0xD0AA	0x4E56
+0xD0AB	0x4E58
+0xD0AC	0x4E82
+0xD0AD	0x4E85
+0xD0AE	0x8C6B
+0xD0AF	0x4E8A
+0xD0B0	0x8212
+0xD0B1	0x5F0D
+0xD0B2	0x4E8E
+0xD0B3	0x4E9E
+0xD0B4	0x4E9F
+0xD0B5	0x4EA0
+0xD0B6	0x4EA2
+0xD0B7	0x4EB0
+0xD0B8	0x4EB3
+0xD0B9	0x4EB6
+0xD0BA	0x4ECE
+0xD0BB	0x4ECD
+0xD0BC	0x4EC4
+0xD0BD	0x4EC6
+0xD0BE	0x4EC2
+0xD0BF	0x4ED7
+0xD0C0	0x4EDE
+0xD0C1	0x4EED
+0xD0C2	0x4EDF
+0xD0C3	0x4EF7
+0xD0C4	0x4F09
+0xD0C5	0x4F5A
+0xD0C6	0x4F30
+0xD0C7	0x4F5B
+0xD0C8	0x4F5D
+0xD0C9	0x4F57
+0xD0CA	0x4F47
+0xD0CB	0x4F76
+0xD0CC	0x4F88
+0xD0CD	0x4F8F
+0xD0CE	0x4F98
+0xD0CF	0x4F7B
+0xD0D0	0x4F69
+0xD0D1	0x4F70
+0xD0D2	0x4F91
+0xD0D3	0x4F6F
+0xD0D4	0x4F86
+0xD0D5	0x4F96
+0xD0D6	0x5118
+0xD0D7	0x4FD4
+0xD0D8	0x4FDF
+0xD0D9	0x4FCE
+0xD0DA	0x4FD8
+0xD0DB	0x4FDB
+0xD0DC	0x4FD1
+0xD0DD	0x4FDA
+0xD0DE	0x4FD0
+0xD0DF	0x4FE4
+0xD0E0	0x4FE5
+0xD0E1	0x501A
+0xD0E2	0x5028
+0xD0E3	0x5014
+0xD0E4	0x502A
+0xD0E5	0x5025
+0xD0E6	0x5005
+0xD0E7	0x4F1C
+0xD0E8	0x4FF6
+0xD0E9	0x5021
+0xD0EA	0x5029
+0xD0EB	0x502C
+0xD0EC	0x4FFE
+0xD0ED	0x4FEF
+0xD0EE	0x5011
+0xD0EF	0x5006
+0xD0F0	0x5043
+0xD0F1	0x5047
+0xD0F2	0x6703
+0xD0F3	0x5055
+0xD0F4	0x5050
+0xD0F5	0x5048
+0xD0F6	0x505A
+0xD0F7	0x5056
+0xD0F8	0x506C
+0xD0F9	0x5078
+0xD0FA	0x5080
+0xD0FB	0x509A
+0xD0FC	0x5085
+0xD0FD	0x50B4
+0xD0FE	0x50B2
+0xD1A1	0x50C9
+0xD1A2	0x50CA
+0xD1A3	0x50B3
+0xD1A4	0x50C2
+0xD1A5	0x50D6
+0xD1A6	0x50DE
+0xD1A7	0x50E5
+0xD1A8	0x50ED
+0xD1A9	0x50E3
+0xD1AA	0x50EE
+0xD1AB	0x50F9
+0xD1AC	0x50F5
+0xD1AD	0x5109
+0xD1AE	0x5101
+0xD1AF	0x5102
+0xD1B0	0x5116
+0xD1B1	0x5115
+0xD1B2	0x5114
+0xD1B3	0x511A
+0xD1B4	0x5121
+0xD1B5	0x513A
+0xD1B6	0x5137
+0xD1B7	0x513C
+0xD1B8	0x513B
+0xD1B9	0x513F
+0xD1BA	0x5140
+0xD1BB	0x5152
+0xD1BC	0x514C
+0xD1BD	0x5154
+0xD1BE	0x5162
+0xD1BF	0x7AF8
+0xD1C0	0x5169
+0xD1C1	0x516A
+0xD1C2	0x516E
+0xD1C3	0x5180
+0xD1C4	0x5182
+0xD1C5	0x56D8
+0xD1C6	0x518C
+0xD1C7	0x5189
+0xD1C8	0x518F
+0xD1C9	0x5191
+0xD1CA	0x5193
+0xD1CB	0x5195
+0xD1CC	0x5196
+0xD1CD	0x51A4
+0xD1CE	0x51A6
+0xD1CF	0x51A2
+0xD1D0	0x51A9
+0xD1D1	0x51AA
+0xD1D2	0x51AB
+0xD1D3	0x51B3
+0xD1D4	0x51B1
+0xD1D5	0x51B2
+0xD1D6	0x51B0
+0xD1D7	0x51B5
+0xD1D8	0x51BD
+0xD1D9	0x51C5
+0xD1DA	0x51C9
+0xD1DB	0x51DB
+0xD1DC	0x51E0
+0xD1DD	0x8655
+0xD1DE	0x51E9
+0xD1DF	0x51ED
+0xD1E0	0x51F0
+0xD1E1	0x51F5
+0xD1E2	0x51FE
+0xD1E3	0x5204
+0xD1E4	0x520B
+0xD1E5	0x5214
+0xD1E6	0x520E
+0xD1E7	0x5227
+0xD1E8	0x522A
+0xD1E9	0x522E
+0xD1EA	0x5233
+0xD1EB	0x5239
+0xD1EC	0x524F
+0xD1ED	0x5244
+0xD1EE	0x524B
+0xD1EF	0x524C
+0xD1F0	0x525E
+0xD1F1	0x5254
+0xD1F2	0x526A
+0xD1F3	0x5274
+0xD1F4	0x5269
+0xD1F5	0x5273
+0xD1F6	0x527F
+0xD1F7	0x527D
+0xD1F8	0x528D
+0xD1F9	0x5294
+0xD1FA	0x5292
+0xD1FB	0x5271
+0xD1FC	0x5288
+0xD1FD	0x5291
+0xD1FE	0x8FA8
+0xD2A1	0x8FA7
+0xD2A2	0x52AC
+0xD2A3	0x52AD
+0xD2A4	0x52BC
+0xD2A5	0x52B5
+0xD2A6	0x52C1
+0xD2A7	0x52CD
+0xD2A8	0x52D7
+0xD2A9	0x52DE
+0xD2AA	0x52E3
+0xD2AB	0x52E6
+0xD2AC	0x98ED
+0xD2AD	0x52E0
+0xD2AE	0x52F3
+0xD2AF	0x52F5
+0xD2B0	0x52F8
+0xD2B1	0x52F9
+0xD2B2	0x5306
+0xD2B3	0x5308
+0xD2B4	0x7538
+0xD2B5	0x530D
+0xD2B6	0x5310
+0xD2B7	0x530F
+0xD2B8	0x5315
+0xD2B9	0x531A
+0xD2BA	0x5323
+0xD2BB	0x532F
+0xD2BC	0x5331
+0xD2BD	0x5333
+0xD2BE	0x5338
+0xD2BF	0x5340
+0xD2C0	0x5346
+0xD2C1	0x5345
+0xD2C2	0x4E17
+0xD2C3	0x5349
+0xD2C4	0x534D
+0xD2C5	0x51D6
+0xD2C6	0x535E
+0xD2C7	0x5369
+0xD2C8	0x536E
+0xD2C9	0x5918
+0xD2CA	0x537B
+0xD2CB	0x5377
+0xD2CC	0x5382
+0xD2CD	0x5396
+0xD2CE	0x53A0
+0xD2CF	0x53A6
+0xD2D0	0x53A5
+0xD2D1	0x53AE
+0xD2D2	0x53B0
+0xD2D3	0x53B6
+0xD2D4	0x53C3
+0xD2D5	0x7C12
+0xD2D6	0x96D9
+0xD2D7	0x53DF
+0xD2D8	0x66FC
+0xD2D9	0x71EE
+0xD2DA	0x53EE
+0xD2DB	0x53E8
+0xD2DC	0x53ED
+0xD2DD	0x53FA
+0xD2DE	0x5401
+0xD2DF	0x543D
+0xD2E0	0x5440
+0xD2E1	0x542C
+0xD2E2	0x542D
+0xD2E3	0x543C
+0xD2E4	0x542E
+0xD2E5	0x5436
+0xD2E6	0x5429
+0xD2E7	0x541D
+0xD2E8	0x544E
+0xD2E9	0x548F
+0xD2EA	0x5475
+0xD2EB	0x548E
+0xD2EC	0x545F
+0xD2ED	0x5471
+0xD2EE	0x5477
+0xD2EF	0x5470
+0xD2F0	0x5492
+0xD2F1	0x547B
+0xD2F2	0x5480
+0xD2F3	0x5476
+0xD2F4	0x5484
+0xD2F5	0x5490
+0xD2F6	0x5486
+0xD2F7	0x54C7
+0xD2F8	0x54A2
+0xD2F9	0x54B8
+0xD2FA	0x54A5
+0xD2FB	0x54AC
+0xD2FC	0x54C4
+0xD2FD	0x54C8
+0xD2FE	0x54A8
+0xD3A1	0x54AB
+0xD3A2	0x54C2
+0xD3A3	0x54A4
+0xD3A4	0x54BE
+0xD3A5	0x54BC
+0xD3A6	0x54D8
+0xD3A7	0x54E5
+0xD3A8	0x54E6
+0xD3A9	0x550F
+0xD3AA	0x5514
+0xD3AB	0x54FD
+0xD3AC	0x54EE
+0xD3AD	0x54ED
+0xD3AE	0x54FA
+0xD3AF	0x54E2
+0xD3B0	0x5539
+0xD3B1	0x5540
+0xD3B2	0x5563
+0xD3B3	0x554C
+0xD3B4	0x552E
+0xD3B5	0x555C
+0xD3B6	0x5545
+0xD3B7	0x5556
+0xD3B8	0x5557
+0xD3B9	0x5538
+0xD3BA	0x5533
+0xD3BB	0x555D
+0xD3BC	0x5599
+0xD3BD	0x5580
+0xD3BE	0x54AF
+0xD3BF	0x558A
+0xD3C0	0x559F
+0xD3C1	0x557B
+0xD3C2	0x557E
+0xD3C3	0x5598
+0xD3C4	0x559E
+0xD3C5	0x55AE
+0xD3C6	0x557C
+0xD3C7	0x5583
+0xD3C8	0x55A9
+0xD3C9	0x5587
+0xD3CA	0x55A8
+0xD3CB	0x55DA
+0xD3CC	0x55C5
+0xD3CD	0x55DF
+0xD3CE	0x55C4
+0xD3CF	0x55DC
+0xD3D0	0x55E4
+0xD3D1	0x55D4
+0xD3D2	0x5614
+0xD3D3	0x55F7
+0xD3D4	0x5616
+0xD3D5	0x55FE
+0xD3D6	0x55FD
+0xD3D7	0x561B
+0xD3D8	0x55F9
+0xD3D9	0x564E
+0xD3DA	0x5650
+0xD3DB	0x71DF
+0xD3DC	0x5634
+0xD3DD	0x5636
+0xD3DE	0x5632
+0xD3DF	0x5638
+0xD3E0	0x566B
+0xD3E1	0x5664
+0xD3E2	0x562F
+0xD3E3	0x566C
+0xD3E4	0x566A
+0xD3E5	0x5686
+0xD3E6	0x5680
+0xD3E7	0x568A
+0xD3E8	0x56A0
+0xD3E9	0x5694
+0xD3EA	0x568F
+0xD3EB	0x56A5
+0xD3EC	0x56AE
+0xD3ED	0x56B6
+0xD3EE	0x56B4
+0xD3EF	0x56C2
+0xD3F0	0x56BC
+0xD3F1	0x56C1
+0xD3F2	0x56C3
+0xD3F3	0x56C0
+0xD3F4	0x56C8
+0xD3F5	0x56CE
+0xD3F6	0x56D1
+0xD3F7	0x56D3
+0xD3F8	0x56D7
+0xD3F9	0x56EE
+0xD3FA	0x56F9
+0xD3FB	0x5700
+0xD3FC	0x56FF
+0xD3FD	0x5704
+0xD3FE	0x5709
+0xD4A1	0x5708
+0xD4A2	0x570B
+0xD4A3	0x570D
+0xD4A4	0x5713
+0xD4A5	0x5718
+0xD4A6	0x5716
+0xD4A7	0x55C7
+0xD4A8	0x571C
+0xD4A9	0x5726
+0xD4AA	0x5737
+0xD4AB	0x5738
+0xD4AC	0x574E
+0xD4AD	0x573B
+0xD4AE	0x5740
+0xD4AF	0x574F
+0xD4B0	0x5769
+0xD4B1	0x57C0
+0xD4B2	0x5788
+0xD4B3	0x5761
+0xD4B4	0x577F
+0xD4B5	0x5789
+0xD4B6	0x5793
+0xD4B7	0x57A0
+0xD4B8	0x57B3
+0xD4B9	0x57A4
+0xD4BA	0x57AA
+0xD4BB	0x57B0
+0xD4BC	0x57C3
+0xD4BD	0x57C6
+0xD4BE	0x57D4
+0xD4BF	0x57D2
+0xD4C0	0x57D3
+0xD4C1	0x580A
+0xD4C2	0x57D6
+0xD4C3	0x57E3
+0xD4C4	0x580B
+0xD4C5	0x5819
+0xD4C6	0x581D
+0xD4C7	0x5872
+0xD4C8	0x5821
+0xD4C9	0x5862
+0xD4CA	0x584B
+0xD4CB	0x5870
+0xD4CC	0x6BC0
+0xD4CD	0x5852
+0xD4CE	0x583D
+0xD4CF	0x5879
+0xD4D0	0x5885
+0xD4D1	0x58B9
+0xD4D2	0x589F
+0xD4D3	0x58AB
+0xD4D4	0x58BA
+0xD4D5	0x58DE
+0xD4D6	0x58BB
+0xD4D7	0x58B8
+0xD4D8	0x58AE
+0xD4D9	0x58C5
+0xD4DA	0x58D3
+0xD4DB	0x58D1
+0xD4DC	0x58D7
+0xD4DD	0x58D9
+0xD4DE	0x58D8
+0xD4DF	0x58E5
+0xD4E0	0x58DC
+0xD4E1	0x58E4
+0xD4E2	0x58DF
+0xD4E3	0x58EF
+0xD4E4	0x58FA
+0xD4E5	0x58F9
+0xD4E6	0x58FB
+0xD4E7	0x58FC
+0xD4E8	0x58FD
+0xD4E9	0x5902
+0xD4EA	0x590A
+0xD4EB	0x5910
+0xD4EC	0x591B
+0xD4ED	0x68A6
+0xD4EE	0x5925
+0xD4EF	0x592C
+0xD4F0	0x592D
+0xD4F1	0x5932
+0xD4F2	0x5938
+0xD4F3	0x593E
+0xD4F4	0x7AD2
+0xD4F5	0x5955
+0xD4F6	0x5950
+0xD4F7	0x594E
+0xD4F8	0x595A
+0xD4F9	0x5958
+0xD4FA	0x5962
+0xD4FB	0x5960
+0xD4FC	0x5967
+0xD4FD	0x596C
+0xD4FE	0x5969
+0xD5A1	0x5978
+0xD5A2	0x5981
+0xD5A3	0x599D
+0xD5A4	0x4F5E
+0xD5A5	0x4FAB
+0xD5A6	0x59A3
+0xD5A7	0x59B2
+0xD5A8	0x59C6
+0xD5A9	0x59E8
+0xD5AA	0x59DC
+0xD5AB	0x598D
+0xD5AC	0x59D9
+0xD5AD	0x59DA
+0xD5AE	0x5A25
+0xD5AF	0x5A1F
+0xD5B0	0x5A11
+0xD5B1	0x5A1C
+0xD5B2	0x5A09
+0xD5B3	0x5A1A
+0xD5B4	0x5A40
+0xD5B5	0x5A6C
+0xD5B6	0x5A49
+0xD5B7	0x5A35
+0xD5B8	0x5A36
+0xD5B9	0x5A62
+0xD5BA	0x5A6A
+0xD5BB	0x5A9A
+0xD5BC	0x5ABC
+0xD5BD	0x5ABE
+0xD5BE	0x5ACB
+0xD5BF	0x5AC2
+0xD5C0	0x5ABD
+0xD5C1	0x5AE3
+0xD5C2	0x5AD7
+0xD5C3	0x5AE6
+0xD5C4	0x5AE9
+0xD5C5	0x5AD6
+0xD5C6	0x5AFA
+0xD5C7	0x5AFB
+0xD5C8	0x5B0C
+0xD5C9	0x5B0B
+0xD5CA	0x5B16
+0xD5CB	0x5B32
+0xD5CC	0x5AD0
+0xD5CD	0x5B2A
+0xD5CE	0x5B36
+0xD5CF	0x5B3E
+0xD5D0	0x5B43
+0xD5D1	0x5B45
+0xD5D2	0x5B40
+0xD5D3	0x5B51
+0xD5D4	0x5B55
+0xD5D5	0x5B5A
+0xD5D6	0x5B5B
+0xD5D7	0x5B65
+0xD5D8	0x5B69
+0xD5D9	0x5B70
+0xD5DA	0x5B73
+0xD5DB	0x5B75
+0xD5DC	0x5B78
+0xD5DD	0x6588
+0xD5DE	0x5B7A
+0xD5DF	0x5B80
+0xD5E0	0x5B83
+0xD5E1	0x5BA6
+0xD5E2	0x5BB8
+0xD5E3	0x5BC3
+0xD5E4	0x5BC7
+0xD5E5	0x5BC9
+0xD5E6	0x5BD4
+0xD5E7	0x5BD0
+0xD5E8	0x5BE4
+0xD5E9	0x5BE6
+0xD5EA	0x5BE2
+0xD5EB	0x5BDE
+0xD5EC	0x5BE5
+0xD5ED	0x5BEB
+0xD5EE	0x5BF0
+0xD5EF	0x5BF6
+0xD5F0	0x5BF3
+0xD5F1	0x5C05
+0xD5F2	0x5C07
+0xD5F3	0x5C08
+0xD5F4	0x5C0D
+0xD5F5	0x5C13
+0xD5F6	0x5C20
+0xD5F7	0x5C22
+0xD5F8	0x5C28
+0xD5F9	0x5C38
+0xD5FA	0x5C39
+0xD5FB	0x5C41
+0xD5FC	0x5C46
+0xD5FD	0x5C4E
+0xD5FE	0x5C53
+0xD6A1	0x5C50
+0xD6A2	0x5C4F
+0xD6A3	0x5B71
+0xD6A4	0x5C6C
+0xD6A5	0x5C6E
+0xD6A6	0x4E62
+0xD6A7	0x5C76
+0xD6A8	0x5C79
+0xD6A9	0x5C8C
+0xD6AA	0x5C91
+0xD6AB	0x5C94
+0xD6AC	0x599B
+0xD6AD	0x5CAB
+0xD6AE	0x5CBB
+0xD6AF	0x5CB6
+0xD6B0	0x5CBC
+0xD6B1	0x5CB7
+0xD6B2	0x5CC5
+0xD6B3	0x5CBE
+0xD6B4	0x5CC7
+0xD6B5	0x5CD9
+0xD6B6	0x5CE9
+0xD6B7	0x5CFD
+0xD6B8	0x5CFA
+0xD6B9	0x5CED
+0xD6BA	0x5D8C
+0xD6BB	0x5CEA
+0xD6BC	0x5D0B
+0xD6BD	0x5D15
+0xD6BE	0x5D17
+0xD6BF	0x5D5C
+0xD6C0	0x5D1F
+0xD6C1	0x5D1B
+0xD6C2	0x5D11
+0xD6C3	0x5D14
+0xD6C4	0x5D22
+0xD6C5	0x5D1A
+0xD6C6	0x5D19
+0xD6C7	0x5D18
+0xD6C8	0x5D4C
+0xD6C9	0x5D52
+0xD6CA	0x5D4E
+0xD6CB	0x5D4B
+0xD6CC	0x5D6C
+0xD6CD	0x5D73
+0xD6CE	0x5D76
+0xD6CF	0x5D87
+0xD6D0	0x5D84
+0xD6D1	0x5D82
+0xD6D2	0x5DA2
+0xD6D3	0x5D9D
+0xD6D4	0x5DAC
+0xD6D5	0x5DAE
+0xD6D6	0x5DBD
+0xD6D7	0x5D90
+0xD6D8	0x5DB7
+0xD6D9	0x5DBC
+0xD6DA	0x5DC9
+0xD6DB	0x5DCD
+0xD6DC	0x5DD3
+0xD6DD	0x5DD2
+0xD6DE	0x5DD6
+0xD6DF	0x5DDB
+0xD6E0	0x5DEB
+0xD6E1	0x5DF2
+0xD6E2	0x5DF5
+0xD6E3	0x5E0B
+0xD6E4	0x5E1A
+0xD6E5	0x5E19
+0xD6E6	0x5E11
+0xD6E7	0x5E1B
+0xD6E8	0x5E36
+0xD6E9	0x5E37
+0xD6EA	0x5E44
+0xD6EB	0x5E43
+0xD6EC	0x5E40
+0xD6ED	0x5E4E
+0xD6EE	0x5E57
+0xD6EF	0x5E54
+0xD6F0	0x5E5F
+0xD6F1	0x5E62
+0xD6F2	0x5E64
+0xD6F3	0x5E47
+0xD6F4	0x5E75
+0xD6F5	0x5E76
+0xD6F6	0x5E7A
+0xD6F7	0x9EBC
+0xD6F8	0x5E7F
+0xD6F9	0x5EA0
+0xD6FA	0x5EC1
+0xD6FB	0x5EC2
+0xD6FC	0x5EC8
+0xD6FD	0x5ED0
+0xD6FE	0x5ECF
+0xD7A1	0x5ED6
+0xD7A2	0x5EE3
+0xD7A3	0x5EDD
+0xD7A4	0x5EDA
+0xD7A5	0x5EDB
+0xD7A6	0x5EE2
+0xD7A7	0x5EE1
+0xD7A8	0x5EE8
+0xD7A9	0x5EE9
+0xD7AA	0x5EEC
+0xD7AB	0x5EF1
+0xD7AC	0x5EF3
+0xD7AD	0x5EF0
+0xD7AE	0x5EF4
+0xD7AF	0x5EF8
+0xD7B0	0x5EFE
+0xD7B1	0x5F03
+0xD7B2	0x5F09
+0xD7B3	0x5F5D
+0xD7B4	0x5F5C
+0xD7B5	0x5F0B
+0xD7B6	0x5F11
+0xD7B7	0x5F16
+0xD7B8	0x5F29
+0xD7B9	0x5F2D
+0xD7BA	0x5F38
+0xD7BB	0x5F41
+0xD7BC	0x5F48
+0xD7BD	0x5F4C
+0xD7BE	0x5F4E
+0xD7BF	0x5F2F
+0xD7C0	0x5F51
+0xD7C1	0x5F56
+0xD7C2	0x5F57
+0xD7C3	0x5F59
+0xD7C4	0x5F61
+0xD7C5	0x5F6D
+0xD7C6	0x5F73
+0xD7C7	0x5F77
+0xD7C8	0x5F83
+0xD7C9	0x5F82
+0xD7CA	0x5F7F
+0xD7CB	0x5F8A
+0xD7CC	0x5F88
+0xD7CD	0x5F91
+0xD7CE	0x5F87
+0xD7CF	0x5F9E
+0xD7D0	0x5F99
+0xD7D1	0x5F98
+0xD7D2	0x5FA0
+0xD7D3	0x5FA8
+0xD7D4	0x5FAD
+0xD7D5	0x5FBC
+0xD7D6	0x5FD6
+0xD7D7	0x5FFB
+0xD7D8	0x5FE4
+0xD7D9	0x5FF8
+0xD7DA	0x5FF1
+0xD7DB	0x5FDD
+0xD7DC	0x60B3
+0xD7DD	0x5FFF
+0xD7DE	0x6021
+0xD7DF	0x6060
+0xD7E0	0x6019
+0xD7E1	0x6010
+0xD7E2	0x6029
+0xD7E3	0x600E
+0xD7E4	0x6031
+0xD7E5	0x601B
+0xD7E6	0x6015
+0xD7E7	0x602B
+0xD7E8	0x6026
+0xD7E9	0x600F
+0xD7EA	0x603A
+0xD7EB	0x605A
+0xD7EC	0x6041
+0xD7ED	0x606A
+0xD7EE	0x6077
+0xD7EF	0x605F
+0xD7F0	0x604A
+0xD7F1	0x6046
+0xD7F2	0x604D
+0xD7F3	0x6063
+0xD7F4	0x6043
+0xD7F5	0x6064
+0xD7F6	0x6042
+0xD7F7	0x606C
+0xD7F8	0x606B
+0xD7F9	0x6059
+0xD7FA	0x6081
+0xD7FB	0x608D
+0xD7FC	0x60E7
+0xD7FD	0x6083
+0xD7FE	0x609A
+0xD8A1	0x6084
+0xD8A2	0x609B
+0xD8A3	0x6096
+0xD8A4	0x6097
+0xD8A5	0x6092
+0xD8A6	0x60A7
+0xD8A7	0x608B
+0xD8A8	0x60E1
+0xD8A9	0x60B8
+0xD8AA	0x60E0
+0xD8AB	0x60D3
+0xD8AC	0x60B4
+0xD8AD	0x5FF0
+0xD8AE	0x60BD
+0xD8AF	0x60C6
+0xD8B0	0x60B5
+0xD8B1	0x60D8
+0xD8B2	0x614D
+0xD8B3	0x6115
+0xD8B4	0x6106
+0xD8B5	0x60F6
+0xD8B6	0x60F7
+0xD8B7	0x6100
+0xD8B8	0x60F4
+0xD8B9	0x60FA
+0xD8BA	0x6103
+0xD8BB	0x6121
+0xD8BC	0x60FB
+0xD8BD	0x60F1
+0xD8BE	0x610D
+0xD8BF	0x610E
+0xD8C0	0x6147
+0xD8C1	0x613E
+0xD8C2	0x6128
+0xD8C3	0x6127
+0xD8C4	0x614A
+0xD8C5	0x613F
+0xD8C6	0x613C
+0xD8C7	0x612C
+0xD8C8	0x6134
+0xD8C9	0x613D
+0xD8CA	0x6142
+0xD8CB	0x6144
+0xD8CC	0x6173
+0xD8CD	0x6177
+0xD8CE	0x6158
+0xD8CF	0x6159
+0xD8D0	0x615A
+0xD8D1	0x616B
+0xD8D2	0x6174
+0xD8D3	0x616F
+0xD8D4	0x6165
+0xD8D5	0x6171
+0xD8D6	0x615F
+0xD8D7	0x615D
+0xD8D8	0x6153
+0xD8D9	0x6175
+0xD8DA	0x6199
+0xD8DB	0x6196
+0xD8DC	0x6187
+0xD8DD	0x61AC
+0xD8DE	0x6194
+0xD8DF	0x619A
+0xD8E0	0x618A
+0xD8E1	0x6191
+0xD8E2	0x61AB
+0xD8E3	0x61AE
+0xD8E4	0x61CC
+0xD8E5	0x61CA
+0xD8E6	0x61C9
+0xD8E7	0x61F7
+0xD8E8	0x61C8
+0xD8E9	0x61C3
+0xD8EA	0x61C6
+0xD8EB	0x61BA
+0xD8EC	0x61CB
+0xD8ED	0x7F79
+0xD8EE	0x61CD
+0xD8EF	0x61E6
+0xD8F0	0x61E3
+0xD8F1	0x61F6
+0xD8F2	0x61FA
+0xD8F3	0x61F4
+0xD8F4	0x61FF
+0xD8F5	0x61FD
+0xD8F6	0x61FC
+0xD8F7	0x61FE
+0xD8F8	0x6200
+0xD8F9	0x6208
+0xD8FA	0x6209
+0xD8FB	0x620D
+0xD8FC	0x620C
+0xD8FD	0x6214
+0xD8FE	0x621B
+0xD9A1	0x621E
+0xD9A2	0x6221
+0xD9A3	0x622A
+0xD9A4	0x622E
+0xD9A5	0x6230
+0xD9A6	0x6232
+0xD9A7	0x6233
+0xD9A8	0x6241
+0xD9A9	0x624E
+0xD9AA	0x625E
+0xD9AB	0x6263
+0xD9AC	0x625B
+0xD9AD	0x6260
+0xD9AE	0x6268
+0xD9AF	0x627C
+0xD9B0	0x6282
+0xD9B1	0x6289
+0xD9B2	0x627E
+0xD9B3	0x6292
+0xD9B4	0x6293
+0xD9B5	0x6296
+0xD9B6	0x62D4
+0xD9B7	0x6283
+0xD9B8	0x6294
+0xD9B9	0x62D7
+0xD9BA	0x62D1
+0xD9BB	0x62BB
+0xD9BC	0x62CF
+0xD9BD	0x62FF
+0xD9BE	0x62C6
+0xD9BF	0x64D4
+0xD9C0	0x62C8
+0xD9C1	0x62DC
+0xD9C2	0x62CC
+0xD9C3	0x62CA
+0xD9C4	0x62C2
+0xD9C5	0x62C7
+0xD9C6	0x629B
+0xD9C7	0x62C9
+0xD9C8	0x630C
+0xD9C9	0x62EE
+0xD9CA	0x62F1
+0xD9CB	0x6327
+0xD9CC	0x6302
+0xD9CD	0x6308
+0xD9CE	0x62EF
+0xD9CF	0x62F5
+0xD9D0	0x6350
+0xD9D1	0x633E
+0xD9D2	0x634D
+0xD9D3	0x641C
+0xD9D4	0x634F
+0xD9D5	0x6396
+0xD9D6	0x638E
+0xD9D7	0x6380
+0xD9D8	0x63AB
+0xD9D9	0x6376
+0xD9DA	0x63A3
+0xD9DB	0x638F
+0xD9DC	0x6389
+0xD9DD	0x639F
+0xD9DE	0x63B5
+0xD9DF	0x636B
+0xD9E0	0x6369
+0xD9E1	0x63BE
+0xD9E2	0x63E9
+0xD9E3	0x63C0
+0xD9E4	0x63C6
+0xD9E5	0x63E3
+0xD9E6	0x63C9
+0xD9E7	0x63D2
+0xD9E8	0x63F6
+0xD9E9	0x63C4
+0xD9EA	0x6416
+0xD9EB	0x6434
+0xD9EC	0x6406
+0xD9ED	0x6413
+0xD9EE	0x6426
+0xD9EF	0x6436
+0xD9F0	0x651D
+0xD9F1	0x6417
+0xD9F2	0x6428
+0xD9F3	0x640F
+0xD9F4	0x6467
+0xD9F5	0x646F
+0xD9F6	0x6476
+0xD9F7	0x644E
+0xD9F8	0x652A
+0xD9F9	0x6495
+0xD9FA	0x6493
+0xD9FB	0x64A5
+0xD9FC	0x64A9
+0xD9FD	0x6488
+0xD9FE	0x64BC
+0xDAA1	0x64DA
+0xDAA2	0x64D2
+0xDAA3	0x64C5
+0xDAA4	0x64C7
+0xDAA5	0x64BB
+0xDAA6	0x64D8
+0xDAA7	0x64C2
+0xDAA8	0x64F1
+0xDAA9	0x64E7
+0xDAAA	0x8209
+0xDAAB	0x64E0
+0xDAAC	0x64E1
+0xDAAD	0x62AC
+0xDAAE	0x64E3
+0xDAAF	0x64EF
+0xDAB0	0x652C
+0xDAB1	0x64F6
+0xDAB2	0x64F4
+0xDAB3	0x64F2
+0xDAB4	0x64FA
+0xDAB5	0x6500
+0xDAB6	0x64FD
+0xDAB7	0x6518
+0xDAB8	0x651C
+0xDAB9	0x6505
+0xDABA	0x6524
+0xDABB	0x6523
+0xDABC	0x652B
+0xDABD	0x6534
+0xDABE	0x6535
+0xDABF	0x6537
+0xDAC0	0x6536
+0xDAC1	0x6538
+0xDAC2	0x754B
+0xDAC3	0x6548
+0xDAC4	0x6556
+0xDAC5	0x6555
+0xDAC6	0x654D
+0xDAC7	0x6558
+0xDAC8	0x655E
+0xDAC9	0x655D
+0xDACA	0x6572
+0xDACB	0x6578
+0xDACC	0x6582
+0xDACD	0x6583
+0xDACE	0x8B8A
+0xDACF	0x659B
+0xDAD0	0x659F
+0xDAD1	0x65AB
+0xDAD2	0x65B7
+0xDAD3	0x65C3
+0xDAD4	0x65C6
+0xDAD5	0x65C1
+0xDAD6	0x65C4
+0xDAD7	0x65CC
+0xDAD8	0x65D2
+0xDAD9	0x65DB
+0xDADA	0x65D9
+0xDADB	0x65E0
+0xDADC	0x65E1
+0xDADD	0x65F1
+0xDADE	0x6772
+0xDADF	0x660A
+0xDAE0	0x6603
+0xDAE1	0x65FB
+0xDAE2	0x6773
+0xDAE3	0x6635
+0xDAE4	0x6636
+0xDAE5	0x6634
+0xDAE6	0x661C
+0xDAE7	0x664F
+0xDAE8	0x6644
+0xDAE9	0x6649
+0xDAEA	0x6641
+0xDAEB	0x665E
+0xDAEC	0x665D
+0xDAED	0x6664
+0xDAEE	0x6667
+0xDAEF	0x6668
+0xDAF0	0x665F
+0xDAF1	0x6662
+0xDAF2	0x6670
+0xDAF3	0x6683
+0xDAF4	0x6688
+0xDAF5	0x668E
+0xDAF6	0x6689
+0xDAF7	0x6684
+0xDAF8	0x6698
+0xDAF9	0x669D
+0xDAFA	0x66C1
+0xDAFB	0x66B9
+0xDAFC	0x66C9
+0xDAFD	0x66BE
+0xDAFE	0x66BC
+0xDBA1	0x66C4
+0xDBA2	0x66B8
+0xDBA3	0x66D6
+0xDBA4	0x66DA
+0xDBA5	0x66E0
+0xDBA6	0x663F
+0xDBA7	0x66E6
+0xDBA8	0x66E9
+0xDBA9	0x66F0
+0xDBAA	0x66F5
+0xDBAB	0x66F7
+0xDBAC	0x670F
+0xDBAD	0x6716
+0xDBAE	0x671E
+0xDBAF	0x6726
+0xDBB0	0x6727
+0xDBB1	0x9738
+0xDBB2	0x672E
+0xDBB3	0x673F
+0xDBB4	0x6736
+0xDBB5	0x6741
+0xDBB6	0x6738
+0xDBB7	0x6737
+0xDBB8	0x6746
+0xDBB9	0x675E
+0xDBBA	0x6760
+0xDBBB	0x6759
+0xDBBC	0x6763
+0xDBBD	0x6764
+0xDBBE	0x6789
+0xDBBF	0x6770
+0xDBC0	0x67A9
+0xDBC1	0x677C
+0xDBC2	0x676A
+0xDBC3	0x678C
+0xDBC4	0x678B
+0xDBC5	0x67A6
+0xDBC6	0x67A1
+0xDBC7	0x6785
+0xDBC8	0x67B7
+0xDBC9	0x67EF
+0xDBCA	0x67B4
+0xDBCB	0x67EC
+0xDBCC	0x67B3
+0xDBCD	0x67E9
+0xDBCE	0x67B8
+0xDBCF	0x67E4
+0xDBD0	0x67DE
+0xDBD1	0x67DD
+0xDBD2	0x67E2
+0xDBD3	0x67EE
+0xDBD4	0x67B9
+0xDBD5	0x67CE
+0xDBD6	0x67C6
+0xDBD7	0x67E7
+0xDBD8	0x6A9C
+0xDBD9	0x681E
+0xDBDA	0x6846
+0xDBDB	0x6829
+0xDBDC	0x6840
+0xDBDD	0x684D
+0xDBDE	0x6832
+0xDBDF	0x684E
+0xDBE0	0x68B3
+0xDBE1	0x682B
+0xDBE2	0x6859
+0xDBE3	0x6863
+0xDBE4	0x6877
+0xDBE5	0x687F
+0xDBE6	0x689F
+0xDBE7	0x688F
+0xDBE8	0x68AD
+0xDBE9	0x6894
+0xDBEA	0x689D
+0xDBEB	0x689B
+0xDBEC	0x6883
+0xDBED	0x6AAE
+0xDBEE	0x68B9
+0xDBEF	0x6874
+0xDBF0	0x68B5
+0xDBF1	0x68A0
+0xDBF2	0x68BA
+0xDBF3	0x690F
+0xDBF4	0x688D
+0xDBF5	0x687E
+0xDBF6	0x6901
+0xDBF7	0x68CA
+0xDBF8	0x6908
+0xDBF9	0x68D8
+0xDBFA	0x6922
+0xDBFB	0x6926
+0xDBFC	0x68E1
+0xDBFD	0x690C
+0xDBFE	0x68CD
+0xDCA1	0x68D4
+0xDCA2	0x68E7
+0xDCA3	0x68D5
+0xDCA4	0x6936
+0xDCA5	0x6912
+0xDCA6	0x6904
+0xDCA7	0x68D7
+0xDCA8	0x68E3
+0xDCA9	0x6925
+0xDCAA	0x68F9
+0xDCAB	0x68E0
+0xDCAC	0x68EF
+0xDCAD	0x6928
+0xDCAE	0x692A
+0xDCAF	0x691A
+0xDCB0	0x6923
+0xDCB1	0x6921
+0xDCB2	0x68C6
+0xDCB3	0x6979
+0xDCB4	0x6977
+0xDCB5	0x695C
+0xDCB6	0x6978
+0xDCB7	0x696B
+0xDCB8	0x6954
+0xDCB9	0x697E
+0xDCBA	0x696E
+0xDCBB	0x6939
+0xDCBC	0x6974
+0xDCBD	0x693D
+0xDCBE	0x6959
+0xDCBF	0x6930
+0xDCC0	0x6961
+0xDCC1	0x695E
+0xDCC2	0x695D
+0xDCC3	0x6981
+0xDCC4	0x696A
+0xDCC5	0x69B2
+0xDCC6	0x69AE
+0xDCC7	0x69D0
+0xDCC8	0x69BF
+0xDCC9	0x69C1
+0xDCCA	0x69D3
+0xDCCB	0x69BE
+0xDCCC	0x69CE
+0xDCCD	0x5BE8
+0xDCCE	0x69CA
+0xDCCF	0x69DD
+0xDCD0	0x69BB
+0xDCD1	0x69C3
+0xDCD2	0x69A7
+0xDCD3	0x6A2E
+0xDCD4	0x6991
+0xDCD5	0x69A0
+0xDCD6	0x699C
+0xDCD7	0x6995
+0xDCD8	0x69B4
+0xDCD9	0x69DE
+0xDCDA	0x69E8
+0xDCDB	0x6A02
+0xDCDC	0x6A1B
+0xDCDD	0x69FF
+0xDCDE	0x6B0A
+0xDCDF	0x69F9
+0xDCE0	0x69F2
+0xDCE1	0x69E7
+0xDCE2	0x6A05
+0xDCE3	0x69B1
+0xDCE4	0x6A1E
+0xDCE5	0x69ED
+0xDCE6	0x6A14
+0xDCE7	0x69EB
+0xDCE8	0x6A0A
+0xDCE9	0x6A12
+0xDCEA	0x6AC1
+0xDCEB	0x6A23
+0xDCEC	0x6A13
+0xDCED	0x6A44
+0xDCEE	0x6A0C
+0xDCEF	0x6A72
+0xDCF0	0x6A36
+0xDCF1	0x6A78
+0xDCF2	0x6A47
+0xDCF3	0x6A62
+0xDCF4	0x6A59
+0xDCF5	0x6A66
+0xDCF6	0x6A48
+0xDCF7	0x6A38
+0xDCF8	0x6A22
+0xDCF9	0x6A90
+0xDCFA	0x6A8D
+0xDCFB	0x6AA0
+0xDCFC	0x6A84
+0xDCFD	0x6AA2
+0xDCFE	0x6AA3
+0xDDA1	0x6A97
+0xDDA2	0x8617
+0xDDA3	0x6ABB
+0xDDA4	0x6AC3
+0xDDA5	0x6AC2
+0xDDA6	0x6AB8
+0xDDA7	0x6AB3
+0xDDA8	0x6AAC
+0xDDA9	0x6ADE
+0xDDAA	0x6AD1
+0xDDAB	0x6ADF
+0xDDAC	0x6AAA
+0xDDAD	0x6ADA
+0xDDAE	0x6AEA
+0xDDAF	0x6AFB
+0xDDB0	0x6B05
+0xDDB1	0x8616
+0xDDB2	0x6AFA
+0xDDB3	0x6B12
+0xDDB4	0x6B16
+0xDDB5	0x9B31
+0xDDB6	0x6B1F
+0xDDB7	0x6B38
+0xDDB8	0x6B37
+0xDDB9	0x76DC
+0xDDBA	0x6B39
+0xDDBB	0x98EE
+0xDDBC	0x6B47
+0xDDBD	0x6B43
+0xDDBE	0x6B49
+0xDDBF	0x6B50
+0xDDC0	0x6B59
+0xDDC1	0x6B54
+0xDDC2	0x6B5B
+0xDDC3	0x6B5F
+0xDDC4	0x6B61
+0xDDC5	0x6B78
+0xDDC6	0x6B79
+0xDDC7	0x6B7F
+0xDDC8	0x6B80
+0xDDC9	0x6B84
+0xDDCA	0x6B83
+0xDDCB	0x6B8D
+0xDDCC	0x6B98
+0xDDCD	0x6B95
+0xDDCE	0x6B9E
+0xDDCF	0x6BA4
+0xDDD0	0x6BAA
+0xDDD1	0x6BAB
+0xDDD2	0x6BAF
+0xDDD3	0x6BB2
+0xDDD4	0x6BB1
+0xDDD5	0x6BB3
+0xDDD6	0x6BB7
+0xDDD7	0x6BBC
+0xDDD8	0x6BC6
+0xDDD9	0x6BCB
+0xDDDA	0x6BD3
+0xDDDB	0x6BDF
+0xDDDC	0x6BEC
+0xDDDD	0x6BEB
+0xDDDE	0x6BF3
+0xDDDF	0x6BEF
+0xDDE0	0x9EBE
+0xDDE1	0x6C08
+0xDDE2	0x6C13
+0xDDE3	0x6C14
+0xDDE4	0x6C1B
+0xDDE5	0x6C24
+0xDDE6	0x6C23
+0xDDE7	0x6C5E
+0xDDE8	0x6C55
+0xDDE9	0x6C62
+0xDDEA	0x6C6A
+0xDDEB	0x6C82
+0xDDEC	0x6C8D
+0xDDED	0x6C9A
+0xDDEE	0x6C81
+0xDDEF	0x6C9B
+0xDDF0	0x6C7E
+0xDDF1	0x6C68
+0xDDF2	0x6C73
+0xDDF3	0x6C92
+0xDDF4	0x6C90
+0xDDF5	0x6CC4
+0xDDF6	0x6CF1
+0xDDF7	0x6CD3
+0xDDF8	0x6CBD
+0xDDF9	0x6CD7
+0xDDFA	0x6CC5
+0xDDFB	0x6CDD
+0xDDFC	0x6CAE
+0xDDFD	0x6CB1
+0xDDFE	0x6CBE
+0xDEA1	0x6CBA
+0xDEA2	0x6CDB
+0xDEA3	0x6CEF
+0xDEA4	0x6CD9
+0xDEA5	0x6CEA
+0xDEA6	0x6D1F
+0xDEA7	0x884D
+0xDEA8	0x6D36
+0xDEA9	0x6D2B
+0xDEAA	0x6D3D
+0xDEAB	0x6D38
+0xDEAC	0x6D19
+0xDEAD	0x6D35
+0xDEAE	0x6D33
+0xDEAF	0x6D12
+0xDEB0	0x6D0C
+0xDEB1	0x6D63
+0xDEB2	0x6D93
+0xDEB3	0x6D64
+0xDEB4	0x6D5A
+0xDEB5	0x6D79
+0xDEB6	0x6D59
+0xDEB7	0x6D8E
+0xDEB8	0x6D95
+0xDEB9	0x6FE4
+0xDEBA	0x6D85
+0xDEBB	0x6DF9
+0xDEBC	0x6E15
+0xDEBD	0x6E0A
+0xDEBE	0x6DB5
+0xDEBF	0x6DC7
+0xDEC0	0x6DE6
+0xDEC1	0x6DB8
+0xDEC2	0x6DC6
+0xDEC3	0x6DEC
+0xDEC4	0x6DDE
+0xDEC5	0x6DCC
+0xDEC6	0x6DE8
+0xDEC7	0x6DD2
+0xDEC8	0x6DC5
+0xDEC9	0x6DFA
+0xDECA	0x6DD9
+0xDECB	0x6DE4
+0xDECC	0x6DD5
+0xDECD	0x6DEA
+0xDECE	0x6DEE
+0xDECF	0x6E2D
+0xDED0	0x6E6E
+0xDED1	0x6E2E
+0xDED2	0x6E19
+0xDED3	0x6E72
+0xDED4	0x6E5F
+0xDED5	0x6E3E
+0xDED6	0x6E23
+0xDED7	0x6E6B
+0xDED8	0x6E2B
+0xDED9	0x6E76
+0xDEDA	0x6E4D
+0xDEDB	0x6E1F
+0xDEDC	0x6E43
+0xDEDD	0x6E3A
+0xDEDE	0x6E4E
+0xDEDF	0x6E24
+0xDEE0	0x6EFF
+0xDEE1	0x6E1D
+0xDEE2	0x6E38
+0xDEE3	0x6E82
+0xDEE4	0x6EAA
+0xDEE5	0x6E98
+0xDEE6	0x6EC9
+0xDEE7	0x6EB7
+0xDEE8	0x6ED3
+0xDEE9	0x6EBD
+0xDEEA	0x6EAF
+0xDEEB	0x6EC4
+0xDEEC	0x6EB2
+0xDEED	0x6ED4
+0xDEEE	0x6ED5
+0xDEEF	0x6E8F
+0xDEF0	0x6EA5
+0xDEF1	0x6EC2
+0xDEF2	0x6E9F
+0xDEF3	0x6F41
+0xDEF4	0x6F11
+0xDEF5	0x704C
+0xDEF6	0x6EEC
+0xDEF7	0x6EF8
+0xDEF8	0x6EFE
+0xDEF9	0x6F3F
+0xDEFA	0x6EF2
+0xDEFB	0x6F31
+0xDEFC	0x6EEF
+0xDEFD	0x6F32
+0xDEFE	0x6ECC
+0xDFA1	0x6F3E
+0xDFA2	0x6F13
+0xDFA3	0x6EF7
+0xDFA4	0x6F86
+0xDFA5	0x6F7A
+0xDFA6	0x6F78
+0xDFA7	0x6F81
+0xDFA8	0x6F80
+0xDFA9	0x6F6F
+0xDFAA	0x6F5B
+0xDFAB	0x6FF3
+0xDFAC	0x6F6D
+0xDFAD	0x6F82
+0xDFAE	0x6F7C
+0xDFAF	0x6F58
+0xDFB0	0x6F8E
+0xDFB1	0x6F91
+0xDFB2	0x6FC2
+0xDFB3	0x6F66
+0xDFB4	0x6FB3
+0xDFB5	0x6FA3
+0xDFB6	0x6FA1
+0xDFB7	0x6FA4
+0xDFB8	0x6FB9
+0xDFB9	0x6FC6
+0xDFBA	0x6FAA
+0xDFBB	0x6FDF
+0xDFBC	0x6FD5
+0xDFBD	0x6FEC
+0xDFBE	0x6FD4
+0xDFBF	0x6FD8
+0xDFC0	0x6FF1
+0xDFC1	0x6FEE
+0xDFC2	0x6FDB
+0xDFC3	0x7009
+0xDFC4	0x700B
+0xDFC5	0x6FFA
+0xDFC6	0x7011
+0xDFC7	0x7001
+0xDFC8	0x700F
+0xDFC9	0x6FFE
+0xDFCA	0x701B
+0xDFCB	0x701A
+0xDFCC	0x6F74
+0xDFCD	0x701D
+0xDFCE	0x7018
+0xDFCF	0x701F
+0xDFD0	0x7030
+0xDFD1	0x703E
+0xDFD2	0x7032
+0xDFD3	0x7051
+0xDFD4	0x7063
+0xDFD5	0x7099
+0xDFD6	0x7092
+0xDFD7	0x70AF
+0xDFD8	0x70F1
+0xDFD9	0x70AC
+0xDFDA	0x70B8
+0xDFDB	0x70B3
+0xDFDC	0x70AE
+0xDFDD	0x70DF
+0xDFDE	0x70CB
+0xDFDF	0x70DD
+0xDFE0	0x70D9
+0xDFE1	0x7109
+0xDFE2	0x70FD
+0xDFE3	0x711C
+0xDFE4	0x7119
+0xDFE5	0x7165
+0xDFE6	0x7155
+0xDFE7	0x7188
+0xDFE8	0x7166
+0xDFE9	0x7162
+0xDFEA	0x714C
+0xDFEB	0x7156
+0xDFEC	0x716C
+0xDFED	0x718F
+0xDFEE	0x71FB
+0xDFEF	0x7184
+0xDFF0	0x7195
+0xDFF1	0x71A8
+0xDFF2	0x71AC
+0xDFF3	0x71D7
+0xDFF4	0x71B9
+0xDFF5	0x71BE
+0xDFF6	0x71D2
+0xDFF7	0x71C9
+0xDFF8	0x71D4
+0xDFF9	0x71CE
+0xDFFA	0x71E0
+0xDFFB	0x71EC
+0xDFFC	0x71E7
+0xDFFD	0x71F5
+0xDFFE	0x71FC
+0xE0A1	0x71F9
+0xE0A2	0x71FF
+0xE0A3	0x720D
+0xE0A4	0x7210
+0xE0A5	0x721B
+0xE0A6	0x7228
+0xE0A7	0x722D
+0xE0A8	0x722C
+0xE0A9	0x7230
+0xE0AA	0x7232
+0xE0AB	0x723B
+0xE0AC	0x723C
+0xE0AD	0x723F
+0xE0AE	0x7240
+0xE0AF	0x7246
+0xE0B0	0x724B
+0xE0B1	0x7258
+0xE0B2	0x7274
+0xE0B3	0x727E
+0xE0B4	0x7282
+0xE0B5	0x7281
+0xE0B6	0x7287
+0xE0B7	0x7292
+0xE0B8	0x7296
+0xE0B9	0x72A2
+0xE0BA	0x72A7
+0xE0BB	0x72B9
+0xE0BC	0x72B2
+0xE0BD	0x72C3
+0xE0BE	0x72C6
+0xE0BF	0x72C4
+0xE0C0	0x72CE
+0xE0C1	0x72D2
+0xE0C2	0x72E2
+0xE0C3	0x72E0
+0xE0C4	0x72E1
+0xE0C5	0x72F9
+0xE0C6	0x72F7
+0xE0C7	0x500F
+0xE0C8	0x7317
+0xE0C9	0x730A
+0xE0CA	0x731C
+0xE0CB	0x7316
+0xE0CC	0x731D
+0xE0CD	0x7334
+0xE0CE	0x732F
+0xE0CF	0x7329
+0xE0D0	0x7325
+0xE0D1	0x733E
+0xE0D2	0x734E
+0xE0D3	0x734F
+0xE0D4	0x9ED8
+0xE0D5	0x7357
+0xE0D6	0x736A
+0xE0D7	0x7368
+0xE0D8	0x7370
+0xE0D9	0x7378
+0xE0DA	0x7375
+0xE0DB	0x737B
+0xE0DC	0x737A
+0xE0DD	0x73C8
+0xE0DE	0x73B3
+0xE0DF	0x73CE
+0xE0E0	0x73BB
+0xE0E1	0x73C0
+0xE0E2	0x73E5
+0xE0E3	0x73EE
+0xE0E4	0x73DE
+0xE0E5	0x74A2
+0xE0E6	0x7405
+0xE0E7	0x746F
+0xE0E8	0x7425
+0xE0E9	0x73F8
+0xE0EA	0x7432
+0xE0EB	0x743A
+0xE0EC	0x7455
+0xE0ED	0x743F
+0xE0EE	0x745F
+0xE0EF	0x7459
+0xE0F0	0x7441
+0xE0F1	0x745C
+0xE0F2	0x7469
+0xE0F3	0x7470
+0xE0F4	0x7463
+0xE0F5	0x746A
+0xE0F6	0x7476
+0xE0F7	0x747E
+0xE0F8	0x748B
+0xE0F9	0x749E
+0xE0FA	0x74A7
+0xE0FB	0x74CA
+0xE0FC	0x74CF
+0xE0FD	0x74D4
+0xE0FE	0x73F1
+0xE1A1	0x74E0
+0xE1A2	0x74E3
+0xE1A3	0x74E7
+0xE1A4	0x74E9
+0xE1A5	0x74EE
+0xE1A6	0x74F2
+0xE1A7	0x74F0
+0xE1A8	0x74F1
+0xE1A9	0x74F8
+0xE1AA	0x74F7
+0xE1AB	0x7504
+0xE1AC	0x7503
+0xE1AD	0x7505
+0xE1AE	0x750C
+0xE1AF	0x750E
+0xE1B0	0x750D
+0xE1B1	0x7515
+0xE1B2	0x7513
+0xE1B3	0x751E
+0xE1B4	0x7526
+0xE1B5	0x752C
+0xE1B6	0x753C
+0xE1B7	0x7544
+0xE1B8	0x754D
+0xE1B9	0x754A
+0xE1BA	0x7549
+0xE1BB	0x755B
+0xE1BC	0x7546
+0xE1BD	0x755A
+0xE1BE	0x7569
+0xE1BF	0x7564
+0xE1C0	0x7567
+0xE1C1	0x756B
+0xE1C2	0x756D
+0xE1C3	0x7578
+0xE1C4	0x7576
+0xE1C5	0x7586
+0xE1C6	0x7587
+0xE1C7	0x7574
+0xE1C8	0x758A
+0xE1C9	0x7589
+0xE1CA	0x7582
+0xE1CB	0x7594
+0xE1CC	0x759A
+0xE1CD	0x759D
+0xE1CE	0x75A5
+0xE1CF	0x75A3
+0xE1D0	0x75C2
+0xE1D1	0x75B3
+0xE1D2	0x75C3
+0xE1D3	0x75B5
+0xE1D4	0x75BD
+0xE1D5	0x75B8
+0xE1D6	0x75BC
+0xE1D7	0x75B1
+0xE1D8	0x75CD
+0xE1D9	0x75CA
+0xE1DA	0x75D2
+0xE1DB	0x75D9
+0xE1DC	0x75E3
+0xE1DD	0x75DE
+0xE1DE	0x75FE
+0xE1DF	0x75FF
+0xE1E0	0x75FC
+0xE1E1	0x7601
+0xE1E2	0x75F0
+0xE1E3	0x75FA
+0xE1E4	0x75F2
+0xE1E5	0x75F3
+0xE1E6	0x760B
+0xE1E7	0x760D
+0xE1E8	0x7609
+0xE1E9	0x761F
+0xE1EA	0x7627
+0xE1EB	0x7620
+0xE1EC	0x7621
+0xE1ED	0x7622
+0xE1EE	0x7624
+0xE1EF	0x7634
+0xE1F0	0x7630
+0xE1F1	0x763B
+0xE1F2	0x7647
+0xE1F3	0x7648
+0xE1F4	0x7646
+0xE1F5	0x765C
+0xE1F6	0x7658
+0xE1F7	0x7661
+0xE1F8	0x7662
+0xE1F9	0x7668
+0xE1FA	0x7669
+0xE1FB	0x766A
+0xE1FC	0x7667
+0xE1FD	0x766C
+0xE1FE	0x7670
+0xE2A1	0x7672
+0xE2A2	0x7676
+0xE2A3	0x7678
+0xE2A4	0x767C
+0xE2A5	0x7680
+0xE2A6	0x7683
+0xE2A7	0x7688
+0xE2A8	0x768B
+0xE2A9	0x768E
+0xE2AA	0x7696
+0xE2AB	0x7693
+0xE2AC	0x7699
+0xE2AD	0x769A
+0xE2AE	0x76B0
+0xE2AF	0x76B4
+0xE2B0	0x76B8
+0xE2B1	0x76B9
+0xE2B2	0x76BA
+0xE2B3	0x76C2
+0xE2B4	0x76CD
+0xE2B5	0x76D6
+0xE2B6	0x76D2
+0xE2B7	0x76DE
+0xE2B8	0x76E1
+0xE2B9	0x76E5
+0xE2BA	0x76E7
+0xE2BB	0x76EA
+0xE2BC	0x862F
+0xE2BD	0x76FB
+0xE2BE	0x7708
+0xE2BF	0x7707
+0xE2C0	0x7704
+0xE2C1	0x7729
+0xE2C2	0x7724
+0xE2C3	0x771E
+0xE2C4	0x7725
+0xE2C5	0x7726
+0xE2C6	0x771B
+0xE2C7	0x7737
+0xE2C8	0x7738
+0xE2C9	0x7747
+0xE2CA	0x775A
+0xE2CB	0x7768
+0xE2CC	0x776B
+0xE2CD	0x775B
+0xE2CE	0x7765
+0xE2CF	0x777F
+0xE2D0	0x777E
+0xE2D1	0x7779
+0xE2D2	0x778E
+0xE2D3	0x778B
+0xE2D4	0x7791
+0xE2D5	0x77A0
+0xE2D6	0x779E
+0xE2D7	0x77B0
+0xE2D8	0x77B6
+0xE2D9	0x77B9
+0xE2DA	0x77BF
+0xE2DB	0x77BC
+0xE2DC	0x77BD
+0xE2DD	0x77BB
+0xE2DE	0x77C7
+0xE2DF	0x77CD
+0xE2E0	0x77D7
+0xE2E1	0x77DA
+0xE2E2	0x77DC
+0xE2E3	0x77E3
+0xE2E4	0x77EE
+0xE2E5	0x77FC
+0xE2E6	0x780C
+0xE2E7	0x7812
+0xE2E8	0x7926
+0xE2E9	0x7820
+0xE2EA	0x792A
+0xE2EB	0x7845
+0xE2EC	0x788E
+0xE2ED	0x7874
+0xE2EE	0x7886
+0xE2EF	0x787C
+0xE2F0	0x789A
+0xE2F1	0x788C
+0xE2F2	0x78A3
+0xE2F3	0x78B5
+0xE2F4	0x78AA
+0xE2F5	0x78AF
+0xE2F6	0x78D1
+0xE2F7	0x78C6
+0xE2F8	0x78CB
+0xE2F9	0x78D4
+0xE2FA	0x78BE
+0xE2FB	0x78BC
+0xE2FC	0x78C5
+0xE2FD	0x78CA
+0xE2FE	0x78EC
+0xE3A1	0x78E7
+0xE3A2	0x78DA
+0xE3A3	0x78FD
+0xE3A4	0x78F4
+0xE3A5	0x7907
+0xE3A6	0x7912
+0xE3A7	0x7911
+0xE3A8	0x7919
+0xE3A9	0x792C
+0xE3AA	0x792B
+0xE3AB	0x7940
+0xE3AC	0x7960
+0xE3AD	0x7957
+0xE3AE	0x795F
+0xE3AF	0x795A
+0xE3B0	0x7955
+0xE3B1	0x7953
+0xE3B2	0x797A
+0xE3B3	0x797F
+0xE3B4	0x798A
+0xE3B5	0x799D
+0xE3B6	0x79A7
+0xE3B7	0x9F4B
+0xE3B8	0x79AA
+0xE3B9	0x79AE
+0xE3BA	0x79B3
+0xE3BB	0x79B9
+0xE3BC	0x79BA
+0xE3BD	0x79C9
+0xE3BE	0x79D5
+0xE3BF	0x79E7
+0xE3C0	0x79EC
+0xE3C1	0x79E1
+0xE3C2	0x79E3
+0xE3C3	0x7A08
+0xE3C4	0x7A0D
+0xE3C5	0x7A18
+0xE3C6	0x7A19
+0xE3C7	0x7A20
+0xE3C8	0x7A1F
+0xE3C9	0x7980
+0xE3CA	0x7A31
+0xE3CB	0x7A3B
+0xE3CC	0x7A3E
+0xE3CD	0x7A37
+0xE3CE	0x7A43
+0xE3CF	0x7A57
+0xE3D0	0x7A49
+0xE3D1	0x7A61
+0xE3D2	0x7A62
+0xE3D3	0x7A69
+0xE3D4	0x9F9D
+0xE3D5	0x7A70
+0xE3D6	0x7A79
+0xE3D7	0x7A7D
+0xE3D8	0x7A88
+0xE3D9	0x7A97
+0xE3DA	0x7A95
+0xE3DB	0x7A98
+0xE3DC	0x7A96
+0xE3DD	0x7AA9
+0xE3DE	0x7AC8
+0xE3DF	0x7AB0
+0xE3E0	0x7AB6
+0xE3E1	0x7AC5
+0xE3E2	0x7AC4
+0xE3E3	0x7ABF
+0xE3E4	0x9083
+0xE3E5	0x7AC7
+0xE3E6	0x7ACA
+0xE3E7	0x7ACD
+0xE3E8	0x7ACF
+0xE3E9	0x7AD5
+0xE3EA	0x7AD3
+0xE3EB	0x7AD9
+0xE3EC	0x7ADA
+0xE3ED	0x7ADD
+0xE3EE	0x7AE1
+0xE3EF	0x7AE2
+0xE3F0	0x7AE6
+0xE3F1	0x7AED
+0xE3F2	0x7AF0
+0xE3F3	0x7B02
+0xE3F4	0x7B0F
+0xE3F5	0x7B0A
+0xE3F6	0x7B06
+0xE3F7	0x7B33
+0xE3F8	0x7B18
+0xE3F9	0x7B19
+0xE3FA	0x7B1E
+0xE3FB	0x7B35
+0xE3FC	0x7B28
+0xE3FD	0x7B36
+0xE3FE	0x7B50
+0xE4A1	0x7B7A
+0xE4A2	0x7B04
+0xE4A3	0x7B4D
+0xE4A4	0x7B0B
+0xE4A5	0x7B4C
+0xE4A6	0x7B45
+0xE4A7	0x7B75
+0xE4A8	0x7B65
+0xE4A9	0x7B74
+0xE4AA	0x7B67
+0xE4AB	0x7B70
+0xE4AC	0x7B71
+0xE4AD	0x7B6C
+0xE4AE	0x7B6E
+0xE4AF	0x7B9D
+0xE4B0	0x7B98
+0xE4B1	0x7B9F
+0xE4B2	0x7B8D
+0xE4B3	0x7B9C
+0xE4B4	0x7B9A
+0xE4B5	0x7B8B
+0xE4B6	0x7B92
+0xE4B7	0x7B8F
+0xE4B8	0x7B5D
+0xE4B9	0x7B99
+0xE4BA	0x7BCB
+0xE4BB	0x7BC1
+0xE4BC	0x7BCC
+0xE4BD	0x7BCF
+0xE4BE	0x7BB4
+0xE4BF	0x7BC6
+0xE4C0	0x7BDD
+0xE4C1	0x7BE9
+0xE4C2	0x7C11
+0xE4C3	0x7C14
+0xE4C4	0x7BE6
+0xE4C5	0x7BE5
+0xE4C6	0x7C60
+0xE4C7	0x7C00
+0xE4C8	0x7C07
+0xE4C9	0x7C13
+0xE4CA	0x7BF3
+0xE4CB	0x7BF7
+0xE4CC	0x7C17
+0xE4CD	0x7C0D
+0xE4CE	0x7BF6
+0xE4CF	0x7C23
+0xE4D0	0x7C27
+0xE4D1	0x7C2A
+0xE4D2	0x7C1F
+0xE4D3	0x7C37
+0xE4D4	0x7C2B
+0xE4D5	0x7C3D
+0xE4D6	0x7C4C
+0xE4D7	0x7C43
+0xE4D8	0x7C54
+0xE4D9	0x7C4F
+0xE4DA	0x7C40
+0xE4DB	0x7C50
+0xE4DC	0x7C58
+0xE4DD	0x7C5F
+0xE4DE	0x7C64
+0xE4DF	0x7C56
+0xE4E0	0x7C65
+0xE4E1	0x7C6C
+0xE4E2	0x7C75
+0xE4E3	0x7C83
+0xE4E4	0x7C90
+0xE4E5	0x7CA4
+0xE4E6	0x7CAD
+0xE4E7	0x7CA2
+0xE4E8	0x7CAB
+0xE4E9	0x7CA1
+0xE4EA	0x7CA8
+0xE4EB	0x7CB3
+0xE4EC	0x7CB2
+0xE4ED	0x7CB1
+0xE4EE	0x7CAE
+0xE4EF	0x7CB9
+0xE4F0	0x7CBD
+0xE4F1	0x7CC0
+0xE4F2	0x7CC5
+0xE4F3	0x7CC2
+0xE4F4	0x7CD8
+0xE4F5	0x7CD2
+0xE4F6	0x7CDC
+0xE4F7	0x7CE2
+0xE4F8	0x9B3B
+0xE4F9	0x7CEF
+0xE4FA	0x7CF2
+0xE4FB	0x7CF4
+0xE4FC	0x7CF6
+0xE4FD	0x7CFA
+0xE4FE	0x7D06
+0xE5A1	0x7D02
+0xE5A2	0x7D1C
+0xE5A3	0x7D15
+0xE5A4	0x7D0A
+0xE5A5	0x7D45
+0xE5A6	0x7D4B
+0xE5A7	0x7D2E
+0xE5A8	0x7D32
+0xE5A9	0x7D3F
+0xE5AA	0x7D35
+0xE5AB	0x7D46
+0xE5AC	0x7D73
+0xE5AD	0x7D56
+0xE5AE	0x7D4E
+0xE5AF	0x7D72
+0xE5B0	0x7D68
+0xE5B1	0x7D6E
+0xE5B2	0x7D4F
+0xE5B3	0x7D63
+0xE5B4	0x7D93
+0xE5B5	0x7D89
+0xE5B6	0x7D5B
+0xE5B7	0x7D8F
+0xE5B8	0x7D7D
+0xE5B9	0x7D9B
+0xE5BA	0x7DBA
+0xE5BB	0x7DAE
+0xE5BC	0x7DA3
+0xE5BD	0x7DB5
+0xE5BE	0x7DC7
+0xE5BF	0x7DBD
+0xE5C0	0x7DAB
+0xE5C1	0x7E3D
+0xE5C2	0x7DA2
+0xE5C3	0x7DAF
+0xE5C4	0x7DDC
+0xE5C5	0x7DB8
+0xE5C6	0x7D9F
+0xE5C7	0x7DB0
+0xE5C8	0x7DD8
+0xE5C9	0x7DDD
+0xE5CA	0x7DE4
+0xE5CB	0x7DDE
+0xE5CC	0x7DFB
+0xE5CD	0x7DF2
+0xE5CE	0x7DE1
+0xE5CF	0x7E05
+0xE5D0	0x7E0A
+0xE5D1	0x7E23
+0xE5D2	0x7E21
+0xE5D3	0x7E12
+0xE5D4	0x7E31
+0xE5D5	0x7E1F
+0xE5D6	0x7E09
+0xE5D7	0x7E0B
+0xE5D8	0x7E22
+0xE5D9	0x7E46
+0xE5DA	0x7E66
+0xE5DB	0x7E3B
+0xE5DC	0x7E35
+0xE5DD	0x7E39
+0xE5DE	0x7E43
+0xE5DF	0x7E37
+0xE5E0	0x7E32
+0xE5E1	0x7E3A
+0xE5E2	0x7E67
+0xE5E3	0x7E5D
+0xE5E4	0x7E56
+0xE5E5	0x7E5E
+0xE5E6	0x7E59
+0xE5E7	0x7E5A
+0xE5E8	0x7E79
+0xE5E9	0x7E6A
+0xE5EA	0x7E69
+0xE5EB	0x7E7C
+0xE5EC	0x7E7B
+0xE5ED	0x7E83
+0xE5EE	0x7DD5
+0xE5EF	0x7E7D
+0xE5F0	0x8FAE
+0xE5F1	0x7E7F
+0xE5F2	0x7E88
+0xE5F3	0x7E89
+0xE5F4	0x7E8C
+0xE5F5	0x7E92
+0xE5F6	0x7E90
+0xE5F7	0x7E93
+0xE5F8	0x7E94
+0xE5F9	0x7E96
+0xE5FA	0x7E8E
+0xE5FB	0x7E9B
+0xE5FC	0x7E9C
+0xE5FD	0x7F38
+0xE5FE	0x7F3A
+0xE6A1	0x7F45
+0xE6A2	0x7F4C
+0xE6A3	0x7F4D
+0xE6A4	0x7F4E
+0xE6A5	0x7F50
+0xE6A6	0x7F51
+0xE6A7	0x7F55
+0xE6A8	0x7F54
+0xE6A9	0x7F58
+0xE6AA	0x7F5F
+0xE6AB	0x7F60
+0xE6AC	0x7F68
+0xE6AD	0x7F69
+0xE6AE	0x7F67
+0xE6AF	0x7F78
+0xE6B0	0x7F82
+0xE6B1	0x7F86
+0xE6B2	0x7F83
+0xE6B3	0x7F88
+0xE6B4	0x7F87
+0xE6B5	0x7F8C
+0xE6B6	0x7F94
+0xE6B7	0x7F9E
+0xE6B8	0x7F9D
+0xE6B9	0x7F9A
+0xE6BA	0x7FA3
+0xE6BB	0x7FAF
+0xE6BC	0x7FB2
+0xE6BD	0x7FB9
+0xE6BE	0x7FAE
+0xE6BF	0x7FB6
+0xE6C0	0x7FB8
+0xE6C1	0x8B71
+0xE6C2	0x7FC5
+0xE6C3	0x7FC6
+0xE6C4	0x7FCA
+0xE6C5	0x7FD5
+0xE6C6	0x7FD4
+0xE6C7	0x7FE1
+0xE6C8	0x7FE6
+0xE6C9	0x7FE9
+0xE6CA	0x7FF3
+0xE6CB	0x7FF9
+0xE6CC	0x98DC
+0xE6CD	0x8006
+0xE6CE	0x8004
+0xE6CF	0x800B
+0xE6D0	0x8012
+0xE6D1	0x8018
+0xE6D2	0x8019
+0xE6D3	0x801C
+0xE6D4	0x8021
+0xE6D5	0x8028
+0xE6D6	0x803F
+0xE6D7	0x803B
+0xE6D8	0x804A
+0xE6D9	0x8046
+0xE6DA	0x8052
+0xE6DB	0x8058
+0xE6DC	0x805A
+0xE6DD	0x805F
+0xE6DE	0x8062
+0xE6DF	0x8068
+0xE6E0	0x8073
+0xE6E1	0x8072
+0xE6E2	0x8070
+0xE6E3	0x8076
+0xE6E4	0x8079
+0xE6E5	0x807D
+0xE6E6	0x807F
+0xE6E7	0x8084
+0xE6E8	0x8086
+0xE6E9	0x8085
+0xE6EA	0x809B
+0xE6EB	0x8093
+0xE6EC	0x809A
+0xE6ED	0x80AD
+0xE6EE	0x5190
+0xE6EF	0x80AC
+0xE6F0	0x80DB
+0xE6F1	0x80E5
+0xE6F2	0x80D9
+0xE6F3	0x80DD
+0xE6F4	0x80C4
+0xE6F5	0x80DA
+0xE6F6	0x80D6
+0xE6F7	0x8109
+0xE6F8	0x80EF
+0xE6F9	0x80F1
+0xE6FA	0x811B
+0xE6FB	0x8129
+0xE6FC	0x8123
+0xE6FD	0x812F
+0xE6FE	0x814B
+0xE7A1	0x968B
+0xE7A2	0x8146
+0xE7A3	0x813E
+0xE7A4	0x8153
+0xE7A5	0x8151
+0xE7A6	0x80FC
+0xE7A7	0x8171
+0xE7A8	0x816E
+0xE7A9	0x8165
+0xE7AA	0x8166
+0xE7AB	0x8174
+0xE7AC	0x8183
+0xE7AD	0x8188
+0xE7AE	0x818A
+0xE7AF	0x8180
+0xE7B0	0x8182
+0xE7B1	0x81A0
+0xE7B2	0x8195
+0xE7B3	0x81A4
+0xE7B4	0x81A3
+0xE7B5	0x815F
+0xE7B6	0x8193
+0xE7B7	0x81A9
+0xE7B8	0x81B0
+0xE7B9	0x81B5
+0xE7BA	0x81BE
+0xE7BB	0x81B8
+0xE7BC	0x81BD
+0xE7BD	0x81C0
+0xE7BE	0x81C2
+0xE7BF	0x81BA
+0xE7C0	0x81C9
+0xE7C1	0x81CD
+0xE7C2	0x81D1
+0xE7C3	0x81D9
+0xE7C4	0x81D8
+0xE7C5	0x81C8
+0xE7C6	0x81DA
+0xE7C7	0x81DF
+0xE7C8	0x81E0
+0xE7C9	0x81E7
+0xE7CA	0x81FA
+0xE7CB	0x81FB
+0xE7CC	0x81FE
+0xE7CD	0x8201
+0xE7CE	0x8202
+0xE7CF	0x8205
+0xE7D0	0x8207
+0xE7D1	0x820A
+0xE7D2	0x820D
+0xE7D3	0x8210
+0xE7D4	0x8216
+0xE7D5	0x8229
+0xE7D6	0x822B
+0xE7D7	0x8238
+0xE7D8	0x8233
+0xE7D9	0x8240
+0xE7DA	0x8259
+0xE7DB	0x8258
+0xE7DC	0x825D
+0xE7DD	0x825A
+0xE7DE	0x825F
+0xE7DF	0x8264
+0xE7E0	0x8262
+0xE7E1	0x8268
+0xE7E2	0x826A
+0xE7E3	0x826B
+0xE7E4	0x822E
+0xE7E5	0x8271
+0xE7E6	0x8277
+0xE7E7	0x8278
+0xE7E8	0x827E
+0xE7E9	0x828D
+0xE7EA	0x8292
+0xE7EB	0x82AB
+0xE7EC	0x829F
+0xE7ED	0x82BB
+0xE7EE	0x82AC
+0xE7EF	0x82E1
+0xE7F0	0x82E3
+0xE7F1	0x82DF
+0xE7F2	0x82D2
+0xE7F3	0x82F4
+0xE7F4	0x82F3
+0xE7F5	0x82FA
+0xE7F6	0x8393
+0xE7F7	0x8303
+0xE7F8	0x82FB
+0xE7F9	0x82F9
+0xE7FA	0x82DE
+0xE7FB	0x8306
+0xE7FC	0x82DC
+0xE7FD	0x8309
+0xE7FE	0x82D9
+0xE8A1	0x8335
+0xE8A2	0x8334
+0xE8A3	0x8316
+0xE8A4	0x8332
+0xE8A5	0x8331
+0xE8A6	0x8340
+0xE8A7	0x8339
+0xE8A8	0x8350
+0xE8A9	0x8345
+0xE8AA	0x832F
+0xE8AB	0x832B
+0xE8AC	0x8317
+0xE8AD	0x8318
+0xE8AE	0x8385
+0xE8AF	0x839A
+0xE8B0	0x83AA
+0xE8B1	0x839F
+0xE8B2	0x83A2
+0xE8B3	0x8396
+0xE8B4	0x8323
+0xE8B5	0x838E
+0xE8B6	0x8387
+0xE8B7	0x838A
+0xE8B8	0x837C
+0xE8B9	0x83B5
+0xE8BA	0x8373
+0xE8BB	0x8375
+0xE8BC	0x83A0
+0xE8BD	0x8389
+0xE8BE	0x83A8
+0xE8BF	0x83F4
+0xE8C0	0x8413
+0xE8C1	0x83EB
+0xE8C2	0x83CE
+0xE8C3	0x83FD
+0xE8C4	0x8403
+0xE8C5	0x83D8
+0xE8C6	0x840B
+0xE8C7	0x83C1
+0xE8C8	0x83F7
+0xE8C9	0x8407
+0xE8CA	0x83E0
+0xE8CB	0x83F2
+0xE8CC	0x840D
+0xE8CD	0x8422
+0xE8CE	0x8420
+0xE8CF	0x83BD
+0xE8D0	0x8438
+0xE8D1	0x8506
+0xE8D2	0x83FB
+0xE8D3	0x846D
+0xE8D4	0x842A
+0xE8D5	0x843C
+0xE8D6	0x855A
+0xE8D7	0x8484
+0xE8D8	0x8477
+0xE8D9	0x846B
+0xE8DA	0x84AD
+0xE8DB	0x846E
+0xE8DC	0x8482
+0xE8DD	0x8469
+0xE8DE	0x8446
+0xE8DF	0x842C
+0xE8E0	0x846F
+0xE8E1	0x8479
+0xE8E2	0x8435
+0xE8E3	0x84CA
+0xE8E4	0x8462
+0xE8E5	0x84B9
+0xE8E6	0x84BF
+0xE8E7	0x849F
+0xE8E8	0x84D9
+0xE8E9	0x84CD
+0xE8EA	0x84BB
+0xE8EB	0x84DA
+0xE8EC	0x84D0
+0xE8ED	0x84C1
+0xE8EE	0x84C6
+0xE8EF	0x84D6
+0xE8F0	0x84A1
+0xE8F1	0x8521
+0xE8F2	0x84FF
+0xE8F3	0x84F4
+0xE8F4	0x8517
+0xE8F5	0x8518
+0xE8F6	0x852C
+0xE8F7	0x851F
+0xE8F8	0x8515
+0xE8F9	0x8514
+0xE8FA	0x84FC
+0xE8FB	0x8540
+0xE8FC	0x8563
+0xE8FD	0x8558
+0xE8FE	0x8548
+0xE9A1	0x8541
+0xE9A2	0x8602
+0xE9A3	0x854B
+0xE9A4	0x8555
+0xE9A5	0x8580
+0xE9A6	0x85A4
+0xE9A7	0x8588
+0xE9A8	0x8591
+0xE9A9	0x858A
+0xE9AA	0x85A8
+0xE9AB	0x856D
+0xE9AC	0x8594
+0xE9AD	0x859B
+0xE9AE	0x85EA
+0xE9AF	0x8587
+0xE9B0	0x859C
+0xE9B1	0x8577
+0xE9B2	0x857E
+0xE9B3	0x8590
+0xE9B4	0x85C9
+0xE9B5	0x85BA
+0xE9B6	0x85CF
+0xE9B7	0x85B9
+0xE9B8	0x85D0
+0xE9B9	0x85D5
+0xE9BA	0x85DD
+0xE9BB	0x85E5
+0xE9BC	0x85DC
+0xE9BD	0x85F9
+0xE9BE	0x860A
+0xE9BF	0x8613
+0xE9C0	0x860B
+0xE9C1	0x85FE
+0xE9C2	0x85FA
+0xE9C3	0x8606
+0xE9C4	0x8622
+0xE9C5	0x861A
+0xE9C6	0x8630
+0xE9C7	0x863F
+0xE9C8	0x864D
+0xE9C9	0x4E55
+0xE9CA	0x8654
+0xE9CB	0x865F
+0xE9CC	0x8667
+0xE9CD	0x8671
+0xE9CE	0x8693
+0xE9CF	0x86A3
+0xE9D0	0x86A9
+0xE9D1	0x86AA
+0xE9D2	0x868B
+0xE9D3	0x868C
+0xE9D4	0x86B6
+0xE9D5	0x86AF
+0xE9D6	0x86C4
+0xE9D7	0x86C6
+0xE9D8	0x86B0
+0xE9D9	0x86C9
+0xE9DA	0x8823
+0xE9DB	0x86AB
+0xE9DC	0x86D4
+0xE9DD	0x86DE
+0xE9DE	0x86E9
+0xE9DF	0x86EC
+0xE9E0	0x86DF
+0xE9E1	0x86DB
+0xE9E2	0x86EF
+0xE9E3	0x8712
+0xE9E4	0x8706
+0xE9E5	0x8708
+0xE9E6	0x8700
+0xE9E7	0x8703
+0xE9E8	0x86FB
+0xE9E9	0x8711
+0xE9EA	0x8709
+0xE9EB	0x870D
+0xE9EC	0x86F9
+0xE9ED	0x870A
+0xE9EE	0x8734
+0xE9EF	0x873F
+0xE9F0	0x8737
+0xE9F1	0x873B
+0xE9F2	0x8725
+0xE9F3	0x8729
+0xE9F4	0x871A
+0xE9F5	0x8760
+0xE9F6	0x875F
+0xE9F7	0x8778
+0xE9F8	0x874C
+0xE9F9	0x874E
+0xE9FA	0x8774
+0xE9FB	0x8757
+0xE9FC	0x8768
+0xE9FD	0x876E
+0xE9FE	0x8759
+0xEAA1	0x8753
+0xEAA2	0x8763
+0xEAA3	0x876A
+0xEAA4	0x8805
+0xEAA5	0x87A2
+0xEAA6	0x879F
+0xEAA7	0x8782
+0xEAA8	0x87AF
+0xEAA9	0x87CB
+0xEAAA	0x87BD
+0xEAAB	0x87C0
+0xEAAC	0x87D0
+0xEAAD	0x96D6
+0xEAAE	0x87AB
+0xEAAF	0x87C4
+0xEAB0	0x87B3
+0xEAB1	0x87C7
+0xEAB2	0x87C6
+0xEAB3	0x87BB
+0xEAB4	0x87EF
+0xEAB5	0x87F2
+0xEAB6	0x87E0
+0xEAB7	0x880F
+0xEAB8	0x880D
+0xEAB9	0x87FE
+0xEABA	0x87F6
+0xEABB	0x87F7
+0xEABC	0x880E
+0xEABD	0x87D2
+0xEABE	0x8811
+0xEABF	0x8816
+0xEAC0	0x8815
+0xEAC1	0x8822
+0xEAC2	0x8821
+0xEAC3	0x8831
+0xEAC4	0x8836
+0xEAC5	0x8839
+0xEAC6	0x8827
+0xEAC7	0x883B
+0xEAC8	0x8844
+0xEAC9	0x8842
+0xEACA	0x8852
+0xEACB	0x8859
+0xEACC	0x885E
+0xEACD	0x8862
+0xEACE	0x886B
+0xEACF	0x8881
+0xEAD0	0x887E
+0xEAD1	0x889E
+0xEAD2	0x8875
+0xEAD3	0x887D
+0xEAD4	0x88B5
+0xEAD5	0x8872
+0xEAD6	0x8882
+0xEAD7	0x8897
+0xEAD8	0x8892
+0xEAD9	0x88AE
+0xEADA	0x8899
+0xEADB	0x88A2
+0xEADC	0x888D
+0xEADD	0x88A4
+0xEADE	0x88B0
+0xEADF	0x88BF
+0xEAE0	0x88B1
+0xEAE1	0x88C3
+0xEAE2	0x88C4
+0xEAE3	0x88D4
+0xEAE4	0x88D8
+0xEAE5	0x88D9
+0xEAE6	0x88DD
+0xEAE7	0x88F9
+0xEAE8	0x8902
+0xEAE9	0x88FC
+0xEAEA	0x88F4
+0xEAEB	0x88E8
+0xEAEC	0x88F2
+0xEAED	0x8904
+0xEAEE	0x890C
+0xEAEF	0x890A
+0xEAF0	0x8913
+0xEAF1	0x8943
+0xEAF2	0x891E
+0xEAF3	0x8925
+0xEAF4	0x892A
+0xEAF5	0x892B
+0xEAF6	0x8941
+0xEAF7	0x8944
+0xEAF8	0x893B
+0xEAF9	0x8936
+0xEAFA	0x8938
+0xEAFB	0x894C
+0xEAFC	0x891D
+0xEAFD	0x8960
+0xEAFE	0x895E
+0xEBA1	0x8966
+0xEBA2	0x8964
+0xEBA3	0x896D
+0xEBA4	0x896A
+0xEBA5	0x896F
+0xEBA6	0x8974
+0xEBA7	0x8977
+0xEBA8	0x897E
+0xEBA9	0x8983
+0xEBAA	0x8988
+0xEBAB	0x898A
+0xEBAC	0x8993
+0xEBAD	0x8998
+0xEBAE	0x89A1
+0xEBAF	0x89A9
+0xEBB0	0x89A6
+0xEBB1	0x89AC
+0xEBB2	0x89AF
+0xEBB3	0x89B2
+0xEBB4	0x89BA
+0xEBB5	0x89BD
+0xEBB6	0x89BF
+0xEBB7	0x89C0
+0xEBB8	0x89DA
+0xEBB9	0x89DC
+0xEBBA	0x89DD
+0xEBBB	0x89E7
+0xEBBC	0x89F4
+0xEBBD	0x89F8
+0xEBBE	0x8A03
+0xEBBF	0x8A16
+0xEBC0	0x8A10
+0xEBC1	0x8A0C
+0xEBC2	0x8A1B
+0xEBC3	0x8A1D
+0xEBC4	0x8A25
+0xEBC5	0x8A36
+0xEBC6	0x8A41
+0xEBC7	0x8A5B
+0xEBC8	0x8A52
+0xEBC9	0x8A46
+0xEBCA	0x8A48
+0xEBCB	0x8A7C
+0xEBCC	0x8A6D
+0xEBCD	0x8A6C
+0xEBCE	0x8A62
+0xEBCF	0x8A85
+0xEBD0	0x8A82
+0xEBD1	0x8A84
+0xEBD2	0x8AA8
+0xEBD3	0x8AA1
+0xEBD4	0x8A91
+0xEBD5	0x8AA5
+0xEBD6	0x8AA6
+0xEBD7	0x8A9A
+0xEBD8	0x8AA3
+0xEBD9	0x8AC4
+0xEBDA	0x8ACD
+0xEBDB	0x8AC2
+0xEBDC	0x8ADA
+0xEBDD	0x8AEB
+0xEBDE	0x8AF3
+0xEBDF	0x8AE7
+0xEBE0	0x8AE4
+0xEBE1	0x8AF1
+0xEBE2	0x8B14
+0xEBE3	0x8AE0
+0xEBE4	0x8AE2
+0xEBE5	0x8AF7
+0xEBE6	0x8ADE
+0xEBE7	0x8ADB
+0xEBE8	0x8B0C
+0xEBE9	0x8B07
+0xEBEA	0x8B1A
+0xEBEB	0x8AE1
+0xEBEC	0x8B16
+0xEBED	0x8B10
+0xEBEE	0x8B17
+0xEBEF	0x8B20
+0xEBF0	0x8B33
+0xEBF1	0x97AB
+0xEBF2	0x8B26
+0xEBF3	0x8B2B
+0xEBF4	0x8B3E
+0xEBF5	0x8B28
+0xEBF6	0x8B41
+0xEBF7	0x8B4C
+0xEBF8	0x8B4F
+0xEBF9	0x8B4E
+0xEBFA	0x8B49
+0xEBFB	0x8B56
+0xEBFC	0x8B5B
+0xEBFD	0x8B5A
+0xEBFE	0x8B6B
+0xECA1	0x8B5F
+0xECA2	0x8B6C
+0xECA3	0x8B6F
+0xECA4	0x8B74
+0xECA5	0x8B7D
+0xECA6	0x8B80
+0xECA7	0x8B8C
+0xECA8	0x8B8E
+0xECA9	0x8B92
+0xECAA	0x8B93
+0xECAB	0x8B96
+0xECAC	0x8B99
+0xECAD	0x8B9A
+0xECAE	0x8C3A
+0xECAF	0x8C41
+0xECB0	0x8C3F
+0xECB1	0x8C48
+0xECB2	0x8C4C
+0xECB3	0x8C4E
+0xECB4	0x8C50
+0xECB5	0x8C55
+0xECB6	0x8C62
+0xECB7	0x8C6C
+0xECB8	0x8C78
+0xECB9	0x8C7A
+0xECBA	0x8C82
+0xECBB	0x8C89
+0xECBC	0x8C85
+0xECBD	0x8C8A
+0xECBE	0x8C8D
+0xECBF	0x8C8E
+0xECC0	0x8C94
+0xECC1	0x8C7C
+0xECC2	0x8C98
+0xECC3	0x621D
+0xECC4	0x8CAD
+0xECC5	0x8CAA
+0xECC6	0x8CBD
+0xECC7	0x8CB2
+0xECC8	0x8CB3
+0xECC9	0x8CAE
+0xECCA	0x8CB6
+0xECCB	0x8CC8
+0xECCC	0x8CC1
+0xECCD	0x8CE4
+0xECCE	0x8CE3
+0xECCF	0x8CDA
+0xECD0	0x8CFD
+0xECD1	0x8CFA
+0xECD2	0x8CFB
+0xECD3	0x8D04
+0xECD4	0x8D05
+0xECD5	0x8D0A
+0xECD6	0x8D07
+0xECD7	0x8D0F
+0xECD8	0x8D0D
+0xECD9	0x8D10
+0xECDA	0x9F4E
+0xECDB	0x8D13
+0xECDC	0x8CCD
+0xECDD	0x8D14
+0xECDE	0x8D16
+0xECDF	0x8D67
+0xECE0	0x8D6D
+0xECE1	0x8D71
+0xECE2	0x8D73
+0xECE3	0x8D81
+0xECE4	0x8D99
+0xECE5	0x8DC2
+0xECE6	0x8DBE
+0xECE7	0x8DBA
+0xECE8	0x8DCF
+0xECE9	0x8DDA
+0xECEA	0x8DD6
+0xECEB	0x8DCC
+0xECEC	0x8DDB
+0xECED	0x8DCB
+0xECEE	0x8DEA
+0xECEF	0x8DEB
+0xECF0	0x8DDF
+0xECF1	0x8DE3
+0xECF2	0x8DFC
+0xECF3	0x8E08
+0xECF4	0x8E09
+0xECF5	0x8DFF
+0xECF6	0x8E1D
+0xECF7	0x8E1E
+0xECF8	0x8E10
+0xECF9	0x8E1F
+0xECFA	0x8E42
+0xECFB	0x8E35
+0xECFC	0x8E30
+0xECFD	0x8E34
+0xECFE	0x8E4A
+0xEDA1	0x8E47
+0xEDA2	0x8E49
+0xEDA3	0x8E4C
+0xEDA4	0x8E50
+0xEDA5	0x8E48
+0xEDA6	0x8E59
+0xEDA7	0x8E64
+0xEDA8	0x8E60
+0xEDA9	0x8E2A
+0xEDAA	0x8E63
+0xEDAB	0x8E55
+0xEDAC	0x8E76
+0xEDAD	0x8E72
+0xEDAE	0x8E7C
+0xEDAF	0x8E81
+0xEDB0	0x8E87
+0xEDB1	0x8E85
+0xEDB2	0x8E84
+0xEDB3	0x8E8B
+0xEDB4	0x8E8A
+0xEDB5	0x8E93
+0xEDB6	0x8E91
+0xEDB7	0x8E94
+0xEDB8	0x8E99
+0xEDB9	0x8EAA
+0xEDBA	0x8EA1
+0xEDBB	0x8EAC
+0xEDBC	0x8EB0
+0xEDBD	0x8EC6
+0xEDBE	0x8EB1
+0xEDBF	0x8EBE
+0xEDC0	0x8EC5
+0xEDC1	0x8EC8
+0xEDC2	0x8ECB
+0xEDC3	0x8EDB
+0xEDC4	0x8EE3
+0xEDC5	0x8EFC
+0xEDC6	0x8EFB
+0xEDC7	0x8EEB
+0xEDC8	0x8EFE
+0xEDC9	0x8F0A
+0xEDCA	0x8F05
+0xEDCB	0x8F15
+0xEDCC	0x8F12
+0xEDCD	0x8F19
+0xEDCE	0x8F13
+0xEDCF	0x8F1C
+0xEDD0	0x8F1F
+0xEDD1	0x8F1B
+0xEDD2	0x8F0C
+0xEDD3	0x8F26
+0xEDD4	0x8F33
+0xEDD5	0x8F3B
+0xEDD6	0x8F39
+0xEDD7	0x8F45
+0xEDD8	0x8F42
+0xEDD9	0x8F3E
+0xEDDA	0x8F4C
+0xEDDB	0x8F49
+0xEDDC	0x8F46
+0xEDDD	0x8F4E
+0xEDDE	0x8F57
+0xEDDF	0x8F5C
+0xEDE0	0x8F62
+0xEDE1	0x8F63
+0xEDE2	0x8F64
+0xEDE3	0x8F9C
+0xEDE4	0x8F9F
+0xEDE5	0x8FA3
+0xEDE6	0x8FAD
+0xEDE7	0x8FAF
+0xEDE8	0x8FB7
+0xEDE9	0x8FDA
+0xEDEA	0x8FE5
+0xEDEB	0x8FE2
+0xEDEC	0x8FEA
+0xEDED	0x8FEF
+0xEDEE	0x9087
+0xEDEF	0x8FF4
+0xEDF0	0x9005
+0xEDF1	0x8FF9
+0xEDF2	0x8FFA
+0xEDF3	0x9011
+0xEDF4	0x9015
+0xEDF5	0x9021
+0xEDF6	0x900D
+0xEDF7	0x901E
+0xEDF8	0x9016
+0xEDF9	0x900B
+0xEDFA	0x9027
+0xEDFB	0x9036
+0xEDFC	0x9035
+0xEDFD	0x9039
+0xEDFE	0x8FF8
+0xEEA1	0x904F
+0xEEA2	0x9050
+0xEEA3	0x9051
+0xEEA4	0x9052
+0xEEA5	0x900E
+0xEEA6	0x9049
+0xEEA7	0x903E
+0xEEA8	0x9056
+0xEEA9	0x9058
+0xEEAA	0x905E
+0xEEAB	0x9068
+0xEEAC	0x906F
+0xEEAD	0x9076
+0xEEAE	0x96A8
+0xEEAF	0x9072
+0xEEB0	0x9082
+0xEEB1	0x907D
+0xEEB2	0x9081
+0xEEB3	0x9080
+0xEEB4	0x908A
+0xEEB5	0x9089
+0xEEB6	0x908F
+0xEEB7	0x90A8
+0xEEB8	0x90AF
+0xEEB9	0x90B1
+0xEEBA	0x90B5
+0xEEBB	0x90E2
+0xEEBC	0x90E4
+0xEEBD	0x6248
+0xEEBE	0x90DB
+0xEEBF	0x9102
+0xEEC0	0x9112
+0xEEC1	0x9119
+0xEEC2	0x9132
+0xEEC3	0x9130
+0xEEC4	0x914A
+0xEEC5	0x9156
+0xEEC6	0x9158
+0xEEC7	0x9163
+0xEEC8	0x9165
+0xEEC9	0x9169
+0xEECA	0x9173
+0xEECB	0x9172
+0xEECC	0x918B
+0xEECD	0x9189
+0xEECE	0x9182
+0xEECF	0x91A2
+0xEED0	0x91AB
+0xEED1	0x91AF
+0xEED2	0x91AA
+0xEED3	0x91B5
+0xEED4	0x91B4
+0xEED5	0x91BA
+0xEED6	0x91C0
+0xEED7	0x91C1
+0xEED8	0x91C9
+0xEED9	0x91CB
+0xEEDA	0x91D0
+0xEEDB	0x91D6
+0xEEDC	0x91DF
+0xEEDD	0x91E1
+0xEEDE	0x91DB
+0xEEDF	0x91FC
+0xEEE0	0x91F5
+0xEEE1	0x91F6
+0xEEE2	0x921E
+0xEEE3	0x91FF
+0xEEE4	0x9214
+0xEEE5	0x922C
+0xEEE6	0x9215
+0xEEE7	0x9211
+0xEEE8	0x925E
+0xEEE9	0x9257
+0xEEEA	0x9245
+0xEEEB	0x9249
+0xEEEC	0x9264
+0xEEED	0x9248
+0xEEEE	0x9295
+0xEEEF	0x923F
+0xEEF0	0x924B
+0xEEF1	0x9250
+0xEEF2	0x929C
+0xEEF3	0x9296
+0xEEF4	0x9293
+0xEEF5	0x929B
+0xEEF6	0x925A
+0xEEF7	0x92CF
+0xEEF8	0x92B9
+0xEEF9	0x92B7
+0xEEFA	0x92E9
+0xEEFB	0x930F
+0xEEFC	0x92FA
+0xEEFD	0x9344
+0xEEFE	0x932E
+0xEFA1	0x9319
+0xEFA2	0x9322
+0xEFA3	0x931A
+0xEFA4	0x9323
+0xEFA5	0x933A
+0xEFA6	0x9335
+0xEFA7	0x933B
+0xEFA8	0x935C
+0xEFA9	0x9360
+0xEFAA	0x937C
+0xEFAB	0x936E
+0xEFAC	0x9356
+0xEFAD	0x93B0
+0xEFAE	0x93AC
+0xEFAF	0x93AD
+0xEFB0	0x9394
+0xEFB1	0x93B9
+0xEFB2	0x93D6
+0xEFB3	0x93D7
+0xEFB4	0x93E8
+0xEFB5	0x93E5
+0xEFB6	0x93D8
+0xEFB7	0x93C3
+0xEFB8	0x93DD
+0xEFB9	0x93D0
+0xEFBA	0x93C8
+0xEFBB	0x93E4
+0xEFBC	0x941A
+0xEFBD	0x9414
+0xEFBE	0x9413
+0xEFBF	0x9403
+0xEFC0	0x9407
+0xEFC1	0x9410
+0xEFC2	0x9436
+0xEFC3	0x942B
+0xEFC4	0x9435
+0xEFC5	0x9421
+0xEFC6	0x943A
+0xEFC7	0x9441
+0xEFC8	0x9452
+0xEFC9	0x9444
+0xEFCA	0x945B
+0xEFCB	0x9460
+0xEFCC	0x9462
+0xEFCD	0x945E
+0xEFCE	0x946A
+0xEFCF	0x9229
+0xEFD0	0x9470
+0xEFD1	0x9475
+0xEFD2	0x9477
+0xEFD3	0x947D
+0xEFD4	0x945A
+0xEFD5	0x947C
+0xEFD6	0x947E
+0xEFD7	0x9481
+0xEFD8	0x947F
+0xEFD9	0x9582
+0xEFDA	0x9587
+0xEFDB	0x958A
+0xEFDC	0x9594
+0xEFDD	0x9596
+0xEFDE	0x9598
+0xEFDF	0x9599
+0xEFE0	0x95A0
+0xEFE1	0x95A8
+0xEFE2	0x95A7
+0xEFE3	0x95AD
+0xEFE4	0x95BC
+0xEFE5	0x95BB
+0xEFE6	0x95B9
+0xEFE7	0x95BE
+0xEFE8	0x95CA
+0xEFE9	0x6FF6
+0xEFEA	0x95C3
+0xEFEB	0x95CD
+0xEFEC	0x95CC
+0xEFED	0x95D5
+0xEFEE	0x95D4
+0xEFEF	0x95D6
+0xEFF0	0x95DC
+0xEFF1	0x95E1
+0xEFF2	0x95E5
+0xEFF3	0x95E2
+0xEFF4	0x9621
+0xEFF5	0x9628
+0xEFF6	0x962E
+0xEFF7	0x962F
+0xEFF8	0x9642
+0xEFF9	0x964C
+0xEFFA	0x964F
+0xEFFB	0x964B
+0xEFFC	0x9677
+0xEFFD	0x965C
+0xEFFE	0x965E
+0xF0A1	0x965D
+0xF0A2	0x965F
+0xF0A3	0x9666
+0xF0A4	0x9672
+0xF0A5	0x966C
+0xF0A6	0x968D
+0xF0A7	0x9698
+0xF0A8	0x9695
+0xF0A9	0x9697
+0xF0AA	0x96AA
+0xF0AB	0x96A7
+0xF0AC	0x96B1
+0xF0AD	0x96B2
+0xF0AE	0x96B0
+0xF0AF	0x96B4
+0xF0B0	0x96B6
+0xF0B1	0x96B8
+0xF0B2	0x96B9
+0xF0B3	0x96CE
+0xF0B4	0x96CB
+0xF0B5	0x96C9
+0xF0B6	0x96CD
+0xF0B7	0x894D
+0xF0B8	0x96DC
+0xF0B9	0x970D
+0xF0BA	0x96D5
+0xF0BB	0x96F9
+0xF0BC	0x9704
+0xF0BD	0x9706
+0xF0BE	0x9708
+0xF0BF	0x9713
+0xF0C0	0x970E
+0xF0C1	0x9711
+0xF0C2	0x970F
+0xF0C3	0x9716
+0xF0C4	0x9719
+0xF0C5	0x9724
+0xF0C6	0x972A
+0xF0C7	0x9730
+0xF0C8	0x9739
+0xF0C9	0x973D
+0xF0CA	0x973E
+0xF0CB	0x9744
+0xF0CC	0x9746
+0xF0CD	0x9748
+0xF0CE	0x9742
+0xF0CF	0x9749
+0xF0D0	0x975C
+0xF0D1	0x9760
+0xF0D2	0x9764
+0xF0D3	0x9766
+0xF0D4	0x9768
+0xF0D5	0x52D2
+0xF0D6	0x976B
+0xF0D7	0x9771
+0xF0D8	0x9779
+0xF0D9	0x9785
+0xF0DA	0x977C
+0xF0DB	0x9781
+0xF0DC	0x977A
+0xF0DD	0x9786
+0xF0DE	0x978B
+0xF0DF	0x978F
+0xF0E0	0x9790
+0xF0E1	0x979C
+0xF0E2	0x97A8
+0xF0E3	0x97A6
+0xF0E4	0x97A3
+0xF0E5	0x97B3
+0xF0E6	0x97B4
+0xF0E7	0x97C3
+0xF0E8	0x97C6
+0xF0E9	0x97C8
+0xF0EA	0x97CB
+0xF0EB	0x97DC
+0xF0EC	0x97ED
+0xF0ED	0x9F4F
+0xF0EE	0x97F2
+0xF0EF	0x7ADF
+0xF0F0	0x97F6
+0xF0F1	0x97F5
+0xF0F2	0x980F
+0xF0F3	0x980C
+0xF0F4	0x9838
+0xF0F5	0x9824
+0xF0F6	0x9821
+0xF0F7	0x9837
+0xF0F8	0x983D
+0xF0F9	0x9846
+0xF0FA	0x984F
+0xF0FB	0x984B
+0xF0FC	0x986B
+0xF0FD	0x986F
+0xF0FE	0x9870
+0xF1A1	0x9871
+0xF1A2	0x9874
+0xF1A3	0x9873
+0xF1A4	0x98AA
+0xF1A5	0x98AF
+0xF1A6	0x98B1
+0xF1A7	0x98B6
+0xF1A8	0x98C4
+0xF1A9	0x98C3
+0xF1AA	0x98C6
+0xF1AB	0x98E9
+0xF1AC	0x98EB
+0xF1AD	0x9903
+0xF1AE	0x9909
+0xF1AF	0x9912
+0xF1B0	0x9914
+0xF1B1	0x9918
+0xF1B2	0x9921
+0xF1B3	0x991D
+0xF1B4	0x991E
+0xF1B5	0x9924
+0xF1B6	0x9920
+0xF1B7	0x992C
+0xF1B8	0x992E
+0xF1B9	0x993D
+0xF1BA	0x993E
+0xF1BB	0x9942
+0xF1BC	0x9949
+0xF1BD	0x9945
+0xF1BE	0x9950
+0xF1BF	0x994B
+0xF1C0	0x9951
+0xF1C1	0x9952
+0xF1C2	0x994C
+0xF1C3	0x9955
+0xF1C4	0x9997
+0xF1C5	0x9998
+0xF1C6	0x99A5
+0xF1C7	0x99AD
+0xF1C8	0x99AE
+0xF1C9	0x99BC
+0xF1CA	0x99DF
+0xF1CB	0x99DB
+0xF1CC	0x99DD
+0xF1CD	0x99D8
+0xF1CE	0x99D1
+0xF1CF	0x99ED
+0xF1D0	0x99EE
+0xF1D1	0x99F1
+0xF1D2	0x99F2
+0xF1D3	0x99FB
+0xF1D4	0x99F8
+0xF1D5	0x9A01
+0xF1D6	0x9A0F
+0xF1D7	0x9A05
+0xF1D8	0x99E2
+0xF1D9	0x9A19
+0xF1DA	0x9A2B
+0xF1DB	0x9A37
+0xF1DC	0x9A45
+0xF1DD	0x9A42
+0xF1DE	0x9A40
+0xF1DF	0x9A43
+0xF1E0	0x9A3E
+0xF1E1	0x9A55
+0xF1E2	0x9A4D
+0xF1E3	0x9A5B
+0xF1E4	0x9A57
+0xF1E5	0x9A5F
+0xF1E6	0x9A62
+0xF1E7	0x9A65
+0xF1E8	0x9A64
+0xF1E9	0x9A69
+0xF1EA	0x9A6B
+0xF1EB	0x9A6A
+0xF1EC	0x9AAD
+0xF1ED	0x9AB0
+0xF1EE	0x9ABC
+0xF1EF	0x9AC0
+0xF1F0	0x9ACF
+0xF1F1	0x9AD1
+0xF1F2	0x9AD3
+0xF1F3	0x9AD4
+0xF1F4	0x9ADE
+0xF1F5	0x9ADF
+0xF1F6	0x9AE2
+0xF1F7	0x9AE3
+0xF1F8	0x9AE6
+0xF1F9	0x9AEF
+0xF1FA	0x9AEB
+0xF1FB	0x9AEE
+0xF1FC	0x9AF4
+0xF1FD	0x9AF1
+0xF1FE	0x9AF7
+0xF2A1	0x9AFB
+0xF2A2	0x9B06
+0xF2A3	0x9B18
+0xF2A4	0x9B1A
+0xF2A5	0x9B1F
+0xF2A6	0x9B22
+0xF2A7	0x9B23
+0xF2A8	0x9B25
+0xF2A9	0x9B27
+0xF2AA	0x9B28
+0xF2AB	0x9B29
+0xF2AC	0x9B2A
+0xF2AD	0x9B2E
+0xF2AE	0x9B2F
+0xF2AF	0x9B32
+0xF2B0	0x9B44
+0xF2B1	0x9B43
+0xF2B2	0x9B4F
+0xF2B3	0x9B4D
+0xF2B4	0x9B4E
+0xF2B5	0x9B51
+0xF2B6	0x9B58
+0xF2B7	0x9B74
+0xF2B8	0x9B93
+0xF2B9	0x9B83
+0xF2BA	0x9B91
+0xF2BB	0x9B96
+0xF2BC	0x9B97
+0xF2BD	0x9B9F
+0xF2BE	0x9BA0
+0xF2BF	0x9BA8
+0xF2C0	0x9BB4
+0xF2C1	0x9BC0
+0xF2C2	0x9BCA
+0xF2C3	0x9BB9
+0xF2C4	0x9BC6
+0xF2C5	0x9BCF
+0xF2C6	0x9BD1
+0xF2C7	0x9BD2
+0xF2C8	0x9BE3
+0xF2C9	0x9BE2
+0xF2CA	0x9BE4
+0xF2CB	0x9BD4
+0xF2CC	0x9BE1
+0xF2CD	0x9C3A
+0xF2CE	0x9BF2
+0xF2CF	0x9BF1
+0xF2D0	0x9BF0
+0xF2D1	0x9C15
+0xF2D2	0x9C14
+0xF2D3	0x9C09
+0xF2D4	0x9C13
+0xF2D5	0x9C0C
+0xF2D6	0x9C06
+0xF2D7	0x9C08
+0xF2D8	0x9C12
+0xF2D9	0x9C0A
+0xF2DA	0x9C04
+0xF2DB	0x9C2E
+0xF2DC	0x9C1B
+0xF2DD	0x9C25
+0xF2DE	0x9C24
+0xF2DF	0x9C21
+0xF2E0	0x9C30
+0xF2E1	0x9C47
+0xF2E2	0x9C32
+0xF2E3	0x9C46
+0xF2E4	0x9C3E
+0xF2E5	0x9C5A
+0xF2E6	0x9C60
+0xF2E7	0x9C67
+0xF2E8	0x9C76
+0xF2E9	0x9C78
+0xF2EA	0x9CE7
+0xF2EB	0x9CEC
+0xF2EC	0x9CF0
+0xF2ED	0x9D09
+0xF2EE	0x9D08
+0xF2EF	0x9CEB
+0xF2F0	0x9D03
+0xF2F1	0x9D06
+0xF2F2	0x9D2A
+0xF2F3	0x9D26
+0xF2F4	0x9DAF
+0xF2F5	0x9D23
+0xF2F6	0x9D1F
+0xF2F7	0x9D44
+0xF2F8	0x9D15
+0xF2F9	0x9D12
+0xF2FA	0x9D41
+0xF2FB	0x9D3F
+0xF2FC	0x9D3E
+0xF2FD	0x9D46
+0xF2FE	0x9D48
+0xF3A1	0x9D5D
+0xF3A2	0x9D5E
+0xF3A3	0x9D64
+0xF3A4	0x9D51
+0xF3A5	0x9D50
+0xF3A6	0x9D59
+0xF3A7	0x9D72
+0xF3A8	0x9D89
+0xF3A9	0x9D87
+0xF3AA	0x9DAB
+0xF3AB	0x9D6F
+0xF3AC	0x9D7A
+0xF3AD	0x9D9A
+0xF3AE	0x9DA4
+0xF3AF	0x9DA9
+0xF3B0	0x9DB2
+0xF3B1	0x9DC4
+0xF3B2	0x9DC1
+0xF3B3	0x9DBB
+0xF3B4	0x9DB8
+0xF3B5	0x9DBA
+0xF3B6	0x9DC6
+0xF3B7	0x9DCF
+0xF3B8	0x9DC2
+0xF3B9	0x9DD9
+0xF3BA	0x9DD3
+0xF3BB	0x9DF8
+0xF3BC	0x9DE6
+0xF3BD	0x9DED
+0xF3BE	0x9DEF
+0xF3BF	0x9DFD
+0xF3C0	0x9E1A
+0xF3C1	0x9E1B
+0xF3C2	0x9E1E
+0xF3C3	0x9E75
+0xF3C4	0x9E79
+0xF3C5	0x9E7D
+0xF3C6	0x9E81
+0xF3C7	0x9E88
+0xF3C8	0x9E8B
+0xF3C9	0x9E8C
+0xF3CA	0x9E92
+0xF3CB	0x9E95
+0xF3CC	0x9E91
+0xF3CD	0x9E9D
+0xF3CE	0x9EA5
+0xF3CF	0x9EA9
+0xF3D0	0x9EB8
+0xF3D1	0x9EAA
+0xF3D2	0x9EAD
+0xF3D3	0x9761
+0xF3D4	0x9ECC
+0xF3D5	0x9ECE
+0xF3D6	0x9ECF
+0xF3D7	0x9ED0
+0xF3D8	0x9ED4
+0xF3D9	0x9EDC
+0xF3DA	0x9EDE
+0xF3DB	0x9EDD
+0xF3DC	0x9EE0
+0xF3DD	0x9EE5
+0xF3DE	0x9EE8
+0xF3DF	0x9EEF
+0xF3E0	0x9EF4
+0xF3E1	0x9EF6
+0xF3E2	0x9EF7
+0xF3E3	0x9EF9
+0xF3E4	0x9EFB
+0xF3E5	0x9EFC
+0xF3E6	0x9EFD
+0xF3E7	0x9F07
+0xF3E8	0x9F08
+0xF3E9	0x76B7
+0xF3EA	0x9F15
+0xF3EB	0x9F21
+0xF3EC	0x9F2C
+0xF3ED	0x9F3E
+0xF3EE	0x9F4A
+0xF3EF	0x9F52
+0xF3F0	0x9F54
+0xF3F1	0x9F63
+0xF3F2	0x9F5F
+0xF3F3	0x9F60
+0xF3F4	0x9F61
+0xF3F5	0x9F66
+0xF3F6	0x9F67
+0xF3F7	0x9F6C
+0xF3F8	0x9F6A
+0xF3F9	0x9F77
+0xF3FA	0x9F72
+0xF3FB	0x9F76
+0xF3FC	0x9F95
+0xF3FD	0x9F9C
+0xF3FE	0x9FA0
+0xF4A1	0x582F
+0xF4A2	0x69C7
+0xF4A3	0x9059
+0xF4A4	0x7464
+0xF4A5	0x51DC
+0xF4A6	0x7199
+0xF5A1	0xE000
+0xF5A2	0xE001
+0xF5A3	0xE002
+0xF5A4	0xE003
+0xF5A5	0xE004
+0xF5A6	0xE005
+0xF5A7	0xE006
+0xF5A8	0xE007
+0xF5A9	0xE008
+0xF5AA	0xE009
+0xF5AB	0xE00A
+0xF5AC	0xE00B
+0xF5AD	0xE00C
+0xF5AE	0xE00D
+0xF5AF	0xE00E
+0xF5B0	0xE00F
+0xF5B1	0xE010
+0xF5B2	0xE011
+0xF5B3	0xE012
+0xF5B4	0xE013
+0xF5B5	0xE014
+0xF5B6	0xE015
+0xF5B7	0xE016
+0xF5B8	0xE017
+0xF5B9	0xE018
+0xF5BA	0xE019
+0xF5BB	0xE01A
+0xF5BC	0xE01B
+0xF5BD	0xE01C
+0xF5BE	0xE01D
+0xF5BF	0xE01E
+0xF5C0	0xE01F
+0xF5C1	0xE020
+0xF5C2	0xE021
+0xF5C3	0xE022
+0xF5C4	0xE023
+0xF5C5	0xE024
+0xF5C6	0xE025
+0xF5C7	0xE026
+0xF5C8	0xE027
+0xF5C9	0xE028
+0xF5CA	0xE029
+0xF5CB	0xE02A
+0xF5CC	0xE02B
+0xF5CD	0xE02C
+0xF5CE	0xE02D
+0xF5CF	0xE02E
+0xF5D0	0xE02F
+0xF5D1	0xE030
+0xF5D2	0xE031
+0xF5D3	0xE032
+0xF5D4	0xE033
+0xF5D5	0xE034
+0xF5D6	0xE035
+0xF5D7	0xE036
+0xF5D8	0xE037
+0xF5D9	0xE038
+0xF5DA	0xE039
+0xF5DB	0xE03A
+0xF5DC	0xE03B
+0xF5DD	0xE03C
+0xF5DE	0xE03D
+0xF5DF	0xE03E
+0xF5E0	0xE03F
+0xF5E1	0xE040
+0xF5E2	0xE041
+0xF5E3	0xE042
+0xF5E4	0xE043
+0xF5E5	0xE044
+0xF5E6	0xE045
+0xF5E7	0xE046
+0xF5E8	0xE047
+0xF5E9	0xE048
+0xF5EA	0xE049
+0xF5EB	0xE04A
+0xF5EC	0xE04B
+0xF5ED	0xE04C
+0xF5EE	0xE04D
+0xF5EF	0xE04E
+0xF5F0	0xE04F
+0xF5F1	0xE050
+0xF5F2	0xE051
+0xF5F3	0xE052
+0xF5F4	0xE053
+0xF5F5	0xE054
+0xF5F6	0xE055
+0xF5F7	0xE056
+0xF5F8	0xE057
+0xF5F9	0xE058
+0xF5FA	0xE059
+0xF5FB	0xE05A
+0xF5FC	0xE05B
+0xF5FD	0xE05C
+0xF5FE	0xE05D
+0xF6A1	0xE05E
+0xF6A2	0xE05F
+0xF6A3	0xE060
+0xF6A4	0xE061
+0xF6A5	0xE062
+0xF6A6	0xE063
+0xF6A7	0xE064
+0xF6A8	0xE065
+0xF6A9	0xE066
+0xF6AA	0xE067
+0xF6AB	0xE068
+0xF6AC	0xE069
+0xF6AD	0xE06A
+0xF6AE	0xE06B
+0xF6AF	0xE06C
+0xF6B0	0xE06D
+0xF6B1	0xE06E
+0xF6B2	0xE06F
+0xF6B3	0xE070
+0xF6B4	0xE071
+0xF6B5	0xE072
+0xF6B6	0xE073
+0xF6B7	0xE074
+0xF6B8	0xE075
+0xF6B9	0xE076
+0xF6BA	0xE077
+0xF6BB	0xE078
+0xF6BC	0xE079
+0xF6BD	0xE07A
+0xF6BE	0xE07B
+0xF6BF	0xE07C
+0xF6C0	0xE07D
+0xF6C1	0xE07E
+0xF6C2	0xE07F
+0xF6C3	0xE080
+0xF6C4	0xE081
+0xF6C5	0xE082
+0xF6C6	0xE083
+0xF6C7	0xE084
+0xF6C8	0xE085
+0xF6C9	0xE086
+0xF6CA	0xE087
+0xF6CB	0xE088
+0xF6CC	0xE089
+0xF6CD	0xE08A
+0xF6CE	0xE08B
+0xF6CF	0xE08C
+0xF6D0	0xE08D
+0xF6D1	0xE08E
+0xF6D2	0xE08F
+0xF6D3	0xE090
+0xF6D4	0xE091
+0xF6D5	0xE092
+0xF6D6	0xE093
+0xF6D7	0xE094
+0xF6D8	0xE095
+0xF6D9	0xE096
+0xF6DA	0xE097
+0xF6DB	0xE098
+0xF6DC	0xE099
+0xF6DD	0xE09A
+0xF6DE	0xE09B
+0xF6DF	0xE09C
+0xF6E0	0xE09D
+0xF6E1	0xE09E
+0xF6E2	0xE09F
+0xF6E3	0xE0A0
+0xF6E4	0xE0A1
+0xF6E5	0xE0A2
+0xF6E6	0xE0A3
+0xF6E7	0xE0A4
+0xF6E8	0xE0A5
+0xF6E9	0xE0A6
+0xF6EA	0xE0A7
+0xF6EB	0xE0A8
+0xF6EC	0xE0A9
+0xF6ED	0xE0AA
+0xF6EE	0xE0AB
+0xF6EF	0xE0AC
+0xF6F0	0xE0AD
+0xF6F1	0xE0AE
+0xF6F2	0xE0AF
+0xF6F3	0xE0B0
+0xF6F4	0xE0B1
+0xF6F5	0xE0B2
+0xF6F6	0xE0B3
+0xF6F7	0xE0B4
+0xF6F8	0xE0B5
+0xF6F9	0xE0B6
+0xF6FA	0xE0B7
+0xF6FB	0xE0B8
+0xF6FC	0xE0B9
+0xF6FD	0xE0BA
+0xF6FE	0xE0BB
+0xF7A1	0xE0BC
+0xF7A2	0xE0BD
+0xF7A3	0xE0BE
+0xF7A4	0xE0BF
+0xF7A5	0xE0C0
+0xF7A6	0xE0C1
+0xF7A7	0xE0C2
+0xF7A8	0xE0C3
+0xF7A9	0xE0C4
+0xF7AA	0xE0C5
+0xF7AB	0xE0C6
+0xF7AC	0xE0C7
+0xF7AD	0xE0C8
+0xF7AE	0xE0C9
+0xF7AF	0xE0CA
+0xF7B0	0xE0CB
+0xF7B1	0xE0CC
+0xF7B2	0xE0CD
+0xF7B3	0xE0CE
+0xF7B4	0xE0CF
+0xF7B5	0xE0D0
+0xF7B6	0xE0D1
+0xF7B7	0xE0D2
+0xF7B8	0xE0D3
+0xF7B9	0xE0D4
+0xF7BA	0xE0D5
+0xF7BB	0xE0D6
+0xF7BC	0xE0D7
+0xF7BD	0xE0D8
+0xF7BE	0xE0D9
+0xF7BF	0xE0DA
+0xF7C0	0xE0DB
+0xF7C1	0xE0DC
+0xF7C2	0xE0DD
+0xF7C3	0xE0DE
+0xF7C4	0xE0DF
+0xF7C5	0xE0E0
+0xF7C6	0xE0E1
+0xF7C7	0xE0E2
+0xF7C8	0xE0E3
+0xF7C9	0xE0E4
+0xF7CA	0xE0E5
+0xF7CB	0xE0E6
+0xF7CC	0xE0E7
+0xF7CD	0xE0E8
+0xF7CE	0xE0E9
+0xF7CF	0xE0EA
+0xF7D0	0xE0EB
+0xF7D1	0xE0EC
+0xF7D2	0xE0ED
+0xF7D3	0xE0EE
+0xF7D4	0xE0EF
+0xF7D5	0xE0F0
+0xF7D6	0xE0F1
+0xF7D7	0xE0F2
+0xF7D8	0xE0F3
+0xF7D9	0xE0F4
+0xF7DA	0xE0F5
+0xF7DB	0xE0F6
+0xF7DC	0xE0F7
+0xF7DD	0xE0F8
+0xF7DE	0xE0F9
+0xF7DF	0xE0FA
+0xF7E0	0xE0FB
+0xF7E1	0xE0FC
+0xF7E2	0xE0FD
+0xF7E3	0xE0FE
+0xF7E4	0xE0FF
+0xF7E5	0xE100
+0xF7E6	0xE101
+0xF7E7	0xE102
+0xF7E8	0xE103
+0xF7E9	0xE104
+0xF7EA	0xE105
+0xF7EB	0xE106
+0xF7EC	0xE107
+0xF7ED	0xE108
+0xF7EE	0xE109
+0xF7EF	0xE10A
+0xF7F0	0xE10B
+0xF7F1	0xE10C
+0xF7F2	0xE10D
+0xF7F3	0xE10E
+0xF7F4	0xE10F
+0xF7F5	0xE110
+0xF7F6	0xE111
+0xF7F7	0xE112
+0xF7F8	0xE113
+0xF7F9	0xE114
+0xF7FA	0xE115
+0xF7FB	0xE116
+0xF7FC	0xE117
+0xF7FD	0xE118
+0xF7FE	0xE119
+0xF8A1	0xE11A
+0xF8A2	0xE11B
+0xF8A3	0xE11C
+0xF8A4	0xE11D
+0xF8A5	0xE11E
+0xF8A6	0xE11F
+0xF8A7	0xE120
+0xF8A8	0xE121
+0xF8A9	0xE122
+0xF8AA	0xE123
+0xF8AB	0xE124
+0xF8AC	0xE125
+0xF8AD	0xE126
+0xF8AE	0xE127
+0xF8AF	0xE128
+0xF8B0	0xE129
+0xF8B1	0xE12A
+0xF8B2	0xE12B
+0xF8B3	0xE12C
+0xF8B4	0xE12D
+0xF8B5	0xE12E
+0xF8B6	0xE12F
+0xF8B7	0xE130
+0xF8B8	0xE131
+0xF8B9	0xE132
+0xF8BA	0xE133
+0xF8BB	0xE134
+0xF8BC	0xE135
+0xF8BD	0xE136
+0xF8BE	0xE137
+0xF8BF	0xE138
+0xF8C0	0xE139
+0xF8C1	0xE13A
+0xF8C2	0xE13B
+0xF8C3	0xE13C
+0xF8C4	0xE13D
+0xF8C5	0xE13E
+0xF8C6	0xE13F
+0xF8C7	0xE140
+0xF8C8	0xE141
+0xF8C9	0xE142
+0xF8CA	0xE143
+0xF8CB	0xE144
+0xF8CC	0xE145
+0xF8CD	0xE146
+0xF8CE	0xE147
+0xF8CF	0xE148
+0xF8D0	0xE149
+0xF8D1	0xE14A
+0xF8D2	0xE14B
+0xF8D3	0xE14C
+0xF8D4	0xE14D
+0xF8D5	0xE14E
+0xF8D6	0xE14F
+0xF8D7	0xE150
+0xF8D8	0xE151
+0xF8D9	0xE152
+0xF8DA	0xE153
+0xF8DB	0xE154
+0xF8DC	0xE155
+0xF8DD	0xE156
+0xF8DE	0xE157
+0xF8DF	0xE158
+0xF8E0	0xE159
+0xF8E1	0xE15A
+0xF8E2	0xE15B
+0xF8E3	0xE15C
+0xF8E4	0xE15D
+0xF8E5	0xE15E
+0xF8E6	0xE15F
+0xF8E7	0xE160
+0xF8E8	0xE161
+0xF8E9	0xE162
+0xF8EA	0xE163
+0xF8EB	0xE164
+0xF8EC	0xE165
+0xF8ED	0xE166
+0xF8EE	0xE167
+0xF8EF	0xE168
+0xF8F0	0xE169
+0xF8F1	0xE16A
+0xF8F2	0xE16B
+0xF8F3	0xE16C
+0xF8F4	0xE16D
+0xF8F5	0xE16E
+0xF8F6	0xE16F
+0xF8F7	0xE170
+0xF8F8	0xE171
+0xF8F9	0xE172
+0xF8FA	0xE173
+0xF8FB	0xE174
+0xF8FC	0xE175
+0xF8FD	0xE176
+0xF8FE	0xE177
+0xF9A1	0xE178
+0xF9A2	0xE179
+0xF9A3	0xE17A
+0xF9A4	0xE17B
+0xF9A5	0xE17C
+0xF9A6	0xE17D
+0xF9A7	0xE17E
+0xF9A8	0xE17F
+0xF9A9	0xE180
+0xF9AA	0xE181
+0xF9AB	0xE182
+0xF9AC	0xE183
+0xF9AD	0xE184
+0xF9AE	0xE185
+0xF9AF	0xE186
+0xF9B0	0xE187
+0xF9B1	0xE188
+0xF9B2	0xE189
+0xF9B3	0xE18A
+0xF9B4	0xE18B
+0xF9B5	0xE18C
+0xF9B6	0xE18D
+0xF9B7	0xE18E
+0xF9B8	0xE18F
+0xF9B9	0xE190
+0xF9BA	0xE191
+0xF9BB	0xE192
+0xF9BC	0xE193
+0xF9BD	0xE194
+0xF9BE	0xE195
+0xF9BF	0xE196
+0xF9C0	0xE197
+0xF9C1	0xE198
+0xF9C2	0xE199
+0xF9C3	0xE19A
+0xF9C4	0xE19B
+0xF9C5	0xE19C
+0xF9C6	0xE19D
+0xF9C7	0xE19E
+0xF9C8	0xE19F
+0xF9C9	0xE1A0
+0xF9CA	0xE1A1
+0xF9CB	0xE1A2
+0xF9CC	0xE1A3
+0xF9CD	0xE1A4
+0xF9CE	0xE1A5
+0xF9CF	0xE1A6
+0xF9D0	0xE1A7
+0xF9D1	0xE1A8
+0xF9D2	0xE1A9
+0xF9D3	0xE1AA
+0xF9D4	0xE1AB
+0xF9D5	0xE1AC
+0xF9D6	0xE1AD
+0xF9D7	0xE1AE
+0xF9D8	0xE1AF
+0xF9D9	0xE1B0
+0xF9DA	0xE1B1
+0xF9DB	0xE1B2
+0xF9DC	0xE1B3
+0xF9DD	0xE1B4
+0xF9DE	0xE1B5
+0xF9DF	0xE1B6
+0xF9E0	0xE1B7
+0xF9E1	0xE1B8
+0xF9E2	0xE1B9
+0xF9E3	0xE1BA
+0xF9E4	0xE1BB
+0xF9E5	0xE1BC
+0xF9E6	0xE1BD
+0xF9E7	0xE1BE
+0xF9E8	0xE1BF
+0xF9E9	0xE1C0
+0xF9EA	0xE1C1
+0xF9EB	0xE1C2
+0xF9EC	0xE1C3
+0xF9ED	0xE1C4
+0xF9EE	0xE1C5
+0xF9EF	0xE1C6
+0xF9F0	0xE1C7
+0xF9F1	0xE1C8
+0xF9F2	0xE1C9
+0xF9F3	0xE1CA
+0xF9F4	0xE1CB
+0xF9F5	0xE1CC
+0xF9F6	0xE1CD
+0xF9F7	0xE1CE
+0xF9F8	0xE1CF
+0xF9F9	0xE1D0
+0xF9FA	0xE1D1
+0xF9FB	0xE1D2
+0xF9FC	0xE1D3
+0xF9FD	0xE1D4
+0xF9FE	0xE1D5
+0xFAA1	0xE1D6
+0xFAA2	0xE1D7
+0xFAA3	0xE1D8
+0xFAA4	0xE1D9
+0xFAA5	0xE1DA
+0xFAA6	0xE1DB
+0xFAA7	0xE1DC
+0xFAA8	0xE1DD
+0xFAA9	0xE1DE
+0xFAAA	0xE1DF
+0xFAAB	0xE1E0
+0xFAAC	0xE1E1
+0xFAAD	0xE1E2
+0xFAAE	0xE1E3
+0xFAAF	0xE1E4
+0xFAB0	0xE1E5
+0xFAB1	0xE1E6
+0xFAB2	0xE1E7
+0xFAB3	0xE1E8
+0xFAB4	0xE1E9
+0xFAB5	0xE1EA
+0xFAB6	0xE1EB
+0xFAB7	0xE1EC
+0xFAB8	0xE1ED
+0xFAB9	0xE1EE
+0xFABA	0xE1EF
+0xFABB	0xE1F0
+0xFABC	0xE1F1
+0xFABD	0xE1F2
+0xFABE	0xE1F3
+0xFABF	0xE1F4
+0xFAC0	0xE1F5
+0xFAC1	0xE1F6
+0xFAC2	0xE1F7
+0xFAC3	0xE1F8
+0xFAC4	0xE1F9
+0xFAC5	0xE1FA
+0xFAC6	0xE1FB
+0xFAC7	0xE1FC
+0xFAC8	0xE1FD
+0xFAC9	0xE1FE
+0xFACA	0xE1FF
+0xFACB	0xE200
+0xFACC	0xE201
+0xFACD	0xE202
+0xFACE	0xE203
+0xFACF	0xE204
+0xFAD0	0xE205
+0xFAD1	0xE206
+0xFAD2	0xE207
+0xFAD3	0xE208
+0xFAD4	0xE209
+0xFAD5	0xE20A
+0xFAD6	0xE20B
+0xFAD7	0xE20C
+0xFAD8	0xE20D
+0xFAD9	0xE20E
+0xFADA	0xE20F
+0xFADB	0xE210
+0xFADC	0xE211
+0xFADD	0xE212
+0xFADE	0xE213
+0xFADF	0xE214
+0xFAE0	0xE215
+0xFAE1	0xE216
+0xFAE2	0xE217
+0xFAE3	0xE218
+0xFAE4	0xE219
+0xFAE5	0xE21A
+0xFAE6	0xE21B
+0xFAE7	0xE21C
+0xFAE8	0xE21D
+0xFAE9	0xE21E
+0xFAEA	0xE21F
+0xFAEB	0xE220
+0xFAEC	0xE221
+0xFAED	0xE222
+0xFAEE	0xE223
+0xFAEF	0xE224
+0xFAF0	0xE225
+0xFAF1	0xE226
+0xFAF2	0xE227
+0xFAF3	0xE228
+0xFAF4	0xE229
+0xFAF5	0xE22A
+0xFAF6	0xE22B
+0xFAF7	0xE22C
+0xFAF8	0xE22D
+0xFAF9	0xE22E
+0xFAFA	0xE22F
+0xFAFB	0xE230
+0xFAFC	0xE231
+0xFAFD	0xE232
+0xFAFE	0xE233
+0xFBA1	0xE234
+0xFBA2	0xE235
+0xFBA3	0xE236
+0xFBA4	0xE237
+0xFBA5	0xE238
+0xFBA6	0xE239
+0xFBA7	0xE23A
+0xFBA8	0xE23B
+0xFBA9	0xE23C
+0xFBAA	0xE23D
+0xFBAB	0xE23E
+0xFBAC	0xE23F
+0xFBAD	0xE240
+0xFBAE	0xE241
+0xFBAF	0xE242
+0xFBB0	0xE243
+0xFBB1	0xE244
+0xFBB2	0xE245
+0xFBB3	0xE246
+0xFBB4	0xE247
+0xFBB5	0xE248
+0xFBB6	0xE249
+0xFBB7	0xE24A
+0xFBB8	0xE24B
+0xFBB9	0xE24C
+0xFBBA	0xE24D
+0xFBBB	0xE24E
+0xFBBC	0xE24F
+0xFBBD	0xE250
+0xFBBE	0xE251
+0xFBBF	0xE252
+0xFBC0	0xE253
+0xFBC1	0xE254
+0xFBC2	0xE255
+0xFBC3	0xE256
+0xFBC4	0xE257
+0xFBC5	0xE258
+0xFBC6	0xE259
+0xFBC7	0xE25A
+0xFBC8	0xE25B
+0xFBC9	0xE25C
+0xFBCA	0xE25D
+0xFBCB	0xE25E
+0xFBCC	0xE25F
+0xFBCD	0xE260
+0xFBCE	0xE261
+0xFBCF	0xE262
+0xFBD0	0xE263
+0xFBD1	0xE264
+0xFBD2	0xE265
+0xFBD3	0xE266
+0xFBD4	0xE267
+0xFBD5	0xE268
+0xFBD6	0xE269
+0xFBD7	0xE26A
+0xFBD8	0xE26B
+0xFBD9	0xE26C
+0xFBDA	0xE26D
+0xFBDB	0xE26E
+0xFBDC	0xE26F
+0xFBDD	0xE270
+0xFBDE	0xE271
+0xFBDF	0xE272
+0xFBE0	0xE273
+0xFBE1	0xE274
+0xFBE2	0xE275
+0xFBE3	0xE276
+0xFBE4	0xE277
+0xFBE5	0xE278
+0xFBE6	0xE279
+0xFBE7	0xE27A
+0xFBE8	0xE27B
+0xFBE9	0xE27C
+0xFBEA	0xE27D
+0xFBEB	0xE27E
+0xFBEC	0xE27F
+0xFBED	0xE280
+0xFBEE	0xE281
+0xFBEF	0xE282
+0xFBF0	0xE283
+0xFBF1	0xE284
+0xFBF2	0xE285
+0xFBF3	0xE286
+0xFBF4	0xE287
+0xFBF5	0xE288
+0xFBF6	0xE289
+0xFBF7	0xE28A
+0xFBF8	0xE28B
+0xFBF9	0xE28C
+0xFBFA	0xE28D
+0xFBFB	0xE28E
+0xFBFC	0xE28F
+0xFBFD	0xE290
+0xFBFE	0xE291
+0xFCA1	0xE292
+0xFCA2	0xE293
+0xFCA3	0xE294
+0xFCA4	0xE295
+0xFCA5	0xE296
+0xFCA6	0xE297
+0xFCA7	0xE298
+0xFCA8	0xE299
+0xFCA9	0xE29A
+0xFCAA	0xE29B
+0xFCAB	0xE29C
+0xFCAC	0xE29D
+0xFCAD	0xE29E
+0xFCAE	0xE29F
+0xFCAF	0xE2A0
+0xFCB0	0xE2A1
+0xFCB1	0xE2A2
+0xFCB2	0xE2A3
+0xFCB3	0xE2A4
+0xFCB4	0xE2A5
+0xFCB5	0xE2A6
+0xFCB6	0xE2A7
+0xFCB7	0xE2A8
+0xFCB8	0xE2A9
+0xFCB9	0xE2AA
+0xFCBA	0xE2AB
+0xFCBB	0xE2AC
+0xFCBC	0xE2AD
+0xFCBD	0xE2AE
+0xFCBE	0xE2AF
+0xFCBF	0xE2B0
+0xFCC0	0xE2B1
+0xFCC1	0xE2B2
+0xFCC2	0xE2B3
+0xFCC3	0xE2B4
+0xFCC4	0xE2B5
+0xFCC5	0xE2B6
+0xFCC6	0xE2B7
+0xFCC7	0xE2B8
+0xFCC8	0xE2B9
+0xFCC9	0xE2BA
+0xFCCA	0xE2BB
+0xFCCB	0xE2BC
+0xFCCC	0xE2BD
+0xFCCD	0xE2BE
+0xFCCE	0xE2BF
+0xFCCF	0xE2C0
+0xFCD0	0xE2C1
+0xFCD1	0xE2C2
+0xFCD2	0xE2C3
+0xFCD3	0xE2C4
+0xFCD4	0xE2C5
+0xFCD5	0xE2C6
+0xFCD6	0xE2C7
+0xFCD7	0xE2C8
+0xFCD8	0xE2C9
+0xFCD9	0xE2CA
+0xFCDA	0xE2CB
+0xFCDB	0xE2CC
+0xFCDC	0xE2CD
+0xFCDD	0xE2CE
+0xFCDE	0xE2CF
+0xFCDF	0xE2D0
+0xFCE0	0xE2D1
+0xFCE1	0xE2D2
+0xFCE2	0xE2D3
+0xFCE3	0xE2D4
+0xFCE4	0xE2D5
+0xFCE5	0xE2D6
+0xFCE6	0xE2D7
+0xFCE7	0xE2D8
+0xFCE8	0xE2D9
+0xFCE9	0xE2DA
+0xFCEA	0xE2DB
+0xFCEB	0xE2DC
+0xFCEC	0xE2DD
+0xFCED	0xE2DE
+0xFCEE	0xE2DF
+0xFCEF	0xE2E0
+0xFCF0	0xE2E1
+0xFCF1	0xE2E2
+0xFCF2	0xE2E3
+0xFCF3	0xE2E4
+0xFCF4	0xE2E5
+0xFCF5	0xE2E6
+0xFCF6	0xE2E7
+0xFCF7	0xE2E8
+0xFCF8	0xE2E9
+0xFCF9	0xE2EA
+0xFCFA	0xE2EB
+0xFCFB	0xE2EC
+0xFCFC	0xE2ED
+0xFCFD	0xE2EE
+0xFCFE	0xE2EF
+0xFDA1	0xE2F0
+0xFDA2	0xE2F1
+0xFDA3	0xE2F2
+0xFDA4	0xE2F3
+0xFDA5	0xE2F4
+0xFDA6	0xE2F5
+0xFDA7	0xE2F6
+0xFDA8	0xE2F7
+0xFDA9	0xE2F8
+0xFDAA	0xE2F9
+0xFDAB	0xE2FA
+0xFDAC	0xE2FB
+0xFDAD	0xE2FC
+0xFDAE	0xE2FD
+0xFDAF	0xE2FE
+0xFDB0	0xE2FF
+0xFDB1	0xE300
+0xFDB2	0xE301
+0xFDB3	0xE302
+0xFDB4	0xE303
+0xFDB5	0xE304
+0xFDB6	0xE305
+0xFDB7	0xE306
+0xFDB8	0xE307
+0xFDB9	0xE308
+0xFDBA	0xE309
+0xFDBB	0xE30A
+0xFDBC	0xE30B
+0xFDBD	0xE30C
+0xFDBE	0xE30D
+0xFDBF	0xE30E
+0xFDC0	0xE30F
+0xFDC1	0xE310
+0xFDC2	0xE311
+0xFDC3	0xE312
+0xFDC4	0xE313
+0xFDC5	0xE314
+0xFDC6	0xE315
+0xFDC7	0xE316
+0xFDC8	0xE317
+0xFDC9	0xE318
+0xFDCA	0xE319
+0xFDCB	0xE31A
+0xFDCC	0xE31B
+0xFDCD	0xE31C
+0xFDCE	0xE31D
+0xFDCF	0xE31E
+0xFDD0	0xE31F
+0xFDD1	0xE320
+0xFDD2	0xE321
+0xFDD3	0xE322
+0xFDD4	0xE323
+0xFDD5	0xE324
+0xFDD6	0xE325
+0xFDD7	0xE326
+0xFDD8	0xE327
+0xFDD9	0xE328
+0xFDDA	0xE329
+0xFDDB	0xE32A
+0xFDDC	0xE32B
+0xFDDD	0xE32C
+0xFDDE	0xE32D
+0xFDDF	0xE32E
+0xFDE0	0xE32F
+0xFDE1	0xE330
+0xFDE2	0xE331
+0xFDE3	0xE332
+0xFDE4	0xE333
+0xFDE5	0xE334
+0xFDE6	0xE335
+0xFDE7	0xE336
+0xFDE8	0xE337
+0xFDE9	0xE338
+0xFDEA	0xE339
+0xFDEB	0xE33A
+0xFDEC	0xE33B
+0xFDED	0xE33C
+0xFDEE	0xE33D
+0xFDEF	0xE33E
+0xFDF0	0xE33F
+0xFDF1	0xE340
+0xFDF2	0xE341
+0xFDF3	0xE342
+0xFDF4	0xE343
+0xFDF5	0xE344
+0xFDF6	0xE345
+0xFDF7	0xE346
+0xFDF8	0xE347
+0xFDF9	0xE348
+0xFDFA	0xE349
+0xFDFB	0xE34A
+0xFDFC	0xE34B
+0xFDFD	0xE34C
+0xFDFE	0xE34D
+0xFEA1	0xE34E
+0xFEA2	0xE34F
+0xFEA3	0xE350
+0xFEA4	0xE351
+0xFEA5	0xE352
+0xFEA6	0xE353
+0xFEA7	0xE354
+0xFEA8	0xE355
+0xFEA9	0xE356
+0xFEAA	0xE357
+0xFEAB	0xE358
+0xFEAC	0xE359
+0xFEAD	0xE35A
+0xFEAE	0xE35B
+0xFEAF	0xE35C
+0xFEB0	0xE35D
+0xFEB1	0xE35E
+0xFEB2	0xE35F
+0xFEB3	0xE360
+0xFEB4	0xE361
+0xFEB5	0xE362
+0xFEB6	0xE363
+0xFEB7	0xE364
+0xFEB8	0xE365
+0xFEB9	0xE366
+0xFEBA	0xE367
+0xFEBB	0xE368
+0xFEBC	0xE369
+0xFEBD	0xE36A
+0xFEBE	0xE36B
+0xFEBF	0xE36C
+0xFEC0	0xE36D
+0xFEC1	0xE36E
+0xFEC2	0xE36F
+0xFEC3	0xE370
+0xFEC4	0xE371
+0xFEC5	0xE372
+0xFEC6	0xE373
+0xFEC7	0xE374
+0xFEC8	0xE375
+0xFEC9	0xE376
+0xFECA	0xE377
+0xFECB	0xE378
+0xFECC	0xE379
+0xFECD	0xE37A
+0xFECE	0xE37B
+0xFECF	0xE37C
+0xFED0	0xE37D
+0xFED1	0xE37E
+0xFED2	0xE37F
+0xFED3	0xE380
+0xFED4	0xE381
+0xFED5	0xE382
+0xFED6	0xE383
+0xFED7	0xE384
+0xFED8	0xE385
+0xFED9	0xE386
+0xFEDA	0xE387
+0xFEDB	0xE388
+0xFEDC	0xE389
+0xFEDD	0xE38A
+0xFEDE	0xE38B
+0xFEDF	0xE38C
+0xFEE0	0xE38D
+0xFEE1	0xE38E
+0xFEE2	0xE38F
+0xFEE3	0xE390
+0xFEE4	0xE391
+0xFEE5	0xE392
+0xFEE6	0xE393
+0xFEE7	0xE394
+0xFEE8	0xE395
+0xFEE9	0xE396
+0xFEEA	0xE397
+0xFEEB	0xE398
+0xFEEC	0xE399
+0xFEED	0xE39A
+0xFEEE	0xE39B
+0xFEEF	0xE39C
+0xFEF0	0xE39D
+0xFEF1	0xE39E
+0xFEF2	0xE39F
+0xFEF3	0xE3A0
+0xFEF4	0xE3A1
+0xFEF5	0xE3A2
+0xFEF6	0xE3A3
+0xFEF7	0xE3A4
+0xFEF8	0xE3A5
+0xFEF9	0xE3A6
+0xFEFA	0xE3A7
+0xFEFB	0xE3A8
+0xFEFC	0xE3A9
+0xFEFD	0xE3AA
+0xFEFE	0xE3AB
diff -uprN libiconv-1.15-old/tests/ISO-2022-JP-3-snippet.UTF-8 libiconv-1.15/tests/ISO-2022-JP-3-snippet.UTF-8
--- libiconv-1.15-old/tests/ISO-2022-JP-3-snippet.UTF-8	2009-06-21 20:17:33.000000000 +0900
+++ libiconv-1.15/tests/ISO-2022-JP-3-snippet.UTF-8	2017-09-17 05:38:54.204554000 +0900
@@ -9,7 +9,7 @@ p q r s t u v w x y z { | } ~
 ﾀ ﾁ ﾂ ﾃ ﾄ ﾅ ﾆ ﾇ ﾈ ﾉ ﾊ ﾋ ﾌ ﾍ ﾎ ﾏ
 ﾐ ﾑ ﾒ ﾓ ﾔ ﾕ ﾖ ﾗ ﾘ ﾙ ﾚ ﾛ ﾜ ﾝ ﾞ ﾟ
    　 、 。 ， ． ・ ： ； ？ ！ ゛ ゜ ´ ｀ ¨
-＾ ￣ ＿ ヽ ヾ ゝ ゞ 〃 仝 々 〆 〇 ー ― ‐ ／
+＾ ￣ ＿ ヽ ヾ ゝ ゞ 〃 仝 々 〆 〇 ー — ‐ ／
 ＼ 〜 ‖ ｜ … ‥ ‘ ’ “ ” （ ） 〔 〕 ［ ］
 ｛ ｝ 〈 〉 《 》 「 」 『 』 【 】 ＋ − ± ×
 ÷ ＝ ≠ ＜ ＞ ≦ ≧ ∞ ∴ ♂ ♀ ° ′ ″ ℃ ￥
diff -uprN libiconv-1.15-old/tests/ISO-2022-JP-MS-snippet libiconv-1.15/tests/ISO-2022-JP-MS-snippet
--- libiconv-1.15-old/tests/ISO-2022-JP-MS-snippet	2014-01-03 07:23:02.000000000 +0900
+++ libiconv-1.15/tests/ISO-2022-JP-MS-snippet	2017-09-17 05:38:54.213773000 +0900
@@ -4,6 +4,620 @@
 P Q R S T U V W X Y Z [ \ ] ^ _
 ` a b c d e f g h i j k l m n o
 p q r s t u v w x y z { | } ~
+   (I!(B (I"(B (I#(B (I$(B (I%(B (I&(B (I'(B (I((B (I)(B (I*(B (I+(B (I,(B (I-(B (I.(B (I/(B
+(I0(B (I1(B (I2(B (I3(B (I4(B (I5(B (I6(B (I7(B (I8(B (I9(B (I:(B (I;(B (I<(B (I=(B (I>(B (I?(B
+(I@(B (IA(B (IB(B (IC(B (ID(B (IE(B (IF(B (IG(B (IH(B (II(B (IJ(B (IK(B (IL(B (IM(B (IN(B (IO(B
+(IP(B (IQ(B (IR(B (IS(B (IT(B (IU(B (IV(B (IW(B (IX(B (IY(B (IZ(B (I[(B (I\(B (I](B (I^(B (I_(B
+  $B!!(B $B!"(B $B!#(B $B!$(B $B!%(B $B!&(B $B!'(B $B!((B $B!)(B $B!*(B $B!+(B $B!,(B $B!-(B $B!.(B $B!/(B
+$B!0(B $B!1(B $B!2(B $B!3(B $B!4(B $B!5(B $B!6(B $B!7(B $B!8(B $B!9(B $B!:(B $B!;(B $B!<(B $B!=(B $B!>(B $B!?(B
+  $B!A(B $B!B(B $B!C(B $B!D(B $B!E(B $B!F(B $B!G(B $B!H(B $B!I(B $B!J(B $B!K(B $B!L(B $B!M(B $B!N(B $B!O(B
+$B!P(B $B!Q(B $B!R(B $B!S(B $B!T(B $B!U(B $B!V(B $B!W(B $B!X(B $B!Y(B $B!Z(B $B![(B $B!\(B $B!](B $B!^(B $B!_(B
+$B!`(B $B!a(B $B!b(B $B!c(B $B!d(B $B!e(B $B!f(B $B!g(B $B!h(B $B!i(B $B!j(B $B!k(B $B!l(B $B!m(B $B!n(B $B!o(B
+$B!p(B $B!q(B $B!r(B $B!s(B $B!t(B $B!u(B $B!v(B $B!w(B $B!x(B $B!y(B $B!z(B $B!{(B $B!|(B $B!}(B $B!~(B
+  $B"!(B $B""(B $B"#(B $B"$(B $B"%(B $B"&(B $B"'(B $B"((B $B")(B $B"*(B $B"+(B $B",(B $B"-(B $B".(B
+                    $B":(B $B";(B $B"<(B $B"=(B $B">(B $B"?(B
+$B"@(B $B"A(B                 $B"J(B $B"K(B $B"L(B $B"M(B $B"N(B $B"O(B
+$B"P(B                       $B"\(B $B"](B $B"^(B $B"_(B
+$B"`(B $B"a(B $B"b(B $B"c(B $B"d(B $B"e(B $B"f(B $B"g(B $B"h(B $B"i(B $B"j(B
+    $B"r(B $B"s(B $B"t(B $B"u(B $B"v(B $B"w(B $B"x(B $B"y(B         $B"~(B
+$B#0(B $B#1(B $B#2(B $B#3(B $B#4(B $B#5(B $B#6(B $B#7(B $B#8(B $B#9(B
+   $B#A(B $B#B(B $B#C(B $B#D(B $B#E(B $B#F(B $B#G(B $B#H(B $B#I(B $B#J(B $B#K(B $B#L(B $B#M(B $B#N(B $B#O(B
+$B#P(B $B#Q(B $B#R(B $B#S(B $B#T(B $B#U(B $B#V(B $B#W(B $B#X(B $B#Y(B $B#Z(B
+   $B#a(B $B#b(B $B#c(B $B#d(B $B#e(B $B#f(B $B#g(B $B#h(B $B#i(B $B#j(B $B#k(B $B#l(B $B#m(B $B#n(B $B#o(B
+$B#p(B $B#q(B $B#r(B $B#s(B $B#t(B $B#u(B $B#v(B $B#w(B $B#x(B $B#y(B $B#z(B
+   $B$!(B $B$"(B $B$#(B $B$$(B $B$%(B $B$&(B $B$'(B $B$((B $B$)(B $B$*(B $B$+(B $B$,(B $B$-(B $B$.(B $B$/(B
+$B$0(B $B$1(B $B$2(B $B$3(B $B$4(B $B$5(B $B$6(B $B$7(B $B$8(B $B$9(B $B$:(B $B$;(B $B$<(B $B$=(B $B$>(B $B$?(B
+$B$@(B $B$A(B $B$B(B $B$C(B $B$D(B $B$E(B $B$F(B $B$G(B $B$H(B $B$I(B $B$J(B $B$K(B $B$L(B $B$M(B $B$N(B $B$O(B
+$B$P(B $B$Q(B $B$R(B $B$S(B $B$T(B $B$U(B $B$V(B $B$W(B $B$X(B $B$Y(B $B$Z(B $B$[(B $B$\(B $B$](B $B$^(B $B$_(B
+$B$`(B $B$a(B $B$b(B $B$c(B $B$d(B $B$e(B $B$f(B $B$g(B $B$h(B $B$i(B $B$j(B $B$k(B $B$l(B $B$m(B $B$n(B $B$o(B
+$B$p(B $B$q(B $B$r(B $B$s(B
+   $B%!(B $B%"(B $B%#(B $B%$(B $B%%(B $B%&(B $B%'(B $B%((B $B%)(B $B%*(B $B%+(B $B%,(B $B%-(B $B%.(B $B%/(B
+$B%0(B $B%1(B $B%2(B $B%3(B $B%4(B $B%5(B $B%6(B $B%7(B $B%8(B $B%9(B $B%:(B $B%;(B $B%<(B $B%=(B $B%>(B $B%?(B
+$B%@(B $B%A(B $B%B(B $B%C(B $B%D(B $B%E(B $B%F(B $B%G(B $B%H(B $B%I(B $B%J(B $B%K(B $B%L(B $B%M(B $B%N(B $B%O(B
+$B%P(B $B%Q(B $B%R(B $B%S(B $B%T(B $B%U(B $B%V(B $B%W(B $B%X(B $B%Y(B $B%Z(B $B%[(B $B%\(B $B%](B $B%^(B $B%_(B
+$B%`(B $B%a(B $B%b(B $B%c(B $B%d(B $B%e(B $B%f(B $B%g(B $B%h(B $B%i(B $B%j(B $B%k(B $B%l(B $B%m(B $B%n(B $B%o(B
+$B%p(B $B%q(B $B%r(B $B%s(B $B%t(B $B%u(B $B%v(B
+  $B&!(B $B&"(B $B&#(B $B&$(B $B&%(B $B&&(B $B&'(B $B&((B $B&)(B $B&*(B $B&+(B $B&,(B $B&-(B $B&.(B $B&/(B
+$B&0(B $B&1(B $B&2(B $B&3(B $B&4(B $B&5(B $B&6(B $B&7(B $B&8(B
+  $B&A(B $B&B(B $B&C(B $B&D(B $B&E(B $B&F(B $B&G(B $B&H(B $B&I(B $B&J(B $B&K(B $B&L(B $B&M(B $B&N(B $B&O(B
+$B&P(B $B&Q(B $B&R(B $B&S(B $B&T(B $B&U(B $B&V(B $B&W(B $B&X(B
+  $B'!(B $B'"(B $B'#(B $B'$(B $B'%(B $B'&(B $B''(B $B'((B $B')(B $B'*(B $B'+(B $B',(B $B'-(B $B'.(B $B'/(B
+$B'0(B $B'1(B $B'2(B $B'3(B $B'4(B $B'5(B $B'6(B $B'7(B $B'8(B $B'9(B $B':(B $B';(B $B'<(B $B'=(B $B'>(B $B'?(B
+$B'@(B $B'A(B
+  $B'Q(B $B'R(B $B'S(B $B'T(B $B'U(B $B'V(B $B'W(B $B'X(B $B'Y(B $B'Z(B $B'[(B $B'\(B $B'](B $B'^(B $B'_(B
+$B'`(B $B'a(B $B'b(B $B'c(B $B'd(B $B'e(B $B'f(B $B'g(B $B'h(B $B'i(B $B'j(B $B'k(B $B'l(B $B'm(B $B'n(B $B'o(B
+$B'p(B $B'q(B
+  $B(!(B $B("(B $B(#(B $B($(B $B(%(B $B(&(B $B('(B $B(((B $B()(B $B(*(B $B(+(B $B(,(B $B(-(B $B(.(B $B(/(B
+$B(0(B $B(1(B $B(2(B $B(3(B $B(4(B $B(5(B $B(6(B $B(7(B $B(8(B $B(9(B $B(:(B $B(;(B $B(<(B $B(=(B $B(>(B $B(?(B
+$B(@(B
+   $B-!(B $B-"(B $B-#(B $B-$(B $B-%(B $B-&(B $B-'(B $B-((B $B-)(B $B-*(B $B-+(B $B-,(B $B--(B $B-.(B $B-/(B
+$B-0(B $B-1(B $B-2(B $B-3(B $B-4(B $B-5(B $B-6(B $B-7(B $B-8(B $B-9(B $B-:(B $B-;(B $B-<(B $B-=(B $B->(B   
+$B-@(B $B-A(B $B-B(B $B-C(B $B-D(B $B-E(B $B-F(B $B-G(B $B-H(B $B-I(B $B-J(B $B-K(B $B-L(B $B-M(B $B-N(B $B-O(B
+$B-P(B $B-Q(B $B-R(B $B-S(B $B-T(B $B-U(B $B-V(B                         $B-_(B
+$B-`(B $B-a(B $B-b(B $B-c(B $B-d(B $B-e(B $B-f(B $B-g(B $B-h(B $B-i(B $B-j(B $B-k(B $B-l(B $B-m(B $B-n(B $B-o(B
+$B"b(B $B"a(B $B"i(B $B-s(B $B-t(B $B"e(B $B"](B $B"\(B $B-x(B $B-y(B $B"h(B $B"A(B $B"@(B      
+   $B0!(B $B0"(B $B0#(B $B0$(B $B0%(B $B0&(B $B0'(B $B0((B $B0)(B $B0*(B $B0+(B $B0,(B $B0-(B $B0.(B $B0/(B
+$B00(B $B01(B $B02(B $B03(B $B04(B $B05(B $B06(B $B07(B $B08(B $B09(B $B0:(B $B0;(B $B0<(B $B0=(B $B0>(B $B0?(B
+$B0@(B $B0A(B $B0B(B $B0C(B $B0D(B $B0E(B $B0F(B $B0G(B $B0H(B $B0I(B $B0J(B $B0K(B $B0L(B $B0M(B $B0N(B $B0O(B
+$B0P(B $B0Q(B $B0R(B $B0S(B $B0T(B $B0U(B $B0V(B $B0W(B $B0X(B $B0Y(B $B0Z(B $B0[(B $B0\(B $B0](B $B0^(B $B0_(B
+$B0`(B $B0a(B $B0b(B $B0c(B $B0d(B $B0e(B $B0f(B $B0g(B $B0h(B $B0i(B $B0j(B $B0k(B $B0l(B $B0m(B $B0n(B $B0o(B
+$B0p(B $B0q(B $B0r(B $B0s(B $B0t(B $B0u(B $B0v(B $B0w(B $B0x(B $B0y(B $B0z(B $B0{(B $B0|(B $B0}(B $B0~(B
+   $B1!(B $B1"(B $B1#(B $B1$(B $B1%(B $B1&(B $B1'(B $B1((B $B1)(B $B1*(B $B1+(B $B1,(B $B1-(B $B1.(B $B1/(B
+$B10(B $B11(B $B12(B $B13(B $B14(B $B15(B $B16(B $B17(B $B18(B $B19(B $B1:(B $B1;(B $B1<(B $B1=(B $B1>(B $B1?(B
+$B1@(B $B1A(B $B1B(B $B1C(B $B1D(B $B1E(B $B1F(B $B1G(B $B1H(B $B1I(B $B1J(B $B1K(B $B1L(B $B1M(B $B1N(B $B1O(B
+$B1P(B $B1Q(B $B1R(B $B1S(B $B1T(B $B1U(B $B1V(B $B1W(B $B1X(B $B1Y(B $B1Z(B $B1[(B $B1\(B $B1](B $B1^(B $B1_(B
+$B1`(B $B1a(B $B1b(B $B1c(B $B1d(B $B1e(B $B1f(B $B1g(B $B1h(B $B1i(B $B1j(B $B1k(B $B1l(B $B1m(B $B1n(B $B1o(B
+$B1p(B $B1q(B $B1r(B $B1s(B $B1t(B $B1u(B $B1v(B $B1w(B $B1x(B $B1y(B $B1z(B $B1{(B $B1|(B $B1}(B $B1~(B
+   $B2!(B $B2"(B $B2#(B $B2$(B $B2%(B $B2&(B $B2'(B $B2((B $B2)(B $B2*(B $B2+(B $B2,(B $B2-(B $B2.(B $B2/(B
+$B20(B $B21(B $B22(B $B23(B $B24(B $B25(B $B26(B $B27(B $B28(B $B29(B $B2:(B $B2;(B $B2<(B $B2=(B $B2>(B $B2?(B
+$B2@(B $B2A(B $B2B(B $B2C(B $B2D(B $B2E(B $B2F(B $B2G(B $B2H(B $B2I(B $B2J(B $B2K(B $B2L(B $B2M(B $B2N(B $B2O(B
+$B2P(B $B2Q(B $B2R(B $B2S(B $B2T(B $B2U(B $B2V(B $B2W(B $B2X(B $B2Y(B $B2Z(B $B2[(B $B2\(B $B2](B $B2^(B $B2_(B
+$B2`(B $B2a(B $B2b(B $B2c(B $B2d(B $B2e(B $B2f(B $B2g(B $B2h(B $B2i(B $B2j(B $B2k(B $B2l(B $B2m(B $B2n(B $B2o(B
+$B2p(B $B2q(B $B2r(B $B2s(B $B2t(B $B2u(B $B2v(B $B2w(B $B2x(B $B2y(B $B2z(B $B2{(B $B2|(B $B2}(B $B2~(B
+   $B3!(B $B3"(B $B3#(B $B3$(B $B3%(B $B3&(B $B3'(B $B3((B $B3)(B $B3*(B $B3+(B $B3,(B $B3-(B $B3.(B $B3/(B
+$B30(B $B31(B $B32(B $B33(B $B34(B $B35(B $B36(B $B37(B $B38(B $B39(B $B3:(B $B3;(B $B3<(B $B3=(B $B3>(B $B3?(B
+$B3@(B $B3A(B $B3B(B $B3C(B $B3D(B $B3E(B $B3F(B $B3G(B $B3H(B $B3I(B $B3J(B $B3K(B $B3L(B $B3M(B $B3N(B $B3O(B
+$B3P(B $B3Q(B $B3R(B $B3S(B $B3T(B $B3U(B $B3V(B $B3W(B $B3X(B $B3Y(B $B3Z(B $B3[(B $B3\(B $B3](B $B3^(B $B3_(B
+$B3`(B $B3a(B $B3b(B $B3c(B $B3d(B $B3e(B $B3f(B $B3g(B $B3h(B $B3i(B $B3j(B $B3k(B $B3l(B $B3m(B $B3n(B $B3o(B
+$B3p(B $B3q(B $B3r(B $B3s(B $B3t(B $B3u(B $B3v(B $B3w(B $B3x(B $B3y(B $B3z(B $B3{(B $B3|(B $B3}(B $B3~(B
+   $B4!(B $B4"(B $B4#(B $B4$(B $B4%(B $B4&(B $B4'(B $B4((B $B4)(B $B4*(B $B4+(B $B4,(B $B4-(B $B4.(B $B4/(B
+$B40(B $B41(B $B42(B $B43(B $B44(B $B45(B $B46(B $B47(B $B48(B $B49(B $B4:(B $B4;(B $B4<(B $B4=(B $B4>(B $B4?(B
+$B4@(B $B4A(B $B4B(B $B4C(B $B4D(B $B4E(B $B4F(B $B4G(B $B4H(B $B4I(B $B4J(B $B4K(B $B4L(B $B4M(B $B4N(B $B4O(B
+$B4P(B $B4Q(B $B4R(B $B4S(B $B4T(B $B4U(B $B4V(B $B4W(B $B4X(B $B4Y(B $B4Z(B $B4[(B $B4\(B $B4](B $B4^(B $B4_(B
+$B4`(B $B4a(B $B4b(B $B4c(B $B4d(B $B4e(B $B4f(B $B4g(B $B4h(B $B4i(B $B4j(B $B4k(B $B4l(B $B4m(B $B4n(B $B4o(B
+$B4p(B $B4q(B $B4r(B $B4s(B $B4t(B $B4u(B $B4v(B $B4w(B $B4x(B $B4y(B $B4z(B $B4{(B $B4|(B $B4}(B $B4~(B
+   $B5!(B $B5"(B $B5#(B $B5$(B $B5%(B $B5&(B $B5'(B $B5((B $B5)(B $B5*(B $B5+(B $B5,(B $B5-(B $B5.(B $B5/(B
+$B50(B $B51(B $B52(B $B53(B $B54(B $B55(B $B56(B $B57(B $B58(B $B59(B $B5:(B $B5;(B $B5<(B $B5=(B $B5>(B $B5?(B
+$B5@(B $B5A(B $B5B(B $B5C(B $B5D(B $B5E(B $B5F(B $B5G(B $B5H(B $B5I(B $B5J(B $B5K(B $B5L(B $B5M(B $B5N(B $B5O(B
+$B5P(B $B5Q(B $B5R(B $B5S(B $B5T(B $B5U(B $B5V(B $B5W(B $B5X(B $B5Y(B $B5Z(B $B5[(B $B5\(B $B5](B $B5^(B $B5_(B
+$B5`(B $B5a(B $B5b(B $B5c(B $B5d(B $B5e(B $B5f(B $B5g(B $B5h(B $B5i(B $B5j(B $B5k(B $B5l(B $B5m(B $B5n(B $B5o(B
+$B5p(B $B5q(B $B5r(B $B5s(B $B5t(B $B5u(B $B5v(B $B5w(B $B5x(B $B5y(B $B5z(B $B5{(B $B5|(B $B5}(B $B5~(B
+   $B6!(B $B6"(B $B6#(B $B6$(B $B6%(B $B6&(B $B6'(B $B6((B $B6)(B $B6*(B $B6+(B $B6,(B $B6-(B $B6.(B $B6/(B
+$B60(B $B61(B $B62(B $B63(B $B64(B $B65(B $B66(B $B67(B $B68(B $B69(B $B6:(B $B6;(B $B6<(B $B6=(B $B6>(B $B6?(B
+$B6@(B $B6A(B $B6B(B $B6C(B $B6D(B $B6E(B $B6F(B $B6G(B $B6H(B $B6I(B $B6J(B $B6K(B $B6L(B $B6M(B $B6N(B $B6O(B
+$B6P(B $B6Q(B $B6R(B $B6S(B $B6T(B $B6U(B $B6V(B $B6W(B $B6X(B $B6Y(B $B6Z(B $B6[(B $B6\(B $B6](B $B6^(B $B6_(B
+$B6`(B $B6a(B $B6b(B $B6c(B $B6d(B $B6e(B $B6f(B $B6g(B $B6h(B $B6i(B $B6j(B $B6k(B $B6l(B $B6m(B $B6n(B $B6o(B
+$B6p(B $B6q(B $B6r(B $B6s(B $B6t(B $B6u(B $B6v(B $B6w(B $B6x(B $B6y(B $B6z(B $B6{(B $B6|(B $B6}(B $B6~(B
+   $B7!(B $B7"(B $B7#(B $B7$(B $B7%(B $B7&(B $B7'(B $B7((B $B7)(B $B7*(B $B7+(B $B7,(B $B7-(B $B7.(B $B7/(B
+$B70(B $B71(B $B72(B $B73(B $B74(B $B75(B $B76(B $B77(B $B78(B $B79(B $B7:(B $B7;(B $B7<(B $B7=(B $B7>(B $B7?(B
+$B7@(B $B7A(B $B7B(B $B7C(B $B7D(B $B7E(B $B7F(B $B7G(B $B7H(B $B7I(B $B7J(B $B7K(B $B7L(B $B7M(B $B7N(B $B7O(B
+$B7P(B $B7Q(B $B7R(B $B7S(B $B7T(B $B7U(B $B7V(B $B7W(B $B7X(B $B7Y(B $B7Z(B $B7[(B $B7\(B $B7](B $B7^(B $B7_(B
+$B7`(B $B7a(B $B7b(B $B7c(B $B7d(B $B7e(B $B7f(B $B7g(B $B7h(B $B7i(B $B7j(B $B7k(B $B7l(B $B7m(B $B7n(B $B7o(B
+$B7p(B $B7q(B $B7r(B $B7s(B $B7t(B $B7u(B $B7v(B $B7w(B $B7x(B $B7y(B $B7z(B $B7{(B $B7|(B $B7}(B $B7~(B
+   $B8!(B $B8"(B $B8#(B $B8$(B $B8%(B $B8&(B $B8'(B $B8((B $B8)(B $B8*(B $B8+(B $B8,(B $B8-(B $B8.(B $B8/(B
+$B80(B $B81(B $B82(B $B83(B $B84(B $B85(B $B86(B $B87(B $B88(B $B89(B $B8:(B $B8;(B $B8<(B $B8=(B $B8>(B $B8?(B
+$B8@(B $B8A(B $B8B(B $B8C(B $B8D(B $B8E(B $B8F(B $B8G(B $B8H(B $B8I(B $B8J(B $B8K(B $B8L(B $B8M(B $B8N(B $B8O(B
+$B8P(B $B8Q(B $B8R(B $B8S(B $B8T(B $B8U(B $B8V(B $B8W(B $B8X(B $B8Y(B $B8Z(B $B8[(B $B8\(B $B8](B $B8^(B $B8_(B
+$B8`(B $B8a(B $B8b(B $B8c(B $B8d(B $B8e(B $B8f(B $B8g(B $B8h(B $B8i(B $B8j(B $B8k(B $B8l(B $B8m(B $B8n(B $B8o(B
+$B8p(B $B8q(B $B8r(B $B8s(B $B8t(B $B8u(B $B8v(B $B8w(B $B8x(B $B8y(B $B8z(B $B8{(B $B8|(B $B8}(B $B8~(B
+   $B9!(B $B9"(B $B9#(B $B9$(B $B9%(B $B9&(B $B9'(B $B9((B $B9)(B $B9*(B $B9+(B $B9,(B $B9-(B $B9.(B $B9/(B
+$B90(B $B91(B $B92(B $B93(B $B94(B $B95(B $B96(B $B97(B $B98(B $B99(B $B9:(B $B9;(B $B9<(B $B9=(B $B9>(B $B9?(B
+$B9@(B $B9A(B $B9B(B $B9C(B $B9D(B $B9E(B $B9F(B $B9G(B $B9H(B $B9I(B $B9J(B $B9K(B $B9L(B $B9M(B $B9N(B $B9O(B
+$B9P(B $B9Q(B $B9R(B $B9S(B $B9T(B $B9U(B $B9V(B $B9W(B $B9X(B $B9Y(B $B9Z(B $B9[(B $B9\(B $B9](B $B9^(B $B9_(B
+$B9`(B $B9a(B $B9b(B $B9c(B $B9d(B $B9e(B $B9f(B $B9g(B $B9h(B $B9i(B $B9j(B $B9k(B $B9l(B $B9m(B $B9n(B $B9o(B
+$B9p(B $B9q(B $B9r(B $B9s(B $B9t(B $B9u(B $B9v(B $B9w(B $B9x(B $B9y(B $B9z(B $B9{(B $B9|(B $B9}(B $B9~(B
+   $B:!(B $B:"(B $B:#(B $B:$(B $B:%(B $B:&(B $B:'(B $B:((B $B:)(B $B:*(B $B:+(B $B:,(B $B:-(B $B:.(B $B:/(B
+$B:0(B $B:1(B $B:2(B $B:3(B $B:4(B $B:5(B $B:6(B $B:7(B $B:8(B $B:9(B $B::(B $B:;(B $B:<(B $B:=(B $B:>(B $B:?(B
+$B:@(B $B:A(B $B:B(B $B:C(B $B:D(B $B:E(B $B:F(B $B:G(B $B:H(B $B:I(B $B:J(B $B:K(B $B:L(B $B:M(B $B:N(B $B:O(B
+$B:P(B $B:Q(B $B:R(B $B:S(B $B:T(B $B:U(B $B:V(B $B:W(B $B:X(B $B:Y(B $B:Z(B $B:[(B $B:\(B $B:](B $B:^(B $B:_(B
+$B:`(B $B:a(B $B:b(B $B:c(B $B:d(B $B:e(B $B:f(B $B:g(B $B:h(B $B:i(B $B:j(B $B:k(B $B:l(B $B:m(B $B:n(B $B:o(B
+$B:p(B $B:q(B $B:r(B $B:s(B $B:t(B $B:u(B $B:v(B $B:w(B $B:x(B $B:y(B $B:z(B $B:{(B $B:|(B $B:}(B $B:~(B
+   $B;!(B $B;"(B $B;#(B $B;$(B $B;%(B $B;&(B $B;'(B $B;((B $B;)(B $B;*(B $B;+(B $B;,(B $B;-(B $B;.(B $B;/(B
+$B;0(B $B;1(B $B;2(B $B;3(B $B;4(B $B;5(B $B;6(B $B;7(B $B;8(B $B;9(B $B;:(B $B;;(B $B;<(B $B;=(B $B;>(B $B;?(B
+$B;@(B $B;A(B $B;B(B $B;C(B $B;D(B $B;E(B $B;F(B $B;G(B $B;H(B $B;I(B $B;J(B $B;K(B $B;L(B $B;M(B $B;N(B $B;O(B
+$B;P(B $B;Q(B $B;R(B $B;S(B $B;T(B $B;U(B $B;V(B $B;W(B $B;X(B $B;Y(B $B;Z(B $B;[(B $B;\(B $B;](B $B;^(B $B;_(B
+$B;`(B $B;a(B $B;b(B $B;c(B $B;d(B $B;e(B $B;f(B $B;g(B $B;h(B $B;i(B $B;j(B $B;k(B $B;l(B $B;m(B $B;n(B $B;o(B
+$B;p(B $B;q(B $B;r(B $B;s(B $B;t(B $B;u(B $B;v(B $B;w(B $B;x(B $B;y(B $B;z(B $B;{(B $B;|(B $B;}(B $B;~(B
+   $B<!(B $B<"(B $B<#(B $B<$(B $B<%(B $B<&(B $B<'(B $B<((B $B<)(B $B<*(B $B<+(B $B<,(B $B<-(B $B<.(B $B</(B
+$B<0(B $B<1(B $B<2(B $B<3(B $B<4(B $B<5(B $B<6(B $B<7(B $B<8(B $B<9(B $B<:(B $B<;(B $B<<(B $B<=(B $B<>(B $B<?(B
+$B<@(B $B<A(B $B<B(B $B<C(B $B<D(B $B<E(B $B<F(B $B<G(B $B<H(B $B<I(B $B<J(B $B<K(B $B<L(B $B<M(B $B<N(B $B<O(B
+$B<P(B $B<Q(B $B<R(B $B<S(B $B<T(B $B<U(B $B<V(B $B<W(B $B<X(B $B<Y(B $B<Z(B $B<[(B $B<\(B $B<](B $B<^(B $B<_(B
+$B<`(B $B<a(B $B<b(B $B<c(B $B<d(B $B<e(B $B<f(B $B<g(B $B<h(B $B<i(B $B<j(B $B<k(B $B<l(B $B<m(B $B<n(B $B<o(B
+$B<p(B $B<q(B $B<r(B $B<s(B $B<t(B $B<u(B $B<v(B $B<w(B $B<x(B $B<y(B $B<z(B $B<{(B $B<|(B $B<}(B $B<~(B
+   $B=!(B $B="(B $B=#(B $B=$(B $B=%(B $B=&(B $B='(B $B=((B $B=)(B $B=*(B $B=+(B $B=,(B $B=-(B $B=.(B $B=/(B
+$B=0(B $B=1(B $B=2(B $B=3(B $B=4(B $B=5(B $B=6(B $B=7(B $B=8(B $B=9(B $B=:(B $B=;(B $B=<(B $B==(B $B=>(B $B=?(B
+$B=@(B $B=A(B $B=B(B $B=C(B $B=D(B $B=E(B $B=F(B $B=G(B $B=H(B $B=I(B $B=J(B $B=K(B $B=L(B $B=M(B $B=N(B $B=O(B
+$B=P(B $B=Q(B $B=R(B $B=S(B $B=T(B $B=U(B $B=V(B $B=W(B $B=X(B $B=Y(B $B=Z(B $B=[(B $B=\(B $B=](B $B=^(B $B=_(B
+$B=`(B $B=a(B $B=b(B $B=c(B $B=d(B $B=e(B $B=f(B $B=g(B $B=h(B $B=i(B $B=j(B $B=k(B $B=l(B $B=m(B $B=n(B $B=o(B
+$B=p(B $B=q(B $B=r(B $B=s(B $B=t(B $B=u(B $B=v(B $B=w(B $B=x(B $B=y(B $B=z(B $B={(B $B=|(B $B=}(B $B=~(B
+   $B>!(B $B>"(B $B>#(B $B>$(B $B>%(B $B>&(B $B>'(B $B>((B $B>)(B $B>*(B $B>+(B $B>,(B $B>-(B $B>.(B $B>/(B
+$B>0(B $B>1(B $B>2(B $B>3(B $B>4(B $B>5(B $B>6(B $B>7(B $B>8(B $B>9(B $B>:(B $B>;(B $B><(B $B>=(B $B>>(B $B>?(B
+$B>@(B $B>A(B $B>B(B $B>C(B $B>D(B $B>E(B $B>F(B $B>G(B $B>H(B $B>I(B $B>J(B $B>K(B $B>L(B $B>M(B $B>N(B $B>O(B
+$B>P(B $B>Q(B $B>R(B $B>S(B $B>T(B $B>U(B $B>V(B $B>W(B $B>X(B $B>Y(B $B>Z(B $B>[(B $B>\(B $B>](B $B>^(B $B>_(B
+$B>`(B $B>a(B $B>b(B $B>c(B $B>d(B $B>e(B $B>f(B $B>g(B $B>h(B $B>i(B $B>j(B $B>k(B $B>l(B $B>m(B $B>n(B $B>o(B
+$B>p(B $B>q(B $B>r(B $B>s(B $B>t(B $B>u(B $B>v(B $B>w(B $B>x(B $B>y(B $B>z(B $B>{(B $B>|(B $B>}(B $B>~(B
+   $B?!(B $B?"(B $B?#(B $B?$(B $B?%(B $B?&(B $B?'(B $B?((B $B?)(B $B?*(B $B?+(B $B?,(B $B?-(B $B?.(B $B?/(B
+$B?0(B $B?1(B $B?2(B $B?3(B $B?4(B $B?5(B $B?6(B $B?7(B $B?8(B $B?9(B $B?:(B $B?;(B $B?<(B $B?=(B $B?>(B $B??(B
+$B?@(B $B?A(B $B?B(B $B?C(B $B?D(B $B?E(B $B?F(B $B?G(B $B?H(B $B?I(B $B?J(B $B?K(B $B?L(B $B?M(B $B?N(B $B?O(B
+$B?P(B $B?Q(B $B?R(B $B?S(B $B?T(B $B?U(B $B?V(B $B?W(B $B?X(B $B?Y(B $B?Z(B $B?[(B $B?\(B $B?](B $B?^(B $B?_(B
+$B?`(B $B?a(B $B?b(B $B?c(B $B?d(B $B?e(B $B?f(B $B?g(B $B?h(B $B?i(B $B?j(B $B?k(B $B?l(B $B?m(B $B?n(B $B?o(B
+$B?p(B $B?q(B $B?r(B $B?s(B $B?t(B $B?u(B $B?v(B $B?w(B $B?x(B $B?y(B $B?z(B $B?{(B $B?|(B $B?}(B $B?~(B
+   $B@!(B $B@"(B $B@#(B $B@$(B $B@%(B $B@&(B $B@'(B $B@((B $B@)(B $B@*(B $B@+(B $B@,(B $B@-(B $B@.(B $B@/(B
+$B@0(B $B@1(B $B@2(B $B@3(B $B@4(B $B@5(B $B@6(B $B@7(B $B@8(B $B@9(B $B@:(B $B@;(B $B@<(B $B@=(B $B@>(B $B@?(B
+$B@@(B $B@A(B $B@B(B $B@C(B $B@D(B $B@E(B $B@F(B $B@G(B $B@H(B $B@I(B $B@J(B $B@K(B $B@L(B $B@M(B $B@N(B $B@O(B
+$B@P(B $B@Q(B $B@R(B $B@S(B $B@T(B $B@U(B $B@V(B $B@W(B $B@X(B $B@Y(B $B@Z(B $B@[(B $B@\(B $B@](B $B@^(B $B@_(B
+$B@`(B $B@a(B $B@b(B $B@c(B $B@d(B $B@e(B $B@f(B $B@g(B $B@h(B $B@i(B $B@j(B $B@k(B $B@l(B $B@m(B $B@n(B $B@o(B
+$B@p(B $B@q(B $B@r(B $B@s(B $B@t(B $B@u(B $B@v(B $B@w(B $B@x(B $B@y(B $B@z(B $B@{(B $B@|(B $B@}(B $B@~(B
+   $BA!(B $BA"(B $BA#(B $BA$(B $BA%(B $BA&(B $BA'(B $BA((B $BA)(B $BA*(B $BA+(B $BA,(B $BA-(B $BA.(B $BA/(B
+$BA0(B $BA1(B $BA2(B $BA3(B $BA4(B $BA5(B $BA6(B $BA7(B $BA8(B $BA9(B $BA:(B $BA;(B $BA<(B $BA=(B $BA>(B $BA?(B
+$BA@(B $BAA(B $BAB(B $BAC(B $BAD(B $BAE(B $BAF(B $BAG(B $BAH(B $BAI(B $BAJ(B $BAK(B $BAL(B $BAM(B $BAN(B $BAO(B
+$BAP(B $BAQ(B $BAR(B $BAS(B $BAT(B $BAU(B $BAV(B $BAW(B $BAX(B $BAY(B $BAZ(B $BA[(B $BA\(B $BA](B $BA^(B $BA_(B
+$BA`(B $BAa(B $BAb(B $BAc(B $BAd(B $BAe(B $BAf(B $BAg(B $BAh(B $BAi(B $BAj(B $BAk(B $BAl(B $BAm(B $BAn(B $BAo(B
+$BAp(B $BAq(B $BAr(B $BAs(B $BAt(B $BAu(B $BAv(B $BAw(B $BAx(B $BAy(B $BAz(B $BA{(B $BA|(B $BA}(B $BA~(B
+   $BB!(B $BB"(B $BB#(B $BB$(B $BB%(B $BB&(B $BB'(B $BB((B $BB)(B $BB*(B $BB+(B $BB,(B $BB-(B $BB.(B $BB/(B
+$BB0(B $BB1(B $BB2(B $BB3(B $BB4(B $BB5(B $BB6(B $BB7(B $BB8(B $BB9(B $BB:(B $BB;(B $BB<(B $BB=(B $BB>(B $BB?(B
+$BB@(B $BBA(B $BBB(B $BBC(B $BBD(B $BBE(B $BBF(B $BBG(B $BBH(B $BBI(B $BBJ(B $BBK(B $BBL(B $BBM(B $BBN(B $BBO(B
+$BBP(B $BBQ(B $BBR(B $BBS(B $BBT(B $BBU(B $BBV(B $BBW(B $BBX(B $BBY(B $BBZ(B $BB[(B $BB\(B $BB](B $BB^(B $BB_(B
+$BB`(B $BBa(B $BBb(B $BBc(B $BBd(B $BBe(B $BBf(B $BBg(B $BBh(B $BBi(B $BBj(B $BBk(B $BBl(B $BBm(B $BBn(B $BBo(B
+$BBp(B $BBq(B $BBr(B $BBs(B $BBt(B $BBu(B $BBv(B $BBw(B $BBx(B $BBy(B $BBz(B $BB{(B $BB|(B $BB}(B $BB~(B
+   $BC!(B $BC"(B $BC#(B $BC$(B $BC%(B $BC&(B $BC'(B $BC((B $BC)(B $BC*(B $BC+(B $BC,(B $BC-(B $BC.(B $BC/(B
+$BC0(B $BC1(B $BC2(B $BC3(B $BC4(B $BC5(B $BC6(B $BC7(B $BC8(B $BC9(B $BC:(B $BC;(B $BC<(B $BC=(B $BC>(B $BC?(B
+$BC@(B $BCA(B $BCB(B $BCC(B $BCD(B $BCE(B $BCF(B $BCG(B $BCH(B $BCI(B $BCJ(B $BCK(B $BCL(B $BCM(B $BCN(B $BCO(B
+$BCP(B $BCQ(B $BCR(B $BCS(B $BCT(B $BCU(B $BCV(B $BCW(B $BCX(B $BCY(B $BCZ(B $BC[(B $BC\(B $BC](B $BC^(B $BC_(B
+$BC`(B $BCa(B $BCb(B $BCc(B $BCd(B $BCe(B $BCf(B $BCg(B $BCh(B $BCi(B $BCj(B $BCk(B $BCl(B $BCm(B $BCn(B $BCo(B
+$BCp(B $BCq(B $BCr(B $BCs(B $BCt(B $BCu(B $BCv(B $BCw(B $BCx(B $BCy(B $BCz(B $BC{(B $BC|(B $BC}(B $BC~(B
+   $BD!(B $BD"(B $BD#(B $BD$(B $BD%(B $BD&(B $BD'(B $BD((B $BD)(B $BD*(B $BD+(B $BD,(B $BD-(B $BD.(B $BD/(B
+$BD0(B $BD1(B $BD2(B $BD3(B $BD4(B $BD5(B $BD6(B $BD7(B $BD8(B $BD9(B $BD:(B $BD;(B $BD<(B $BD=(B $BD>(B $BD?(B
+$BD@(B $BDA(B $BDB(B $BDC(B $BDD(B $BDE(B $BDF(B $BDG(B $BDH(B $BDI(B $BDJ(B $BDK(B $BDL(B $BDM(B $BDN(B $BDO(B
+$BDP(B $BDQ(B $BDR(B $BDS(B $BDT(B $BDU(B $BDV(B $BDW(B $BDX(B $BDY(B $BDZ(B $BD[(B $BD\(B $BD](B $BD^(B $BD_(B
+$BD`(B $BDa(B $BDb(B $BDc(B $BDd(B $BDe(B $BDf(B $BDg(B $BDh(B $BDi(B $BDj(B $BDk(B $BDl(B $BDm(B $BDn(B $BDo(B
+$BDp(B $BDq(B $BDr(B $BDs(B $BDt(B $BDu(B $BDv(B $BDw(B $BDx(B $BDy(B $BDz(B $BD{(B $BD|(B $BD}(B $BD~(B
+   $BE!(B $BE"(B $BE#(B $BE$(B $BE%(B $BE&(B $BE'(B $BE((B $BE)(B $BE*(B $BE+(B $BE,(B $BE-(B $BE.(B $BE/(B
+$BE0(B $BE1(B $BE2(B $BE3(B $BE4(B $BE5(B $BE6(B $BE7(B $BE8(B $BE9(B $BE:(B $BE;(B $BE<(B $BE=(B $BE>(B $BE?(B
+$BE@(B $BEA(B $BEB(B $BEC(B $BED(B $BEE(B $BEF(B $BEG(B $BEH(B $BEI(B $BEJ(B $BEK(B $BEL(B $BEM(B $BEN(B $BEO(B
+$BEP(B $BEQ(B $BER(B $BES(B $BET(B $BEU(B $BEV(B $BEW(B $BEX(B $BEY(B $BEZ(B $BE[(B $BE\(B $BE](B $BE^(B $BE_(B
+$BE`(B $BEa(B $BEb(B $BEc(B $BEd(B $BEe(B $BEf(B $BEg(B $BEh(B $BEi(B $BEj(B $BEk(B $BEl(B $BEm(B $BEn(B $BEo(B
+$BEp(B $BEq(B $BEr(B $BEs(B $BEt(B $BEu(B $BEv(B $BEw(B $BEx(B $BEy(B $BEz(B $BE{(B $BE|(B $BE}(B $BE~(B
+   $BF!(B $BF"(B $BF#(B $BF$(B $BF%(B $BF&(B $BF'(B $BF((B $BF)(B $BF*(B $BF+(B $BF,(B $BF-(B $BF.(B $BF/(B
+$BF0(B $BF1(B $BF2(B $BF3(B $BF4(B $BF5(B $BF6(B $BF7(B $BF8(B $BF9(B $BF:(B $BF;(B $BF<(B $BF=(B $BF>(B $BF?(B
+$BF@(B $BFA(B $BFB(B $BFC(B $BFD(B $BFE(B $BFF(B $BFG(B $BFH(B $BFI(B $BFJ(B $BFK(B $BFL(B $BFM(B $BFN(B $BFO(B
+$BFP(B $BFQ(B $BFR(B $BFS(B $BFT(B $BFU(B $BFV(B $BFW(B $BFX(B $BFY(B $BFZ(B $BF[(B $BF\(B $BF](B $BF^(B $BF_(B
+$BF`(B $BFa(B $BFb(B $BFc(B $BFd(B $BFe(B $BFf(B $BFg(B $BFh(B $BFi(B $BFj(B $BFk(B $BFl(B $BFm(B $BFn(B $BFo(B
+$BFp(B $BFq(B $BFr(B $BFs(B $BFt(B $BFu(B $BFv(B $BFw(B $BFx(B $BFy(B $BFz(B $BF{(B $BF|(B $BF}(B $BF~(B
+   $BG!(B $BG"(B $BG#(B $BG$(B $BG%(B $BG&(B $BG'(B $BG((B $BG)(B $BG*(B $BG+(B $BG,(B $BG-(B $BG.(B $BG/(B
+$BG0(B $BG1(B $BG2(B $BG3(B $BG4(B $BG5(B $BG6(B $BG7(B $BG8(B $BG9(B $BG:(B $BG;(B $BG<(B $BG=(B $BG>(B $BG?(B
+$BG@(B $BGA(B $BGB(B $BGC(B $BGD(B $BGE(B $BGF(B $BGG(B $BGH(B $BGI(B $BGJ(B $BGK(B $BGL(B $BGM(B $BGN(B $BGO(B
+$BGP(B $BGQ(B $BGR(B $BGS(B $BGT(B $BGU(B $BGV(B $BGW(B $BGX(B $BGY(B $BGZ(B $BG[(B $BG\(B $BG](B $BG^(B $BG_(B
+$BG`(B $BGa(B $BGb(B $BGc(B $BGd(B $BGe(B $BGf(B $BGg(B $BGh(B $BGi(B $BGj(B $BGk(B $BGl(B $BGm(B $BGn(B $BGo(B
+$BGp(B $BGq(B $BGr(B $BGs(B $BGt(B $BGu(B $BGv(B $BGw(B $BGx(B $BGy(B $BGz(B $BG{(B $BG|(B $BG}(B $BG~(B
+   $BH!(B $BH"(B $BH#(B $BH$(B $BH%(B $BH&(B $BH'(B $BH((B $BH)(B $BH*(B $BH+(B $BH,(B $BH-(B $BH.(B $BH/(B
+$BH0(B $BH1(B $BH2(B $BH3(B $BH4(B $BH5(B $BH6(B $BH7(B $BH8(B $BH9(B $BH:(B $BH;(B $BH<(B $BH=(B $BH>(B $BH?(B
+$BH@(B $BHA(B $BHB(B $BHC(B $BHD(B $BHE(B $BHF(B $BHG(B $BHH(B $BHI(B $BHJ(B $BHK(B $BHL(B $BHM(B $BHN(B $BHO(B
+$BHP(B $BHQ(B $BHR(B $BHS(B $BHT(B $BHU(B $BHV(B $BHW(B $BHX(B $BHY(B $BHZ(B $BH[(B $BH\(B $BH](B $BH^(B $BH_(B
+$BH`(B $BHa(B $BHb(B $BHc(B $BHd(B $BHe(B $BHf(B $BHg(B $BHh(B $BHi(B $BHj(B $BHk(B $BHl(B $BHm(B $BHn(B $BHo(B
+$BHp(B $BHq(B $BHr(B $BHs(B $BHt(B $BHu(B $BHv(B $BHw(B $BHx(B $BHy(B $BHz(B $BH{(B $BH|(B $BH}(B $BH~(B
+   $BI!(B $BI"(B $BI#(B $BI$(B $BI%(B $BI&(B $BI'(B $BI((B $BI)(B $BI*(B $BI+(B $BI,(B $BI-(B $BI.(B $BI/(B
+$BI0(B $BI1(B $BI2(B $BI3(B $BI4(B $BI5(B $BI6(B $BI7(B $BI8(B $BI9(B $BI:(B $BI;(B $BI<(B $BI=(B $BI>(B $BI?(B
+$BI@(B $BIA(B $BIB(B $BIC(B $BID(B $BIE(B $BIF(B $BIG(B $BIH(B $BII(B $BIJ(B $BIK(B $BIL(B $BIM(B $BIN(B $BIO(B
+$BIP(B $BIQ(B $BIR(B $BIS(B $BIT(B $BIU(B $BIV(B $BIW(B $BIX(B $BIY(B $BIZ(B $BI[(B $BI\(B $BI](B $BI^(B $BI_(B
+$BI`(B $BIa(B $BIb(B $BIc(B $BId(B $BIe(B $BIf(B $BIg(B $BIh(B $BIi(B $BIj(B $BIk(B $BIl(B $BIm(B $BIn(B $BIo(B
+$BIp(B $BIq(B $BIr(B $BIs(B $BIt(B $BIu(B $BIv(B $BIw(B $BIx(B $BIy(B $BIz(B $BI{(B $BI|(B $BI}(B $BI~(B
+   $BJ!(B $BJ"(B $BJ#(B $BJ$(B $BJ%(B $BJ&(B $BJ'(B $BJ((B $BJ)(B $BJ*(B $BJ+(B $BJ,(B $BJ-(B $BJ.(B $BJ/(B
+$BJ0(B $BJ1(B $BJ2(B $BJ3(B $BJ4(B $BJ5(B $BJ6(B $BJ7(B $BJ8(B $BJ9(B $BJ:(B $BJ;(B $BJ<(B $BJ=(B $BJ>(B $BJ?(B
+$BJ@(B $BJA(B $BJB(B $BJC(B $BJD(B $BJE(B $BJF(B $BJG(B $BJH(B $BJI(B $BJJ(B $BJK(B $BJL(B $BJM(B $BJN(B $BJO(B
+$BJP(B $BJQ(B $BJR(B $BJS(B $BJT(B $BJU(B $BJV(B $BJW(B $BJX(B $BJY(B $BJZ(B $BJ[(B $BJ\(B $BJ](B $BJ^(B $BJ_(B
+$BJ`(B $BJa(B $BJb(B $BJc(B $BJd(B $BJe(B $BJf(B $BJg(B $BJh(B $BJi(B $BJj(B $BJk(B $BJl(B $BJm(B $BJn(B $BJo(B
+$BJp(B $BJq(B $BJr(B $BJs(B $BJt(B $BJu(B $BJv(B $BJw(B $BJx(B $BJy(B $BJz(B $BJ{(B $BJ|(B $BJ}(B $BJ~(B
+   $BK!(B $BK"(B $BK#(B $BK$(B $BK%(B $BK&(B $BK'(B $BK((B $BK)(B $BK*(B $BK+(B $BK,(B $BK-(B $BK.(B $BK/(B
+$BK0(B $BK1(B $BK2(B $BK3(B $BK4(B $BK5(B $BK6(B $BK7(B $BK8(B $BK9(B $BK:(B $BK;(B $BK<(B $BK=(B $BK>(B $BK?(B
+$BK@(B $BKA(B $BKB(B $BKC(B $BKD(B $BKE(B $BKF(B $BKG(B $BKH(B $BKI(B $BKJ(B $BKK(B $BKL(B $BKM(B $BKN(B $BKO(B
+$BKP(B $BKQ(B $BKR(B $BKS(B $BKT(B $BKU(B $BKV(B $BKW(B $BKX(B $BKY(B $BKZ(B $BK[(B $BK\(B $BK](B $BK^(B $BK_(B
+$BK`(B $BKa(B $BKb(B $BKc(B $BKd(B $BKe(B $BKf(B $BKg(B $BKh(B $BKi(B $BKj(B $BKk(B $BKl(B $BKm(B $BKn(B $BKo(B
+$BKp(B $BKq(B $BKr(B $BKs(B $BKt(B $BKu(B $BKv(B $BKw(B $BKx(B $BKy(B $BKz(B $BK{(B $BK|(B $BK}(B $BK~(B
+   $BL!(B $BL"(B $BL#(B $BL$(B $BL%(B $BL&(B $BL'(B $BL((B $BL)(B $BL*(B $BL+(B $BL,(B $BL-(B $BL.(B $BL/(B
+$BL0(B $BL1(B $BL2(B $BL3(B $BL4(B $BL5(B $BL6(B $BL7(B $BL8(B $BL9(B $BL:(B $BL;(B $BL<(B $BL=(B $BL>(B $BL?(B
+$BL@(B $BLA(B $BLB(B $BLC(B $BLD(B $BLE(B $BLF(B $BLG(B $BLH(B $BLI(B $BLJ(B $BLK(B $BLL(B $BLM(B $BLN(B $BLO(B
+$BLP(B $BLQ(B $BLR(B $BLS(B $BLT(B $BLU(B $BLV(B $BLW(B $BLX(B $BLY(B $BLZ(B $BL[(B $BL\(B $BL](B $BL^(B $BL_(B
+$BL`(B $BLa(B $BLb(B $BLc(B $BLd(B $BLe(B $BLf(B $BLg(B $BLh(B $BLi(B $BLj(B $BLk(B $BLl(B $BLm(B $BLn(B $BLo(B
+$BLp(B $BLq(B $BLr(B $BLs(B $BLt(B $BLu(B $BLv(B $BLw(B $BLx(B $BLy(B $BLz(B $BL{(B $BL|(B $BL}(B $BL~(B
+   $BM!(B $BM"(B $BM#(B $BM$(B $BM%(B $BM&(B $BM'(B $BM((B $BM)(B $BM*(B $BM+(B $BM,(B $BM-(B $BM.(B $BM/(B
+$BM0(B $BM1(B $BM2(B $BM3(B $BM4(B $BM5(B $BM6(B $BM7(B $BM8(B $BM9(B $BM:(B $BM;(B $BM<(B $BM=(B $BM>(B $BM?(B
+$BM@(B $BMA(B $BMB(B $BMC(B $BMD(B $BME(B $BMF(B $BMG(B $BMH(B $BMI(B $BMJ(B $BMK(B $BML(B $BMM(B $BMN(B $BMO(B
+$BMP(B $BMQ(B $BMR(B $BMS(B $BMT(B $BMU(B $BMV(B $BMW(B $BMX(B $BMY(B $BMZ(B $BM[(B $BM\(B $BM](B $BM^(B $BM_(B
+$BM`(B $BMa(B $BMb(B $BMc(B $BMd(B $BMe(B $BMf(B $BMg(B $BMh(B $BMi(B $BMj(B $BMk(B $BMl(B $BMm(B $BMn(B $BMo(B
+$BMp(B $BMq(B $BMr(B $BMs(B $BMt(B $BMu(B $BMv(B $BMw(B $BMx(B $BMy(B $BMz(B $BM{(B $BM|(B $BM}(B $BM~(B
+   $BN!(B $BN"(B $BN#(B $BN$(B $BN%(B $BN&(B $BN'(B $BN((B $BN)(B $BN*(B $BN+(B $BN,(B $BN-(B $BN.(B $BN/(B
+$BN0(B $BN1(B $BN2(B $BN3(B $BN4(B $BN5(B $BN6(B $BN7(B $BN8(B $BN9(B $BN:(B $BN;(B $BN<(B $BN=(B $BN>(B $BN?(B
+$BN@(B $BNA(B $BNB(B $BNC(B $BND(B $BNE(B $BNF(B $BNG(B $BNH(B $BNI(B $BNJ(B $BNK(B $BNL(B $BNM(B $BNN(B $BNO(B
+$BNP(B $BNQ(B $BNR(B $BNS(B $BNT(B $BNU(B $BNV(B $BNW(B $BNX(B $BNY(B $BNZ(B $BN[(B $BN\(B $BN](B $BN^(B $BN_(B
+$BN`(B $BNa(B $BNb(B $BNc(B $BNd(B $BNe(B $BNf(B $BNg(B $BNh(B $BNi(B $BNj(B $BNk(B $BNl(B $BNm(B $BNn(B $BNo(B
+$BNp(B $BNq(B $BNr(B $BNs(B $BNt(B $BNu(B $BNv(B $BNw(B $BNx(B $BNy(B $BNz(B $BN{(B $BN|(B $BN}(B $BN~(B
+   $BO!(B $BO"(B $BO#(B $BO$(B $BO%(B $BO&(B $BO'(B $BO((B $BO)(B $BO*(B $BO+(B $BO,(B $BO-(B $BO.(B $BO/(B
+$BO0(B $BO1(B $BO2(B $BO3(B $BO4(B $BO5(B $BO6(B $BO7(B $BO8(B $BO9(B $BO:(B $BO;(B $BO<(B $BO=(B $BO>(B $BO?(B
+$BO@(B $BOA(B $BOB(B $BOC(B $BOD(B $BOE(B $BOF(B $BOG(B $BOH(B $BOI(B $BOJ(B $BOK(B $BOL(B $BOM(B $BON(B $BOO(B
+$BOP(B $BOQ(B $BOR(B $BOS(B
+   $BP!(B $BP"(B $BP#(B $BP$(B $BP%(B $BP&(B $BP'(B $BP((B $BP)(B $BP*(B $BP+(B $BP,(B $BP-(B $BP.(B $BP/(B
+$BP0(B $BP1(B $BP2(B $BP3(B $BP4(B $BP5(B $BP6(B $BP7(B $BP8(B $BP9(B $BP:(B $BP;(B $BP<(B $BP=(B $BP>(B $BP?(B
+$BP@(B $BPA(B $BPB(B $BPC(B $BPD(B $BPE(B $BPF(B $BPG(B $BPH(B $BPI(B $BPJ(B $BPK(B $BPL(B $BPM(B $BPN(B $BPO(B
+$BPP(B $BPQ(B $BPR(B $BPS(B $BPT(B $BPU(B $BPV(B $BPW(B $BPX(B $BPY(B $BPZ(B $BP[(B $BP\(B $BP](B $BP^(B $BP_(B
+$BP`(B $BPa(B $BPb(B $BPc(B $BPd(B $BPe(B $BPf(B $BPg(B $BPh(B $BPi(B $BPj(B $BPk(B $BPl(B $BPm(B $BPn(B $BPo(B
+$BPp(B $BPq(B $BPr(B $BPs(B $BPt(B $BPu(B $BPv(B $BPw(B $BPx(B $BPy(B $BPz(B $BP{(B $BP|(B $BP}(B $BP~(B
+   $BQ!(B $BQ"(B $BQ#(B $BQ$(B $BQ%(B $BQ&(B $BQ'(B $BQ((B $BQ)(B $BQ*(B $BQ+(B $BQ,(B $BQ-(B $BQ.(B $BQ/(B
+$BQ0(B $BQ1(B $BQ2(B $BQ3(B $BQ4(B $BQ5(B $BQ6(B $BQ7(B $BQ8(B $BQ9(B $BQ:(B $BQ;(B $BQ<(B $BQ=(B $BQ>(B $BQ?(B
+$BQ@(B $BQA(B $BQB(B $BQC(B $BQD(B $BQE(B $BQF(B $BQG(B $BQH(B $BQI(B $BQJ(B $BQK(B $BQL(B $BQM(B $BQN(B $BQO(B
+$BQP(B $BQQ(B $BQR(B $BQS(B $BQT(B $BQU(B $BQV(B $BQW(B $BQX(B $BQY(B $BQZ(B $BQ[(B $BQ\(B $BQ](B $BQ^(B $BQ_(B
+$BQ`(B $BQa(B $BQb(B $BQc(B $BQd(B $BQe(B $BQf(B $BQg(B $BQh(B $BQi(B $BQj(B $BQk(B $BQl(B $BQm(B $BQn(B $BQo(B
+$BQp(B $BQq(B $BQr(B $BQs(B $BQt(B $BQu(B $BQv(B $BQw(B $BQx(B $BQy(B $BQz(B $BQ{(B $BQ|(B $BQ}(B $BQ~(B
+   $BR!(B $BR"(B $BR#(B $BR$(B $BR%(B $BR&(B $BR'(B $BR((B $BR)(B $BR*(B $BR+(B $BR,(B $BR-(B $BR.(B $BR/(B
+$BR0(B $BR1(B $BR2(B $BR3(B $BR4(B $BR5(B $BR6(B $BR7(B $BR8(B $BR9(B $BR:(B $BR;(B $BR<(B $BR=(B $BR>(B $BR?(B
+$BR@(B $BRA(B $BRB(B $BRC(B $BRD(B $BRE(B $BRF(B $BRG(B $BRH(B $BRI(B $BRJ(B $BRK(B $BRL(B $BRM(B $BRN(B $BRO(B
+$BRP(B $BRQ(B $BRR(B $BRS(B $BRT(B $BRU(B $BRV(B $BRW(B $BRX(B $BRY(B $BRZ(B $BR[(B $BR\(B $BR](B $BR^(B $BR_(B
+$BR`(B $BRa(B $BRb(B $BRc(B $BRd(B $BRe(B $BRf(B $BRg(B $BRh(B $BRi(B $BRj(B $BRk(B $BRl(B $BRm(B $BRn(B $BRo(B
+$BRp(B $BRq(B $BRr(B $BRs(B $BRt(B $BRu(B $BRv(B $BRw(B $BRx(B $BRy(B $BRz(B $BR{(B $BR|(B $BR}(B $BR~(B
+   $BS!(B $BS"(B $BS#(B $BS$(B $BS%(B $BS&(B $BS'(B $BS((B $BS)(B $BS*(B $BS+(B $BS,(B $BS-(B $BS.(B $BS/(B
+$BS0(B $BS1(B $BS2(B $BS3(B $BS4(B $BS5(B $BS6(B $BS7(B $BS8(B $BS9(B $BS:(B $BS;(B $BS<(B $BS=(B $BS>(B $BS?(B
+$BS@(B $BSA(B $BSB(B $BSC(B $BSD(B $BSE(B $BSF(B $BSG(B $BSH(B $BSI(B $BSJ(B $BSK(B $BSL(B $BSM(B $BSN(B $BSO(B
+$BSP(B $BSQ(B $BSR(B $BSS(B $BST(B $BSU(B $BSV(B $BSW(B $BSX(B $BSY(B $BSZ(B $BS[(B $BS\(B $BS](B $BS^(B $BS_(B
+$BS`(B $BSa(B $BSb(B $BSc(B $BSd(B $BSe(B $BSf(B $BSg(B $BSh(B $BSi(B $BSj(B $BSk(B $BSl(B $BSm(B $BSn(B $BSo(B
+$BSp(B $BSq(B $BSr(B $BSs(B $BSt(B $BSu(B $BSv(B $BSw(B $BSx(B $BSy(B $BSz(B $BS{(B $BS|(B $BS}(B $BS~(B
+   $BT!(B $BT"(B $BT#(B $BT$(B $BT%(B $BT&(B $BT'(B $BT((B $BT)(B $BT*(B $BT+(B $BT,(B $BT-(B $BT.(B $BT/(B
+$BT0(B $BT1(B $BT2(B $BT3(B $BT4(B $BT5(B $BT6(B $BT7(B $BT8(B $BT9(B $BT:(B $BT;(B $BT<(B $BT=(B $BT>(B $BT?(B
+$BT@(B $BTA(B $BTB(B $BTC(B $BTD(B $BTE(B $BTF(B $BTG(B $BTH(B $BTI(B $BTJ(B $BTK(B $BTL(B $BTM(B $BTN(B $BTO(B
+$BTP(B $BTQ(B $BTR(B $BTS(B $BTT(B $BTU(B $BTV(B $BTW(B $BTX(B $BTY(B $BTZ(B $BT[(B $BT\(B $BT](B $BT^(B $BT_(B
+$BT`(B $BTa(B $BTb(B $BTc(B $BTd(B $BTe(B $BTf(B $BTg(B $BTh(B $BTi(B $BTj(B $BTk(B $BTl(B $BTm(B $BTn(B $BTo(B
+$BTp(B $BTq(B $BTr(B $BTs(B $BTt(B $BTu(B $BTv(B $BTw(B $BTx(B $BTy(B $BTz(B $BT{(B $BT|(B $BT}(B $BT~(B
+   $BU!(B $BU"(B $BU#(B $BU$(B $BU%(B $BU&(B $BU'(B $BU((B $BU)(B $BU*(B $BU+(B $BU,(B $BU-(B $BU.(B $BU/(B
+$BU0(B $BU1(B $BU2(B $BU3(B $BU4(B $BU5(B $BU6(B $BU7(B $BU8(B $BU9(B $BU:(B $BU;(B $BU<(B $BU=(B $BU>(B $BU?(B
+$BU@(B $BUA(B $BUB(B $BUC(B $BUD(B $BUE(B $BUF(B $BUG(B $BUH(B $BUI(B $BUJ(B $BUK(B $BUL(B $BUM(B $BUN(B $BUO(B
+$BUP(B $BUQ(B $BUR(B $BUS(B $BUT(B $BUU(B $BUV(B $BUW(B $BUX(B $BUY(B $BUZ(B $BU[(B $BU\(B $BU](B $BU^(B $BU_(B
+$BU`(B $BUa(B $BUb(B $BUc(B $BUd(B $BUe(B $BUf(B $BUg(B $BUh(B $BUi(B $BUj(B $BUk(B $BUl(B $BUm(B $BUn(B $BUo(B
+$BUp(B $BUq(B $BUr(B $BUs(B $BUt(B $BUu(B $BUv(B $BUw(B $BUx(B $BUy(B $BUz(B $BU{(B $BU|(B $BU}(B $BU~(B
+   $BV!(B $BV"(B $BV#(B $BV$(B $BV%(B $BV&(B $BV'(B $BV((B $BV)(B $BV*(B $BV+(B $BV,(B $BV-(B $BV.(B $BV/(B
+$BV0(B $BV1(B $BV2(B $BV3(B $BV4(B $BV5(B $BV6(B $BV7(B $BV8(B $BV9(B $BV:(B $BV;(B $BV<(B $BV=(B $BV>(B $BV?(B
+$BV@(B $BVA(B $BVB(B $BVC(B $BVD(B $BVE(B $BVF(B $BVG(B $BVH(B $BVI(B $BVJ(B $BVK(B $BVL(B $BVM(B $BVN(B $BVO(B
+$BVP(B $BVQ(B $BVR(B $BVS(B $BVT(B $BVU(B $BVV(B $BVW(B $BVX(B $BVY(B $BVZ(B $BV[(B $BV\(B $BV](B $BV^(B $BV_(B
+$BV`(B $BVa(B $BVb(B $BVc(B $BVd(B $BVe(B $BVf(B $BVg(B $BVh(B $BVi(B $BVj(B $BVk(B $BVl(B $BVm(B $BVn(B $BVo(B
+$BVp(B $BVq(B $BVr(B $BVs(B $BVt(B $BVu(B $BVv(B $BVw(B $BVx(B $BVy(B $BVz(B $BV{(B $BV|(B $BV}(B $BV~(B
+   $BW!(B $BW"(B $BW#(B $BW$(B $BW%(B $BW&(B $BW'(B $BW((B $BW)(B $BW*(B $BW+(B $BW,(B $BW-(B $BW.(B $BW/(B
+$BW0(B $BW1(B $BW2(B $BW3(B $BW4(B $BW5(B $BW6(B $BW7(B $BW8(B $BW9(B $BW:(B $BW;(B $BW<(B $BW=(B $BW>(B $BW?(B
+$BW@(B $BWA(B $BWB(B $BWC(B $BWD(B $BWE(B $BWF(B $BWG(B $BWH(B $BWI(B $BWJ(B $BWK(B $BWL(B $BWM(B $BWN(B $BWO(B
+$BWP(B $BWQ(B $BWR(B $BWS(B $BWT(B $BWU(B $BWV(B $BWW(B $BWX(B $BWY(B $BWZ(B $BW[(B $BW\(B $BW](B $BW^(B $BW_(B
+$BW`(B $BWa(B $BWb(B $BWc(B $BWd(B $BWe(B $BWf(B $BWg(B $BWh(B $BWi(B $BWj(B $BWk(B $BWl(B $BWm(B $BWn(B $BWo(B
+$BWp(B $BWq(B $BWr(B $BWs(B $BWt(B $BWu(B $BWv(B $BWw(B $BWx(B $BWy(B $BWz(B $BW{(B $BW|(B $BW}(B $BW~(B
+   $BX!(B $BX"(B $BX#(B $BX$(B $BX%(B $BX&(B $BX'(B $BX((B $BX)(B $BX*(B $BX+(B $BX,(B $BX-(B $BX.(B $BX/(B
+$BX0(B $BX1(B $BX2(B $BX3(B $BX4(B $BX5(B $BX6(B $BX7(B $BX8(B $BX9(B $BX:(B $BX;(B $BX<(B $BX=(B $BX>(B $BX?(B
+$BX@(B $BXA(B $BXB(B $BXC(B $BXD(B $BXE(B $BXF(B $BXG(B $BXH(B $BXI(B $BXJ(B $BXK(B $BXL(B $BXM(B $BXN(B $BXO(B
+$BXP(B $BXQ(B $BXR(B $BXS(B $BXT(B $BXU(B $BXV(B $BXW(B $BXX(B $BXY(B $BXZ(B $BX[(B $BX\(B $BX](B $BX^(B $BX_(B
+$BX`(B $BXa(B $BXb(B $BXc(B $BXd(B $BXe(B $BXf(B $BXg(B $BXh(B $BXi(B $BXj(B $BXk(B $BXl(B $BXm(B $BXn(B $BXo(B
+$BXp(B $BXq(B $BXr(B $BXs(B $BXt(B $BXu(B $BXv(B $BXw(B $BXx(B $BXy(B $BXz(B $BX{(B $BX|(B $BX}(B $BX~(B
+   $BY!(B $BY"(B $BY#(B $BY$(B $BY%(B $BY&(B $BY'(B $BY((B $BY)(B $BY*(B $BY+(B $BY,(B $BY-(B $BY.(B $BY/(B
+$BY0(B $BY1(B $BY2(B $BY3(B $BY4(B $BY5(B $BY6(B $BY7(B $BY8(B $BY9(B $BY:(B $BY;(B $BY<(B $BY=(B $BY>(B $BY?(B
+$BY@(B $BYA(B $BYB(B $BYC(B $BYD(B $BYE(B $BYF(B $BYG(B $BYH(B $BYI(B $BYJ(B $BYK(B $BYL(B $BYM(B $BYN(B $BYO(B
+$BYP(B $BYQ(B $BYR(B $BYS(B $BYT(B $BYU(B $BYV(B $BYW(B $BYX(B $BYY(B $BYZ(B $BY[(B $BY\(B $BY](B $BY^(B $BY_(B
+$BY`(B $BYa(B $BYb(B $BYc(B $BYd(B $BYe(B $BYf(B $BYg(B $BYh(B $BYi(B $BYj(B $BYk(B $BYl(B $BYm(B $BYn(B $BYo(B
+$BYp(B $BYq(B $BYr(B $BYs(B $BYt(B $BYu(B $BYv(B $BYw(B $BYx(B $BYy(B $BYz(B $BY{(B $BY|(B $BY}(B $BY~(B
+   $BZ!(B $BZ"(B $BZ#(B $BZ$(B $BZ%(B $BZ&(B $BZ'(B $BZ((B $BZ)(B $BZ*(B $BZ+(B $BZ,(B $BZ-(B $BZ.(B $BZ/(B
+$BZ0(B $BZ1(B $BZ2(B $BZ3(B $BZ4(B $BZ5(B $BZ6(B $BZ7(B $BZ8(B $BZ9(B $BZ:(B $BZ;(B $BZ<(B $BZ=(B $BZ>(B $BZ?(B
+$BZ@(B $BZA(B $BZB(B $BZC(B $BZD(B $BZE(B $BZF(B $BZG(B $BZH(B $BZI(B $BZJ(B $BZK(B $BZL(B $BZM(B $BZN(B $BZO(B
+$BZP(B $BZQ(B $BZR(B $BZS(B $BZT(B $BZU(B $BZV(B $BZW(B $BZX(B $BZY(B $BZZ(B $BZ[(B $BZ\(B $BZ](B $BZ^(B $BZ_(B
+$BZ`(B $BZa(B $BZb(B $BZc(B $BZd(B $BZe(B $BZf(B $BZg(B $BZh(B $BZi(B $BZj(B $BZk(B $BZl(B $BZm(B $BZn(B $BZo(B
+$BZp(B $BZq(B $BZr(B $BZs(B $BZt(B $BZu(B $BZv(B $BZw(B $BZx(B $BZy(B $BZz(B $BZ{(B $BZ|(B $BZ}(B $BZ~(B
+   $B[!(B $B["(B $B[#(B $B[$(B $B[%(B $B[&(B $B['(B $B[((B $B[)(B $B[*(B $B[+(B $B[,(B $B[-(B $B[.(B $B[/(B
+$B[0(B $B[1(B $B[2(B $B[3(B $B[4(B $B[5(B $B[6(B $B[7(B $B[8(B $B[9(B $B[:(B $B[;(B $B[<(B $B[=(B $B[>(B $B[?(B
+$B[@(B $B[A(B $B[B(B $B[C(B $B[D(B $B[E(B $B[F(B $B[G(B $B[H(B $B[I(B $B[J(B $B[K(B $B[L(B $B[M(B $B[N(B $B[O(B
+$B[P(B $B[Q(B $B[R(B $B[S(B $B[T(B $B[U(B $B[V(B $B[W(B $B[X(B $B[Y(B $B[Z(B $B[[(B $B[\(B $B[](B $B[^(B $B[_(B
+$B[`(B $B[a(B $B[b(B $B[c(B $B[d(B $B[e(B $B[f(B $B[g(B $B[h(B $B[i(B $B[j(B $B[k(B $B[l(B $B[m(B $B[n(B $B[o(B
+$B[p(B $B[q(B $B[r(B $B[s(B $B[t(B $B[u(B $B[v(B $B[w(B $B[x(B $B[y(B $B[z(B $B[{(B $B[|(B $B[}(B $B[~(B
+   $B\!(B $B\"(B $B\#(B $B\$(B $B\%(B $B\&(B $B\'(B $B\((B $B\)(B $B\*(B $B\+(B $B\,(B $B\-(B $B\.(B $B\/(B
+$B\0(B $B\1(B $B\2(B $B\3(B $B\4(B $B\5(B $B\6(B $B\7(B $B\8(B $B\9(B $B\:(B $B\;(B $B\<(B $B\=(B $B\>(B $B\?(B
+$B\@(B $B\A(B $B\B(B $B\C(B $B\D(B $B\E(B $B\F(B $B\G(B $B\H(B $B\I(B $B\J(B $B\K(B $B\L(B $B\M(B $B\N(B $B\O(B
+$B\P(B $B\Q(B $B\R(B $B\S(B $B\T(B $B\U(B $B\V(B $B\W(B $B\X(B $B\Y(B $B\Z(B $B\[(B $B\\(B $B\](B $B\^(B $B\_(B
+$B\`(B $B\a(B $B\b(B $B\c(B $B\d(B $B\e(B $B\f(B $B\g(B $B\h(B $B\i(B $B\j(B $B\k(B $B\l(B $B\m(B $B\n(B $B\o(B
+$B\p(B $B\q(B $B\r(B $B\s(B $B\t(B $B\u(B $B\v(B $B\w(B $B\x(B $B\y(B $B\z(B $B\{(B $B\|(B $B\}(B $B\~(B
+   $B]!(B $B]"(B $B]#(B $B]$(B $B]%(B $B]&(B $B]'(B $B]((B $B])(B $B]*(B $B]+(B $B],(B $B]-(B $B].(B $B]/(B
+$B]0(B $B]1(B $B]2(B $B]3(B $B]4(B $B]5(B $B]6(B $B]7(B $B]8(B $B]9(B $B]:(B $B];(B $B]<(B $B]=(B $B]>(B $B]?(B
+$B]@(B $B]A(B $B]B(B $B]C(B $B]D(B $B]E(B $B]F(B $B]G(B $B]H(B $B]I(B $B]J(B $B]K(B $B]L(B $B]M(B $B]N(B $B]O(B
+$B]P(B $B]Q(B $B]R(B $B]S(B $B]T(B $B]U(B $B]V(B $B]W(B $B]X(B $B]Y(B $B]Z(B $B][(B $B]\(B $B]](B $B]^(B $B]_(B
+$B]`(B $B]a(B $B]b(B $B]c(B $B]d(B $B]e(B $B]f(B $B]g(B $B]h(B $B]i(B $B]j(B $B]k(B $B]l(B $B]m(B $B]n(B $B]o(B
+$B]p(B $B]q(B $B]r(B $B]s(B $B]t(B $B]u(B $B]v(B $B]w(B $B]x(B $B]y(B $B]z(B $B]{(B $B]|(B $B]}(B $B]~(B
+   $B^!(B $B^"(B $B^#(B $B^$(B $B^%(B $B^&(B $B^'(B $B^((B $B^)(B $B^*(B $B^+(B $B^,(B $B^-(B $B^.(B $B^/(B
+$B^0(B $B^1(B $B^2(B $B^3(B $B^4(B $B^5(B $B^6(B $B^7(B $B^8(B $B^9(B $B^:(B $B^;(B $B^<(B $B^=(B $B^>(B $B^?(B
+$B^@(B $B^A(B $B^B(B $B^C(B $B^D(B $B^E(B $B^F(B $B^G(B $B^H(B $B^I(B $B^J(B $B^K(B $B^L(B $B^M(B $B^N(B $B^O(B
+$B^P(B $B^Q(B $B^R(B $B^S(B $B^T(B $B^U(B $B^V(B $B^W(B $B^X(B $B^Y(B $B^Z(B $B^[(B $B^\(B $B^](B $B^^(B $B^_(B
+$B^`(B $B^a(B $B^b(B $B^c(B $B^d(B $B^e(B $B^f(B $B^g(B $B^h(B $B^i(B $B^j(B $B^k(B $B^l(B $B^m(B $B^n(B $B^o(B
+$B^p(B $B^q(B $B^r(B $B^s(B $B^t(B $B^u(B $B^v(B $B^w(B $B^x(B $B^y(B $B^z(B $B^{(B $B^|(B $B^}(B $B^~(B
+   $B_!(B $B_"(B $B_#(B $B_$(B $B_%(B $B_&(B $B_'(B $B_((B $B_)(B $B_*(B $B_+(B $B_,(B $B_-(B $B_.(B $B_/(B
+$B_0(B $B_1(B $B_2(B $B_3(B $B_4(B $B_5(B $B_6(B $B_7(B $B_8(B $B_9(B $B_:(B $B_;(B $B_<(B $B_=(B $B_>(B $B_?(B
+$B_@(B $B_A(B $B_B(B $B_C(B $B_D(B $B_E(B $B_F(B $B_G(B $B_H(B $B_I(B $B_J(B $B_K(B $B_L(B $B_M(B $B_N(B $B_O(B
+$B_P(B $B_Q(B $B_R(B $B_S(B $B_T(B $B_U(B $B_V(B $B_W(B $B_X(B $B_Y(B $B_Z(B $B_[(B $B_\(B $B_](B $B_^(B $B__(B
+$B_`(B $B_a(B $B_b(B $B_c(B $B_d(B $B_e(B $B_f(B $B_g(B $B_h(B $B_i(B $B_j(B $B_k(B $B_l(B $B_m(B $B_n(B $B_o(B
+$B_p(B $B_q(B $B_r(B $B_s(B $B_t(B $B_u(B $B_v(B $B_w(B $B_x(B $B_y(B $B_z(B $B_{(B $B_|(B $B_}(B $B_~(B
+   $B`!(B $B`"(B $B`#(B $B`$(B $B`%(B $B`&(B $B`'(B $B`((B $B`)(B $B`*(B $B`+(B $B`,(B $B`-(B $B`.(B $B`/(B
+$B`0(B $B`1(B $B`2(B $B`3(B $B`4(B $B`5(B $B`6(B $B`7(B $B`8(B $B`9(B $B`:(B $B`;(B $B`<(B $B`=(B $B`>(B $B`?(B
+$B`@(B $B`A(B $B`B(B $B`C(B $B`D(B $B`E(B $B`F(B $B`G(B $B`H(B $B`I(B $B`J(B $B`K(B $B`L(B $B`M(B $B`N(B $B`O(B
+$B`P(B $B`Q(B $B`R(B $B`S(B $B`T(B $B`U(B $B`V(B $B`W(B $B`X(B $B`Y(B $B`Z(B $B`[(B $B`\(B $B`](B $B`^(B $B`_(B
+$B``(B $B`a(B $B`b(B $B`c(B $B`d(B $B`e(B $B`f(B $B`g(B $B`h(B $B`i(B $B`j(B $B`k(B $B`l(B $B`m(B $B`n(B $B`o(B
+$B`p(B $B`q(B $B`r(B $B`s(B $B`t(B $B`u(B $B`v(B $B`w(B $B`x(B $B`y(B $B`z(B $B`{(B $B`|(B $B`}(B $B`~(B
+   $Ba!(B $Ba"(B $Ba#(B $Ba$(B $Ba%(B $Ba&(B $Ba'(B $Ba((B $Ba)(B $Ba*(B $Ba+(B $Ba,(B $Ba-(B $Ba.(B $Ba/(B
+$Ba0(B $Ba1(B $Ba2(B $Ba3(B $Ba4(B $Ba5(B $Ba6(B $Ba7(B $Ba8(B $Ba9(B $Ba:(B $Ba;(B $Ba<(B $Ba=(B $Ba>(B $Ba?(B
+$Ba@(B $BaA(B $BaB(B $BaC(B $BaD(B $BaE(B $BaF(B $BaG(B $BaH(B $BaI(B $BaJ(B $BaK(B $BaL(B $BaM(B $BaN(B $BaO(B
+$BaP(B $BaQ(B $BaR(B $BaS(B $BaT(B $BaU(B $BaV(B $BaW(B $BaX(B $BaY(B $BaZ(B $Ba[(B $Ba\(B $Ba](B $Ba^(B $Ba_(B
+$Ba`(B $Baa(B $Bab(B $Bac(B $Bad(B $Bae(B $Baf(B $Bag(B $Bah(B $Bai(B $Baj(B $Bak(B $Bal(B $Bam(B $Ban(B $Bao(B
+$Bap(B $Baq(B $Bar(B $Bas(B $Bat(B $Bau(B $Bav(B $Baw(B $Bax(B $Bay(B $Baz(B $Ba{(B $Ba|(B $Ba}(B $Ba~(B
+   $Bb!(B $Bb"(B $Bb#(B $Bb$(B $Bb%(B $Bb&(B $Bb'(B $Bb((B $Bb)(B $Bb*(B $Bb+(B $Bb,(B $Bb-(B $Bb.(B $Bb/(B
+$Bb0(B $Bb1(B $Bb2(B $Bb3(B $Bb4(B $Bb5(B $Bb6(B $Bb7(B $Bb8(B $Bb9(B $Bb:(B $Bb;(B $Bb<(B $Bb=(B $Bb>(B $Bb?(B
+$Bb@(B $BbA(B $BbB(B $BbC(B $BbD(B $BbE(B $BbF(B $BbG(B $BbH(B $BbI(B $BbJ(B $BbK(B $BbL(B $BbM(B $BbN(B $BbO(B
+$BbP(B $BbQ(B $BbR(B $BbS(B $BbT(B $BbU(B $BbV(B $BbW(B $BbX(B $BbY(B $BbZ(B $Bb[(B $Bb\(B $Bb](B $Bb^(B $Bb_(B
+$Bb`(B $Bba(B $Bbb(B $Bbc(B $Bbd(B $Bbe(B $Bbf(B $Bbg(B $Bbh(B $Bbi(B $Bbj(B $Bbk(B $Bbl(B $Bbm(B $Bbn(B $Bbo(B
+$Bbp(B $Bbq(B $Bbr(B $Bbs(B $Bbt(B $Bbu(B $Bbv(B $Bbw(B $Bbx(B $Bby(B $Bbz(B $Bb{(B $Bb|(B $Bb}(B $Bb~(B
+   $Bc!(B $Bc"(B $Bc#(B $Bc$(B $Bc%(B $Bc&(B $Bc'(B $Bc((B $Bc)(B $Bc*(B $Bc+(B $Bc,(B $Bc-(B $Bc.(B $Bc/(B
+$Bc0(B $Bc1(B $Bc2(B $Bc3(B $Bc4(B $Bc5(B $Bc6(B $Bc7(B $Bc8(B $Bc9(B $Bc:(B $Bc;(B $Bc<(B $Bc=(B $Bc>(B $Bc?(B
+$Bc@(B $BcA(B $BcB(B $BcC(B $BcD(B $BcE(B $BcF(B $BcG(B $BcH(B $BcI(B $BcJ(B $BcK(B $BcL(B $BcM(B $BcN(B $BcO(B
+$BcP(B $BcQ(B $BcR(B $BcS(B $BcT(B $BcU(B $BcV(B $BcW(B $BcX(B $BcY(B $BcZ(B $Bc[(B $Bc\(B $Bc](B $Bc^(B $Bc_(B
+$Bc`(B $Bca(B $Bcb(B $Bcc(B $Bcd(B $Bce(B $Bcf(B $Bcg(B $Bch(B $Bci(B $Bcj(B $Bck(B $Bcl(B $Bcm(B $Bcn(B $Bco(B
+$Bcp(B $Bcq(B $Bcr(B $Bcs(B $Bct(B $Bcu(B $Bcv(B $Bcw(B $Bcx(B $Bcy(B $Bcz(B $Bc{(B $Bc|(B $Bc}(B $Bc~(B
+   $Bd!(B $Bd"(B $Bd#(B $Bd$(B $Bd%(B $Bd&(B $Bd'(B $Bd((B $Bd)(B $Bd*(B $Bd+(B $Bd,(B $Bd-(B $Bd.(B $Bd/(B
+$Bd0(B $Bd1(B $Bd2(B $Bd3(B $Bd4(B $Bd5(B $Bd6(B $Bd7(B $Bd8(B $Bd9(B $Bd:(B $Bd;(B $Bd<(B $Bd=(B $Bd>(B $Bd?(B
+$Bd@(B $BdA(B $BdB(B $BdC(B $BdD(B $BdE(B $BdF(B $BdG(B $BdH(B $BdI(B $BdJ(B $BdK(B $BdL(B $BdM(B $BdN(B $BdO(B
+$BdP(B $BdQ(B $BdR(B $BdS(B $BdT(B $BdU(B $BdV(B $BdW(B $BdX(B $BdY(B $BdZ(B $Bd[(B $Bd\(B $Bd](B $Bd^(B $Bd_(B
+$Bd`(B $Bda(B $Bdb(B $Bdc(B $Bdd(B $Bde(B $Bdf(B $Bdg(B $Bdh(B $Bdi(B $Bdj(B $Bdk(B $Bdl(B $Bdm(B $Bdn(B $Bdo(B
+$Bdp(B $Bdq(B $Bdr(B $Bds(B $Bdt(B $Bdu(B $Bdv(B $Bdw(B $Bdx(B $Bdy(B $Bdz(B $Bd{(B $Bd|(B $Bd}(B $Bd~(B
+   $Be!(B $Be"(B $Be#(B $Be$(B $Be%(B $Be&(B $Be'(B $Be((B $Be)(B $Be*(B $Be+(B $Be,(B $Be-(B $Be.(B $Be/(B
+$Be0(B $Be1(B $Be2(B $Be3(B $Be4(B $Be5(B $Be6(B $Be7(B $Be8(B $Be9(B $Be:(B $Be;(B $Be<(B $Be=(B $Be>(B $Be?(B
+$Be@(B $BeA(B $BeB(B $BeC(B $BeD(B $BeE(B $BeF(B $BeG(B $BeH(B $BeI(B $BeJ(B $BeK(B $BeL(B $BeM(B $BeN(B $BeO(B
+$BeP(B $BeQ(B $BeR(B $BeS(B $BeT(B $BeU(B $BeV(B $BeW(B $BeX(B $BeY(B $BeZ(B $Be[(B $Be\(B $Be](B $Be^(B $Be_(B
+$Be`(B $Bea(B $Beb(B $Bec(B $Bed(B $Bee(B $Bef(B $Beg(B $Beh(B $Bei(B $Bej(B $Bek(B $Bel(B $Bem(B $Ben(B $Beo(B
+$Bep(B $Beq(B $Ber(B $Bes(B $Bet(B $Beu(B $Bev(B $Bew(B $Bex(B $Bey(B $Bez(B $Be{(B $Be|(B $Be}(B $Be~(B
+   $Bf!(B $Bf"(B $Bf#(B $Bf$(B $Bf%(B $Bf&(B $Bf'(B $Bf((B $Bf)(B $Bf*(B $Bf+(B $Bf,(B $Bf-(B $Bf.(B $Bf/(B
+$Bf0(B $Bf1(B $Bf2(B $Bf3(B $Bf4(B $Bf5(B $Bf6(B $Bf7(B $Bf8(B $Bf9(B $Bf:(B $Bf;(B $Bf<(B $Bf=(B $Bf>(B $Bf?(B
+$Bf@(B $BfA(B $BfB(B $BfC(B $BfD(B $BfE(B $BfF(B $BfG(B $BfH(B $BfI(B $BfJ(B $BfK(B $BfL(B $BfM(B $BfN(B $BfO(B
+$BfP(B $BfQ(B $BfR(B $BfS(B $BfT(B $BfU(B $BfV(B $BfW(B $BfX(B $BfY(B $BfZ(B $Bf[(B $Bf\(B $Bf](B $Bf^(B $Bf_(B
+$Bf`(B $Bfa(B $Bfb(B $Bfc(B $Bfd(B $Bfe(B $Bff(B $Bfg(B $Bfh(B $Bfi(B $Bfj(B $Bfk(B $Bfl(B $Bfm(B $Bfn(B $Bfo(B
+$Bfp(B $Bfq(B $Bfr(B $Bfs(B $Bft(B $Bfu(B $Bfv(B $Bfw(B $Bfx(B $Bfy(B $Bfz(B $Bf{(B $Bf|(B $Bf}(B $Bf~(B
+   $Bg!(B $Bg"(B $Bg#(B $Bg$(B $Bg%(B $Bg&(B $Bg'(B $Bg((B $Bg)(B $Bg*(B $Bg+(B $Bg,(B $Bg-(B $Bg.(B $Bg/(B
+$Bg0(B $Bg1(B $Bg2(B $Bg3(B $Bg4(B $Bg5(B $Bg6(B $Bg7(B $Bg8(B $Bg9(B $Bg:(B $Bg;(B $Bg<(B $Bg=(B $Bg>(B $Bg?(B
+$Bg@(B $BgA(B $BgB(B $BgC(B $BgD(B $BgE(B $BgF(B $BgG(B $BgH(B $BgI(B $BgJ(B $BgK(B $BgL(B $BgM(B $BgN(B $BgO(B
+$BgP(B $BgQ(B $BgR(B $BgS(B $BgT(B $BgU(B $BgV(B $BgW(B $BgX(B $BgY(B $BgZ(B $Bg[(B $Bg\(B $Bg](B $Bg^(B $Bg_(B
+$Bg`(B $Bga(B $Bgb(B $Bgc(B $Bgd(B $Bge(B $Bgf(B $Bgg(B $Bgh(B $Bgi(B $Bgj(B $Bgk(B $Bgl(B $Bgm(B $Bgn(B $Bgo(B
+$Bgp(B $Bgq(B $Bgr(B $Bgs(B $Bgt(B $Bgu(B $Bgv(B $Bgw(B $Bgx(B $Bgy(B $Bgz(B $Bg{(B $Bg|(B $Bg}(B $Bg~(B
+   $Bh!(B $Bh"(B $Bh#(B $Bh$(B $Bh%(B $Bh&(B $Bh'(B $Bh((B $Bh)(B $Bh*(B $Bh+(B $Bh,(B $Bh-(B $Bh.(B $Bh/(B
+$Bh0(B $Bh1(B $Bh2(B $Bh3(B $Bh4(B $Bh5(B $Bh6(B $Bh7(B $Bh8(B $Bh9(B $Bh:(B $Bh;(B $Bh<(B $Bh=(B $Bh>(B $Bh?(B
+$Bh@(B $BhA(B $BhB(B $BhC(B $BhD(B $BhE(B $BhF(B $BhG(B $BhH(B $BhI(B $BhJ(B $BhK(B $BhL(B $BhM(B $BhN(B $BhO(B
+$BhP(B $BhQ(B $BhR(B $BhS(B $BhT(B $BhU(B $BhV(B $BhW(B $BhX(B $BhY(B $BhZ(B $Bh[(B $Bh\(B $Bh](B $Bh^(B $Bh_(B
+$Bh`(B $Bha(B $Bhb(B $Bhc(B $Bhd(B $Bhe(B $Bhf(B $Bhg(B $Bhh(B $Bhi(B $Bhj(B $Bhk(B $Bhl(B $Bhm(B $Bhn(B $Bho(B
+$Bhp(B $Bhq(B $Bhr(B $Bhs(B $Bht(B $Bhu(B $Bhv(B $Bhw(B $Bhx(B $Bhy(B $Bhz(B $Bh{(B $Bh|(B $Bh}(B $Bh~(B
+   $Bi!(B $Bi"(B $Bi#(B $Bi$(B $Bi%(B $Bi&(B $Bi'(B $Bi((B $Bi)(B $Bi*(B $Bi+(B $Bi,(B $Bi-(B $Bi.(B $Bi/(B
+$Bi0(B $Bi1(B $Bi2(B $Bi3(B $Bi4(B $Bi5(B $Bi6(B $Bi7(B $Bi8(B $Bi9(B $Bi:(B $Bi;(B $Bi<(B $Bi=(B $Bi>(B $Bi?(B
+$Bi@(B $BiA(B $BiB(B $BiC(B $BiD(B $BiE(B $BiF(B $BiG(B $BiH(B $BiI(B $BiJ(B $BiK(B $BiL(B $BiM(B $BiN(B $BiO(B
+$BiP(B $BiQ(B $BiR(B $BiS(B $BiT(B $BiU(B $BiV(B $BiW(B $BiX(B $BiY(B $BiZ(B $Bi[(B $Bi\(B $Bi](B $Bi^(B $Bi_(B
+$Bi`(B $Bia(B $Bib(B $Bic(B $Bid(B $Bie(B $Bif(B $Big(B $Bih(B $Bii(B $Bij(B $Bik(B $Bil(B $Bim(B $Bin(B $Bio(B
+$Bip(B $Biq(B $Bir(B $Bis(B $Bit(B $Biu(B $Biv(B $Biw(B $Bix(B $Biy(B $Biz(B $Bi{(B $Bi|(B $Bi}(B $Bi~(B
+   $Bj!(B $Bj"(B $Bj#(B $Bj$(B $Bj%(B $Bj&(B $Bj'(B $Bj((B $Bj)(B $Bj*(B $Bj+(B $Bj,(B $Bj-(B $Bj.(B $Bj/(B
+$Bj0(B $Bj1(B $Bj2(B $Bj3(B $Bj4(B $Bj5(B $Bj6(B $Bj7(B $Bj8(B $Bj9(B $Bj:(B $Bj;(B $Bj<(B $Bj=(B $Bj>(B $Bj?(B
+$Bj@(B $BjA(B $BjB(B $BjC(B $BjD(B $BjE(B $BjF(B $BjG(B $BjH(B $BjI(B $BjJ(B $BjK(B $BjL(B $BjM(B $BjN(B $BjO(B
+$BjP(B $BjQ(B $BjR(B $BjS(B $BjT(B $BjU(B $BjV(B $BjW(B $BjX(B $BjY(B $BjZ(B $Bj[(B $Bj\(B $Bj](B $Bj^(B $Bj_(B
+$Bj`(B $Bja(B $Bjb(B $Bjc(B $Bjd(B $Bje(B $Bjf(B $Bjg(B $Bjh(B $Bji(B $Bjj(B $Bjk(B $Bjl(B $Bjm(B $Bjn(B $Bjo(B
+$Bjp(B $Bjq(B $Bjr(B $Bjs(B $Bjt(B $Bju(B $Bjv(B $Bjw(B $Bjx(B $Bjy(B $Bjz(B $Bj{(B $Bj|(B $Bj}(B $Bj~(B
+   $Bk!(B $Bk"(B $Bk#(B $Bk$(B $Bk%(B $Bk&(B $Bk'(B $Bk((B $Bk)(B $Bk*(B $Bk+(B $Bk,(B $Bk-(B $Bk.(B $Bk/(B
+$Bk0(B $Bk1(B $Bk2(B $Bk3(B $Bk4(B $Bk5(B $Bk6(B $Bk7(B $Bk8(B $Bk9(B $Bk:(B $Bk;(B $Bk<(B $Bk=(B $Bk>(B $Bk?(B
+$Bk@(B $BkA(B $BkB(B $BkC(B $BkD(B $BkE(B $BkF(B $BkG(B $BkH(B $BkI(B $BkJ(B $BkK(B $BkL(B $BkM(B $BkN(B $BkO(B
+$BkP(B $BkQ(B $BkR(B $BkS(B $BkT(B $BkU(B $BkV(B $BkW(B $BkX(B $BkY(B $BkZ(B $Bk[(B $Bk\(B $Bk](B $Bk^(B $Bk_(B
+$Bk`(B $Bka(B $Bkb(B $Bkc(B $Bkd(B $Bke(B $Bkf(B $Bkg(B $Bkh(B $Bki(B $Bkj(B $Bkk(B $Bkl(B $Bkm(B $Bkn(B $Bko(B
+$Bkp(B $Bkq(B $Bkr(B $Bks(B $Bkt(B $Bku(B $Bkv(B $Bkw(B $Bkx(B $Bky(B $Bkz(B $Bk{(B $Bk|(B $Bk}(B $Bk~(B
+   $Bl!(B $Bl"(B $Bl#(B $Bl$(B $Bl%(B $Bl&(B $Bl'(B $Bl((B $Bl)(B $Bl*(B $Bl+(B $Bl,(B $Bl-(B $Bl.(B $Bl/(B
+$Bl0(B $Bl1(B $Bl2(B $Bl3(B $Bl4(B $Bl5(B $Bl6(B $Bl7(B $Bl8(B $Bl9(B $Bl:(B $Bl;(B $Bl<(B $Bl=(B $Bl>(B $Bl?(B
+$Bl@(B $BlA(B $BlB(B $BlC(B $BlD(B $BlE(B $BlF(B $BlG(B $BlH(B $BlI(B $BlJ(B $BlK(B $BlL(B $BlM(B $BlN(B $BlO(B
+$BlP(B $BlQ(B $BlR(B $BlS(B $BlT(B $BlU(B $BlV(B $BlW(B $BlX(B $BlY(B $BlZ(B $Bl[(B $Bl\(B $Bl](B $Bl^(B $Bl_(B
+$Bl`(B $Bla(B $Blb(B $Blc(B $Bld(B $Ble(B $Blf(B $Blg(B $Blh(B $Bli(B $Blj(B $Blk(B $Bll(B $Blm(B $Bln(B $Blo(B
+$Blp(B $Blq(B $Blr(B $Bls(B $Blt(B $Blu(B $Blv(B $Blw(B $Blx(B $Bly(B $Blz(B $Bl{(B $Bl|(B $Bl}(B $Bl~(B
+   $Bm!(B $Bm"(B $Bm#(B $Bm$(B $Bm%(B $Bm&(B $Bm'(B $Bm((B $Bm)(B $Bm*(B $Bm+(B $Bm,(B $Bm-(B $Bm.(B $Bm/(B
+$Bm0(B $Bm1(B $Bm2(B $Bm3(B $Bm4(B $Bm5(B $Bm6(B $Bm7(B $Bm8(B $Bm9(B $Bm:(B $Bm;(B $Bm<(B $Bm=(B $Bm>(B $Bm?(B
+$Bm@(B $BmA(B $BmB(B $BmC(B $BmD(B $BmE(B $BmF(B $BmG(B $BmH(B $BmI(B $BmJ(B $BmK(B $BmL(B $BmM(B $BmN(B $BmO(B
+$BmP(B $BmQ(B $BmR(B $BmS(B $BmT(B $BmU(B $BmV(B $BmW(B $BmX(B $BmY(B $BmZ(B $Bm[(B $Bm\(B $Bm](B $Bm^(B $Bm_(B
+$Bm`(B $Bma(B $Bmb(B $Bmc(B $Bmd(B $Bme(B $Bmf(B $Bmg(B $Bmh(B $Bmi(B $Bmj(B $Bmk(B $Bml(B $Bmm(B $Bmn(B $Bmo(B
+$Bmp(B $Bmq(B $Bmr(B $Bms(B $Bmt(B $Bmu(B $Bmv(B $Bmw(B $Bmx(B $Bmy(B $Bmz(B $Bm{(B $Bm|(B $Bm}(B $Bm~(B
+   $Bn!(B $Bn"(B $Bn#(B $Bn$(B $Bn%(B $Bn&(B $Bn'(B $Bn((B $Bn)(B $Bn*(B $Bn+(B $Bn,(B $Bn-(B $Bn.(B $Bn/(B
+$Bn0(B $Bn1(B $Bn2(B $Bn3(B $Bn4(B $Bn5(B $Bn6(B $Bn7(B $Bn8(B $Bn9(B $Bn:(B $Bn;(B $Bn<(B $Bn=(B $Bn>(B $Bn?(B
+$Bn@(B $BnA(B $BnB(B $BnC(B $BnD(B $BnE(B $BnF(B $BnG(B $BnH(B $BnI(B $BnJ(B $BnK(B $BnL(B $BnM(B $BnN(B $BnO(B
+$BnP(B $BnQ(B $BnR(B $BnS(B $BnT(B $BnU(B $BnV(B $BnW(B $BnX(B $BnY(B $BnZ(B $Bn[(B $Bn\(B $Bn](B $Bn^(B $Bn_(B
+$Bn`(B $Bna(B $Bnb(B $Bnc(B $Bnd(B $Bne(B $Bnf(B $Bng(B $Bnh(B $Bni(B $Bnj(B $Bnk(B $Bnl(B $Bnm(B $Bnn(B $Bno(B
+$Bnp(B $Bnq(B $Bnr(B $Bns(B $Bnt(B $Bnu(B $Bnv(B $Bnw(B $Bnx(B $Bny(B $Bnz(B $Bn{(B $Bn|(B $Bn}(B $Bn~(B
+   $Bo!(B $Bo"(B $Bo#(B $Bo$(B $Bo%(B $Bo&(B $Bo'(B $Bo((B $Bo)(B $Bo*(B $Bo+(B $Bo,(B $Bo-(B $Bo.(B $Bo/(B
+$Bo0(B $Bo1(B $Bo2(B $Bo3(B $Bo4(B $Bo5(B $Bo6(B $Bo7(B $Bo8(B $Bo9(B $Bo:(B $Bo;(B $Bo<(B $Bo=(B $Bo>(B $Bo?(B
+$Bo@(B $BoA(B $BoB(B $BoC(B $BoD(B $BoE(B $BoF(B $BoG(B $BoH(B $BoI(B $BoJ(B $BoK(B $BoL(B $BoM(B $BoN(B $BoO(B
+$BoP(B $BoQ(B $BoR(B $BoS(B $BoT(B $BoU(B $BoV(B $BoW(B $BoX(B $BoY(B $BoZ(B $Bo[(B $Bo\(B $Bo](B $Bo^(B $Bo_(B
+$Bo`(B $Boa(B $Bob(B $Boc(B $Bod(B $Boe(B $Bof(B $Bog(B $Boh(B $Boi(B $Boj(B $Bok(B $Bol(B $Bom(B $Bon(B $Boo(B
+$Bop(B $Boq(B $Bor(B $Bos(B $Bot(B $Bou(B $Bov(B $Bow(B $Box(B $Boy(B $Boz(B $Bo{(B $Bo|(B $Bo}(B $Bo~(B
+   $Bp!(B $Bp"(B $Bp#(B $Bp$(B $Bp%(B $Bp&(B $Bp'(B $Bp((B $Bp)(B $Bp*(B $Bp+(B $Bp,(B $Bp-(B $Bp.(B $Bp/(B
+$Bp0(B $Bp1(B $Bp2(B $Bp3(B $Bp4(B $Bp5(B $Bp6(B $Bp7(B $Bp8(B $Bp9(B $Bp:(B $Bp;(B $Bp<(B $Bp=(B $Bp>(B $Bp?(B
+$Bp@(B $BpA(B $BpB(B $BpC(B $BpD(B $BpE(B $BpF(B $BpG(B $BpH(B $BpI(B $BpJ(B $BpK(B $BpL(B $BpM(B $BpN(B $BpO(B
+$BpP(B $BpQ(B $BpR(B $BpS(B $BpT(B $BpU(B $BpV(B $BpW(B $BpX(B $BpY(B $BpZ(B $Bp[(B $Bp\(B $Bp](B $Bp^(B $Bp_(B
+$Bp`(B $Bpa(B $Bpb(B $Bpc(B $Bpd(B $Bpe(B $Bpf(B $Bpg(B $Bph(B $Bpi(B $Bpj(B $Bpk(B $Bpl(B $Bpm(B $Bpn(B $Bpo(B
+$Bpp(B $Bpq(B $Bpr(B $Bps(B $Bpt(B $Bpu(B $Bpv(B $Bpw(B $Bpx(B $Bpy(B $Bpz(B $Bp{(B $Bp|(B $Bp}(B $Bp~(B
+   $Bq!(B $Bq"(B $Bq#(B $Bq$(B $Bq%(B $Bq&(B $Bq'(B $Bq((B $Bq)(B $Bq*(B $Bq+(B $Bq,(B $Bq-(B $Bq.(B $Bq/(B
+$Bq0(B $Bq1(B $Bq2(B $Bq3(B $Bq4(B $Bq5(B $Bq6(B $Bq7(B $Bq8(B $Bq9(B $Bq:(B $Bq;(B $Bq<(B $Bq=(B $Bq>(B $Bq?(B
+$Bq@(B $BqA(B $BqB(B $BqC(B $BqD(B $BqE(B $BqF(B $BqG(B $BqH(B $BqI(B $BqJ(B $BqK(B $BqL(B $BqM(B $BqN(B $BqO(B
+$BqP(B $BqQ(B $BqR(B $BqS(B $BqT(B $BqU(B $BqV(B $BqW(B $BqX(B $BqY(B $BqZ(B $Bq[(B $Bq\(B $Bq](B $Bq^(B $Bq_(B
+$Bq`(B $Bqa(B $Bqb(B $Bqc(B $Bqd(B $Bqe(B $Bqf(B $Bqg(B $Bqh(B $Bqi(B $Bqj(B $Bqk(B $Bql(B $Bqm(B $Bqn(B $Bqo(B
+$Bqp(B $Bqq(B $Bqr(B $Bqs(B $Bqt(B $Bqu(B $Bqv(B $Bqw(B $Bqx(B $Bqy(B $Bqz(B $Bq{(B $Bq|(B $Bq}(B $Bq~(B
+   $Br!(B $Br"(B $Br#(B $Br$(B $Br%(B $Br&(B $Br'(B $Br((B $Br)(B $Br*(B $Br+(B $Br,(B $Br-(B $Br.(B $Br/(B
+$Br0(B $Br1(B $Br2(B $Br3(B $Br4(B $Br5(B $Br6(B $Br7(B $Br8(B $Br9(B $Br:(B $Br;(B $Br<(B $Br=(B $Br>(B $Br?(B
+$Br@(B $BrA(B $BrB(B $BrC(B $BrD(B $BrE(B $BrF(B $BrG(B $BrH(B $BrI(B $BrJ(B $BrK(B $BrL(B $BrM(B $BrN(B $BrO(B
+$BrP(B $BrQ(B $BrR(B $BrS(B $BrT(B $BrU(B $BrV(B $BrW(B $BrX(B $BrY(B $BrZ(B $Br[(B $Br\(B $Br](B $Br^(B $Br_(B
+$Br`(B $Bra(B $Brb(B $Brc(B $Brd(B $Bre(B $Brf(B $Brg(B $Brh(B $Bri(B $Brj(B $Brk(B $Brl(B $Brm(B $Brn(B $Bro(B
+$Brp(B $Brq(B $Brr(B $Brs(B $Brt(B $Bru(B $Brv(B $Brw(B $Brx(B $Bry(B $Brz(B $Br{(B $Br|(B $Br}(B $Br~(B
+   $Bs!(B $Bs"(B $Bs#(B $Bs$(B $Bs%(B $Bs&(B $Bs'(B $Bs((B $Bs)(B $Bs*(B $Bs+(B $Bs,(B $Bs-(B $Bs.(B $Bs/(B
+$Bs0(B $Bs1(B $Bs2(B $Bs3(B $Bs4(B $Bs5(B $Bs6(B $Bs7(B $Bs8(B $Bs9(B $Bs:(B $Bs;(B $Bs<(B $Bs=(B $Bs>(B $Bs?(B
+$Bs@(B $BsA(B $BsB(B $BsC(B $BsD(B $BsE(B $BsF(B $BsG(B $BsH(B $BsI(B $BsJ(B $BsK(B $BsL(B $BsM(B $BsN(B $BsO(B
+$BsP(B $BsQ(B $BsR(B $BsS(B $BsT(B $BsU(B $BsV(B $BsW(B $BsX(B $BsY(B $BsZ(B $Bs[(B $Bs\(B $Bs](B $Bs^(B $Bs_(B
+$Bs`(B $Bsa(B $Bsb(B $Bsc(B $Bsd(B $Bse(B $Bsf(B $Bsg(B $Bsh(B $Bsi(B $Bsj(B $Bsk(B $Bsl(B $Bsm(B $Bsn(B $Bso(B
+$Bsp(B $Bsq(B $Bsr(B $Bss(B $Bst(B $Bsu(B $Bsv(B $Bsw(B $Bsx(B $Bsy(B $Bsz(B $Bs{(B $Bs|(B $Bs}(B $Bs~(B
+   $Bt!(B $Bt"(B $Bt#(B $Bt$(B $Bt%(B $Bt&(B
+   $By!(B $By"(B $By#(B $By$(B $By%(B $By&(B $By'(B $By((B $By)(B $By*(B $By+(B $By,(B $By-(B $By.(B $By/(B
+$By0(B $By1(B $By2(B $By3(B $By4(B $By5(B $By6(B $By7(B $By8(B $By9(B $By:(B $By;(B $By<(B $By=(B $By>(B $By?(B
+$By@(B $ByA(B $ByB(B $ByC(B $ByD(B $ByE(B $ByF(B $ByG(B $ByH(B $ByI(B $ByJ(B $ByK(B $ByL(B $ByM(B $ByN(B $ByO(B
+$ByP(B $ByQ(B $ByR(B $ByS(B $ByT(B $ByU(B $ByV(B $ByW(B $ByX(B $ByY(B $ByZ(B $By[(B $By\(B $By](B $By^(B $By_(B
+$By`(B $Bya(B $Byb(B $Byc(B $Byd(B $Bye(B $Byf(B $Byg(B $Byh(B $Byi(B $Byj(B $Byk(B $Byl(B $Bym(B $Byn(B $Byo(B
+$Byp(B $Byq(B $Byr(B $Bys(B $Byt(B $Byu(B $Byv(B $Byw(B $Byx(B $Byy(B $Byz(B $By{(B $By|(B $By}(B $By~(B
+   $Bz!(B $Bz"(B $Bz#(B $Bz$(B $Bz%(B $Bz&(B $Bz'(B $Bz((B $Bz)(B $Bz*(B $Bz+(B $Bz,(B $Bz-(B $Bz.(B $Bz/(B
+$Bz0(B $Bz1(B $Bz2(B $Bz3(B $Bz4(B $Bz5(B $Bz6(B $Bz7(B $Bz8(B $Bz9(B $Bz:(B $Bz;(B $Bz<(B $Bz=(B $Bz>(B $Bz?(B
+$Bz@(B $BzA(B $BzB(B $BzC(B $BzD(B $BzE(B $BzF(B $BzG(B $BzH(B $BzI(B $BzJ(B $BzK(B $BzL(B $BzM(B $BzN(B $BzO(B
+$BzP(B $BzQ(B $BzR(B $BzS(B $BzT(B $BzU(B $BzV(B $BzW(B $BzX(B $BzY(B $BzZ(B $Bz[(B $Bz\(B $Bz](B $Bz^(B $Bz_(B
+$Bz`(B $Bza(B $Bzb(B $Bzc(B $Bzd(B $Bze(B $Bzf(B $Bzg(B $Bzh(B $Bzi(B $Bzj(B $Bzk(B $Bzl(B $Bzm(B $Bzn(B $Bzo(B
+$Bzp(B $Bzq(B $Bzr(B $Bzs(B $Bzt(B $Bzu(B $Bzv(B $Bzw(B $Bzx(B $Bzy(B $Bzz(B $Bz{(B $Bz|(B $Bz}(B $Bz~(B
+   $B{!(B $B{"(B $B{#(B $B{$(B $B{%(B $B{&(B $B{'(B $B{((B $B{)(B $B{*(B $B{+(B $B{,(B $B{-(B $B{.(B $B{/(B
+$B{0(B $B{1(B $B{2(B $B{3(B $B{4(B $B{5(B $B{6(B $B{7(B $B{8(B $B{9(B $B{:(B $B{;(B $B{<(B $B{=(B $B{>(B $B{?(B
+$B{@(B $B{A(B $B{B(B $B{C(B $B{D(B $B{E(B $B{F(B $B{G(B $B{H(B $B{I(B $B{J(B $B{K(B $B{L(B $B{M(B $B{N(B $B{O(B
+$B{P(B $B{Q(B $B{R(B $B{S(B $B{T(B $B{U(B $B{V(B $B{W(B $B{X(B $B{Y(B $B{Z(B $B{[(B $B{\(B $B{](B $B{^(B $B{_(B
+$B{`(B $B{a(B $B{b(B $B{c(B $B{d(B $B{e(B $B{f(B $B{g(B $B{h(B $B{i(B $B{j(B $B{k(B $B{l(B $B{m(B $B{n(B $B{o(B
+$B{p(B $B{q(B $B{r(B $B{s(B $B{t(B $B{u(B $B{v(B $B{w(B $B{x(B $B{y(B $B{z(B $B{{(B $B{|(B $B{}(B $B{~(B
+   $B|!(B $B|"(B $B|#(B $B|$(B $B|%(B $B|&(B $B|'(B $B|((B $B|)(B $B|*(B $B|+(B $B|,(B $B|-(B $B|.(B $B|/(B
+$B|0(B $B|1(B $B|2(B $B|3(B $B|4(B $B|5(B $B|6(B $B|7(B $B|8(B $B|9(B $B|:(B $B|;(B $B|<(B $B|=(B $B|>(B $B|?(B
+$B|@(B $B|A(B $B|B(B $B|C(B $B|D(B $B|E(B $B|F(B $B|G(B $B|H(B $B|I(B $B|J(B $B|K(B $B|L(B $B|M(B $B|N(B $B|O(B
+$B|P(B $B|Q(B $B|R(B $B|S(B $B|T(B $B|U(B $B|V(B $B|W(B $B|X(B $B|Y(B $B|Z(B $B|[(B $B|\(B $B|](B $B|^(B $B|_(B
+$B|`(B $B|a(B $B|b(B $B|c(B $B|d(B $B|e(B $B|f(B $B|g(B $B|h(B $B|i(B $B|j(B $B|k(B $B|l(B $B|m(B $B|n(B   
+   $B|q(B $B|r(B $B|s(B $B|t(B $B|u(B $B|v(B $B|w(B $B|x(B $B|y(B $B|z(B $B"L(B $B||(B $B|}(B $B|~(B
+   $(?!!(B $(?!"(B $(?!#(B $(?!$(B $(?!%(B $(?!&(B $(?!'(B $(?!((B $(?!)(B $(?!*(B $(?!+(B $(?!,(B $(?!-(B $(?!.(B $(?!/(B
+$(?!0(B $(?!1(B $(?!2(B $(?!3(B $(?!4(B $(?!5(B $(?!6(B $(?!7(B $(?!8(B $(?!9(B $(?!:(B $(?!;(B $(?!<(B $(?!=(B $(?!>(B $(?!?(B
+$(?!@(B $(?!A(B $(?!B(B $(?!C(B $(?!D(B $(?!E(B $(?!F(B $(?!G(B $(?!H(B $(?!I(B $(?!J(B $(?!K(B $(?!L(B $(?!M(B $(?!N(B $(?!O(B
+$(?!P(B $(?!Q(B $(?!R(B $(?!S(B $(?!T(B $(?!U(B $(?!V(B $(?!W(B $(?!X(B $(?!Y(B $(?!Z(B $(?![(B $(?!\(B $(?!](B $(?!^(B $(?!_(B
+$(?!`(B $(?!a(B $(?!b(B $(?!c(B $(?!d(B $(?!e(B $(?!f(B $(?!g(B $(?!h(B $(?!i(B $(?!j(B $(?!k(B $(?!l(B $(?!m(B $(?!n(B $(?!o(B
+$(?!p(B $(?!q(B $(?!r(B $(?!s(B $(?!t(B $(?!u(B $(?!v(B $(?!w(B $(?!x(B $(?!y(B $(?!z(B $(?!{(B $(?!|(B $(?!}(B $(?!~(B
+   $(?"!(B $(?""(B $(?"#(B $(?"$(B $(?"%(B $(?"&(B $(?"'(B $(?"((B $(?")(B $(?"*(B $(?"+(B $(?",(B $(?"-(B $(?".(B $(?"/(B
+$(?"0(B $(?"1(B $(?"2(B $(?"3(B $(?"4(B $(?"5(B $(?"6(B $(?"7(B $(?"8(B $(?"9(B $(?":(B $(?";(B $(?"<(B $(?"=(B $(?">(B $(?"?(B
+$(?"@(B $(?"A(B $(?"B(B $(?"C(B $(?"D(B $(?"E(B $(?"F(B $(?"G(B $(?"H(B $(?"I(B $(?"J(B $(?"K(B $(?"L(B $(?"M(B $(?"N(B $(?"O(B
+$(?"P(B $(?"Q(B $(?"R(B $(?"S(B $(?"T(B $(?"U(B $(?"V(B $(?"W(B $(?"X(B $(?"Y(B $(?"Z(B $(?"[(B $(?"\(B $(?"](B $(?"^(B $(?"_(B
+$(?"`(B $(?"a(B $(?"b(B $(?"c(B $(?"d(B $(?"e(B $(?"f(B $(?"g(B $(?"h(B $(?"i(B $(?"j(B $(?"k(B $(?"l(B $(?"m(B $(?"n(B $(?"o(B
+$(?"p(B $(?"q(B $(?"r(B $(?"s(B $(?"t(B $(?"u(B $(?"v(B $(?"w(B $(?"x(B $(?"y(B $(?"z(B $(?"{(B $(?"|(B $(?"}(B $(?"~(B
+   $(?#!(B $(?#"(B $(?##(B $(?#$(B $(?#%(B $(?#&(B $(?#'(B $(?#((B $(?#)(B $(?#*(B $(?#+(B $(?#,(B $(?#-(B $(?#.(B $(?#/(B
+$(?#0(B $(?#1(B $(?#2(B $(?#3(B $(?#4(B $(?#5(B $(?#6(B $(?#7(B $(?#8(B $(?#9(B $(?#:(B $(?#;(B $(?#<(B $(?#=(B $(?#>(B $(?#?(B
+$(?#@(B $(?#A(B $(?#B(B $(?#C(B $(?#D(B $(?#E(B $(?#F(B $(?#G(B $(?#H(B $(?#I(B $(?#J(B $(?#K(B $(?#L(B $(?#M(B $(?#N(B $(?#O(B
+$(?#P(B $(?#Q(B $(?#R(B $(?#S(B $(?#T(B $(?#U(B $(?#V(B $(?#W(B $(?#X(B $(?#Y(B $(?#Z(B $(?#[(B $(?#\(B $(?#](B $(?#^(B $(?#_(B
+$(?#`(B $(?#a(B $(?#b(B $(?#c(B $(?#d(B $(?#e(B $(?#f(B $(?#g(B $(?#h(B $(?#i(B $(?#j(B $(?#k(B $(?#l(B $(?#m(B $(?#n(B $(?#o(B
+$(?#p(B $(?#q(B $(?#r(B $(?#s(B $(?#t(B $(?#u(B $(?#v(B $(?#w(B $(?#x(B $(?#y(B $(?#z(B $(?#{(B $(?#|(B $(?#}(B $(?#~(B
+   $(?$!(B $(?$"(B $(?$#(B $(?$$(B $(?$%(B $(?$&(B $(?$'(B $(?$((B $(?$)(B $(?$*(B $(?$+(B $(?$,(B $(?$-(B $(?$.(B $(?$/(B
+$(?$0(B $(?$1(B $(?$2(B $(?$3(B $(?$4(B $(?$5(B $(?$6(B $(?$7(B $(?$8(B $(?$9(B $(?$:(B $(?$;(B $(?$<(B $(?$=(B $(?$>(B $(?$?(B
+$(?$@(B $(?$A(B $(?$B(B $(?$C(B $(?$D(B $(?$E(B $(?$F(B $(?$G(B $(?$H(B $(?$I(B $(?$J(B $(?$K(B $(?$L(B $(?$M(B $(?$N(B $(?$O(B
+$(?$P(B $(?$Q(B $(?$R(B $(?$S(B $(?$T(B $(?$U(B $(?$V(B $(?$W(B $(?$X(B $(?$Y(B $(?$Z(B $(?$[(B $(?$\(B $(?$](B $(?$^(B $(?$_(B
+$(?$`(B $(?$a(B $(?$b(B $(?$c(B $(?$d(B $(?$e(B $(?$f(B $(?$g(B $(?$h(B $(?$i(B $(?$j(B $(?$k(B $(?$l(B $(?$m(B $(?$n(B $(?$o(B
+$(?$p(B $(?$q(B $(?$r(B $(?$s(B $(?$t(B $(?$u(B $(?$v(B $(?$w(B $(?$x(B $(?$y(B $(?$z(B $(?${(B $(?$|(B $(?$}(B $(?$~(B
+   $(?%!(B $(?%"(B $(?%#(B $(?%$(B $(?%%(B $(?%&(B $(?%'(B $(?%((B $(?%)(B $(?%*(B $(?%+(B $(?%,(B $(?%-(B $(?%.(B $(?%/(B
+$(?%0(B $(?%1(B $(?%2(B $(?%3(B $(?%4(B $(?%5(B $(?%6(B $(?%7(B $(?%8(B $(?%9(B $(?%:(B $(?%;(B $(?%<(B $(?%=(B $(?%>(B $(?%?(B
+$(?%@(B $(?%A(B $(?%B(B $(?%C(B $(?%D(B $(?%E(B $(?%F(B $(?%G(B $(?%H(B $(?%I(B $(?%J(B $(?%K(B $(?%L(B $(?%M(B $(?%N(B $(?%O(B
+$(?%P(B $(?%Q(B $(?%R(B $(?%S(B $(?%T(B $(?%U(B $(?%V(B $(?%W(B $(?%X(B $(?%Y(B $(?%Z(B $(?%[(B $(?%\(B $(?%](B $(?%^(B $(?%_(B
+$(?%`(B $(?%a(B $(?%b(B $(?%c(B $(?%d(B $(?%e(B $(?%f(B $(?%g(B $(?%h(B $(?%i(B $(?%j(B $(?%k(B $(?%l(B $(?%m(B $(?%n(B $(?%o(B
+$(?%p(B $(?%q(B $(?%r(B $(?%s(B $(?%t(B $(?%u(B $(?%v(B $(?%w(B $(?%x(B $(?%y(B $(?%z(B $(?%{(B $(?%|(B $(?%}(B $(?%~(B
+   $(?&!(B $(?&"(B $(?&#(B $(?&$(B $(?&%(B $(?&&(B $(?&'(B $(?&((B $(?&)(B $(?&*(B $(?&+(B $(?&,(B $(?&-(B $(?&.(B $(?&/(B
+$(?&0(B $(?&1(B $(?&2(B $(?&3(B $(?&4(B $(?&5(B $(?&6(B $(?&7(B $(?&8(B $(?&9(B $(?&:(B $(?&;(B $(?&<(B $(?&=(B $(?&>(B $(?&?(B
+$(?&@(B $(?&A(B $(?&B(B $(?&C(B $(?&D(B $(?&E(B $(?&F(B $(?&G(B $(?&H(B $(?&I(B $(?&J(B $(?&K(B $(?&L(B $(?&M(B $(?&N(B $(?&O(B
+$(?&P(B $(?&Q(B $(?&R(B $(?&S(B $(?&T(B $(?&U(B $(?&V(B $(?&W(B $(?&X(B $(?&Y(B $(?&Z(B $(?&[(B $(?&\(B $(?&](B $(?&^(B $(?&_(B
+$(?&`(B $(?&a(B $(?&b(B $(?&c(B $(?&d(B $(?&e(B $(?&f(B $(?&g(B $(?&h(B $(?&i(B $(?&j(B $(?&k(B $(?&l(B $(?&m(B $(?&n(B $(?&o(B
+$(?&p(B $(?&q(B $(?&r(B $(?&s(B $(?&t(B $(?&u(B $(?&v(B $(?&w(B $(?&x(B $(?&y(B $(?&z(B $(?&{(B $(?&|(B $(?&}(B $(?&~(B
+   $(?'!(B $(?'"(B $(?'#(B $(?'$(B $(?'%(B $(?'&(B $(?''(B $(?'((B $(?')(B $(?'*(B $(?'+(B $(?',(B $(?'-(B $(?'.(B $(?'/(B
+$(?'0(B $(?'1(B $(?'2(B $(?'3(B $(?'4(B $(?'5(B $(?'6(B $(?'7(B $(?'8(B $(?'9(B $(?':(B $(?';(B $(?'<(B $(?'=(B $(?'>(B $(?'?(B
+$(?'@(B $(?'A(B $(?'B(B $(?'C(B $(?'D(B $(?'E(B $(?'F(B $(?'G(B $(?'H(B $(?'I(B $(?'J(B $(?'K(B $(?'L(B $(?'M(B $(?'N(B $(?'O(B
+$(?'P(B $(?'Q(B $(?'R(B $(?'S(B $(?'T(B $(?'U(B $(?'V(B $(?'W(B $(?'X(B $(?'Y(B $(?'Z(B $(?'[(B $(?'\(B $(?'](B $(?'^(B $(?'_(B
+$(?'`(B $(?'a(B $(?'b(B $(?'c(B $(?'d(B $(?'e(B $(?'f(B $(?'g(B $(?'h(B $(?'i(B $(?'j(B $(?'k(B $(?'l(B $(?'m(B $(?'n(B $(?'o(B
+$(?'p(B $(?'q(B $(?'r(B $(?'s(B $(?'t(B $(?'u(B $(?'v(B $(?'w(B $(?'x(B $(?'y(B $(?'z(B $(?'{(B $(?'|(B $(?'}(B $(?'~(B
+   $(?(!(B $(?("(B $(?(#(B $(?($(B $(?(%(B $(?(&(B $(?('(B $(?(((B $(?()(B $(?(*(B $(?(+(B $(?(,(B $(?(-(B $(?(.(B $(?(/(B
+$(?(0(B $(?(1(B $(?(2(B $(?(3(B $(?(4(B $(?(5(B $(?(6(B $(?(7(B $(?(8(B $(?(9(B $(?(:(B $(?(;(B $(?(<(B $(?(=(B $(?(>(B $(?(?(B
+$(?(@(B $(?(A(B $(?(B(B $(?(C(B $(?(D(B $(?(E(B $(?(F(B $(?(G(B $(?(H(B $(?(I(B $(?(J(B $(?(K(B $(?(L(B $(?(M(B $(?(N(B $(?(O(B
+$(?(P(B $(?(Q(B $(?(R(B $(?(S(B $(?(T(B $(?(U(B $(?(V(B $(?(W(B $(?(X(B $(?(Y(B $(?(Z(B $(?([(B $(?(\(B $(?(](B $(?(^(B $(?(_(B
+$(?(`(B $(?(a(B $(?(b(B $(?(c(B $(?(d(B $(?(e(B $(?(f(B $(?(g(B $(?(h(B $(?(i(B $(?(j(B $(?(k(B $(?(l(B $(?(m(B $(?(n(B $(?(o(B
+$(?(p(B $(?(q(B $(?(r(B $(?(s(B $(?(t(B $(?(u(B $(?(v(B $(?(w(B $(?(x(B $(?(y(B $(?(z(B $(?({(B $(?(|(B $(?(}(B $(?(~(B
+   $(?)!(B $(?)"(B $(?)#(B $(?)$(B $(?)%(B $(?)&(B $(?)'(B $(?)((B $(?))(B $(?)*(B $(?)+(B $(?),(B $(?)-(B $(?).(B $(?)/(B
+$(?)0(B $(?)1(B $(?)2(B $(?)3(B $(?)4(B $(?)5(B $(?)6(B $(?)7(B $(?)8(B $(?)9(B $(?):(B $(?);(B $(?)<(B $(?)=(B $(?)>(B $(?)?(B
+$(?)@(B $(?)A(B $(?)B(B $(?)C(B $(?)D(B $(?)E(B $(?)F(B $(?)G(B $(?)H(B $(?)I(B $(?)J(B $(?)K(B $(?)L(B $(?)M(B $(?)N(B $(?)O(B
+$(?)P(B $(?)Q(B $(?)R(B $(?)S(B $(?)T(B $(?)U(B $(?)V(B $(?)W(B $(?)X(B $(?)Y(B $(?)Z(B $(?)[(B $(?)\(B $(?)](B $(?)^(B $(?)_(B
+$(?)`(B $(?)a(B $(?)b(B $(?)c(B $(?)d(B $(?)e(B $(?)f(B $(?)g(B $(?)h(B $(?)i(B $(?)j(B $(?)k(B $(?)l(B $(?)m(B $(?)n(B $(?)o(B
+$(?)p(B $(?)q(B $(?)r(B $(?)s(B $(?)t(B $(?)u(B $(?)v(B $(?)w(B $(?)x(B $(?)y(B $(?)z(B $(?){(B $(?)|(B $(?)}(B $(?)~(B
+   $(?*!(B $(?*"(B $(?*#(B $(?*$(B $(?*%(B $(?*&(B $(?*'(B $(?*((B $(?*)(B $(?**(B $(?*+(B $(?*,(B $(?*-(B $(?*.(B $(?*/(B
+$(?*0(B $(?*1(B $(?*2(B $(?*3(B $(?*4(B $(?*5(B $(?*6(B $(?*7(B $(?*8(B $(?*9(B $(?*:(B $(?*;(B $(?*<(B $(?*=(B $(?*>(B $(?*?(B
+$(?*@(B $(?*A(B $(?*B(B $(?*C(B $(?*D(B $(?*E(B $(?*F(B $(?*G(B $(?*H(B $(?*I(B $(?*J(B $(?*K(B $(?*L(B $(?*M(B $(?*N(B $(?*O(B
+$(?*P(B $(?*Q(B $(?*R(B $(?*S(B $(?*T(B $(?*U(B $(?*V(B $(?*W(B $(?*X(B $(?*Y(B $(?*Z(B $(?*[(B $(?*\(B $(?*](B $(?*^(B $(?*_(B
+$(?*`(B $(?*a(B $(?*b(B $(?*c(B $(?*d(B $(?*e(B $(?*f(B $(?*g(B $(?*h(B $(?*i(B $(?*j(B $(?*k(B $(?*l(B $(?*m(B $(?*n(B $(?*o(B
+$(?*p(B $(?*q(B $(?*r(B $(?*s(B $(?*t(B $(?*u(B $(?*v(B $(?*w(B $(?*x(B $(?*y(B $(?*z(B $(?*{(B $(?*|(B $(?*}(B $(?*~(B
+   $(?+!(B $(?+"(B $(?+#(B $(?+$(B $(?+%(B $(?+&(B $(?+'(B $(?+((B $(?+)(B $(?+*(B $(?++(B $(?+,(B $(?+-(B $(?+.(B $(?+/(B
+$(?+0(B $(?+1(B $(?+2(B $(?+3(B $(?+4(B $(?+5(B $(?+6(B $(?+7(B $(?+8(B $(?+9(B $(?+:(B $(?+;(B $(?+<(B $(?+=(B $(?+>(B $(?+?(B
+$(?+@(B $(?+A(B $(?+B(B $(?+C(B $(?+D(B $(?+E(B $(?+F(B $(?+G(B $(?+H(B $(?+I(B $(?+J(B $(?+K(B $(?+L(B $(?+M(B $(?+N(B $(?+O(B
+$(?+P(B $(?+Q(B $(?+R(B $(?+S(B $(?+T(B $(?+U(B $(?+V(B $(?+W(B $(?+X(B $(?+Y(B $(?+Z(B $(?+[(B $(?+\(B $(?+](B $(?+^(B $(?+_(B
+$(?+`(B $(?+a(B $(?+b(B $(?+c(B $(?+d(B $(?+e(B $(?+f(B $(?+g(B $(?+h(B $(?+i(B $(?+j(B $(?+k(B $(?+l(B $(?+m(B $(?+n(B $(?+o(B
+$(?+p(B $(?+q(B $(?+r(B $(?+s(B $(?+t(B $(?+u(B $(?+v(B $(?+w(B $(?+x(B $(?+y(B $(?+z(B $(?+{(B $(?+|(B $(?+}(B $(?+~(B
+   $(?,!(B $(?,"(B $(?,#(B $(?,$(B $(?,%(B $(?,&(B $(?,'(B $(?,((B $(?,)(B $(?,*(B $(?,+(B $(?,,(B $(?,-(B $(?,.(B $(?,/(B
+$(?,0(B $(?,1(B $(?,2(B $(?,3(B $(?,4(B $(?,5(B $(?,6(B $(?,7(B $(?,8(B $(?,9(B $(?,:(B $(?,;(B $(?,<(B $(?,=(B $(?,>(B $(?,?(B
+$(?,@(B $(?,A(B $(?,B(B $(?,C(B $(?,D(B $(?,E(B $(?,F(B $(?,G(B $(?,H(B $(?,I(B $(?,J(B $(?,K(B $(?,L(B $(?,M(B $(?,N(B $(?,O(B
+$(?,P(B $(?,Q(B $(?,R(B $(?,S(B $(?,T(B $(?,U(B $(?,V(B $(?,W(B $(?,X(B $(?,Y(B $(?,Z(B $(?,[(B $(?,\(B $(?,](B $(?,^(B $(?,_(B
+$(?,`(B $(?,a(B $(?,b(B $(?,c(B $(?,d(B $(?,e(B $(?,f(B $(?,g(B $(?,h(B $(?,i(B $(?,j(B $(?,k(B $(?,l(B $(?,m(B $(?,n(B $(?,o(B
+$(?,p(B $(?,q(B $(?,r(B $(?,s(B $(?,t(B $(?,u(B $(?,v(B $(?,w(B $(?,x(B $(?,y(B $(?,z(B $(?,{(B $(?,|(B $(?,}(B $(?,~(B
+   $(?-!(B $(?-"(B $(?-#(B $(?-$(B $(?-%(B $(?-&(B $(?-'(B $(?-((B $(?-)(B $(?-*(B $(?-+(B $(?-,(B $(?--(B $(?-.(B $(?-/(B
+$(?-0(B $(?-1(B $(?-2(B $(?-3(B $(?-4(B $(?-5(B $(?-6(B $(?-7(B $(?-8(B $(?-9(B $(?-:(B $(?-;(B $(?-<(B $(?-=(B $(?->(B $(?-?(B
+$(?-@(B $(?-A(B $(?-B(B $(?-C(B $(?-D(B $(?-E(B $(?-F(B $(?-G(B $(?-H(B $(?-I(B $(?-J(B $(?-K(B $(?-L(B $(?-M(B $(?-N(B $(?-O(B
+$(?-P(B $(?-Q(B $(?-R(B $(?-S(B $(?-T(B $(?-U(B $(?-V(B $(?-W(B $(?-X(B $(?-Y(B $(?-Z(B $(?-[(B $(?-\(B $(?-](B $(?-^(B $(?-_(B
+$(?-`(B $(?-a(B $(?-b(B $(?-c(B $(?-d(B $(?-e(B $(?-f(B $(?-g(B $(?-h(B $(?-i(B $(?-j(B $(?-k(B $(?-l(B $(?-m(B $(?-n(B $(?-o(B
+$(?-p(B $(?-q(B $(?-r(B $(?-s(B $(?-t(B $(?-u(B $(?-v(B $(?-w(B $(?-x(B $(?-y(B $(?-z(B $(?-{(B $(?-|(B $(?-}(B $(?-~(B
+   $(?.!(B $(?."(B $(?.#(B $(?.$(B $(?.%(B $(?.&(B $(?.'(B $(?.((B $(?.)(B $(?.*(B $(?.+(B $(?.,(B $(?.-(B $(?..(B $(?./(B
+$(?.0(B $(?.1(B $(?.2(B $(?.3(B $(?.4(B $(?.5(B $(?.6(B $(?.7(B $(?.8(B $(?.9(B $(?.:(B $(?.;(B $(?.<(B $(?.=(B $(?.>(B $(?.?(B
+$(?.@(B $(?.A(B $(?.B(B $(?.C(B $(?.D(B $(?.E(B $(?.F(B $(?.G(B $(?.H(B $(?.I(B $(?.J(B $(?.K(B $(?.L(B $(?.M(B $(?.N(B $(?.O(B
+$(?.P(B $(?.Q(B $(?.R(B $(?.S(B $(?.T(B $(?.U(B $(?.V(B $(?.W(B $(?.X(B $(?.Y(B $(?.Z(B $(?.[(B $(?.\(B $(?.](B $(?.^(B $(?._(B
+$(?.`(B $(?.a(B $(?.b(B $(?.c(B $(?.d(B $(?.e(B $(?.f(B $(?.g(B $(?.h(B $(?.i(B $(?.j(B $(?.k(B $(?.l(B $(?.m(B $(?.n(B $(?.o(B
+$(?.p(B $(?.q(B $(?.r(B $(?.s(B $(?.t(B $(?.u(B $(?.v(B $(?.w(B $(?.x(B $(?.y(B $(?.z(B $(?.{(B $(?.|(B $(?.}(B $(?.~(B
+   $(?/!(B $(?/"(B $(?/#(B $(?/$(B $(?/%(B $(?/&(B $(?/'(B $(?/((B $(?/)(B $(?/*(B $(?/+(B $(?/,(B $(?/-(B $(?/.(B $(?//(B
+$(?/0(B $(?/1(B $(?/2(B $(?/3(B $(?/4(B $(?/5(B $(?/6(B $(?/7(B $(?/8(B $(?/9(B $(?/:(B $(?/;(B $(?/<(B $(?/=(B $(?/>(B $(?/?(B
+$(?/@(B $(?/A(B $(?/B(B $(?/C(B $(?/D(B $(?/E(B $(?/F(B $(?/G(B $(?/H(B $(?/I(B $(?/J(B $(?/K(B $(?/L(B $(?/M(B $(?/N(B $(?/O(B
+$(?/P(B $(?/Q(B $(?/R(B $(?/S(B $(?/T(B $(?/U(B $(?/V(B $(?/W(B $(?/X(B $(?/Y(B $(?/Z(B $(?/[(B $(?/\(B $(?/](B $(?/^(B $(?/_(B
+$(?/`(B $(?/a(B $(?/b(B $(?/c(B $(?/d(B $(?/e(B $(?/f(B $(?/g(B $(?/h(B $(?/i(B $(?/j(B $(?/k(B $(?/l(B $(?/m(B $(?/n(B $(?/o(B
+$(?/p(B $(?/q(B $(?/r(B $(?/s(B $(?/t(B $(?/u(B $(?/v(B $(?/w(B $(?/x(B $(?/y(B $(?/z(B $(?/{(B $(?/|(B $(?/}(B $(?/~(B
+   $(?0!(B $(?0"(B $(?0#(B $(?0$(B $(?0%(B $(?0&(B $(?0'(B $(?0((B $(?0)(B $(?0*(B $(?0+(B $(?0,(B $(?0-(B $(?0.(B $(?0/(B
+$(?00(B $(?01(B $(?02(B $(?03(B $(?04(B $(?05(B $(?06(B $(?07(B $(?08(B $(?09(B $(?0:(B $(?0;(B $(?0<(B $(?0=(B $(?0>(B $(?0?(B
+$(?0@(B $(?0A(B $(?0B(B $(?0C(B $(?0D(B $(?0E(B $(?0F(B $(?0G(B $(?0H(B $(?0I(B $(?0J(B $(?0K(B $(?0L(B $(?0M(B $(?0N(B $(?0O(B
+$(?0P(B $(?0Q(B $(?0R(B $(?0S(B $(?0T(B $(?0U(B $(?0V(B $(?0W(B $(?0X(B $(?0Y(B $(?0Z(B $(?0[(B $(?0\(B $(?0](B $(?0^(B $(?0_(B
+$(?0`(B $(?0a(B $(?0b(B $(?0c(B $(?0d(B $(?0e(B $(?0f(B $(?0g(B $(?0h(B $(?0i(B $(?0j(B $(?0k(B $(?0l(B $(?0m(B $(?0n(B $(?0o(B
+$(?0p(B $(?0q(B $(?0r(B $(?0s(B $(?0t(B $(?0u(B $(?0v(B $(?0w(B $(?0x(B $(?0y(B $(?0z(B $(?0{(B $(?0|(B $(?0}(B $(?0~(B
+   $(?1!(B $(?1"(B $(?1#(B $(?1$(B $(?1%(B $(?1&(B $(?1'(B $(?1((B $(?1)(B $(?1*(B $(?1+(B $(?1,(B $(?1-(B $(?1.(B $(?1/(B
+$(?10(B $(?11(B $(?12(B $(?13(B $(?14(B $(?15(B $(?16(B $(?17(B $(?18(B $(?19(B $(?1:(B $(?1;(B $(?1<(B $(?1=(B $(?1>(B $(?1?(B
+$(?1@(B $(?1A(B $(?1B(B $(?1C(B $(?1D(B $(?1E(B $(?1F(B $(?1G(B $(?1H(B $(?1I(B $(?1J(B $(?1K(B $(?1L(B $(?1M(B $(?1N(B $(?1O(B
+$(?1P(B $(?1Q(B $(?1R(B $(?1S(B $(?1T(B $(?1U(B $(?1V(B $(?1W(B $(?1X(B $(?1Y(B $(?1Z(B $(?1[(B $(?1\(B $(?1](B $(?1^(B $(?1_(B
+$(?1`(B $(?1a(B $(?1b(B $(?1c(B $(?1d(B $(?1e(B $(?1f(B $(?1g(B $(?1h(B $(?1i(B $(?1j(B $(?1k(B $(?1l(B $(?1m(B $(?1n(B $(?1o(B
+$(?1p(B $(?1q(B $(?1r(B $(?1s(B $(?1t(B $(?1u(B $(?1v(B $(?1w(B $(?1x(B $(?1y(B $(?1z(B $(?1{(B $(?1|(B $(?1}(B $(?1~(B
+   $(?2!(B $(?2"(B $(?2#(B $(?2$(B $(?2%(B $(?2&(B $(?2'(B $(?2((B $(?2)(B $(?2*(B $(?2+(B $(?2,(B $(?2-(B $(?2.(B $(?2/(B
+$(?20(B $(?21(B $(?22(B $(?23(B $(?24(B $(?25(B $(?26(B $(?27(B $(?28(B $(?29(B $(?2:(B $(?2;(B $(?2<(B $(?2=(B $(?2>(B $(?2?(B
+$(?2@(B $(?2A(B $(?2B(B $(?2C(B $(?2D(B $(?2E(B $(?2F(B $(?2G(B $(?2H(B $(?2I(B $(?2J(B $(?2K(B $(?2L(B $(?2M(B $(?2N(B $(?2O(B
+$(?2P(B $(?2Q(B $(?2R(B $(?2S(B $(?2T(B $(?2U(B $(?2V(B $(?2W(B $(?2X(B $(?2Y(B $(?2Z(B $(?2[(B $(?2\(B $(?2](B $(?2^(B $(?2_(B
+$(?2`(B $(?2a(B $(?2b(B $(?2c(B $(?2d(B $(?2e(B $(?2f(B $(?2g(B $(?2h(B $(?2i(B $(?2j(B $(?2k(B $(?2l(B $(?2m(B $(?2n(B $(?2o(B
+$(?2p(B $(?2q(B $(?2r(B $(?2s(B $(?2t(B $(?2u(B $(?2v(B $(?2w(B $(?2x(B $(?2y(B $(?2z(B $(?2{(B $(?2|(B $(?2}(B $(?2~(B
+   $(?3!(B $(?3"(B $(?3#(B $(?3$(B $(?3%(B $(?3&(B $(?3'(B $(?3((B $(?3)(B $(?3*(B $(?3+(B $(?3,(B $(?3-(B $(?3.(B $(?3/(B
+$(?30(B $(?31(B $(?32(B $(?33(B $(?34(B $(?35(B $(?36(B $(?37(B $(?38(B $(?39(B $(?3:(B $(?3;(B $(?3<(B $(?3=(B $(?3>(B $(?3?(B
+$(?3@(B $(?3A(B $(?3B(B $(?3C(B $(?3D(B $(?3E(B $(?3F(B $(?3G(B $(?3H(B $(?3I(B $(?3J(B $(?3K(B $(?3L(B $(?3M(B $(?3N(B $(?3O(B
+$(?3P(B $(?3Q(B $(?3R(B $(?3S(B $(?3T(B $(?3U(B $(?3V(B $(?3W(B $(?3X(B $(?3Y(B $(?3Z(B $(?3[(B $(?3\(B $(?3](B $(?3^(B $(?3_(B
+$(?3`(B $(?3a(B $(?3b(B $(?3c(B $(?3d(B $(?3e(B $(?3f(B $(?3g(B $(?3h(B $(?3i(B $(?3j(B $(?3k(B $(?3l(B $(?3m(B $(?3n(B $(?3o(B
+$(?3p(B $(?3q(B $(?3r(B $(?3s(B $(?3t(B $(?3u(B $(?3v(B $(?3w(B $(?3x(B $(?3y(B $(?3z(B $(?3{(B $(?3|(B $(?3}(B $(?3~(B
+   $(?4!(B $(?4"(B $(?4#(B $(?4$(B $(?4%(B $(?4&(B $(?4'(B $(?4((B $(?4)(B $(?4*(B $(?4+(B $(?4,(B $(?4-(B $(?4.(B $(?4/(B
+$(?40(B $(?41(B $(?42(B $(?43(B $(?44(B $(?45(B $(?46(B $(?47(B $(?48(B $(?49(B $(?4:(B $(?4;(B $(?4<(B $(?4=(B $(?4>(B $(?4?(B
+$(?4@(B $(?4A(B $(?4B(B $(?4C(B $(?4D(B $(?4E(B $(?4F(B $(?4G(B $(?4H(B $(?4I(B $(?4J(B $(?4K(B $(?4L(B $(?4M(B $(?4N(B $(?4O(B
+$(?4P(B $(?4Q(B $(?4R(B $(?4S(B $(?4T(B $(?4U(B $(?4V(B $(?4W(B $(?4X(B $(?4Y(B $(?4Z(B $(?4[(B $(?4\(B $(?4](B $(?4^(B $(?4_(B
+$(?4`(B $(?4a(B $(?4b(B $(?4c(B $(?4d(B $(?4e(B $(?4f(B $(?4g(B $(?4h(B $(?4i(B $(?4j(B $(?4k(B $(?4l(B $(?4m(B $(?4n(B $(?4o(B
+$(?4p(B $(?4q(B $(?4r(B $(?4s(B $(?4t(B $(?4u(B $(?4v(B $(?4w(B $(?4x(B $(?4y(B $(?4z(B $(?4{(B $(?4|(B $(?4}(B $(?4~(B
+
+Japanese ($BF|K\8l(B)		$B$3$s$K$A$O(B
+	JIS  -- $B855$(B  $B3+H/(B
+	NEC$BFC<lJ8;z(B  -- $B-!-"-#(B
+	NEC$BA*Dj(BIBM$B3HD%J8;z(B -- $BFbEDI4|N(B  $B|bEg20(B  $BApy,9d(B
+  ! " # $ % & ' ( ) * + , - . /
+0 1 2 3 4 5 6 7 8 9 : ; < = > ?
+@ A B C D E F G H I J K L M N O
+P Q R S T U V W X Y Z [ \ ] ^ _
+` a b c d e f g h i j k l m n o
+p q r s t u v w x y z { | } ~
   (I!(B (I"(B (I#(B (I$(B (I%(B (I&(B (I'(B (I((B (I)(B (I*(B (I+(B (I,(B (I-(B (I.(B (I/(B
 (I0(B (I1(B (I2(B (I3(B (I4(B (I5(B (I6(B (I7(B (I8(B (I9(B (I:(B (I;(B (I<(B (I=(B (I>(B (I?(B
 (I@(B (IA(B (IB(B (IC(B (ID(B (IE(B (IF(B (IG(B (IH(B (II(B (IJ(B (IK(B (IL(B (IM(B (IN(B (IO(B
diff -uprN libiconv-1.15-old/tests/ISO-2022-JP-MS-snippet.UTF-8 libiconv-1.15/tests/ISO-2022-JP-MS-snippet.UTF-8
--- libiconv-1.15-old/tests/ISO-2022-JP-MS-snippet.UTF-8	2014-01-03 07:23:02.000000000 +0900
+++ libiconv-1.15/tests/ISO-2022-JP-MS-snippet.UTF-8	2017-09-17 05:38:54.221616000 +0900
@@ -4,6 +4,620 @@
 P Q R S T U V W X Y Z [ \ ] ^ _
 ` a b c d e f g h i j k l m n o
 p q r s t u v w x y z { | } ~
+   ｡ ｢ ｣ ､ ･ ｦ ｧ ｨ ｩ ｪ ｫ ｬ ｭ ｮ ｯ
+ｰ ｱ ｲ ｳ ｴ ｵ ｶ ｷ ｸ ｹ ｺ ｻ ｼ ｽ ｾ ｿ
+ﾀ ﾁ ﾂ ﾃ ﾄ ﾅ ﾆ ﾇ ﾈ ﾉ ﾊ ﾋ ﾌ ﾍ ﾎ ﾏ
+ﾐ ﾑ ﾒ ﾓ ﾔ ﾕ ﾖ ﾗ ﾘ ﾙ ﾚ ﾛ ﾜ ﾝ ﾞ ﾟ
+  　 、 。 ， ． ・ ： ； ？ ！ ゛ ゜ ´ ｀ ¨
+＾ ￣ ＿ ヽ ヾ ゝ ゞ 〃 仝 々 〆 〇 ー ― ‐ ／
+  ～ ∥ ｜ … ‥ ‘ ’ “ ” （ ） 〔 〕 ［ ］
+｛ ｝ 〈 〉 《 》 「 」 『 』 【 】 ＋ － ± ×
+÷ ＝ ≠ ＜ ＞ ≦ ≧ ∞ ∴ ♂ ♀ ° ′ ″ ℃ ￥
+＄ ￠ ￡ ％ ＃ ＆ ＊ ＠ § ☆ ★ ○ ● ◎ ◇
+  ◆ □ ■ △ ▲ ▽ ▼ ※ 〒 → ← ↑ ↓ 〓
+                    ∈ ∋ ⊆ ⊇ ⊂ ⊃
+∪ ∩                 ∧ ∨ ￢ ⇒ ⇔ ∀
+∃                       ∠ ⊥ ⌒ ∂
+∇ ≡ ≒ ≪ ≫ √ ∽ ∝ ∵ ∫ ∬
+    Å ‰ ♯ ♭ ♪ † ‡ ¶         ◯
+０ １ ２ ３ ４ ５ ６ ７ ８ ９
+   Ａ Ｂ Ｃ Ｄ Ｅ Ｆ Ｇ Ｈ Ｉ Ｊ Ｋ Ｌ Ｍ Ｎ Ｏ
+Ｐ Ｑ Ｒ Ｓ Ｔ Ｕ Ｖ Ｗ Ｘ Ｙ Ｚ
+   ａ ｂ ｃ ｄ ｅ ｆ ｇ ｈ ｉ ｊ ｋ ｌ ｍ ｎ ｏ
+ｐ ｑ ｒ ｓ ｔ ｕ ｖ ｗ ｘ ｙ ｚ
+   ぁ あ ぃ い ぅ う ぇ え ぉ お か が き ぎ く
+ぐ け げ こ ご さ ざ し じ す ず せ ぜ そ ぞ た
+だ ち ぢ っ つ づ て で と ど な に ぬ ね の は
+ば ぱ ひ び ぴ ふ ぶ ぷ へ べ ぺ ほ ぼ ぽ ま み
+む め も ゃ や ゅ ゆ ょ よ ら り る れ ろ ゎ わ
+ゐ ゑ を ん
+   ァ ア ィ イ ゥ ウ ェ エ ォ オ カ ガ キ ギ ク
+グ ケ ゲ コ ゴ サ ザ シ ジ ス ズ セ ゼ ソ ゾ タ
+ダ チ ヂ ッ ツ ヅ テ デ ト ド ナ ニ ヌ ネ ノ ハ
+バ パ ヒ ビ ピ フ ブ プ ヘ ベ ペ ホ ボ ポ マ ミ
+ム メ モ ャ ヤ ュ ユ ョ ヨ ラ リ ル レ ロ ヮ ワ
+ヰ ヱ ヲ ン ヴ ヵ ヶ
+  Α Β Γ Δ Ε Ζ Η Θ Ι Κ Λ Μ Ν Ξ Ο
+Π Ρ Σ Τ Υ Φ Χ Ψ Ω
+  α β γ δ ε ζ η θ ι κ λ μ ν ξ ο
+π ρ σ τ υ φ χ ψ ω
+  А Б В Г Д Е Ё Ж З И Й К Л М Н
+О П Р С Т У Ф Х Ц Ч Ш Щ Ъ Ы Ь Э
+Ю Я
+  а б в г д е ё ж з и й к л м н
+о п р с т у ф х ц ч ш щ ъ ы ь э
+ю я
+  ─ │ ┌ ┐ ┘ └ ├ ┬ ┤ ┴ ┼ ━ ┃ ┏ ┓
+┛ ┗ ┣ ┳ ┫ ┻ ╋ ┠ ┯ ┨ ┷ ┿ ┝ ┰ ┥ ┸
+╂
+   ① ② ③ ④ ⑤ ⑥ ⑦ ⑧ ⑨ ⑩ ⑪ ⑫ ⑬ ⑭ ⑮
+⑯ ⑰ ⑱ ⑲ ⑳ Ⅰ Ⅱ Ⅲ Ⅳ Ⅴ Ⅵ Ⅶ Ⅷ Ⅸ Ⅹ   
+㍉ ㌔ ㌢ ㍍ ㌘ ㌧ ㌃ ㌶ ㍑ ㍗ ㌍ ㌦ ㌣ ㌫ ㍊ ㌻
+㎜ ㎝ ㎞ ㎎ ㎏ ㏄ ㎡                         ㍻
+〝 〟 № ㏍ ℡ ㊤ ㊥ ㊦ ㊧ ㊨ ㈱ ㈲ ㈹ ㍾ ㍽ ㍼
+≒ ≡ ∫ ∮ ∑ √ ⊥ ∠ ∟ ⊿ ∵ ∩ ∪      
+   亜 唖 娃 阿 哀 愛 挨 姶 逢 葵 茜 穐 悪 握 渥
+旭 葦 芦 鯵 梓 圧 斡 扱 宛 姐 虻 飴 絢 綾 鮎 或
+粟 袷 安 庵 按 暗 案 闇 鞍 杏 以 伊 位 依 偉 囲
+夷 委 威 尉 惟 意 慰 易 椅 為 畏 異 移 維 緯 胃
+萎 衣 謂 違 遺 医 井 亥 域 育 郁 磯 一 壱 溢 逸
+稲 茨 芋 鰯 允 印 咽 員 因 姻 引 飲 淫 胤 蔭
+   院 陰 隠 韻 吋 右 宇 烏 羽 迂 雨 卯 鵜 窺 丑
+碓 臼 渦 嘘 唄 欝 蔚 鰻 姥 厩 浦 瓜 閏 噂 云 運
+雲 荏 餌 叡 営 嬰 影 映 曳 栄 永 泳 洩 瑛 盈 穎
+頴 英 衛 詠 鋭 液 疫 益 駅 悦 謁 越 閲 榎 厭 円
+園 堰 奄 宴 延 怨 掩 援 沿 演 炎 焔 煙 燕 猿 縁
+艶 苑 薗 遠 鉛 鴛 塩 於 汚 甥 凹 央 奥 往 応
+   押 旺 横 欧 殴 王 翁 襖 鴬 鴎 黄 岡 沖 荻 億
+屋 憶 臆 桶 牡 乙 俺 卸 恩 温 穏 音 下 化 仮 何
+伽 価 佳 加 可 嘉 夏 嫁 家 寡 科 暇 果 架 歌 河
+火 珂 禍 禾 稼 箇 花 苛 茄 荷 華 菓 蝦 課 嘩 貨
+迦 過 霞 蚊 俄 峨 我 牙 画 臥 芽 蛾 賀 雅 餓 駕
+介 会 解 回 塊 壊 廻 快 怪 悔 恢 懐 戒 拐 改
+   魁 晦 械 海 灰 界 皆 絵 芥 蟹 開 階 貝 凱 劾
+外 咳 害 崖 慨 概 涯 碍 蓋 街 該 鎧 骸 浬 馨 蛙
+垣 柿 蛎 鈎 劃 嚇 各 廓 拡 撹 格 核 殻 獲 確 穫
+覚 角 赫 較 郭 閣 隔 革 学 岳 楽 額 顎 掛 笠 樫
+橿 梶 鰍 潟 割 喝 恰 括 活 渇 滑 葛 褐 轄 且 鰹
+叶 椛 樺 鞄 株 兜 竃 蒲 釜 鎌 噛 鴨 栢 茅 萱
+   粥 刈 苅 瓦 乾 侃 冠 寒 刊 勘 勧 巻 喚 堪 姦
+完 官 寛 干 幹 患 感 慣 憾 換 敢 柑 桓 棺 款 歓
+汗 漢 澗 潅 環 甘 監 看 竿 管 簡 緩 缶 翰 肝 艦
+莞 観 諌 貫 還 鑑 間 閑 関 陥 韓 館 舘 丸 含 岸
+巌 玩 癌 眼 岩 翫 贋 雁 頑 顔 願 企 伎 危 喜 器
+基 奇 嬉 寄 岐 希 幾 忌 揮 机 旗 既 期 棋 棄
+   機 帰 毅 気 汽 畿 祈 季 稀 紀 徽 規 記 貴 起
+軌 輝 飢 騎 鬼 亀 偽 儀 妓 宜 戯 技 擬 欺 犠 疑
+祇 義 蟻 誼 議 掬 菊 鞠 吉 吃 喫 桔 橘 詰 砧 杵
+黍 却 客 脚 虐 逆 丘 久 仇 休 及 吸 宮 弓 急 救
+朽 求 汲 泣 灸 球 究 窮 笈 級 糾 給 旧 牛 去 居
+巨 拒 拠 挙 渠 虚 許 距 鋸 漁 禦 魚 亨 享 京
+   供 侠 僑 兇 競 共 凶 協 匡 卿 叫 喬 境 峡 強
+彊 怯 恐 恭 挟 教 橋 況 狂 狭 矯 胸 脅 興 蕎 郷
+鏡 響 饗 驚 仰 凝 尭 暁 業 局 曲 極 玉 桐 粁 僅
+勤 均 巾 錦 斤 欣 欽 琴 禁 禽 筋 緊 芹 菌 衿 襟
+謹 近 金 吟 銀 九 倶 句 区 狗 玖 矩 苦 躯 駆 駈
+駒 具 愚 虞 喰 空 偶 寓 遇 隅 串 櫛 釧 屑 屈
+   掘 窟 沓 靴 轡 窪 熊 隈 粂 栗 繰 桑 鍬 勲 君
+薫 訓 群 軍 郡 卦 袈 祁 係 傾 刑 兄 啓 圭 珪 型
+契 形 径 恵 慶 慧 憩 掲 携 敬 景 桂 渓 畦 稽 系
+経 継 繋 罫 茎 荊 蛍 計 詣 警 軽 頚 鶏 芸 迎 鯨
+劇 戟 撃 激 隙 桁 傑 欠 決 潔 穴 結 血 訣 月 件
+倹 倦 健 兼 券 剣 喧 圏 堅 嫌 建 憲 懸 拳 捲
+   検 権 牽 犬 献 研 硯 絹 県 肩 見 謙 賢 軒 遣
+鍵 険 顕 験 鹸 元 原 厳 幻 弦 減 源 玄 現 絃 舷
+言 諺 限 乎 個 古 呼 固 姑 孤 己 庫 弧 戸 故 枯
+湖 狐 糊 袴 股 胡 菰 虎 誇 跨 鈷 雇 顧 鼓 五 互
+伍 午 呉 吾 娯 後 御 悟 梧 檎 瑚 碁 語 誤 護 醐
+乞 鯉 交 佼 侯 候 倖 光 公 功 効 勾 厚 口 向
+   后 喉 坑 垢 好 孔 孝 宏 工 巧 巷 幸 広 庚 康
+弘 恒 慌 抗 拘 控 攻 昂 晃 更 杭 校 梗 構 江 洪
+浩 港 溝 甲 皇 硬 稿 糠 紅 紘 絞 綱 耕 考 肯 肱
+腔 膏 航 荒 行 衡 講 貢 購 郊 酵 鉱 砿 鋼 閤 降
+項 香 高 鴻 剛 劫 号 合 壕 拷 濠 豪 轟 麹 克 刻
+告 国 穀 酷 鵠 黒 獄 漉 腰 甑 忽 惚 骨 狛 込
+   此 頃 今 困 坤 墾 婚 恨 懇 昏 昆 根 梱 混 痕
+紺 艮 魂 些 佐 叉 唆 嵯 左 差 査 沙 瑳 砂 詐 鎖
+裟 坐 座 挫 債 催 再 最 哉 塞 妻 宰 彩 才 採 栽
+歳 済 災 采 犀 砕 砦 祭 斎 細 菜 裁 載 際 剤 在
+材 罪 財 冴 坂 阪 堺 榊 肴 咲 崎 埼 碕 鷺 作 削
+咋 搾 昨 朔 柵 窄 策 索 錯 桜 鮭 笹 匙 冊 刷
+   察 拶 撮 擦 札 殺 薩 雑 皐 鯖 捌 錆 鮫 皿 晒
+三 傘 参 山 惨 撒 散 桟 燦 珊 産 算 纂 蚕 讃 賛
+酸 餐 斬 暫 残 仕 仔 伺 使 刺 司 史 嗣 四 士 始
+姉 姿 子 屍 市 師 志 思 指 支 孜 斯 施 旨 枝 止
+死 氏 獅 祉 私 糸 紙 紫 肢 脂 至 視 詞 詩 試 誌
+諮 資 賜 雌 飼 歯 事 似 侍 児 字 寺 慈 持 時
+   次 滋 治 爾 璽 痔 磁 示 而 耳 自 蒔 辞 汐 鹿
+式 識 鴫 竺 軸 宍 雫 七 叱 執 失 嫉 室 悉 湿 漆
+疾 質 実 蔀 篠 偲 柴 芝 屡 蕊 縞 舎 写 射 捨 赦
+斜 煮 社 紗 者 謝 車 遮 蛇 邪 借 勺 尺 杓 灼 爵
+酌 釈 錫 若 寂 弱 惹 主 取 守 手 朱 殊 狩 珠 種
+腫 趣 酒 首 儒 受 呪 寿 授 樹 綬 需 囚 収 周
+   宗 就 州 修 愁 拾 洲 秀 秋 終 繍 習 臭 舟 蒐
+衆 襲 讐 蹴 輯 週 酋 酬 集 醜 什 住 充 十 従 戎
+柔 汁 渋 獣 縦 重 銃 叔 夙 宿 淑 祝 縮 粛 塾 熟
+出 術 述 俊 峻 春 瞬 竣 舜 駿 准 循 旬 楯 殉 淳
+準 潤 盾 純 巡 遵 醇 順 処 初 所 暑 曙 渚 庶 緒
+署 書 薯 藷 諸 助 叙 女 序 徐 恕 鋤 除 傷 償
+   勝 匠 升 召 哨 商 唱 嘗 奨 妾 娼 宵 将 小 少
+尚 庄 床 廠 彰 承 抄 招 掌 捷 昇 昌 昭 晶 松 梢
+樟 樵 沼 消 渉 湘 焼 焦 照 症 省 硝 礁 祥 称 章
+笑 粧 紹 肖 菖 蒋 蕉 衝 裳 訟 証 詔 詳 象 賞 醤
+鉦 鍾 鐘 障 鞘 上 丈 丞 乗 冗 剰 城 場 壌 嬢 常
+情 擾 条 杖 浄 状 畳 穣 蒸 譲 醸 錠 嘱 埴 飾
+   拭 植 殖 燭 織 職 色 触 食 蝕 辱 尻 伸 信 侵
+唇 娠 寝 審 心 慎 振 新 晋 森 榛 浸 深 申 疹 真
+神 秦 紳 臣 芯 薪 親 診 身 辛 進 針 震 人 仁 刃
+塵 壬 尋 甚 尽 腎 訊 迅 陣 靭 笥 諏 須 酢 図 厨
+逗 吹 垂 帥 推 水 炊 睡 粋 翠 衰 遂 酔 錐 錘 随
+瑞 髄 崇 嵩 数 枢 趨 雛 据 杉 椙 菅 頗 雀 裾
+   澄 摺 寸 世 瀬 畝 是 凄 制 勢 姓 征 性 成 政
+整 星 晴 棲 栖 正 清 牲 生 盛 精 聖 声 製 西 誠
+誓 請 逝 醒 青 静 斉 税 脆 隻 席 惜 戚 斥 昔 析
+石 積 籍 績 脊 責 赤 跡 蹟 碩 切 拙 接 摂 折 設
+窃 節 説 雪 絶 舌 蝉 仙 先 千 占 宣 専 尖 川 戦
+扇 撰 栓 栴 泉 浅 洗 染 潜 煎 煽 旋 穿 箭 線
+   繊 羨 腺 舛 船 薦 詮 賎 践 選 遷 銭 銑 閃 鮮
+前 善 漸 然 全 禅 繕 膳 糎 噌 塑 岨 措 曾 曽 楚
+狙 疏 疎 礎 祖 租 粗 素 組 蘇 訴 阻 遡 鼠 僧 創
+双 叢 倉 喪 壮 奏 爽 宋 層 匝 惣 想 捜 掃 挿 掻
+操 早 曹 巣 槍 槽 漕 燥 争 痩 相 窓 糟 総 綜 聡
+草 荘 葬 蒼 藻 装 走 送 遭 鎗 霜 騒 像 増 憎
+   臓 蔵 贈 造 促 側 則 即 息 捉 束 測 足 速 俗
+属 賊 族 続 卒 袖 其 揃 存 孫 尊 損 村 遜 他 多
+太 汰 詑 唾 堕 妥 惰 打 柁 舵 楕 陀 駄 騨 体 堆
+対 耐 岱 帯 待 怠 態 戴 替 泰 滞 胎 腿 苔 袋 貸
+退 逮 隊 黛 鯛 代 台 大 第 醍 題 鷹 滝 瀧 卓 啄
+宅 托 択 拓 沢 濯 琢 託 鐸 濁 諾 茸 凧 蛸 只
+   叩 但 達 辰 奪 脱 巽 竪 辿 棚 谷 狸 鱈 樽 誰
+丹 単 嘆 坦 担 探 旦 歎 淡 湛 炭 短 端 箪 綻 耽
+胆 蛋 誕 鍛 団 壇 弾 断 暖 檀 段 男 談 値 知 地
+弛 恥 智 池 痴 稚 置 致 蜘 遅 馳 築 畜 竹 筑 蓄
+逐 秩 窒 茶 嫡 着 中 仲 宙 忠 抽 昼 柱 注 虫 衷
+註 酎 鋳 駐 樗 瀦 猪 苧 著 貯 丁 兆 凋 喋 寵
+   帖 帳 庁 弔 張 彫 徴 懲 挑 暢 朝 潮 牒 町 眺
+聴 脹 腸 蝶 調 諜 超 跳 銚 長 頂 鳥 勅 捗 直 朕
+沈 珍 賃 鎮 陳 津 墜 椎 槌 追 鎚 痛 通 塚 栂 掴
+槻 佃 漬 柘 辻 蔦 綴 鍔 椿 潰 坪 壷 嬬 紬 爪 吊
+釣 鶴 亭 低 停 偵 剃 貞 呈 堤 定 帝 底 庭 廷 弟
+悌 抵 挺 提 梯 汀 碇 禎 程 締 艇 訂 諦 蹄 逓
+   邸 鄭 釘 鼎 泥 摘 擢 敵 滴 的 笛 適 鏑 溺 哲
+徹 撤 轍 迭 鉄 典 填 天 展 店 添 纏 甜 貼 転 顛
+点 伝 殿 澱 田 電 兎 吐 堵 塗 妬 屠 徒 斗 杜 渡
+登 菟 賭 途 都 鍍 砥 砺 努 度 土 奴 怒 倒 党 冬
+凍 刀 唐 塔 塘 套 宕 島 嶋 悼 投 搭 東 桃 梼 棟
+盗 淘 湯 涛 灯 燈 当 痘 祷 等 答 筒 糖 統 到
+   董 蕩 藤 討 謄 豆 踏 逃 透 鐙 陶 頭 騰 闘 働
+動 同 堂 導 憧 撞 洞 瞳 童 胴 萄 道 銅 峠 鴇 匿
+得 徳 涜 特 督 禿 篤 毒 独 読 栃 橡 凸 突 椴 届
+鳶 苫 寅 酉 瀞 噸 屯 惇 敦 沌 豚 遁 頓 呑 曇 鈍
+奈 那 内 乍 凪 薙 謎 灘 捺 鍋 楢 馴 縄 畷 南 楠
+軟 難 汝 二 尼 弐 迩 匂 賑 肉 虹 廿 日 乳 入
+   如 尿 韮 任 妊 忍 認 濡 禰 祢 寧 葱 猫 熱 年
+念 捻 撚 燃 粘 乃 廼 之 埜 嚢 悩 濃 納 能 脳 膿
+農 覗 蚤 巴 把 播 覇 杷 波 派 琶 破 婆 罵 芭 馬
+俳 廃 拝 排 敗 杯 盃 牌 背 肺 輩 配 倍 培 媒 梅
+楳 煤 狽 買 売 賠 陪 這 蝿 秤 矧 萩 伯 剥 博 拍
+柏 泊 白 箔 粕 舶 薄 迫 曝 漠 爆 縛 莫 駁 麦
+   函 箱 硲 箸 肇 筈 櫨 幡 肌 畑 畠 八 鉢 溌 発
+醗 髪 伐 罰 抜 筏 閥 鳩 噺 塙 蛤 隼 伴 判 半 反
+叛 帆 搬 斑 板 氾 汎 版 犯 班 畔 繁 般 藩 販 範
+釆 煩 頒 飯 挽 晩 番 盤 磐 蕃 蛮 匪 卑 否 妃 庇
+彼 悲 扉 批 披 斐 比 泌 疲 皮 碑 秘 緋 罷 肥 被
+誹 費 避 非 飛 樋 簸 備 尾 微 枇 毘 琵 眉 美
+   鼻 柊 稗 匹 疋 髭 彦 膝 菱 肘 弼 必 畢 筆 逼
+桧 姫 媛 紐 百 謬 俵 彪 標 氷 漂 瓢 票 表 評 豹
+廟 描 病 秒 苗 錨 鋲 蒜 蛭 鰭 品 彬 斌 浜 瀕 貧
+賓 頻 敏 瓶 不 付 埠 夫 婦 富 冨 布 府 怖 扶 敷
+斧 普 浮 父 符 腐 膚 芙 譜 負 賦 赴 阜 附 侮 撫
+武 舞 葡 蕪 部 封 楓 風 葺 蕗 伏 副 復 幅 服
+   福 腹 複 覆 淵 弗 払 沸 仏 物 鮒 分 吻 噴 墳
+憤 扮 焚 奮 粉 糞 紛 雰 文 聞 丙 併 兵 塀 幣 平
+弊 柄 並 蔽 閉 陛 米 頁 僻 壁 癖 碧 別 瞥 蔑 箆
+偏 変 片 篇 編 辺 返 遍 便 勉 娩 弁 鞭 保 舗 鋪
+圃 捕 歩 甫 補 輔 穂 募 墓 慕 戊 暮 母 簿 菩 倣
+俸 包 呆 報 奉 宝 峰 峯 崩 庖 抱 捧 放 方 朋
+   法 泡 烹 砲 縫 胞 芳 萌 蓬 蜂 褒 訪 豊 邦 鋒
+飽 鳳 鵬 乏 亡 傍 剖 坊 妨 帽 忘 忙 房 暴 望 某
+棒 冒 紡 肪 膨 謀 貌 貿 鉾 防 吠 頬 北 僕 卜 墨
+撲 朴 牧 睦 穆 釦 勃 没 殆 堀 幌 奔 本 翻 凡 盆
+摩 磨 魔 麻 埋 妹 昧 枚 毎 哩 槙 幕 膜 枕 鮪 柾
+鱒 桝 亦 俣 又 抹 末 沫 迄 侭 繭 麿 万 慢 満
+   漫 蔓 味 未 魅 巳 箕 岬 密 蜜 湊 蓑 稔 脈 妙
+粍 民 眠 務 夢 無 牟 矛 霧 鵡 椋 婿 娘 冥 名 命
+明 盟 迷 銘 鳴 姪 牝 滅 免 棉 綿 緬 面 麺 摸 模
+茂 妄 孟 毛 猛 盲 網 耗 蒙 儲 木 黙 目 杢 勿 餅
+尤 戻 籾 貰 問 悶 紋 門 匁 也 冶 夜 爺 耶 野 弥
+矢 厄 役 約 薬 訳 躍 靖 柳 薮 鑓 愉 愈 油 癒
+   諭 輸 唯 佑 優 勇 友 宥 幽 悠 憂 揖 有 柚 湧
+涌 猶 猷 由 祐 裕 誘 遊 邑 郵 雄 融 夕 予 余 与
+誉 輿 預 傭 幼 妖 容 庸 揚 揺 擁 曜 楊 様 洋 溶
+熔 用 窯 羊 耀 葉 蓉 要 謡 踊 遥 陽 養 慾 抑 欲
+沃 浴 翌 翼 淀 羅 螺 裸 来 莱 頼 雷 洛 絡 落 酪
+乱 卵 嵐 欄 濫 藍 蘭 覧 利 吏 履 李 梨 理 璃
+   痢 裏 裡 里 離 陸 律 率 立 葎 掠 略 劉 流 溜
+琉 留 硫 粒 隆 竜 龍 侶 慮 旅 虜 了 亮 僚 両 凌
+寮 料 梁 涼 猟 療 瞭 稜 糧 良 諒 遼 量 陵 領 力
+緑 倫 厘 林 淋 燐 琳 臨 輪 隣 鱗 麟 瑠 塁 涙 累
+類 令 伶 例 冷 励 嶺 怜 玲 礼 苓 鈴 隷 零 霊 麗
+齢 暦 歴 列 劣 烈 裂 廉 恋 憐 漣 煉 簾 練 聯
+   蓮 連 錬 呂 魯 櫓 炉 賂 路 露 労 婁 廊 弄 朗
+楼 榔 浪 漏 牢 狼 篭 老 聾 蝋 郎 六 麓 禄 肋 録
+論 倭 和 話 歪 賄 脇 惑 枠 鷲 亙 亘 鰐 詫 藁 蕨
+椀 湾 碗 腕
+   弌 丐 丕 个 丱 丶 丼 丿 乂 乖 乘 亂 亅 豫 亊
+舒 弍 于 亞 亟 亠 亢 亰 亳 亶 从 仍 仄 仆 仂 仗
+仞 仭 仟 价 伉 佚 估 佛 佝 佗 佇 佶 侈 侏 侘 佻
+佩 佰 侑 佯 來 侖 儘 俔 俟 俎 俘 俛 俑 俚 俐 俤
+俥 倚 倨 倔 倪 倥 倅 伜 俶 倡 倩 倬 俾 俯 們 倆
+偃 假 會 偕 偐 偈 做 偖 偬 偸 傀 傚 傅 傴 傲
+   僉 僊 傳 僂 僖 僞 僥 僭 僣 僮 價 僵 儉 儁 儂
+儖 儕 儔 儚 儡 儺 儷 儼 儻 儿 兀 兒 兌 兔 兢 竸
+兩 兪 兮 冀 冂 囘 册 冉 冏 冑 冓 冕 冖 冤 冦 冢
+冩 冪 冫 决 冱 冲 冰 况 冽 凅 凉 凛 几 處 凩 凭
+凰 凵 凾 刄 刋 刔 刎 刧 刪 刮 刳 刹 剏 剄 剋 剌
+剞 剔 剪 剴 剩 剳 剿 剽 劍 劔 劒 剱 劈 劑 辨
+   辧 劬 劭 劼 劵 勁 勍 勗 勞 勣 勦 飭 勠 勳 勵
+勸 勹 匆 匈 甸 匍 匐 匏 匕 匚 匣 匯 匱 匳 匸 區
+卆 卅 丗 卉 卍 凖 卞 卩 卮 夘 卻 卷 厂 厖 厠 厦
+厥 厮 厰 厶 參 簒 雙 叟 曼 燮 叮 叨 叭 叺 吁 吽
+呀 听 吭 吼 吮 吶 吩 吝 呎 咏 呵 咎 呟 呱 呷 呰
+咒 呻 咀 呶 咄 咐 咆 哇 咢 咸 咥 咬 哄 哈 咨
+   咫 哂 咤 咾 咼 哘 哥 哦 唏 唔 哽 哮 哭 哺 哢
+唹 啀 啣 啌 售 啜 啅 啖 啗 唸 唳 啝 喙 喀 咯 喊
+喟 啻 啾 喘 喞 單 啼 喃 喩 喇 喨 嗚 嗅 嗟 嗄 嗜
+嗤 嗔 嘔 嗷 嘖 嗾 嗽 嘛 嗹 噎 噐 營 嘴 嘶 嘲 嘸
+噫 噤 嘯 噬 噪 嚆 嚀 嚊 嚠 嚔 嚏 嚥 嚮 嚶 嚴 囂
+嚼 囁 囃 囀 囈 囎 囑 囓 囗 囮 囹 圀 囿 圄 圉
+   圈 國 圍 圓 團 圖 嗇 圜 圦 圷 圸 坎 圻 址 坏
+坩 埀 垈 坡 坿 垉 垓 垠 垳 垤 垪 垰 埃 埆 埔 埒
+埓 堊 埖 埣 堋 堙 堝 塲 堡 塢 塋 塰 毀 塒 堽 塹
+墅 墹 墟 墫 墺 壞 墻 墸 墮 壅 壓 壑 壗 壙 壘 壥
+壜 壤 壟 壯 壺 壹 壻 壼 壽 夂 夊 夐 夛 梦 夥 夬
+夭 夲 夸 夾 竒 奕 奐 奎 奚 奘 奢 奠 奧 奬 奩
+   奸 妁 妝 佞 侫 妣 妲 姆 姨 姜 妍 姙 姚 娥 娟
+娑 娜 娉 娚 婀 婬 婉 娵 娶 婢 婪 媚 媼 媾 嫋 嫂
+媽 嫣 嫗 嫦 嫩 嫖 嫺 嫻 嬌 嬋 嬖 嬲 嫐 嬪 嬶 嬾
+孃 孅 孀 孑 孕 孚 孛 孥 孩 孰 孳 孵 學 斈 孺 宀
+它 宦 宸 寃 寇 寉 寔 寐 寤 實 寢 寞 寥 寫 寰 寶
+寳 尅 將 專 對 尓 尠 尢 尨 尸 尹 屁 屆 屎 屓
+   屐 屏 孱 屬 屮 乢 屶 屹 岌 岑 岔 妛 岫 岻 岶
+岼 岷 峅 岾 峇 峙 峩 峽 峺 峭 嶌 峪 崋 崕 崗 嵜
+崟 崛 崑 崔 崢 崚 崙 崘 嵌 嵒 嵎 嵋 嵬 嵳 嵶 嶇
+嶄 嶂 嶢 嶝 嶬 嶮 嶽 嶐 嶷 嶼 巉 巍 巓 巒 巖 巛
+巫 已 巵 帋 帚 帙 帑 帛 帶 帷 幄 幃 幀 幎 幗 幔
+幟 幢 幤 幇 幵 并 幺 麼 广 庠 廁 廂 廈 廐 廏
+   廖 廣 廝 廚 廛 廢 廡 廨 廩 廬 廱 廳 廰 廴 廸
+廾 弃 弉 彝 彜 弋 弑 弖 弩 弭 弸 彁 彈 彌 彎 弯
+彑 彖 彗 彙 彡 彭 彳 彷 徃 徂 彿 徊 很 徑 徇 從
+徙 徘 徠 徨 徭 徼 忖 忻 忤 忸 忱 忝 悳 忿 怡 恠
+怙 怐 怩 怎 怱 怛 怕 怫 怦 怏 怺 恚 恁 恪 恷 恟
+恊 恆 恍 恣 恃 恤 恂 恬 恫 恙 悁 悍 惧 悃 悚
+   悄 悛 悖 悗 悒 悧 悋 惡 悸 惠 惓 悴 忰 悽 惆
+悵 惘 慍 愕 愆 惶 惷 愀 惴 惺 愃 愡 惻 惱 愍 愎
+慇 愾 愨 愧 慊 愿 愼 愬 愴 愽 慂 慄 慳 慷 慘 慙
+慚 慫 慴 慯 慥 慱 慟 慝 慓 慵 憙 憖 憇 憬 憔 憚
+憊 憑 憫 憮 懌 懊 應 懷 懈 懃 懆 憺 懋 罹 懍 懦
+懣 懶 懺 懴 懿 懽 懼 懾 戀 戈 戉 戍 戌 戔 戛
+   戞 戡 截 戮 戰 戲 戳 扁 扎 扞 扣 扛 扠 扨 扼
+抂 抉 找 抒 抓 抖 拔 抃 抔 拗 拑 抻 拏 拿 拆 擔
+拈 拜 拌 拊 拂 拇 抛 拉 挌 拮 拱 挧 挂 挈 拯 拵
+捐 挾 捍 搜 捏 掖 掎 掀 掫 捶 掣 掏 掉 掟 掵 捫
+捩 掾 揩 揀 揆 揣 揉 插 揶 揄 搖 搴 搆 搓 搦 搶
+攝 搗 搨 搏 摧 摯 摶 摎 攪 撕 撓 撥 撩 撈 撼
+   據 擒 擅 擇 撻 擘 擂 擱 擧 舉 擠 擡 抬 擣 擯
+攬 擶 擴 擲 擺 攀 擽 攘 攜 攅 攤 攣 攫 攴 攵 攷
+收 攸 畋 效 敖 敕 敍 敘 敞 敝 敲 數 斂 斃 變 斛
+斟 斫 斷 旃 旆 旁 旄 旌 旒 旛 旙 无 旡 旱 杲 昊
+昃 旻 杳 昵 昶 昴 昜 晏 晄 晉 晁 晞 晝 晤 晧 晨
+晟 晢 晰 暃 暈 暎 暉 暄 暘 暝 曁 暹 曉 暾 暼
+   曄 暸 曖 曚 曠 昿 曦 曩 曰 曵 曷 朏 朖 朞 朦
+朧 霸 朮 朿 朶 杁 朸 朷 杆 杞 杠 杙 杣 杤 枉 杰
+枩 杼 杪 枌 枋 枦 枡 枅 枷 柯 枴 柬 枳 柩 枸 柤
+柞 柝 柢 柮 枹 柎 柆 柧 檜 栞 框 栩 桀 桍 栲 桎
+梳 栫 桙 档 桷 桿 梟 梏 梭 梔 條 梛 梃 檮 梹 桴
+梵 梠 梺 椏 梍 桾 椁 棊 椈 棘 椢 椦 棡 椌 棍
+   棔 棧 棕 椶 椒 椄 棗 棣 椥 棹 棠 棯 椨 椪 椚
+椣 椡 棆 楹 楷 楜 楸 楫 楔 楾 楮 椹 楴 椽 楙 椰
+楡 楞 楝 榁 楪 榲 榮 槐 榿 槁 槓 榾 槎 寨 槊 槝
+榻 槃 榧 樮 榑 榠 榜 榕 榴 槞 槨 樂 樛 槿 權 槹
+槲 槧 樅 榱 樞 槭 樔 槫 樊 樒 櫁 樣 樓 橄 樌 橲
+樶 橸 橇 橢 橙 橦 橈 樸 樢 檐 檍 檠 檄 檢 檣
+   檗 蘗 檻 櫃 櫂 檸 檳 檬 櫞 櫑 櫟 檪 櫚 櫪 櫻
+欅 蘖 櫺 欒 欖 鬱 欟 欸 欷 盜 欹 飮 歇 歃 歉 歐
+歙 歔 歛 歟 歡 歸 歹 歿 殀 殄 殃 殍 殘 殕 殞 殤
+殪 殫 殯 殲 殱 殳 殷 殼 毆 毋 毓 毟 毬 毫 毳 毯
+麾 氈 氓 气 氛 氤 氣 汞 汕 汢 汪 沂 沍 沚 沁 沛
+汾 汨 汳 沒 沐 泄 泱 泓 沽 泗 泅 泝 沮 沱 沾
+   沺 泛 泯 泙 泪 洟 衍 洶 洫 洽 洸 洙 洵 洳 洒
+洌 浣 涓 浤 浚 浹 浙 涎 涕 濤 涅 淹 渕 渊 涵 淇
+淦 涸 淆 淬 淞 淌 淨 淒 淅 淺 淙 淤 淕 淪 淮 渭
+湮 渮 渙 湲 湟 渾 渣 湫 渫 湶 湍 渟 湃 渺 湎 渤
+滿 渝 游 溂 溪 溘 滉 溷 滓 溽 溯 滄 溲 滔 滕 溏
+溥 滂 溟 潁 漑 灌 滬 滸 滾 漿 滲 漱 滯 漲 滌
+   漾 漓 滷 澆 潺 潸 澁 澀 潯 潛 濳 潭 澂 潼 潘
+澎 澑 濂 潦 澳 澣 澡 澤 澹 濆 澪 濟 濕 濬 濔 濘
+濱 濮 濛 瀉 瀋 濺 瀑 瀁 瀏 濾 瀛 瀚 潴 瀝 瀘 瀟
+瀰 瀾 瀲 灑 灣 炙 炒 炯 烱 炬 炸 炳 炮 烟 烋 烝
+烙 焉 烽 焜 焙 煥 煕 熈 煦 煢 煌 煖 煬 熏 燻 熄
+熕 熨 熬 燗 熹 熾 燒 燉 燔 燎 燠 燬 燧 燵 燼
+   燹 燿 爍 爐 爛 爨 爭 爬 爰 爲 爻 爼 爿 牀 牆
+牋 牘 牴 牾 犂 犁 犇 犒 犖 犢 犧 犹 犲 狃 狆 狄
+狎 狒 狢 狠 狡 狹 狷 倏 猗 猊 猜 猖 猝 猴 猯 猩
+猥 猾 獎 獏 默 獗 獪 獨 獰 獸 獵 獻 獺 珈 玳 珎
+玻 珀 珥 珮 珞 璢 琅 瑯 琥 珸 琲 琺 瑕 琿 瑟 瑙
+瑁 瑜 瑩 瑰 瑣 瑪 瑶 瑾 璋 璞 璧 瓊 瓏 瓔 珱
+   瓠 瓣 瓧 瓩 瓮 瓲 瓰 瓱 瓸 瓷 甄 甃 甅 甌 甎
+甍 甕 甓 甞 甦 甬 甼 畄 畍 畊 畉 畛 畆 畚 畩 畤
+畧 畫 畭 畸 當 疆 疇 畴 疊 疉 疂 疔 疚 疝 疥 疣
+痂 疳 痃 疵 疽 疸 疼 疱 痍 痊 痒 痙 痣 痞 痾 痿
+痼 瘁 痰 痺 痲 痳 瘋 瘍 瘉 瘟 瘧 瘠 瘡 瘢 瘤 瘴
+瘰 瘻 癇 癈 癆 癜 癘 癡 癢 癨 癩 癪 癧 癬 癰
+   癲 癶 癸 發 皀 皃 皈 皋 皎 皖 皓 皙 皚 皰 皴
+皸 皹 皺 盂 盍 盖 盒 盞 盡 盥 盧 盪 蘯 盻 眈 眇
+眄 眩 眤 眞 眥 眦 眛 眷 眸 睇 睚 睨 睫 睛 睥 睿
+睾 睹 瞎 瞋 瞑 瞠 瞞 瞰 瞶 瞹 瞿 瞼 瞽 瞻 矇 矍
+矗 矚 矜 矣 矮 矼 砌 砒 礦 砠 礪 硅 碎 硴 碆 硼
+碚 碌 碣 碵 碪 碯 磑 磆 磋 磔 碾 碼 磅 磊 磬
+   磧 磚 磽 磴 礇 礒 礑 礙 礬 礫 祀 祠 祗 祟 祚
+祕 祓 祺 祿 禊 禝 禧 齋 禪 禮 禳 禹 禺 秉 秕 秧
+秬 秡 秣 稈 稍 稘 稙 稠 稟 禀 稱 稻 稾 稷 穃 穗
+穉 穡 穢 穩 龝 穰 穹 穽 窈 窗 窕 窘 窖 窩 竈 窰
+窶 竅 竄 窿 邃 竇 竊 竍 竏 竕 竓 站 竚 竝 竡 竢
+竦 竭 竰 笂 笏 笊 笆 笳 笘 笙 笞 笵 笨 笶 筐
+   筺 笄 筍 笋 筌 筅 筵 筥 筴 筧 筰 筱 筬 筮 箝
+箘 箟 箍 箜 箚 箋 箒 箏 筝 箙 篋 篁 篌 篏 箴 篆
+篝 篩 簑 簔 篦 篥 籠 簀 簇 簓 篳 篷 簗 簍 篶 簣
+簧 簪 簟 簷 簫 簽 籌 籃 籔 籏 籀 籐 籘 籟 籤 籖
+籥 籬 籵 粃 粐 粤 粭 粢 粫 粡 粨 粳 粲 粱 粮 粹
+粽 糀 糅 糂 糘 糒 糜 糢 鬻 糯 糲 糴 糶 糺 紆
+   紂 紜 紕 紊 絅 絋 紮 紲 紿 紵 絆 絳 絖 絎 絲
+絨 絮 絏 絣 經 綉 絛 綏 絽 綛 綺 綮 綣 綵 緇 綽
+綫 總 綢 綯 緜 綸 綟 綰 緘 緝 緤 緞 緻 緲 緡 縅
+縊 縣 縡 縒 縱 縟 縉 縋 縢 繆 繦 縻 縵 縹 繃 縷
+縲 縺 繧 繝 繖 繞 繙 繚 繹 繪 繩 繼 繻 纃 緕 繽
+辮 繿 纈 纉 續 纒 纐 纓 纔 纖 纎 纛 纜 缸 缺
+   罅 罌 罍 罎 罐 网 罕 罔 罘 罟 罠 罨 罩 罧 罸
+羂 羆 羃 羈 羇 羌 羔 羞 羝 羚 羣 羯 羲 羹 羮 羶
+羸 譱 翅 翆 翊 翕 翔 翡 翦 翩 翳 翹 飜 耆 耄 耋
+耒 耘 耙 耜 耡 耨 耿 耻 聊 聆 聒 聘 聚 聟 聢 聨
+聳 聲 聰 聶 聹 聽 聿 肄 肆 肅 肛 肓 肚 肭 冐 肬
+胛 胥 胙 胝 胄 胚 胖 脉 胯 胱 脛 脩 脣 脯 腋
+   隋 腆 脾 腓 腑 胼 腱 腮 腥 腦 腴 膃 膈 膊 膀
+膂 膠 膕 膤 膣 腟 膓 膩 膰 膵 膾 膸 膽 臀 臂 膺
+臉 臍 臑 臙 臘 臈 臚 臟 臠 臧 臺 臻 臾 舁 舂 舅
+與 舊 舍 舐 舖 舩 舫 舸 舳 艀 艙 艘 艝 艚 艟 艤
+艢 艨 艪 艫 舮 艱 艷 艸 艾 芍 芒 芫 芟 芻 芬 苡
+苣 苟 苒 苴 苳 苺 莓 范 苻 苹 苞 茆 苜 茉 苙
+   茵 茴 茖 茲 茱 荀 茹 荐 荅 茯 茫 茗 茘 莅 莚
+莪 莟 莢 莖 茣 莎 莇 莊 荼 莵 荳 荵 莠 莉 莨 菴
+萓 菫 菎 菽 萃 菘 萋 菁 菷 萇 菠 菲 萍 萢 萠 莽
+萸 蔆 菻 葭 萪 萼 蕚 蒄 葷 葫 蒭 葮 蒂 葩 葆 萬
+葯 葹 萵 蓊 葢 蒹 蒿 蒟 蓙 蓍 蒻 蓚 蓐 蓁 蓆 蓖
+蒡 蔡 蓿 蓴 蔗 蔘 蔬 蔟 蔕 蔔 蓼 蕀 蕣 蕘 蕈
+   蕁 蘂 蕋 蕕 薀 薤 薈 薑 薊 薨 蕭 薔 薛 藪 薇
+薜 蕷 蕾 薐 藉 薺 藏 薹 藐 藕 藝 藥 藜 藹 蘊 蘓
+蘋 藾 藺 蘆 蘢 蘚 蘰 蘿 虍 乕 虔 號 虧 虱 蚓 蚣
+蚩 蚪 蚋 蚌 蚶 蚯 蛄 蛆 蚰 蛉 蠣 蚫 蛔 蛞 蛩 蛬
+蛟 蛛 蛯 蜒 蜆 蜈 蜀 蜃 蛻 蜑 蜉 蜍 蛹 蜊 蜴 蜿
+蜷 蜻 蜥 蜩 蜚 蝠 蝟 蝸 蝌 蝎 蝴 蝗 蝨 蝮 蝙
+   蝓 蝣 蝪 蠅 螢 螟 螂 螯 蟋 螽 蟀 蟐 雖 螫 蟄
+螳 蟇 蟆 螻 蟯 蟲 蟠 蠏 蠍 蟾 蟶 蟷 蠎 蟒 蠑 蠖
+蠕 蠢 蠡 蠱 蠶 蠹 蠧 蠻 衄 衂 衒 衙 衞 衢 衫 袁
+衾 袞 衵 衽 袵 衲 袂 袗 袒 袮 袙 袢 袍 袤 袰 袿
+袱 裃 裄 裔 裘 裙 裝 裹 褂 裼 裴 裨 裲 褄 褌 褊
+褓 襃 褞 褥 褪 褫 襁 襄 褻 褶 褸 襌 褝 襠 襞
+   襦 襤 襭 襪 襯 襴 襷 襾 覃 覈 覊 覓 覘 覡 覩
+覦 覬 覯 覲 覺 覽 覿 觀 觚 觜 觝 觧 觴 觸 訃 訖
+訐 訌 訛 訝 訥 訶 詁 詛 詒 詆 詈 詼 詭 詬 詢 誅
+誂 誄 誨 誡 誑 誥 誦 誚 誣 諄 諍 諂 諚 諫 諳 諧
+諤 諱 謔 諠 諢 諷 諞 諛 謌 謇 謚 諡 謖 謐 謗 謠
+謳 鞫 謦 謫 謾 謨 譁 譌 譏 譎 證 譖 譛 譚 譫
+   譟 譬 譯 譴 譽 讀 讌 讎 讒 讓 讖 讙 讚 谺 豁
+谿 豈 豌 豎 豐 豕 豢 豬 豸 豺 貂 貉 貅 貊 貍 貎
+貔 豼 貘 戝 貭 貪 貽 貲 貳 貮 貶 賈 賁 賤 賣 賚
+賽 賺 賻 贄 贅 贊 贇 贏 贍 贐 齎 贓 賍 贔 贖 赧
+赭 赱 赳 趁 趙 跂 趾 趺 跏 跚 跖 跌 跛 跋 跪 跫
+跟 跣 跼 踈 踉 跿 踝 踞 踐 踟 蹂 踵 踰 踴 蹊
+   蹇 蹉 蹌 蹐 蹈 蹙 蹤 蹠 踪 蹣 蹕 蹶 蹲 蹼 躁
+躇 躅 躄 躋 躊 躓 躑 躔 躙 躪 躡 躬 躰 軆 躱 躾
+軅 軈 軋 軛 軣 軼 軻 軫 軾 輊 輅 輕 輒 輙 輓 輜
+輟 輛 輌 輦 輳 輻 輹 轅 轂 輾 轌 轉 轆 轎 轗 轜
+轢 轣 轤 辜 辟 辣 辭 辯 辷 迚 迥 迢 迪 迯 邇 迴
+逅 迹 迺 逑 逕 逡 逍 逞 逖 逋 逧 逶 逵 逹 迸
+   遏 遐 遑 遒 逎 遉 逾 遖 遘 遞 遨 遯 遶 隨 遲
+邂 遽 邁 邀 邊 邉 邏 邨 邯 邱 邵 郢 郤 扈 郛 鄂
+鄒 鄙 鄲 鄰 酊 酖 酘 酣 酥 酩 酳 酲 醋 醉 醂 醢
+醫 醯 醪 醵 醴 醺 釀 釁 釉 釋 釐 釖 釟 釡 釛 釼
+釵 釶 鈞 釿 鈔 鈬 鈕 鈑 鉞 鉗 鉅 鉉 鉤 鉈 銕 鈿
+鉋 鉐 銜 銖 銓 銛 鉚 鋏 銹 銷 鋩 錏 鋺 鍄 錮
+   錙 錢 錚 錣 錺 錵 錻 鍜 鍠 鍼 鍮 鍖 鎰 鎬 鎭
+鎔 鎹 鏖 鏗 鏨 鏥 鏘 鏃 鏝 鏐 鏈 鏤 鐚 鐔 鐓 鐃
+鐇 鐐 鐶 鐫 鐵 鐡 鐺 鑁 鑒 鑄 鑛 鑠 鑢 鑞 鑪 鈩
+鑰 鑵 鑷 鑽 鑚 鑼 鑾 钁 鑿 閂 閇 閊 閔 閖 閘 閙
+閠 閨 閧 閭 閼 閻 閹 閾 闊 濶 闃 闍 闌 闕 闔 闖
+關 闡 闥 闢 阡 阨 阮 阯 陂 陌 陏 陋 陷 陜 陞
+   陝 陟 陦 陲 陬 隍 隘 隕 隗 險 隧 隱 隲 隰 隴
+隶 隸 隹 雎 雋 雉 雍 襍 雜 霍 雕 雹 霄 霆 霈 霓
+霎 霑 霏 霖 霙 霤 霪 霰 霹 霽 霾 靄 靆 靈 靂 靉
+靜 靠 靤 靦 靨 勒 靫 靱 靹 鞅 靼 鞁 靺 鞆 鞋 鞏
+鞐 鞜 鞨 鞦 鞣 鞳 鞴 韃 韆 韈 韋 韜 韭 齏 韲 竟
+韶 韵 頏 頌 頸 頤 頡 頷 頽 顆 顏 顋 顫 顯 顰
+   顱 顴 顳 颪 颯 颱 颶 飄 飃 飆 飩 飫 餃 餉 餒
+餔 餘 餡 餝 餞 餤 餠 餬 餮 餽 餾 饂 饉 饅 饐 饋
+饑 饒 饌 饕 馗 馘 馥 馭 馮 馼 駟 駛 駝 駘 駑 駭
+駮 駱 駲 駻 駸 騁 騏 騅 駢 騙 騫 騷 驅 驂 驀 驃
+騾 驕 驍 驛 驗 驟 驢 驥 驤 驩 驫 驪 骭 骰 骼 髀
+髏 髑 髓 體 髞 髟 髢 髣 髦 髯 髫 髮 髴 髱 髷
+   髻 鬆 鬘 鬚 鬟 鬢 鬣 鬥 鬧 鬨 鬩 鬪 鬮 鬯 鬲
+魄 魃 魏 魍 魎 魑 魘 魴 鮓 鮃 鮑 鮖 鮗 鮟 鮠 鮨
+鮴 鯀 鯊 鮹 鯆 鯏 鯑 鯒 鯣 鯢 鯤 鯔 鯡 鰺 鯲 鯱
+鯰 鰕 鰔 鰉 鰓 鰌 鰆 鰈 鰒 鰊 鰄 鰮 鰛 鰥 鰤 鰡
+鰰 鱇 鰲 鱆 鰾 鱚 鱠 鱧 鱶 鱸 鳧 鳬 鳰 鴉 鴈 鳫
+鴃 鴆 鴪 鴦 鶯 鴣 鴟 鵄 鴕 鴒 鵁 鴿 鴾 鵆 鵈
+   鵝 鵞 鵤 鵑 鵐 鵙 鵲 鶉 鶇 鶫 鵯 鵺 鶚 鶤 鶩
+鶲 鷄 鷁 鶻 鶸 鶺 鷆 鷏 鷂 鷙 鷓 鷸 鷦 鷭 鷯 鷽
+鸚 鸛 鸞 鹵 鹹 鹽 麁 麈 麋 麌 麒 麕 麑 麝 麥 麩
+麸 麪 麭 靡 黌 黎 黏 黐 黔 黜 點 黝 黠 黥 黨 黯
+黴 黶 黷 黹 黻 黼 黽 鼇 鼈 皷 鼕 鼡 鼬 鼾 齊 齒
+齔 齣 齟 齠 齡 齦 齧 齬 齪 齷 齲 齶 龕 龜 龠
+   堯 槇 遙 瑤 凜 熙
+   纊 褜 鍈 銈 蓜 俉 炻 昱 棈 鋹 曻 彅 丨 仡 仼
+伀 伃 伹 佖 侒 侊 侚 侔 俍 偀 倢 俿 倞 偆 偰 偂
+傔 僴 僘 兊 兤 冝 冾 凬 刕 劜 劦 勀 勛 匀 匇 匤
+卲 厓 厲 叝 﨎 咜 咊 咩 哿 喆 坙 坥 垬 埈 埇 﨏
+塚 增 墲 夋 奓 奛 奝 奣 妤 妺 孖 寀 甯 寘 寬 尞
+岦 岺 峵 崧 嵓 﨑 嵂 嵭 嶸 嶹 巐 弡 弴 彧 德
+   忞 恝 悅 悊 惞 惕 愠 惲 愑 愷 愰 憘 戓 抦 揵
+摠 撝 擎 敎 昀 昕 昻 昉 昮 昞 昤 晥 晗 晙 晴 晳
+暙 暠 暲 暿 曺 朎 朗 杦 枻 桒 柀 栁 桄 棏 﨓 楨
+﨔 榘 槢 樰 橫 橆 橳 橾 櫢 櫤 毖 氿 汜 沆 汯 泚
+洄 涇 浯 涖 涬 淏 淸 淲 淼 渹 湜 渧 渼 溿 澈 澵
+濵 瀅 瀇 瀨 炅 炫 焏 焄 煜 煆 煇 凞 燁 燾 犱
+   犾 猤 猪 獷 玽 珉 珖 珣 珒 琇 珵 琦 琪 琩 琮
+瑢 璉 璟 甁 畯 皂 皜 皞 皛 皦 益 睆 劯 砡 硎 硤
+硺 礰 礼 神 祥 禔 福 禛 竑 竧 靖 竫 箞 精 絈 絜
+綷 綠 緖 繒 罇 羡 羽 茁 荢 荿 菇 菶 葈 蒴 蕓 蕙
+蕫 﨟 薰 蘒 﨡 蠇 裵 訒 訷 詹 誧 誾 諟 諸 諶 譓
+譿 賰 賴 贒 赶 﨣 軏 﨤 逸 遧 郞 都 鄕 鄧 釚
+   釗 釞 釭 釮 釤 釥 鈆 鈐 鈊 鈺 鉀 鈼 鉎 鉙 鉑
+鈹 鉧 銧 鉷 鉸 鋧 鋗 鋙 鋐 﨧 鋕 鋠 鋓 錥 錡 鋻
+﨨 錞 鋿 錝 錂 鍰 鍗 鎤 鏆 鏞 鏸 鐱 鑅 鑈 閒 隆
+﨩 隝 隯 霳 霻 靃 靍 靏 靑 靕 顗 顥 飯 飼 餧 館
+馞 驎 髙 髜 魵 魲 鮏 鮱 鮻 鰀 鵰 鵫 鶴 鸙 黑   
+   ⅰ ⅱ ⅲ ⅳ ⅴ ⅵ ⅶ ⅷ ⅸ ⅹ ￢ ￤ ＇ ＂
+                 
+               
+               
+               
+               
+              
+                 
+               
+               
+               
+               
+              
+                 
+               
+               
+               
+               
+              
+                 
+               
+               
+               
+               
+              
+                 
+               
+               
+               
+               
+              
+                 
+               
+               
+               
+               
+              
+                 
+               
+               
+               
+               
+              
+                 
+               
+               
+               
+               
+              
+                 
+               
+               
+               
+               
+              
+                 
+               
+               
+               
+               
+              
+                 
+               
+               
+               
+               
+              
+                 
+               
+               
+               
+               
+              
+                 
+               
+               
+               
+               
+              
+                 
+               
+               
+               
+               
+              
+                 
+               
+               
+               
+               
+              
+                 
+               
+               
+               
+               
+              
+                 
+               
+               
+               
+               
+              
+                 
+               
+               
+               
+               
+              
+                 
+               
+               
+               
+               
+              
+                 
+               
+               
+               
+               
+              
+
+Japanese (日本語)		こんにちは
+	JIS  -- 元気  開発
+	NEC特殊文字  -- ①②③
+	NEC選定IBM拡張文字 -- 内田百閒  髙島屋  草彅剛
+  ! " # $ % & ' ( ) * + , - . /
+0 1 2 3 4 5 6 7 8 9 : ; < = > ?
+@ A B C D E F G H I J K L M N O
+P Q R S T U V W X Y Z [ \ ] ^ _
+` a b c d e f g h i j k l m n o
+p q r s t u v w x y z { | } ~
   ｡ ｢ ｣ ､ ･ ｦ ｧ ｨ ｩ ｪ ｫ ｬ ｭ ｮ ｯ
 ｰ ｱ ｲ ｳ ｴ ｵ ｶ ｷ ｸ ｹ ｺ ｻ ｼ ｽ ｾ ｿ
 ﾀ ﾁ ﾂ ﾃ ﾄ ﾅ ﾆ ﾇ ﾈ ﾉ ﾊ ﾋ ﾌ ﾍ ﾎ ﾏ
diff -uprN libiconv-1.15-old/tests/JIS_X0201.TXT libiconv-1.15/tests/JIS_X0201.TXT
--- libiconv-1.15-old/tests/JIS_X0201.TXT	2009-06-21 20:17:33.000000000 +0900
+++ libiconv-1.15/tests/JIS_X0201.TXT	2017-09-17 05:38:54.222346000 +0900
@@ -90,7 +90,7 @@
 0x59	0x0059
 0x5A	0x005A
 0x5B	0x005B
-0x5C	0x00A5
+0x5C	0x005C
 0x5D	0x005D
 0x5E	0x005E
 0x5F	0x005F
@@ -124,7 +124,7 @@
 0x7B	0x007B
 0x7C	0x007C
 0x7D	0x007D
-0x7E	0x203E
+0x7E	0x007E
 0x7F	0x007F
 0xA1	0xFF61
 0xA2	0xFF62
diff -uprN libiconv-1.15-old/tests/Makefile.in libiconv-1.15/tests/Makefile.in
--- libiconv-1.15-old/tests/Makefile.in	2016-12-05 02:19:03.000000000 +0900
+++ libiconv-1.15/tests/Makefile.in	2017-09-17 05:50:22.895920000 +0900
@@ -17,6 +17,7 @@ LIBTOOL_LINK = $(LIBTOOL) --mode=link
 LIBTOOL_INSTALL = $(LIBTOOL) --mode=install
 LIBTOOL_UNINSTALL = $(LIBTOOL) --mode=uninstall
 RM = rm -f
+CHARSET_ALIAS =
 @SET_MAKE@
 
 #### End of system configuration section. ####
@@ -118,6 +119,8 @@ check : all table-from table-to ../src/i
 #	$(srcdir)/check-stateless $(srcdir) KSC_5601 # redundant, see EUC-KR
 #	/* CJK encodings */
 	$(srcdir)/check-stateless $(srcdir) EUC-JP
+	$(srcdir)/check-stateless $(srcdir) EUCJP-MS
+	$(srcdir)/check-stateless $(srcdir) CP51932
 	$(srcdir)/check-stateless $(srcdir) SHIFT_JIS
 	$(srcdir)/check-stateless $(srcdir) CP932
 	$(srcdir)/check-stateful $(srcdir) ISO-2022-JP
diff -uprN libiconv-1.15-old/tests/SHIFT_JIS.TXT libiconv-1.15/tests/SHIFT_JIS.TXT
--- libiconv-1.15-old/tests/SHIFT_JIS.TXT	2009-06-21 20:17:33.000000000 +0900
+++ libiconv-1.15/tests/SHIFT_JIS.TXT	2017-09-17 05:38:54.227148000 +0900
@@ -90,7 +90,7 @@
 0x59	0x0059
 0x5A	0x005A
 0x5B	0x005B
-0x5C	0x00A5
+0x5C	0x005C
 0x5D	0x005D
 0x5E	0x005E
 0x5F	0x005F
@@ -124,7 +124,7 @@
 0x7B	0x007B
 0x7C	0x007C
 0x7D	0x007D
-0x7E	0x203E
+0x7E	0x007E
 0x7F	0x007F
 0x8140	0x3000
 0x8141	0x3001
@@ -154,7 +154,7 @@
 0x8159	0x3006
 0x815A	0x3007
 0x815B	0x30FC
-0x815C	0x2015
+0x815C	0x2014
 0x815D	0x2010
 0x815E	0xFF0F
 0x815F	0xFF3C
@@ -7068,1883 +7068,3 @@
 0xEAA2	0x7464
 0xEAA3	0x51DC
 0xEAA4	0x7199
-0xF040	0xE000
-0xF041	0xE001
-0xF042	0xE002
-0xF043	0xE003
-0xF044	0xE004
-0xF045	0xE005
-0xF046	0xE006
-0xF047	0xE007
-0xF048	0xE008
-0xF049	0xE009
-0xF04A	0xE00A
-0xF04B	0xE00B
-0xF04C	0xE00C
-0xF04D	0xE00D
-0xF04E	0xE00E
-0xF04F	0xE00F
-0xF050	0xE010
-0xF051	0xE011
-0xF052	0xE012
-0xF053	0xE013
-0xF054	0xE014
-0xF055	0xE015
-0xF056	0xE016
-0xF057	0xE017
-0xF058	0xE018
-0xF059	0xE019
-0xF05A	0xE01A
-0xF05B	0xE01B
-0xF05C	0xE01C
-0xF05D	0xE01D
-0xF05E	0xE01E
-0xF05F	0xE01F
-0xF060	0xE020
-0xF061	0xE021
-0xF062	0xE022
-0xF063	0xE023
-0xF064	0xE024
-0xF065	0xE025
-0xF066	0xE026
-0xF067	0xE027
-0xF068	0xE028
-0xF069	0xE029
-0xF06A	0xE02A
-0xF06B	0xE02B
-0xF06C	0xE02C
-0xF06D	0xE02D
-0xF06E	0xE02E
-0xF06F	0xE02F
-0xF070	0xE030
-0xF071	0xE031
-0xF072	0xE032
-0xF073	0xE033
-0xF074	0xE034
-0xF075	0xE035
-0xF076	0xE036
-0xF077	0xE037
-0xF078	0xE038
-0xF079	0xE039
-0xF07A	0xE03A
-0xF07B	0xE03B
-0xF07C	0xE03C
-0xF07D	0xE03D
-0xF07E	0xE03E
-0xF080	0xE03F
-0xF081	0xE040
-0xF082	0xE041
-0xF083	0xE042
-0xF084	0xE043
-0xF085	0xE044
-0xF086	0xE045
-0xF087	0xE046
-0xF088	0xE047
-0xF089	0xE048
-0xF08A	0xE049
-0xF08B	0xE04A
-0xF08C	0xE04B
-0xF08D	0xE04C
-0xF08E	0xE04D
-0xF08F	0xE04E
-0xF090	0xE04F
-0xF091	0xE050
-0xF092	0xE051
-0xF093	0xE052
-0xF094	0xE053
-0xF095	0xE054
-0xF096	0xE055
-0xF097	0xE056
-0xF098	0xE057
-0xF099	0xE058
-0xF09A	0xE059
-0xF09B	0xE05A
-0xF09C	0xE05B
-0xF09D	0xE05C
-0xF09E	0xE05D
-0xF09F	0xE05E
-0xF0A0	0xE05F
-0xF0A1	0xE060
-0xF0A2	0xE061
-0xF0A3	0xE062
-0xF0A4	0xE063
-0xF0A5	0xE064
-0xF0A6	0xE065
-0xF0A7	0xE066
-0xF0A8	0xE067
-0xF0A9	0xE068
-0xF0AA	0xE069
-0xF0AB	0xE06A
-0xF0AC	0xE06B
-0xF0AD	0xE06C
-0xF0AE	0xE06D
-0xF0AF	0xE06E
-0xF0B0	0xE06F
-0xF0B1	0xE070
-0xF0B2	0xE071
-0xF0B3	0xE072
-0xF0B4	0xE073
-0xF0B5	0xE074
-0xF0B6	0xE075
-0xF0B7	0xE076
-0xF0B8	0xE077
-0xF0B9	0xE078
-0xF0BA	0xE079
-0xF0BB	0xE07A
-0xF0BC	0xE07B
-0xF0BD	0xE07C
-0xF0BE	0xE07D
-0xF0BF	0xE07E
-0xF0C0	0xE07F
-0xF0C1	0xE080
-0xF0C2	0xE081
-0xF0C3	0xE082
-0xF0C4	0xE083
-0xF0C5	0xE084
-0xF0C6	0xE085
-0xF0C7	0xE086
-0xF0C8	0xE087
-0xF0C9	0xE088
-0xF0CA	0xE089
-0xF0CB	0xE08A
-0xF0CC	0xE08B
-0xF0CD	0xE08C
-0xF0CE	0xE08D
-0xF0CF	0xE08E
-0xF0D0	0xE08F
-0xF0D1	0xE090
-0xF0D2	0xE091
-0xF0D3	0xE092
-0xF0D4	0xE093
-0xF0D5	0xE094
-0xF0D6	0xE095
-0xF0D7	0xE096
-0xF0D8	0xE097
-0xF0D9	0xE098
-0xF0DA	0xE099
-0xF0DB	0xE09A
-0xF0DC	0xE09B
-0xF0DD	0xE09C
-0xF0DE	0xE09D
-0xF0DF	0xE09E
-0xF0E0	0xE09F
-0xF0E1	0xE0A0
-0xF0E2	0xE0A1
-0xF0E3	0xE0A2
-0xF0E4	0xE0A3
-0xF0E5	0xE0A4
-0xF0E6	0xE0A5
-0xF0E7	0xE0A6
-0xF0E8	0xE0A7
-0xF0E9	0xE0A8
-0xF0EA	0xE0A9
-0xF0EB	0xE0AA
-0xF0EC	0xE0AB
-0xF0ED	0xE0AC
-0xF0EE	0xE0AD
-0xF0EF	0xE0AE
-0xF0F0	0xE0AF
-0xF0F1	0xE0B0
-0xF0F2	0xE0B1
-0xF0F3	0xE0B2
-0xF0F4	0xE0B3
-0xF0F5	0xE0B4
-0xF0F6	0xE0B5
-0xF0F7	0xE0B6
-0xF0F8	0xE0B7
-0xF0F9	0xE0B8
-0xF0FA	0xE0B9
-0xF0FB	0xE0BA
-0xF0FC	0xE0BB
-0xF140	0xE0BC
-0xF141	0xE0BD
-0xF142	0xE0BE
-0xF143	0xE0BF
-0xF144	0xE0C0
-0xF145	0xE0C1
-0xF146	0xE0C2
-0xF147	0xE0C3
-0xF148	0xE0C4
-0xF149	0xE0C5
-0xF14A	0xE0C6
-0xF14B	0xE0C7
-0xF14C	0xE0C8
-0xF14D	0xE0C9
-0xF14E	0xE0CA
-0xF14F	0xE0CB
-0xF150	0xE0CC
-0xF151	0xE0CD
-0xF152	0xE0CE
-0xF153	0xE0CF
-0xF154	0xE0D0
-0xF155	0xE0D1
-0xF156	0xE0D2
-0xF157	0xE0D3
-0xF158	0xE0D4
-0xF159	0xE0D5
-0xF15A	0xE0D6
-0xF15B	0xE0D7
-0xF15C	0xE0D8
-0xF15D	0xE0D9
-0xF15E	0xE0DA
-0xF15F	0xE0DB
-0xF160	0xE0DC
-0xF161	0xE0DD
-0xF162	0xE0DE
-0xF163	0xE0DF
-0xF164	0xE0E0
-0xF165	0xE0E1
-0xF166	0xE0E2
-0xF167	0xE0E3
-0xF168	0xE0E4
-0xF169	0xE0E5
-0xF16A	0xE0E6
-0xF16B	0xE0E7
-0xF16C	0xE0E8
-0xF16D	0xE0E9
-0xF16E	0xE0EA
-0xF16F	0xE0EB
-0xF170	0xE0EC
-0xF171	0xE0ED
-0xF172	0xE0EE
-0xF173	0xE0EF
-0xF174	0xE0F0
-0xF175	0xE0F1
-0xF176	0xE0F2
-0xF177	0xE0F3
-0xF178	0xE0F4
-0xF179	0xE0F5
-0xF17A	0xE0F6
-0xF17B	0xE0F7
-0xF17C	0xE0F8
-0xF17D	0xE0F9
-0xF17E	0xE0FA
-0xF180	0xE0FB
-0xF181	0xE0FC
-0xF182	0xE0FD
-0xF183	0xE0FE
-0xF184	0xE0FF
-0xF185	0xE100
-0xF186	0xE101
-0xF187	0xE102
-0xF188	0xE103
-0xF189	0xE104
-0xF18A	0xE105
-0xF18B	0xE106
-0xF18C	0xE107
-0xF18D	0xE108
-0xF18E	0xE109
-0xF18F	0xE10A
-0xF190	0xE10B
-0xF191	0xE10C
-0xF192	0xE10D
-0xF193	0xE10E
-0xF194	0xE10F
-0xF195	0xE110
-0xF196	0xE111
-0xF197	0xE112
-0xF198	0xE113
-0xF199	0xE114
-0xF19A	0xE115
-0xF19B	0xE116
-0xF19C	0xE117
-0xF19D	0xE118
-0xF19E	0xE119
-0xF19F	0xE11A
-0xF1A0	0xE11B
-0xF1A1	0xE11C
-0xF1A2	0xE11D
-0xF1A3	0xE11E
-0xF1A4	0xE11F
-0xF1A5	0xE120
-0xF1A6	0xE121
-0xF1A7	0xE122
-0xF1A8	0xE123
-0xF1A9	0xE124
-0xF1AA	0xE125
-0xF1AB	0xE126
-0xF1AC	0xE127
-0xF1AD	0xE128
-0xF1AE	0xE129
-0xF1AF	0xE12A
-0xF1B0	0xE12B
-0xF1B1	0xE12C
-0xF1B2	0xE12D
-0xF1B3	0xE12E
-0xF1B4	0xE12F
-0xF1B5	0xE130
-0xF1B6	0xE131
-0xF1B7	0xE132
-0xF1B8	0xE133
-0xF1B9	0xE134
-0xF1BA	0xE135
-0xF1BB	0xE136
-0xF1BC	0xE137
-0xF1BD	0xE138
-0xF1BE	0xE139
-0xF1BF	0xE13A
-0xF1C0	0xE13B
-0xF1C1	0xE13C
-0xF1C2	0xE13D
-0xF1C3	0xE13E
-0xF1C4	0xE13F
-0xF1C5	0xE140
-0xF1C6	0xE141
-0xF1C7	0xE142
-0xF1C8	0xE143
-0xF1C9	0xE144
-0xF1CA	0xE145
-0xF1CB	0xE146
-0xF1CC	0xE147
-0xF1CD	0xE148
-0xF1CE	0xE149
-0xF1CF	0xE14A
-0xF1D0	0xE14B
-0xF1D1	0xE14C
-0xF1D2	0xE14D
-0xF1D3	0xE14E
-0xF1D4	0xE14F
-0xF1D5	0xE150
-0xF1D6	0xE151
-0xF1D7	0xE152
-0xF1D8	0xE153
-0xF1D9	0xE154
-0xF1DA	0xE155
-0xF1DB	0xE156
-0xF1DC	0xE157
-0xF1DD	0xE158
-0xF1DE	0xE159
-0xF1DF	0xE15A
-0xF1E0	0xE15B
-0xF1E1	0xE15C
-0xF1E2	0xE15D
-0xF1E3	0xE15E
-0xF1E4	0xE15F
-0xF1E5	0xE160
-0xF1E6	0xE161
-0xF1E7	0xE162
-0xF1E8	0xE163
-0xF1E9	0xE164
-0xF1EA	0xE165
-0xF1EB	0xE166
-0xF1EC	0xE167
-0xF1ED	0xE168
-0xF1EE	0xE169
-0xF1EF	0xE16A
-0xF1F0	0xE16B
-0xF1F1	0xE16C
-0xF1F2	0xE16D
-0xF1F3	0xE16E
-0xF1F4	0xE16F
-0xF1F5	0xE170
-0xF1F6	0xE171
-0xF1F7	0xE172
-0xF1F8	0xE173
-0xF1F9	0xE174
-0xF1FA	0xE175
-0xF1FB	0xE176
-0xF1FC	0xE177
-0xF240	0xE178
-0xF241	0xE179
-0xF242	0xE17A
-0xF243	0xE17B
-0xF244	0xE17C
-0xF245	0xE17D
-0xF246	0xE17E
-0xF247	0xE17F
-0xF248	0xE180
-0xF249	0xE181
-0xF24A	0xE182
-0xF24B	0xE183
-0xF24C	0xE184
-0xF24D	0xE185
-0xF24E	0xE186
-0xF24F	0xE187
-0xF250	0xE188
-0xF251	0xE189
-0xF252	0xE18A
-0xF253	0xE18B
-0xF254	0xE18C
-0xF255	0xE18D
-0xF256	0xE18E
-0xF257	0xE18F
-0xF258	0xE190
-0xF259	0xE191
-0xF25A	0xE192
-0xF25B	0xE193
-0xF25C	0xE194
-0xF25D	0xE195
-0xF25E	0xE196
-0xF25F	0xE197
-0xF260	0xE198
-0xF261	0xE199
-0xF262	0xE19A
-0xF263	0xE19B
-0xF264	0xE19C
-0xF265	0xE19D
-0xF266	0xE19E
-0xF267	0xE19F
-0xF268	0xE1A0
-0xF269	0xE1A1
-0xF26A	0xE1A2
-0xF26B	0xE1A3
-0xF26C	0xE1A4
-0xF26D	0xE1A5
-0xF26E	0xE1A6
-0xF26F	0xE1A7
-0xF270	0xE1A8
-0xF271	0xE1A9
-0xF272	0xE1AA
-0xF273	0xE1AB
-0xF274	0xE1AC
-0xF275	0xE1AD
-0xF276	0xE1AE
-0xF277	0xE1AF
-0xF278	0xE1B0
-0xF279	0xE1B1
-0xF27A	0xE1B2
-0xF27B	0xE1B3
-0xF27C	0xE1B4
-0xF27D	0xE1B5
-0xF27E	0xE1B6
-0xF280	0xE1B7
-0xF281	0xE1B8
-0xF282	0xE1B9
-0xF283	0xE1BA
-0xF284	0xE1BB
-0xF285	0xE1BC
-0xF286	0xE1BD
-0xF287	0xE1BE
-0xF288	0xE1BF
-0xF289	0xE1C0
-0xF28A	0xE1C1
-0xF28B	0xE1C2
-0xF28C	0xE1C3
-0xF28D	0xE1C4
-0xF28E	0xE1C5
-0xF28F	0xE1C6
-0xF290	0xE1C7
-0xF291	0xE1C8
-0xF292	0xE1C9
-0xF293	0xE1CA
-0xF294	0xE1CB
-0xF295	0xE1CC
-0xF296	0xE1CD
-0xF297	0xE1CE
-0xF298	0xE1CF
-0xF299	0xE1D0
-0xF29A	0xE1D1
-0xF29B	0xE1D2
-0xF29C	0xE1D3
-0xF29D	0xE1D4
-0xF29E	0xE1D5
-0xF29F	0xE1D6
-0xF2A0	0xE1D7
-0xF2A1	0xE1D8
-0xF2A2	0xE1D9
-0xF2A3	0xE1DA
-0xF2A4	0xE1DB
-0xF2A5	0xE1DC
-0xF2A6	0xE1DD
-0xF2A7	0xE1DE
-0xF2A8	0xE1DF
-0xF2A9	0xE1E0
-0xF2AA	0xE1E1
-0xF2AB	0xE1E2
-0xF2AC	0xE1E3
-0xF2AD	0xE1E4
-0xF2AE	0xE1E5
-0xF2AF	0xE1E6
-0xF2B0	0xE1E7
-0xF2B1	0xE1E8
-0xF2B2	0xE1E9
-0xF2B3	0xE1EA
-0xF2B4	0xE1EB
-0xF2B5	0xE1EC
-0xF2B6	0xE1ED
-0xF2B7	0xE1EE
-0xF2B8	0xE1EF
-0xF2B9	0xE1F0
-0xF2BA	0xE1F1
-0xF2BB	0xE1F2
-0xF2BC	0xE1F3
-0xF2BD	0xE1F4
-0xF2BE	0xE1F5
-0xF2BF	0xE1F6
-0xF2C0	0xE1F7
-0xF2C1	0xE1F8
-0xF2C2	0xE1F9
-0xF2C3	0xE1FA
-0xF2C4	0xE1FB
-0xF2C5	0xE1FC
-0xF2C6	0xE1FD
-0xF2C7	0xE1FE
-0xF2C8	0xE1FF
-0xF2C9	0xE200
-0xF2CA	0xE201
-0xF2CB	0xE202
-0xF2CC	0xE203
-0xF2CD	0xE204
-0xF2CE	0xE205
-0xF2CF	0xE206
-0xF2D0	0xE207
-0xF2D1	0xE208
-0xF2D2	0xE209
-0xF2D3	0xE20A
-0xF2D4	0xE20B
-0xF2D5	0xE20C
-0xF2D6	0xE20D
-0xF2D7	0xE20E
-0xF2D8	0xE20F
-0xF2D9	0xE210
-0xF2DA	0xE211
-0xF2DB	0xE212
-0xF2DC	0xE213
-0xF2DD	0xE214
-0xF2DE	0xE215
-0xF2DF	0xE216
-0xF2E0	0xE217
-0xF2E1	0xE218
-0xF2E2	0xE219
-0xF2E3	0xE21A
-0xF2E4	0xE21B
-0xF2E5	0xE21C
-0xF2E6	0xE21D
-0xF2E7	0xE21E
-0xF2E8	0xE21F
-0xF2E9	0xE220
-0xF2EA	0xE221
-0xF2EB	0xE222
-0xF2EC	0xE223
-0xF2ED	0xE224
-0xF2EE	0xE225
-0xF2EF	0xE226
-0xF2F0	0xE227
-0xF2F1	0xE228
-0xF2F2	0xE229
-0xF2F3	0xE22A
-0xF2F4	0xE22B
-0xF2F5	0xE22C
-0xF2F6	0xE22D
-0xF2F7	0xE22E
-0xF2F8	0xE22F
-0xF2F9	0xE230
-0xF2FA	0xE231
-0xF2FB	0xE232
-0xF2FC	0xE233
-0xF340	0xE234
-0xF341	0xE235
-0xF342	0xE236
-0xF343	0xE237
-0xF344	0xE238
-0xF345	0xE239
-0xF346	0xE23A
-0xF347	0xE23B
-0xF348	0xE23C
-0xF349	0xE23D
-0xF34A	0xE23E
-0xF34B	0xE23F
-0xF34C	0xE240
-0xF34D	0xE241
-0xF34E	0xE242
-0xF34F	0xE243
-0xF350	0xE244
-0xF351	0xE245
-0xF352	0xE246
-0xF353	0xE247
-0xF354	0xE248
-0xF355	0xE249
-0xF356	0xE24A
-0xF357	0xE24B
-0xF358	0xE24C
-0xF359	0xE24D
-0xF35A	0xE24E
-0xF35B	0xE24F
-0xF35C	0xE250
-0xF35D	0xE251
-0xF35E	0xE252
-0xF35F	0xE253
-0xF360	0xE254
-0xF361	0xE255
-0xF362	0xE256
-0xF363	0xE257
-0xF364	0xE258
-0xF365	0xE259
-0xF366	0xE25A
-0xF367	0xE25B
-0xF368	0xE25C
-0xF369	0xE25D
-0xF36A	0xE25E
-0xF36B	0xE25F
-0xF36C	0xE260
-0xF36D	0xE261
-0xF36E	0xE262
-0xF36F	0xE263
-0xF370	0xE264
-0xF371	0xE265
-0xF372	0xE266
-0xF373	0xE267
-0xF374	0xE268
-0xF375	0xE269
-0xF376	0xE26A
-0xF377	0xE26B
-0xF378	0xE26C
-0xF379	0xE26D
-0xF37A	0xE26E
-0xF37B	0xE26F
-0xF37C	0xE270
-0xF37D	0xE271
-0xF37E	0xE272
-0xF380	0xE273
-0xF381	0xE274
-0xF382	0xE275
-0xF383	0xE276
-0xF384	0xE277
-0xF385	0xE278
-0xF386	0xE279
-0xF387	0xE27A
-0xF388	0xE27B
-0xF389	0xE27C
-0xF38A	0xE27D
-0xF38B	0xE27E
-0xF38C	0xE27F
-0xF38D	0xE280
-0xF38E	0xE281
-0xF38F	0xE282
-0xF390	0xE283
-0xF391	0xE284
-0xF392	0xE285
-0xF393	0xE286
-0xF394	0xE287
-0xF395	0xE288
-0xF396	0xE289
-0xF397	0xE28A
-0xF398	0xE28B
-0xF399	0xE28C
-0xF39A	0xE28D
-0xF39B	0xE28E
-0xF39C	0xE28F
-0xF39D	0xE290
-0xF39E	0xE291
-0xF39F	0xE292
-0xF3A0	0xE293
-0xF3A1	0xE294
-0xF3A2	0xE295
-0xF3A3	0xE296
-0xF3A4	0xE297
-0xF3A5	0xE298
-0xF3A6	0xE299
-0xF3A7	0xE29A
-0xF3A8	0xE29B
-0xF3A9	0xE29C
-0xF3AA	0xE29D
-0xF3AB	0xE29E
-0xF3AC	0xE29F
-0xF3AD	0xE2A0
-0xF3AE	0xE2A1
-0xF3AF	0xE2A2
-0xF3B0	0xE2A3
-0xF3B1	0xE2A4
-0xF3B2	0xE2A5
-0xF3B3	0xE2A6
-0xF3B4	0xE2A7
-0xF3B5	0xE2A8
-0xF3B6	0xE2A9
-0xF3B7	0xE2AA
-0xF3B8	0xE2AB
-0xF3B9	0xE2AC
-0xF3BA	0xE2AD
-0xF3BB	0xE2AE
-0xF3BC	0xE2AF
-0xF3BD	0xE2B0
-0xF3BE	0xE2B1
-0xF3BF	0xE2B2
-0xF3C0	0xE2B3
-0xF3C1	0xE2B4
-0xF3C2	0xE2B5
-0xF3C3	0xE2B6
-0xF3C4	0xE2B7
-0xF3C5	0xE2B8
-0xF3C6	0xE2B9
-0xF3C7	0xE2BA
-0xF3C8	0xE2BB
-0xF3C9	0xE2BC
-0xF3CA	0xE2BD
-0xF3CB	0xE2BE
-0xF3CC	0xE2BF
-0xF3CD	0xE2C0
-0xF3CE	0xE2C1
-0xF3CF	0xE2C2
-0xF3D0	0xE2C3
-0xF3D1	0xE2C4
-0xF3D2	0xE2C5
-0xF3D3	0xE2C6
-0xF3D4	0xE2C7
-0xF3D5	0xE2C8
-0xF3D6	0xE2C9
-0xF3D7	0xE2CA
-0xF3D8	0xE2CB
-0xF3D9	0xE2CC
-0xF3DA	0xE2CD
-0xF3DB	0xE2CE
-0xF3DC	0xE2CF
-0xF3DD	0xE2D0
-0xF3DE	0xE2D1
-0xF3DF	0xE2D2
-0xF3E0	0xE2D3
-0xF3E1	0xE2D4
-0xF3E2	0xE2D5
-0xF3E3	0xE2D6
-0xF3E4	0xE2D7
-0xF3E5	0xE2D8
-0xF3E6	0xE2D9
-0xF3E7	0xE2DA
-0xF3E8	0xE2DB
-0xF3E9	0xE2DC
-0xF3EA	0xE2DD
-0xF3EB	0xE2DE
-0xF3EC	0xE2DF
-0xF3ED	0xE2E0
-0xF3EE	0xE2E1
-0xF3EF	0xE2E2
-0xF3F0	0xE2E3
-0xF3F1	0xE2E4
-0xF3F2	0xE2E5
-0xF3F3	0xE2E6
-0xF3F4	0xE2E7
-0xF3F5	0xE2E8
-0xF3F6	0xE2E9
-0xF3F7	0xE2EA
-0xF3F8	0xE2EB
-0xF3F9	0xE2EC
-0xF3FA	0xE2ED
-0xF3FB	0xE2EE
-0xF3FC	0xE2EF
-0xF440	0xE2F0
-0xF441	0xE2F1
-0xF442	0xE2F2
-0xF443	0xE2F3
-0xF444	0xE2F4
-0xF445	0xE2F5
-0xF446	0xE2F6
-0xF447	0xE2F7
-0xF448	0xE2F8
-0xF449	0xE2F9
-0xF44A	0xE2FA
-0xF44B	0xE2FB
-0xF44C	0xE2FC
-0xF44D	0xE2FD
-0xF44E	0xE2FE
-0xF44F	0xE2FF
-0xF450	0xE300
-0xF451	0xE301
-0xF452	0xE302
-0xF453	0xE303
-0xF454	0xE304
-0xF455	0xE305
-0xF456	0xE306
-0xF457	0xE307
-0xF458	0xE308
-0xF459	0xE309
-0xF45A	0xE30A
-0xF45B	0xE30B
-0xF45C	0xE30C
-0xF45D	0xE30D
-0xF45E	0xE30E
-0xF45F	0xE30F
-0xF460	0xE310
-0xF461	0xE311
-0xF462	0xE312
-0xF463	0xE313
-0xF464	0xE314
-0xF465	0xE315
-0xF466	0xE316
-0xF467	0xE317
-0xF468	0xE318
-0xF469	0xE319
-0xF46A	0xE31A
-0xF46B	0xE31B
-0xF46C	0xE31C
-0xF46D	0xE31D
-0xF46E	0xE31E
-0xF46F	0xE31F
-0xF470	0xE320
-0xF471	0xE321
-0xF472	0xE322
-0xF473	0xE323
-0xF474	0xE324
-0xF475	0xE325
-0xF476	0xE326
-0xF477	0xE327
-0xF478	0xE328
-0xF479	0xE329
-0xF47A	0xE32A
-0xF47B	0xE32B
-0xF47C	0xE32C
-0xF47D	0xE32D
-0xF47E	0xE32E
-0xF480	0xE32F
-0xF481	0xE330
-0xF482	0xE331
-0xF483	0xE332
-0xF484	0xE333
-0xF485	0xE334
-0xF486	0xE335
-0xF487	0xE336
-0xF488	0xE337
-0xF489	0xE338
-0xF48A	0xE339
-0xF48B	0xE33A
-0xF48C	0xE33B
-0xF48D	0xE33C
-0xF48E	0xE33D
-0xF48F	0xE33E
-0xF490	0xE33F
-0xF491	0xE340
-0xF492	0xE341
-0xF493	0xE342
-0xF494	0xE343
-0xF495	0xE344
-0xF496	0xE345
-0xF497	0xE346
-0xF498	0xE347
-0xF499	0xE348
-0xF49A	0xE349
-0xF49B	0xE34A
-0xF49C	0xE34B
-0xF49D	0xE34C
-0xF49E	0xE34D
-0xF49F	0xE34E
-0xF4A0	0xE34F
-0xF4A1	0xE350
-0xF4A2	0xE351
-0xF4A3	0xE352
-0xF4A4	0xE353
-0xF4A5	0xE354
-0xF4A6	0xE355
-0xF4A7	0xE356
-0xF4A8	0xE357
-0xF4A9	0xE358
-0xF4AA	0xE359
-0xF4AB	0xE35A
-0xF4AC	0xE35B
-0xF4AD	0xE35C
-0xF4AE	0xE35D
-0xF4AF	0xE35E
-0xF4B0	0xE35F
-0xF4B1	0xE360
-0xF4B2	0xE361
-0xF4B3	0xE362
-0xF4B4	0xE363
-0xF4B5	0xE364
-0xF4B6	0xE365
-0xF4B7	0xE366
-0xF4B8	0xE367
-0xF4B9	0xE368
-0xF4BA	0xE369
-0xF4BB	0xE36A
-0xF4BC	0xE36B
-0xF4BD	0xE36C
-0xF4BE	0xE36D
-0xF4BF	0xE36E
-0xF4C0	0xE36F
-0xF4C1	0xE370
-0xF4C2	0xE371
-0xF4C3	0xE372
-0xF4C4	0xE373
-0xF4C5	0xE374
-0xF4C6	0xE375
-0xF4C7	0xE376
-0xF4C8	0xE377
-0xF4C9	0xE378
-0xF4CA	0xE379
-0xF4CB	0xE37A
-0xF4CC	0xE37B
-0xF4CD	0xE37C
-0xF4CE	0xE37D
-0xF4CF	0xE37E
-0xF4D0	0xE37F
-0xF4D1	0xE380
-0xF4D2	0xE381
-0xF4D3	0xE382
-0xF4D4	0xE383
-0xF4D5	0xE384
-0xF4D6	0xE385
-0xF4D7	0xE386
-0xF4D8	0xE387
-0xF4D9	0xE388
-0xF4DA	0xE389
-0xF4DB	0xE38A
-0xF4DC	0xE38B
-0xF4DD	0xE38C
-0xF4DE	0xE38D
-0xF4DF	0xE38E
-0xF4E0	0xE38F
-0xF4E1	0xE390
-0xF4E2	0xE391
-0xF4E3	0xE392
-0xF4E4	0xE393
-0xF4E5	0xE394
-0xF4E6	0xE395
-0xF4E7	0xE396
-0xF4E8	0xE397
-0xF4E9	0xE398
-0xF4EA	0xE399
-0xF4EB	0xE39A
-0xF4EC	0xE39B
-0xF4ED	0xE39C
-0xF4EE	0xE39D
-0xF4EF	0xE39E
-0xF4F0	0xE39F
-0xF4F1	0xE3A0
-0xF4F2	0xE3A1
-0xF4F3	0xE3A2
-0xF4F4	0xE3A3
-0xF4F5	0xE3A4
-0xF4F6	0xE3A5
-0xF4F7	0xE3A6
-0xF4F8	0xE3A7
-0xF4F9	0xE3A8
-0xF4FA	0xE3A9
-0xF4FB	0xE3AA
-0xF4FC	0xE3AB
-0xF540	0xE3AC
-0xF541	0xE3AD
-0xF542	0xE3AE
-0xF543	0xE3AF
-0xF544	0xE3B0
-0xF545	0xE3B1
-0xF546	0xE3B2
-0xF547	0xE3B3
-0xF548	0xE3B4
-0xF549	0xE3B5
-0xF54A	0xE3B6
-0xF54B	0xE3B7
-0xF54C	0xE3B8
-0xF54D	0xE3B9
-0xF54E	0xE3BA
-0xF54F	0xE3BB
-0xF550	0xE3BC
-0xF551	0xE3BD
-0xF552	0xE3BE
-0xF553	0xE3BF
-0xF554	0xE3C0
-0xF555	0xE3C1
-0xF556	0xE3C2
-0xF557	0xE3C3
-0xF558	0xE3C4
-0xF559	0xE3C5
-0xF55A	0xE3C6
-0xF55B	0xE3C7
-0xF55C	0xE3C8
-0xF55D	0xE3C9
-0xF55E	0xE3CA
-0xF55F	0xE3CB
-0xF560	0xE3CC
-0xF561	0xE3CD
-0xF562	0xE3CE
-0xF563	0xE3CF
-0xF564	0xE3D0
-0xF565	0xE3D1
-0xF566	0xE3D2
-0xF567	0xE3D3
-0xF568	0xE3D4
-0xF569	0xE3D5
-0xF56A	0xE3D6
-0xF56B	0xE3D7
-0xF56C	0xE3D8
-0xF56D	0xE3D9
-0xF56E	0xE3DA
-0xF56F	0xE3DB
-0xF570	0xE3DC
-0xF571	0xE3DD
-0xF572	0xE3DE
-0xF573	0xE3DF
-0xF574	0xE3E0
-0xF575	0xE3E1
-0xF576	0xE3E2
-0xF577	0xE3E3
-0xF578	0xE3E4
-0xF579	0xE3E5
-0xF57A	0xE3E6
-0xF57B	0xE3E7
-0xF57C	0xE3E8
-0xF57D	0xE3E9
-0xF57E	0xE3EA
-0xF580	0xE3EB
-0xF581	0xE3EC
-0xF582	0xE3ED
-0xF583	0xE3EE
-0xF584	0xE3EF
-0xF585	0xE3F0
-0xF586	0xE3F1
-0xF587	0xE3F2
-0xF588	0xE3F3
-0xF589	0xE3F4
-0xF58A	0xE3F5
-0xF58B	0xE3F6
-0xF58C	0xE3F7
-0xF58D	0xE3F8
-0xF58E	0xE3F9
-0xF58F	0xE3FA
-0xF590	0xE3FB
-0xF591	0xE3FC
-0xF592	0xE3FD
-0xF593	0xE3FE
-0xF594	0xE3FF
-0xF595	0xE400
-0xF596	0xE401
-0xF597	0xE402
-0xF598	0xE403
-0xF599	0xE404
-0xF59A	0xE405
-0xF59B	0xE406
-0xF59C	0xE407
-0xF59D	0xE408
-0xF59E	0xE409
-0xF59F	0xE40A
-0xF5A0	0xE40B
-0xF5A1	0xE40C
-0xF5A2	0xE40D
-0xF5A3	0xE40E
-0xF5A4	0xE40F
-0xF5A5	0xE410
-0xF5A6	0xE411
-0xF5A7	0xE412
-0xF5A8	0xE413
-0xF5A9	0xE414
-0xF5AA	0xE415
-0xF5AB	0xE416
-0xF5AC	0xE417
-0xF5AD	0xE418
-0xF5AE	0xE419
-0xF5AF	0xE41A
-0xF5B0	0xE41B
-0xF5B1	0xE41C
-0xF5B2	0xE41D
-0xF5B3	0xE41E
-0xF5B4	0xE41F
-0xF5B5	0xE420
-0xF5B6	0xE421
-0xF5B7	0xE422
-0xF5B8	0xE423
-0xF5B9	0xE424
-0xF5BA	0xE425
-0xF5BB	0xE426
-0xF5BC	0xE427
-0xF5BD	0xE428
-0xF5BE	0xE429
-0xF5BF	0xE42A
-0xF5C0	0xE42B
-0xF5C1	0xE42C
-0xF5C2	0xE42D
-0xF5C3	0xE42E
-0xF5C4	0xE42F
-0xF5C5	0xE430
-0xF5C6	0xE431
-0xF5C7	0xE432
-0xF5C8	0xE433
-0xF5C9	0xE434
-0xF5CA	0xE435
-0xF5CB	0xE436
-0xF5CC	0xE437
-0xF5CD	0xE438
-0xF5CE	0xE439
-0xF5CF	0xE43A
-0xF5D0	0xE43B
-0xF5D1	0xE43C
-0xF5D2	0xE43D
-0xF5D3	0xE43E
-0xF5D4	0xE43F
-0xF5D5	0xE440
-0xF5D6	0xE441
-0xF5D7	0xE442
-0xF5D8	0xE443
-0xF5D9	0xE444
-0xF5DA	0xE445
-0xF5DB	0xE446
-0xF5DC	0xE447
-0xF5DD	0xE448
-0xF5DE	0xE449
-0xF5DF	0xE44A
-0xF5E0	0xE44B
-0xF5E1	0xE44C
-0xF5E2	0xE44D
-0xF5E3	0xE44E
-0xF5E4	0xE44F
-0xF5E5	0xE450
-0xF5E6	0xE451
-0xF5E7	0xE452
-0xF5E8	0xE453
-0xF5E9	0xE454
-0xF5EA	0xE455
-0xF5EB	0xE456
-0xF5EC	0xE457
-0xF5ED	0xE458
-0xF5EE	0xE459
-0xF5EF	0xE45A
-0xF5F0	0xE45B
-0xF5F1	0xE45C
-0xF5F2	0xE45D
-0xF5F3	0xE45E
-0xF5F4	0xE45F
-0xF5F5	0xE460
-0xF5F6	0xE461
-0xF5F7	0xE462
-0xF5F8	0xE463
-0xF5F9	0xE464
-0xF5FA	0xE465
-0xF5FB	0xE466
-0xF5FC	0xE467
-0xF640	0xE468
-0xF641	0xE469
-0xF642	0xE46A
-0xF643	0xE46B
-0xF644	0xE46C
-0xF645	0xE46D
-0xF646	0xE46E
-0xF647	0xE46F
-0xF648	0xE470
-0xF649	0xE471
-0xF64A	0xE472
-0xF64B	0xE473
-0xF64C	0xE474
-0xF64D	0xE475
-0xF64E	0xE476
-0xF64F	0xE477
-0xF650	0xE478
-0xF651	0xE479
-0xF652	0xE47A
-0xF653	0xE47B
-0xF654	0xE47C
-0xF655	0xE47D
-0xF656	0xE47E
-0xF657	0xE47F
-0xF658	0xE480
-0xF659	0xE481
-0xF65A	0xE482
-0xF65B	0xE483
-0xF65C	0xE484
-0xF65D	0xE485
-0xF65E	0xE486
-0xF65F	0xE487
-0xF660	0xE488
-0xF661	0xE489
-0xF662	0xE48A
-0xF663	0xE48B
-0xF664	0xE48C
-0xF665	0xE48D
-0xF666	0xE48E
-0xF667	0xE48F
-0xF668	0xE490
-0xF669	0xE491
-0xF66A	0xE492
-0xF66B	0xE493
-0xF66C	0xE494
-0xF66D	0xE495
-0xF66E	0xE496
-0xF66F	0xE497
-0xF670	0xE498
-0xF671	0xE499
-0xF672	0xE49A
-0xF673	0xE49B
-0xF674	0xE49C
-0xF675	0xE49D
-0xF676	0xE49E
-0xF677	0xE49F
-0xF678	0xE4A0
-0xF679	0xE4A1
-0xF67A	0xE4A2
-0xF67B	0xE4A3
-0xF67C	0xE4A4
-0xF67D	0xE4A5
-0xF67E	0xE4A6
-0xF680	0xE4A7
-0xF681	0xE4A8
-0xF682	0xE4A9
-0xF683	0xE4AA
-0xF684	0xE4AB
-0xF685	0xE4AC
-0xF686	0xE4AD
-0xF687	0xE4AE
-0xF688	0xE4AF
-0xF689	0xE4B0
-0xF68A	0xE4B1
-0xF68B	0xE4B2
-0xF68C	0xE4B3
-0xF68D	0xE4B4
-0xF68E	0xE4B5
-0xF68F	0xE4B6
-0xF690	0xE4B7
-0xF691	0xE4B8
-0xF692	0xE4B9
-0xF693	0xE4BA
-0xF694	0xE4BB
-0xF695	0xE4BC
-0xF696	0xE4BD
-0xF697	0xE4BE
-0xF698	0xE4BF
-0xF699	0xE4C0
-0xF69A	0xE4C1
-0xF69B	0xE4C2
-0xF69C	0xE4C3
-0xF69D	0xE4C4
-0xF69E	0xE4C5
-0xF69F	0xE4C6
-0xF6A0	0xE4C7
-0xF6A1	0xE4C8
-0xF6A2	0xE4C9
-0xF6A3	0xE4CA
-0xF6A4	0xE4CB
-0xF6A5	0xE4CC
-0xF6A6	0xE4CD
-0xF6A7	0xE4CE
-0xF6A8	0xE4CF
-0xF6A9	0xE4D0
-0xF6AA	0xE4D1
-0xF6AB	0xE4D2
-0xF6AC	0xE4D3
-0xF6AD	0xE4D4
-0xF6AE	0xE4D5
-0xF6AF	0xE4D6
-0xF6B0	0xE4D7
-0xF6B1	0xE4D8
-0xF6B2	0xE4D9
-0xF6B3	0xE4DA
-0xF6B4	0xE4DB
-0xF6B5	0xE4DC
-0xF6B6	0xE4DD
-0xF6B7	0xE4DE
-0xF6B8	0xE4DF
-0xF6B9	0xE4E0
-0xF6BA	0xE4E1
-0xF6BB	0xE4E2
-0xF6BC	0xE4E3
-0xF6BD	0xE4E4
-0xF6BE	0xE4E5
-0xF6BF	0xE4E6
-0xF6C0	0xE4E7
-0xF6C1	0xE4E8
-0xF6C2	0xE4E9
-0xF6C3	0xE4EA
-0xF6C4	0xE4EB
-0xF6C5	0xE4EC
-0xF6C6	0xE4ED
-0xF6C7	0xE4EE
-0xF6C8	0xE4EF
-0xF6C9	0xE4F0
-0xF6CA	0xE4F1
-0xF6CB	0xE4F2
-0xF6CC	0xE4F3
-0xF6CD	0xE4F4
-0xF6CE	0xE4F5
-0xF6CF	0xE4F6
-0xF6D0	0xE4F7
-0xF6D1	0xE4F8
-0xF6D2	0xE4F9
-0xF6D3	0xE4FA
-0xF6D4	0xE4FB
-0xF6D5	0xE4FC
-0xF6D6	0xE4FD
-0xF6D7	0xE4FE
-0xF6D8	0xE4FF
-0xF6D9	0xE500
-0xF6DA	0xE501
-0xF6DB	0xE502
-0xF6DC	0xE503
-0xF6DD	0xE504
-0xF6DE	0xE505
-0xF6DF	0xE506
-0xF6E0	0xE507
-0xF6E1	0xE508
-0xF6E2	0xE509
-0xF6E3	0xE50A
-0xF6E4	0xE50B
-0xF6E5	0xE50C
-0xF6E6	0xE50D
-0xF6E7	0xE50E
-0xF6E8	0xE50F
-0xF6E9	0xE510
-0xF6EA	0xE511
-0xF6EB	0xE512
-0xF6EC	0xE513
-0xF6ED	0xE514
-0xF6EE	0xE515
-0xF6EF	0xE516
-0xF6F0	0xE517
-0xF6F1	0xE518
-0xF6F2	0xE519
-0xF6F3	0xE51A
-0xF6F4	0xE51B
-0xF6F5	0xE51C
-0xF6F6	0xE51D
-0xF6F7	0xE51E
-0xF6F8	0xE51F
-0xF6F9	0xE520
-0xF6FA	0xE521
-0xF6FB	0xE522
-0xF6FC	0xE523
-0xF740	0xE524
-0xF741	0xE525
-0xF742	0xE526
-0xF743	0xE527
-0xF744	0xE528
-0xF745	0xE529
-0xF746	0xE52A
-0xF747	0xE52B
-0xF748	0xE52C
-0xF749	0xE52D
-0xF74A	0xE52E
-0xF74B	0xE52F
-0xF74C	0xE530
-0xF74D	0xE531
-0xF74E	0xE532
-0xF74F	0xE533
-0xF750	0xE534
-0xF751	0xE535
-0xF752	0xE536
-0xF753	0xE537
-0xF754	0xE538
-0xF755	0xE539
-0xF756	0xE53A
-0xF757	0xE53B
-0xF758	0xE53C
-0xF759	0xE53D
-0xF75A	0xE53E
-0xF75B	0xE53F
-0xF75C	0xE540
-0xF75D	0xE541
-0xF75E	0xE542
-0xF75F	0xE543
-0xF760	0xE544
-0xF761	0xE545
-0xF762	0xE546
-0xF763	0xE547
-0xF764	0xE548
-0xF765	0xE549
-0xF766	0xE54A
-0xF767	0xE54B
-0xF768	0xE54C
-0xF769	0xE54D
-0xF76A	0xE54E
-0xF76B	0xE54F
-0xF76C	0xE550
-0xF76D	0xE551
-0xF76E	0xE552
-0xF76F	0xE553
-0xF770	0xE554
-0xF771	0xE555
-0xF772	0xE556
-0xF773	0xE557
-0xF774	0xE558
-0xF775	0xE559
-0xF776	0xE55A
-0xF777	0xE55B
-0xF778	0xE55C
-0xF779	0xE55D
-0xF77A	0xE55E
-0xF77B	0xE55F
-0xF77C	0xE560
-0xF77D	0xE561
-0xF77E	0xE562
-0xF780	0xE563
-0xF781	0xE564
-0xF782	0xE565
-0xF783	0xE566
-0xF784	0xE567
-0xF785	0xE568
-0xF786	0xE569
-0xF787	0xE56A
-0xF788	0xE56B
-0xF789	0xE56C
-0xF78A	0xE56D
-0xF78B	0xE56E
-0xF78C	0xE56F
-0xF78D	0xE570
-0xF78E	0xE571
-0xF78F	0xE572
-0xF790	0xE573
-0xF791	0xE574
-0xF792	0xE575
-0xF793	0xE576
-0xF794	0xE577
-0xF795	0xE578
-0xF796	0xE579
-0xF797	0xE57A
-0xF798	0xE57B
-0xF799	0xE57C
-0xF79A	0xE57D
-0xF79B	0xE57E
-0xF79C	0xE57F
-0xF79D	0xE580
-0xF79E	0xE581
-0xF79F	0xE582
-0xF7A0	0xE583
-0xF7A1	0xE584
-0xF7A2	0xE585
-0xF7A3	0xE586
-0xF7A4	0xE587
-0xF7A5	0xE588
-0xF7A6	0xE589
-0xF7A7	0xE58A
-0xF7A8	0xE58B
-0xF7A9	0xE58C
-0xF7AA	0xE58D
-0xF7AB	0xE58E
-0xF7AC	0xE58F
-0xF7AD	0xE590
-0xF7AE	0xE591
-0xF7AF	0xE592
-0xF7B0	0xE593
-0xF7B1	0xE594
-0xF7B2	0xE595
-0xF7B3	0xE596
-0xF7B4	0xE597
-0xF7B5	0xE598
-0xF7B6	0xE599
-0xF7B7	0xE59A
-0xF7B8	0xE59B
-0xF7B9	0xE59C
-0xF7BA	0xE59D
-0xF7BB	0xE59E
-0xF7BC	0xE59F
-0xF7BD	0xE5A0
-0xF7BE	0xE5A1
-0xF7BF	0xE5A2
-0xF7C0	0xE5A3
-0xF7C1	0xE5A4
-0xF7C2	0xE5A5
-0xF7C3	0xE5A6
-0xF7C4	0xE5A7
-0xF7C5	0xE5A8
-0xF7C6	0xE5A9
-0xF7C7	0xE5AA
-0xF7C8	0xE5AB
-0xF7C9	0xE5AC
-0xF7CA	0xE5AD
-0xF7CB	0xE5AE
-0xF7CC	0xE5AF
-0xF7CD	0xE5B0
-0xF7CE	0xE5B1
-0xF7CF	0xE5B2
-0xF7D0	0xE5B3
-0xF7D1	0xE5B4
-0xF7D2	0xE5B5
-0xF7D3	0xE5B6
-0xF7D4	0xE5B7
-0xF7D5	0xE5B8
-0xF7D6	0xE5B9
-0xF7D7	0xE5BA
-0xF7D8	0xE5BB
-0xF7D9	0xE5BC
-0xF7DA	0xE5BD
-0xF7DB	0xE5BE
-0xF7DC	0xE5BF
-0xF7DD	0xE5C0
-0xF7DE	0xE5C1
-0xF7DF	0xE5C2
-0xF7E0	0xE5C3
-0xF7E1	0xE5C4
-0xF7E2	0xE5C5
-0xF7E3	0xE5C6
-0xF7E4	0xE5C7
-0xF7E5	0xE5C8
-0xF7E6	0xE5C9
-0xF7E7	0xE5CA
-0xF7E8	0xE5CB
-0xF7E9	0xE5CC
-0xF7EA	0xE5CD
-0xF7EB	0xE5CE
-0xF7EC	0xE5CF
-0xF7ED	0xE5D0
-0xF7EE	0xE5D1
-0xF7EF	0xE5D2
-0xF7F0	0xE5D3
-0xF7F1	0xE5D4
-0xF7F2	0xE5D5
-0xF7F3	0xE5D6
-0xF7F4	0xE5D7
-0xF7F5	0xE5D8
-0xF7F6	0xE5D9
-0xF7F7	0xE5DA
-0xF7F8	0xE5DB
-0xF7F9	0xE5DC
-0xF7FA	0xE5DD
-0xF7FB	0xE5DE
-0xF7FC	0xE5DF
-0xF840	0xE5E0
-0xF841	0xE5E1
-0xF842	0xE5E2
-0xF843	0xE5E3
-0xF844	0xE5E4
-0xF845	0xE5E5
-0xF846	0xE5E6
-0xF847	0xE5E7
-0xF848	0xE5E8
-0xF849	0xE5E9
-0xF84A	0xE5EA
-0xF84B	0xE5EB
-0xF84C	0xE5EC
-0xF84D	0xE5ED
-0xF84E	0xE5EE
-0xF84F	0xE5EF
-0xF850	0xE5F0
-0xF851	0xE5F1
-0xF852	0xE5F2
-0xF853	0xE5F3
-0xF854	0xE5F4
-0xF855	0xE5F5
-0xF856	0xE5F6
-0xF857	0xE5F7
-0xF858	0xE5F8
-0xF859	0xE5F9
-0xF85A	0xE5FA
-0xF85B	0xE5FB
-0xF85C	0xE5FC
-0xF85D	0xE5FD
-0xF85E	0xE5FE
-0xF85F	0xE5FF
-0xF860	0xE600
-0xF861	0xE601
-0xF862	0xE602
-0xF863	0xE603
-0xF864	0xE604
-0xF865	0xE605
-0xF866	0xE606
-0xF867	0xE607
-0xF868	0xE608
-0xF869	0xE609
-0xF86A	0xE60A
-0xF86B	0xE60B
-0xF86C	0xE60C
-0xF86D	0xE60D
-0xF86E	0xE60E
-0xF86F	0xE60F
-0xF870	0xE610
-0xF871	0xE611
-0xF872	0xE612
-0xF873	0xE613
-0xF874	0xE614
-0xF875	0xE615
-0xF876	0xE616
-0xF877	0xE617
-0xF878	0xE618
-0xF879	0xE619
-0xF87A	0xE61A
-0xF87B	0xE61B
-0xF87C	0xE61C
-0xF87D	0xE61D
-0xF87E	0xE61E
-0xF880	0xE61F
-0xF881	0xE620
-0xF882	0xE621
-0xF883	0xE622
-0xF884	0xE623
-0xF885	0xE624
-0xF886	0xE625
-0xF887	0xE626
-0xF888	0xE627
-0xF889	0xE628
-0xF88A	0xE629
-0xF88B	0xE62A
-0xF88C	0xE62B
-0xF88D	0xE62C
-0xF88E	0xE62D
-0xF88F	0xE62E
-0xF890	0xE62F
-0xF891	0xE630
-0xF892	0xE631
-0xF893	0xE632
-0xF894	0xE633
-0xF895	0xE634
-0xF896	0xE635
-0xF897	0xE636
-0xF898	0xE637
-0xF899	0xE638
-0xF89A	0xE639
-0xF89B	0xE63A
-0xF89C	0xE63B
-0xF89D	0xE63C
-0xF89E	0xE63D
-0xF89F	0xE63E
-0xF8A0	0xE63F
-0xF8A1	0xE640
-0xF8A2	0xE641
-0xF8A3	0xE642
-0xF8A4	0xE643
-0xF8A5	0xE644
-0xF8A6	0xE645
-0xF8A7	0xE646
-0xF8A8	0xE647
-0xF8A9	0xE648
-0xF8AA	0xE649
-0xF8AB	0xE64A
-0xF8AC	0xE64B
-0xF8AD	0xE64C
-0xF8AE	0xE64D
-0xF8AF	0xE64E
-0xF8B0	0xE64F
-0xF8B1	0xE650
-0xF8B2	0xE651
-0xF8B3	0xE652
-0xF8B4	0xE653
-0xF8B5	0xE654
-0xF8B6	0xE655
-0xF8B7	0xE656
-0xF8B8	0xE657
-0xF8B9	0xE658
-0xF8BA	0xE659
-0xF8BB	0xE65A
-0xF8BC	0xE65B
-0xF8BD	0xE65C
-0xF8BE	0xE65D
-0xF8BF	0xE65E
-0xF8C0	0xE65F
-0xF8C1	0xE660
-0xF8C2	0xE661
-0xF8C3	0xE662
-0xF8C4	0xE663
-0xF8C5	0xE664
-0xF8C6	0xE665
-0xF8C7	0xE666
-0xF8C8	0xE667
-0xF8C9	0xE668
-0xF8CA	0xE669
-0xF8CB	0xE66A
-0xF8CC	0xE66B
-0xF8CD	0xE66C
-0xF8CE	0xE66D
-0xF8CF	0xE66E
-0xF8D0	0xE66F
-0xF8D1	0xE670
-0xF8D2	0xE671
-0xF8D3	0xE672
-0xF8D4	0xE673
-0xF8D5	0xE674
-0xF8D6	0xE675
-0xF8D7	0xE676
-0xF8D8	0xE677
-0xF8D9	0xE678
-0xF8DA	0xE679
-0xF8DB	0xE67A
-0xF8DC	0xE67B
-0xF8DD	0xE67C
-0xF8DE	0xE67D
-0xF8DF	0xE67E
-0xF8E0	0xE67F
-0xF8E1	0xE680
-0xF8E2	0xE681
-0xF8E3	0xE682
-0xF8E4	0xE683
-0xF8E5	0xE684
-0xF8E6	0xE685
-0xF8E7	0xE686
-0xF8E8	0xE687
-0xF8E9	0xE688
-0xF8EA	0xE689
-0xF8EB	0xE68A
-0xF8EC	0xE68B
-0xF8ED	0xE68C
-0xF8EE	0xE68D
-0xF8EF	0xE68E
-0xF8F0	0xE68F
-0xF8F1	0xE690
-0xF8F2	0xE691
-0xF8F3	0xE692
-0xF8F4	0xE693
-0xF8F5	0xE694
-0xF8F6	0xE695
-0xF8F7	0xE696
-0xF8F8	0xE697
-0xF8F9	0xE698
-0xF8FA	0xE699
-0xF8FB	0xE69A
-0xF8FC	0xE69B
-0xF940	0xE69C
-0xF941	0xE69D
-0xF942	0xE69E
-0xF943	0xE69F
-0xF944	0xE6A0
-0xF945	0xE6A1
-0xF946	0xE6A2
-0xF947	0xE6A3
-0xF948	0xE6A4
-0xF949	0xE6A5
-0xF94A	0xE6A6
-0xF94B	0xE6A7
-0xF94C	0xE6A8
-0xF94D	0xE6A9
-0xF94E	0xE6AA
-0xF94F	0xE6AB
-0xF950	0xE6AC
-0xF951	0xE6AD
-0xF952	0xE6AE
-0xF953	0xE6AF
-0xF954	0xE6B0
-0xF955	0xE6B1
-0xF956	0xE6B2
-0xF957	0xE6B3
-0xF958	0xE6B4
-0xF959	0xE6B5
-0xF95A	0xE6B6
-0xF95B	0xE6B7
-0xF95C	0xE6B8
-0xF95D	0xE6B9
-0xF95E	0xE6BA
-0xF95F	0xE6BB
-0xF960	0xE6BC
-0xF961	0xE6BD
-0xF962	0xE6BE
-0xF963	0xE6BF
-0xF964	0xE6C0
-0xF965	0xE6C1
-0xF966	0xE6C2
-0xF967	0xE6C3
-0xF968	0xE6C4
-0xF969	0xE6C5
-0xF96A	0xE6C6
-0xF96B	0xE6C7
-0xF96C	0xE6C8
-0xF96D	0xE6C9
-0xF96E	0xE6CA
-0xF96F	0xE6CB
-0xF970	0xE6CC
-0xF971	0xE6CD
-0xF972	0xE6CE
-0xF973	0xE6CF
-0xF974	0xE6D0
-0xF975	0xE6D1
-0xF976	0xE6D2
-0xF977	0xE6D3
-0xF978	0xE6D4
-0xF979	0xE6D5
-0xF97A	0xE6D6
-0xF97B	0xE6D7
-0xF97C	0xE6D8
-0xF97D	0xE6D9
-0xF97E	0xE6DA
-0xF980	0xE6DB
-0xF981	0xE6DC
-0xF982	0xE6DD
-0xF983	0xE6DE
-0xF984	0xE6DF
-0xF985	0xE6E0
-0xF986	0xE6E1
-0xF987	0xE6E2
-0xF988	0xE6E3
-0xF989	0xE6E4
-0xF98A	0xE6E5
-0xF98B	0xE6E6
-0xF98C	0xE6E7
-0xF98D	0xE6E8
-0xF98E	0xE6E9
-0xF98F	0xE6EA
-0xF990	0xE6EB
-0xF991	0xE6EC
-0xF992	0xE6ED
-0xF993	0xE6EE
-0xF994	0xE6EF
-0xF995	0xE6F0
-0xF996	0xE6F1
-0xF997	0xE6F2
-0xF998	0xE6F3
-0xF999	0xE6F4
-0xF99A	0xE6F5
-0xF99B	0xE6F6
-0xF99C	0xE6F7
-0xF99D	0xE6F8
-0xF99E	0xE6F9
-0xF99F	0xE6FA
-0xF9A0	0xE6FB
-0xF9A1	0xE6FC
-0xF9A2	0xE6FD
-0xF9A3	0xE6FE
-0xF9A4	0xE6FF
-0xF9A5	0xE700
-0xF9A6	0xE701
-0xF9A7	0xE702
-0xF9A8	0xE703
-0xF9A9	0xE704
-0xF9AA	0xE705
-0xF9AB	0xE706
-0xF9AC	0xE707
-0xF9AD	0xE708
-0xF9AE	0xE709
-0xF9AF	0xE70A
-0xF9B0	0xE70B
-0xF9B1	0xE70C
-0xF9B2	0xE70D
-0xF9B3	0xE70E
-0xF9B4	0xE70F
-0xF9B5	0xE710
-0xF9B6	0xE711
-0xF9B7	0xE712
-0xF9B8	0xE713
-0xF9B9	0xE714
-0xF9BA	0xE715
-0xF9BB	0xE716
-0xF9BC	0xE717
-0xF9BD	0xE718
-0xF9BE	0xE719
-0xF9BF	0xE71A
-0xF9C0	0xE71B
-0xF9C1	0xE71C
-0xF9C2	0xE71D
-0xF9C3	0xE71E
-0xF9C4	0xE71F
-0xF9C5	0xE720
-0xF9C6	0xE721
-0xF9C7	0xE722
-0xF9C8	0xE723
-0xF9C9	0xE724
-0xF9CA	0xE725
-0xF9CB	0xE726
-0xF9CC	0xE727
-0xF9CD	0xE728
-0xF9CE	0xE729
-0xF9CF	0xE72A
-0xF9D0	0xE72B
-0xF9D1	0xE72C
-0xF9D2	0xE72D
-0xF9D3	0xE72E
-0xF9D4	0xE72F
-0xF9D5	0xE730
-0xF9D6	0xE731
-0xF9D7	0xE732
-0xF9D8	0xE733
-0xF9D9	0xE734
-0xF9DA	0xE735
-0xF9DB	0xE736
-0xF9DC	0xE737
-0xF9DD	0xE738
-0xF9DE	0xE739
-0xF9DF	0xE73A
-0xF9E0	0xE73B
-0xF9E1	0xE73C
-0xF9E2	0xE73D
-0xF9E3	0xE73E
-0xF9E4	0xE73F
-0xF9E5	0xE740
-0xF9E6	0xE741
-0xF9E7	0xE742
-0xF9E8	0xE743
-0xF9E9	0xE744
-0xF9EA	0xE745
-0xF9EB	0xE746
-0xF9EC	0xE747
-0xF9ED	0xE748
-0xF9EE	0xE749
-0xF9EF	0xE74A
-0xF9F0	0xE74B
-0xF9F1	0xE74C
-0xF9F2	0xE74D
-0xF9F3	0xE74E
-0xF9F4	0xE74F
-0xF9F5	0xE750
-0xF9F6	0xE751
-0xF9F7	0xE752
-0xF9F8	0xE753
-0xF9F9	0xE754
-0xF9FA	0xE755
-0xF9FB	0xE756
-0xF9FC	0xE757
diff -uprN libiconv-1.15-old/tests/SHIFT_JISX0213.TXT libiconv-1.15/tests/SHIFT_JISX0213.TXT
--- libiconv-1.15-old/tests/SHIFT_JISX0213.TXT	2009-06-21 20:17:33.000000000 +0900
+++ libiconv-1.15/tests/SHIFT_JISX0213.TXT	2017-09-17 05:38:54.230655000 +0900
@@ -90,7 +90,7 @@
 0x59	0x0059
 0x5A	0x005A
 0x5B	0x005B
-0x5C	0x00A5
+0x5C	0x005C
 0x5D	0x005D
 0x5E	0x005E
 0x5F	0x005F
@@ -124,7 +124,7 @@
 0x7B	0x007B
 0x7C	0x007C
 0x7D	0x007D
-0x7E	0x203E
+0x7E	0x007E
 0x7F	0x007F
 0x8140	0x3000
 0x8141	0x3001
diff -uprN libiconv-1.15-old/tools/Makefile libiconv-1.15/tools/Makefile
--- libiconv-1.15-old/tools/Makefile	2014-01-03 07:23:02.000000000 +0900
+++ libiconv-1.15/tools/Makefile	2017-09-17 05:46:52.540086000 +0900
@@ -66,6 +66,7 @@ ALL = \
  jisx0208.h \
  jisx0212.h \
  cp932ext.h \
+ eucjp_msext.h \
  cp50221_0208_ext.h \
  cp50221_0212_ext.h \
  gb2312.h \
@@ -321,14 +322,19 @@ jisx0201.h : $(TABLESDIR)/clisp/JIS_X020
 
 # Unicode.org maps 0x2140 to U+005C. We map it to U+FF3C.
 jisx0208.h : $(TABLESDIR)/unicode.org-mappings/EASTASIA/JIS/JIS0208.TXT cjk_tab_to_h
-	sed -e 's,^0x....[ 	]*\(0x....[ 	]*0x.....*\)$$,\1,' < $< | sed -e 's,\([ 	]\)0x005C,\10xFF3C,' | ./cjk_tab_to_h JISX0208.1990-0 jisx0208 > $@
+	sed -e 's,^0x....[ 	]*\(0x....[ 	]*0x.....*\)$$,\1,' < $< | sed -e 's,\([ 	]\)0x005C,\10xFF3C,' | sed -e 's,\([ 	]\)0x2015,\10x2014,' | ./cjk_tab_to_h JISX0208.1990-0 jisx0208 > $@
 
 # Unicode.org maps 0x2237 to U+007E. We map it to U+FF5E.
 jisx0212.h : $(TABLESDIR)/unicode.org-mappings/EASTASIA/JIS/JIS0212.TXT cjk_tab_to_h
 	sed -e 's,\([ 	]\)0x007E,\10xFF5E,' < $< | ./cjk_tab_to_h JISX0212.1990-0 jisx0212 > $@
 
 cp932ext.h : $(TABLESDIR)/unicode.org-mappings/VENDORS/MICSFT/WINDOWS/CP932.TXT cjk_tab_to_h
-	(echo '#' ; grep '^0x\(87\|E[D-F]\|F[0-9A-F]\)[0-9A-F][0-9A-F]' < $< ) | ./cjk_tab_to_h 'CP932 extensions' cp932ext > $@
+	(echo '#' ; grep '^0x\(81\|87\|E[D-F]\|F[0-9A-F]\)[0-9A-F][0-9A-F]' < $< ) | ./cjk_tab_to_h 'CP932 extensions' cp932ext > $@
+
+# http://www.opengroup.or.jp/jvc/cde/ucs-conv-e.html
+# http://www.opengroup.or.jp/jvc/cde/eucJP-ibmext.txt
+eucjp_msext.h : $(TABLESDIR)/opengroup.or.jp-jvc-cde/eucJP-ibmext.txt cjk_tab_to_h
+	(echo '#' ; cat $<) | ./cjk_tab_to_h 'eucJP-ms extensions' eucjp_msext > $@
 
 cp50221_0208_ext.h : CP50221-0208-EXT.TXT 8bit_tab_to_h
 	./8bit_tab_to_h 'CP50221 JISX0208 extensions' cp50221_0208_ext < $<
diff -uprN libiconv-1.15-old/tools/cjk_tab_to_h.c libiconv-1.15/tools/cjk_tab_to_h.c
--- libiconv-1.15-old/tools/cjk_tab_to_h.c	2016-10-14 09:08:05.000000000 +0900
+++ libiconv-1.15/tools/cjk_tab_to_h.c	2017-09-17 05:38:54.233929000 +0900
@@ -1404,6 +1404,95 @@ static void do_sjis (const char* name)
   invert(&enc); output_uni2charset_sparse(name,&enc,false);
 }
 
+/* cp932 specifics */
+
+/*
+ * Computes the uni2charset[0x0000..0x2ffff] array.
+ */
+static void invert_cp932 (Encoding* enc)
+{
+  int row, col, j;
+
+  enc->uni2charset = (int*) malloc(0x30000*sizeof(int));
+
+  for (j = 0; j < 0x30000; j++)
+    enc->uni2charset[j] = 0;
+
+  for (row = 0; row < enc->rows; row++)
+    for (col = 0; col < enc->cols; col++) {
+      j = enc->charset2uni[row][col];
+      if (j != 0xfffd)
+        if (enc->uni2charset[j] == 0
+          && (row < enc->byte_row(0xed) || row > enc->byte_row(0xee)))
+          /* see Microsoft Knowledge Base Article - Q170559
+           * http://support.microsoft.com/default.aspx?scid=kb;en-us;Q170559 */
+          enc->uni2charset[j] = 0x100 * enc->row_byte(row) + enc->col_byte(col);
+    }
+}
+
+static void do_cp932 (const char* name)
+{
+  Encoding enc;
+
+  enc.rows = 94;
+  enc.cols = 188;
+  enc.row_byte = row_byte_sjis;
+  enc.col_byte = col_byte_sjis;
+  enc.byte_row = byte_row_sjis;
+  enc.byte_col = byte_col_sjis;
+  enc.check_row_expr = "(%1$s >= 0x81 && %1$s < 0xa0) || (%1$s >= 0xe0)";
+  enc.check_col_expr = "(%1$s >= 0x40 && %1$s < 0x7f) || (%1$s >= 0x80 && %1$s < 0xfd)";
+  enc.byte_row_expr = "%1$s - (%1$s >= 0xe0 ? 0xc1 : 0x81)";
+  enc.byte_col_expr = "%1$s - (%1$s >= 0x80 ? 0x41 : 0x40)";
+
+  read_table(&enc);
+  output_charset2uni(name,&enc);
+  invert_cp932(&enc); output_uni2charset_sparse(name,&enc,false);
+}
+
+/* EUC specifics */
+
+static int row_byte_euc (int row) {
+  return 0xa1 + row;
+}
+static int col_byte_euc (int col) {
+  return 0xa1 + col;
+}
+static int byte_row_euc (int byte) {
+  if (byte >= 0xa1 && byte < 0xff)
+    return byte-0xa1;
+  else if (byte >= 0x8fa1 && byte < 0x8fff)
+    return byte-0x8fa1;
+  else
+    return -1;
+}
+static int byte_col_euc (int byte) {
+  if (byte >= 0xa1 && byte < 0xff)
+    return byte-0xa1;
+  else
+    return -1;
+}
+
+static void do_euc (const char* name)
+{
+  Encoding enc;
+
+  enc.rows = 94;
+  enc.cols = 94;
+  enc.row_byte = row_byte_euc;
+  enc.col_byte = col_byte_euc;
+  enc.byte_row = byte_row_euc;
+  enc.byte_col = byte_col_euc;
+  enc.check_row_expr = "%1$s >= 0xa1 && %1$s < 0xff";
+  enc.check_col_expr = "%1$s >= 0xa1 && %1$s < 0xff";
+  enc.byte_row_expr = "%1$s - 0xa1";
+  enc.byte_col_expr = "%1$s - 0xa1";
+
+  read_table(&enc);
+  output_charset2uni(name,&enc);
+  invert(&enc); output_uni2charset_sparse(name,&enc,false);
+}
+
 /* GB18030 Unicode specifics */
 
 static void do_gb18030uni (const char* name)
@@ -2134,11 +2223,13 @@ int main (int argc, char *argv[])
   else if (!strcmp(name,"johab_hangul"))
     do_johab_hangul(name);
   else if (!strcmp(name,"cp932ext"))
-    do_sjis(name);
+    do_cp932(name);
   else if (!strcmp(name,"gb18030uni"))
     do_gb18030uni(name);
   else if (!strcmp(name,"jisx0213"))
     do_jisx0213(name);
+  else if (!strcmp(name,"eucjp_msext"))
+    do_euc(name);
   else
     exit(1);
 
